@@ -29,19 +29,19 @@ import java.util.TreeSet;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.impl.ScannerOptions;
 import org.apache.accumulo.core.client.sample.SamplerConfiguration;
-import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.clientImpl.ScannerOptions;
+import org.apache.accumulo.core.conf.IterConfigUtil;
+import org.apache.accumulo.core.conf.IterLoad;
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.thrift.IterInfo;
+import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.iterators.IteratorAdapter;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
-import org.apache.accumulo.core.iterators.IteratorUtil;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.security.Authorizations;
@@ -57,7 +57,7 @@ import org.apache.hadoop.io.Text;
  *
  * <pre>
  * <code>
- * Scanner scanner = connector.createScanner(tableName, authorizations);
+ * Scanner scanner = client.createScanner(tableName, authorizations);
  * scanner = new ClientSideIteratorScanner(scanner);
  * </code>
  * </pre>
@@ -75,22 +75,6 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
   private long readaheadThreshold = Constants.SCANNER_DEFAULT_READAHEAD_THRESHOLD;
   private SamplerConfiguration iteratorSamplerConfig;
 
-  /**
-   * @deprecated since 1.7.0 was never intended for public use. However this could have been used by
-   *             anything extending this class.
-   */
-  @Deprecated
-  public class ScannerTranslator extends ScannerTranslatorImpl {
-    public ScannerTranslator(Scanner scanner) {
-      super(scanner, scanner.getSamplerConfiguration());
-    }
-
-    @Override
-    public SortedKeyValueIterator<Key,Value> deepCopy(final IteratorEnvironment env) {
-      return new ScannerTranslator(scanner);
-    }
-  }
-
   private class ClientSideIteratorEnvironment implements IteratorEnvironment {
 
     private SamplerConfiguration samplerConfig;
@@ -101,17 +85,6 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
       this.samplerConfig = samplerConfig;
     }
 
-    @Override
-    public SortedKeyValueIterator<Key,Value> reserveMapFileReader(String mapFileName)
-        throws IOException {
-      throw new UnsupportedOperationException();
-    }
-
-    @Override
-    public AccumuloConfiguration getConfig() {
-      throw new UnsupportedOperationException();
-    }
-
     @Override
     public IteratorScope getIteratorScope() {
       return IteratorScope.scan;
@@ -123,8 +96,8 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
     }
 
     @Override
-    public void registerSideChannel(SortedKeyValueIterator<Key,Value> iter) {
-      throw new UnsupportedOperationException();
+    public boolean isUserCompaction() {
+      return false;
     }
 
     @Override
@@ -239,8 +212,8 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
     smi = new ScannerTranslatorImpl(scanner, scanner.getSamplerConfiguration());
     this.range = scanner.getRange();
     this.size = scanner.getBatchSize();
-    this.retryTimeout = scanner.getTimeout(TimeUnit.MILLISECONDS);
-    this.batchTimeout = scanner.getTimeout(TimeUnit.MILLISECONDS);
+    this.timeOut = scanner.getTimeout(TimeUnit.MILLISECONDS);
+    this.batchTimeOut = scanner.getTimeout(TimeUnit.MILLISECONDS);
     this.readaheadThreshold = scanner.getReadaheadThreshold();
     SamplerConfiguration samplerConfig = scanner.getSamplerConfiguration();
     if (samplerConfig != null)
@@ -257,8 +230,8 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
   @Override
   public Iterator<Entry<Key,Value>> iterator() {
     smi.scanner.setBatchSize(size);
-    smi.scanner.setTimeout(retryTimeout, TimeUnit.MILLISECONDS);
-    smi.scanner.setBatchTimeout(batchTimeout, TimeUnit.MILLISECONDS);
+    smi.scanner.setTimeout(timeOut, TimeUnit.MILLISECONDS);
+    smi.scanner.setBatchTimeout(batchTimeOut, TimeUnit.MILLISECONDS);
     smi.scanner.setReadaheadThreshold(readaheadThreshold);
     if (isolated)
       smi.scanner.enableIsolation();
@@ -275,10 +248,11 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
 
     SortedKeyValueIterator<Key,Value> skvi;
     try {
-      skvi = IteratorUtil.loadIterators(smi, tm.values(), serverSideIteratorOptions,
-          new ClientSideIteratorEnvironment(getSamplerConfiguration() != null,
-              getIteratorSamplerConfigurationInternal()),
-          false, null);
+      IteratorEnvironment env = new ClientSideIteratorEnvironment(getSamplerConfiguration() != null,
+          getIteratorSamplerConfigurationInternal());
+      IterLoad iterLoad = new IterLoad().iters(tm.values()).iterOpts(serverSideIteratorOptions)
+          .iterEnv(env).useAccumuloClassLoader(false);
+      skvi = IterConfigUtil.loadIterators(smi, iterLoad);
     } catch (IOException e) {
       throw new RuntimeException(e);
     }
@@ -302,24 +276,6 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
     return smi.scanner.getAuthorizations();
   }
 
-  @Deprecated
-  @Override
-  public void setTimeOut(int timeOut) {
-    if (timeOut == Integer.MAX_VALUE)
-      setTimeout(Long.MAX_VALUE, TimeUnit.MILLISECONDS);
-    else
-      setTimeout(timeOut, TimeUnit.SECONDS);
-  }
-
-  @Deprecated
-  @Override
-  public int getTimeOut() {
-    long timeout = getTimeout(TimeUnit.SECONDS);
-    if (timeout >= Integer.MAX_VALUE)
-      return Integer.MAX_VALUE;
-    return (int) timeout;
-  }
-
   @Override
   public void setRange(final Range range) {
     this.range = range;
@@ -357,7 +313,7 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
 
   @Override
   public void setReadaheadThreshold(long batches) {
-    if (0 > batches) {
+    if (batches < 0) {
       throw new IllegalArgumentException(
           "Number of batches before read-ahead must be non-negative");
     }
@@ -411,4 +367,9 @@ public class ClientSideIteratorScanner extends ScannerOptions implements Scanner
   public SamplerConfiguration getIteratorSamplerConfiguration() {
     return iteratorSamplerConfig;
   }
+
+  @Override
+  public void close() {
+    smi.scanner.close();
+  }
 }
