@@ -23,8 +23,8 @@ import java.util.Iterator;
 import java.util.Map.Entry;
 import java.util.concurrent.TimeUnit;
 
-import org.apache.accumulo.core.client.impl.IsolationException;
-import org.apache.accumulo.core.client.impl.ScannerOptions;
+import org.apache.accumulo.core.clientImpl.IsolationException;
+import org.apache.accumulo.core.clientImpl.ScannerOptions;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.PartialKey;
@@ -37,9 +37,7 @@ import org.apache.hadoop.io.Text;
  * the client side. If you think your rows may not fit into memory, then you can provide an
  * alternative row buffer factory to the constructor. This would allow rows to be buffered to disk
  * for example.
- *
  */
-
 public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   private static class RowBufferingIterator implements Iterator<Entry<Key,Value>> {
@@ -173,11 +171,11 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   }
 
-  public static interface RowBufferFactory {
+  public interface RowBufferFactory {
     RowBuffer newBuffer();
   }
 
-  public static interface RowBuffer extends Iterable<Entry<Key,Value>> {
+  public interface RowBuffer extends Iterable<Entry<Key,Value>> {
     void add(Entry<Key,Value> entry);
 
     @Override
@@ -228,8 +226,8 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
   public IsolatedScanner(Scanner scanner, RowBufferFactory bufferFactory) {
     this.scanner = scanner;
     this.range = scanner.getRange();
-    this.retryTimeout = scanner.getTimeout(TimeUnit.MILLISECONDS);
-    this.batchTimeout = scanner.getBatchTimeout(TimeUnit.MILLISECONDS);
+    this.timeOut = scanner.getTimeout(TimeUnit.MILLISECONDS);
+    this.batchTimeOut = scanner.getBatchTimeout(TimeUnit.MILLISECONDS);
     this.batchSize = scanner.getBatchSize();
     this.readaheadThreshold = scanner.getReadaheadThreshold();
     this.bufferFactory = bufferFactory;
@@ -237,26 +235,8 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   @Override
   public Iterator<Entry<Key,Value>> iterator() {
-    return new RowBufferingIterator(scanner, this, range, retryTimeout, batchSize,
-        readaheadThreshold, bufferFactory);
-  }
-
-  @Deprecated
-  @Override
-  public void setTimeOut(int timeOut) {
-    if (timeOut == Integer.MAX_VALUE)
-      setTimeout(Long.MAX_VALUE, TimeUnit.MILLISECONDS);
-    else
-      setTimeout(timeOut, TimeUnit.SECONDS);
-  }
-
-  @Deprecated
-  @Override
-  public int getTimeOut() {
-    long timeout = getTimeout(TimeUnit.SECONDS);
-    if (timeout >= Integer.MAX_VALUE)
-      return Integer.MAX_VALUE;
-    return (int) timeout;
+    return new RowBufferingIterator(scanner, this, range, timeOut, batchSize, readaheadThreshold,
+        bufferFactory);
   }
 
   @Override
@@ -296,11 +276,16 @@ public class IsolatedScanner extends ScannerOptions implements Scanner {
 
   @Override
   public void setReadaheadThreshold(long batches) {
-    if (0 > batches) {
+    if (batches < 0) {
       throw new IllegalArgumentException(
           "Number of batches before read-ahead must be non-negative");
     }
 
     this.readaheadThreshold = batches;
   }
+
+  @Override
+  public void close() {
+    scanner.close();
+  }
 }
