@@ -16,24 +16,29 @@
  */
 package org.apache.accumulo.core.client;
 
-import org.apache.accumulo.core.client.impl.Tables;
-
 public class TableOfflineException extends RuntimeException {
 
   private static final long serialVersionUID = 1L;
 
-  private static String getTableName(Instance instance, String tableId) {
-    if (tableId == null)
-      return " <unknown table> ";
-    try {
-      String tableName = Tables.getTableName(instance, tableId);
-      return tableName + " (" + tableId + ")";
-    } catch (TableNotFoundException e) {
-      return " <unknown table> (" + tableId + ")";
-    }
+  /**
+   * @deprecated since 2.0.0, replaced by {@link #TableOfflineException(String)}
+   */
+  @Deprecated
+  public TableOfflineException(Instance instance, String tableId) {
+    super("Table with ID (" + tableId + ") is offline");
   }
 
-  public TableOfflineException(Instance instance, String tableId) {
-    super("Table " + getTableName(instance, tableId) + " is offline");
+  /**
+   * @since 2.0.0
+   */
+  public TableOfflineException(String msg) {
+    super(msg);
+  }
+
+  /**
+   * @since 2.0.0
+   */
+  public TableOfflineException(Exception cause) {
+    super(cause);
   }
 }
