@@ -33,7 +33,6 @@ import javax.security.auth.Destroyable;
 import org.apache.hadoop.io.Writable;
 
 /**
- *
  * @since 1.5.0
  */
 public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
@@ -45,7 +44,7 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
    *
    * @since 1.6.0
    */
-  public static final class AuthenticationTokenSerializer {
+  final class AuthenticationTokenSerializer {
     /**
      * A convenience method to create tokens from serialized bytes, created by
      * {@link #serialize(AuthenticationToken)}
@@ -251,7 +250,7 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
     }
   }
 
-  static class TokenProperty implements Comparable<TokenProperty> {
+  class TokenProperty implements Comparable<TokenProperty> {
     private String key, description;
     private boolean masked;
 
@@ -296,9 +295,9 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
     }
   }
 
-  public void init(Properties properties);
+  void init(Properties properties);
 
-  public Set<TokenProperty> getProperties();
+  Set<TokenProperty> getProperties();
 
-  public AuthenticationToken clone();
+  AuthenticationToken clone();
 }
