@@ -26,7 +26,6 @@ import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.ConcurrentHashMap;
 
-import org.apache.accumulo.core.util.CachedConfiguration;
 import org.apache.hadoop.conf.Configuration;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -84,15 +83,12 @@ public class CredentialProviderFactoryShim {
    */
   public static synchronized boolean isHadoopCredentialProviderAvailable() {
     // If we already found the class
-    if (null != hadoopClassesAvailable) {
+    if (hadoopClassesAvailable != null) {
       // Make sure everything is initialized as expected
-      if (hadoopClassesAvailable && null != getProvidersMethod && null != hadoopCredProviderFactory
-          && null != getCredentialEntryMethod && null != getCredentialMethod) {
-        return true;
-      } else {
-        // Otherwise we failed to load it
-        return false;
-      }
+      // Otherwise we failed to load it
+      return hadoopClassesAvailable && getProvidersMethod != null
+          && hadoopCredProviderFactory != null && getCredentialEntryMethod != null
+          && getCredentialMethod != null;
     }
 
     hadoopClassesAvailable = false;
@@ -110,12 +106,7 @@ public class CredentialProviderFactoryShim {
     try {
       getProvidersMethod = hadoopCredProviderFactoryClz
           .getMethod(HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME, Configuration.class);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}",
-          HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME,
-          HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME, e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}",
           HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME,
           HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME, e);
@@ -125,10 +116,7 @@ public class CredentialProviderFactoryShim {
     // Instantiate Hadoop CredentialProviderFactory
     try {
       hadoopCredProviderFactory = hadoopCredProviderFactoryClz.newInstance();
-    } catch (InstantiationException e) {
-      log.trace("Could not instantiate class {}", HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME, e);
-      return false;
-    } catch (IllegalAccessException e) {
+    } catch (InstantiationException | IllegalAccessException e) {
       log.trace("Could not instantiate class {}", HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME, e);
       return false;
     }
@@ -146,12 +134,7 @@ public class CredentialProviderFactoryShim {
     try {
       getCredentialEntryMethod = hadoopCredProviderClz
           .getMethod(HADOOP_CRED_PROVIDER_GET_CREDENTIAL_ENTRY_METHOD_NAME, String.class);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}",
-          HADOOP_CRED_PROVIDER_GET_CREDENTIAL_ENTRY_METHOD_NAME, HADOOP_CRED_PROVIDER_CLASS_NAME,
-          e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}",
           HADOOP_CRED_PROVIDER_GET_CREDENTIAL_ENTRY_METHOD_NAME, HADOOP_CRED_PROVIDER_CLASS_NAME,
           e);
@@ -162,11 +145,7 @@ public class CredentialProviderFactoryShim {
     try {
       getAliasesMethod =
           hadoopCredProviderClz.getMethod(HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}", HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME,
-          HADOOP_CRED_PROVIDER_CLASS_NAME, e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}", HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME,
           HADOOP_CRED_PROVIDER_CLASS_NAME, e);
       return false;
@@ -176,12 +155,7 @@ public class CredentialProviderFactoryShim {
     try {
       createCredentialEntryMethod = hadoopCredProviderClz.getMethod(
           HADOOP_CRED_PROVIDER_CREATE_CREDENTIAL_ENTRY_METHOD_NAME, String.class, char[].class);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}",
-          HADOOP_CRED_PROVIDER_CREATE_CREDENTIAL_ENTRY_METHOD_NAME, HADOOP_CRED_PROVIDER_CLASS_NAME,
-          e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}",
           HADOOP_CRED_PROVIDER_CREATE_CREDENTIAL_ENTRY_METHOD_NAME, HADOOP_CRED_PROVIDER_CLASS_NAME,
           e);
@@ -191,11 +165,7 @@ public class CredentialProviderFactoryShim {
     // Load Hadoop CredentialProvider.flush()
     try {
       flushMethod = hadoopCredProviderClz.getMethod(HADOOP_CRED_PROVIDER_FLUSH_METHOD_NAME);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}", HADOOP_CRED_PROVIDER_FLUSH_METHOD_NAME,
-          HADOOP_CRED_PROVIDER_CLASS_NAME, e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}", HADOOP_CRED_PROVIDER_FLUSH_METHOD_NAME,
           HADOOP_CRED_PROVIDER_CLASS_NAME, e);
       return false;
@@ -214,11 +184,7 @@ public class CredentialProviderFactoryShim {
     try {
       getCredentialMethod =
           hadoopCredentialEntryClz.getMethod(HADOOP_CRED_ENTRY_GET_CREDENTIAL_METHOD_NAME);
-    } catch (SecurityException e) {
-      log.trace("Could not find {} method on {}", HADOOP_CRED_ENTRY_GET_CREDENTIAL_METHOD_NAME,
-          HADOOP_CRED_ENTRY_CLASS_NAME, e);
-      return false;
-    } catch (NoSuchMethodException e) {
+    } catch (SecurityException | NoSuchMethodException e) {
       log.trace("Could not find {} method on {}", HADOOP_CRED_ENTRY_GET_CREDENTIAL_METHOD_NAME,
           HADOOP_CRED_ENTRY_CLASS_NAME, e);
       return false;
@@ -252,15 +218,7 @@ public class CredentialProviderFactoryShim {
     Object providersObj = null;
     try {
       providersObj = getProvidersMethod.invoke(hadoopCredProviderFactory, conf);
-    } catch (IllegalArgumentException e) {
-      log.warn("Could not invoke {}.{}", HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME,
-          HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME, e);
-      return null;
-    } catch (IllegalAccessException e) {
-      log.warn("Could not invoke {}.{}", HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME,
-          HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME, e);
-      return null;
-    } catch (InvocationTargetException e) {
+    } catch (IllegalArgumentException | InvocationTargetException | IllegalAccessException e) {
       log.warn("Could not invoke {}.{}", HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME,
           HADOOP_CRED_PROVIDER_FACTORY_GET_PROVIDERS_METHOD_NAME, e);
       return null;
@@ -285,7 +243,7 @@ public class CredentialProviderFactoryShim {
   protected static char[] getFromHadoopCredentialProvider(Configuration conf, String alias) {
     List<Object> providerObjList = getCredentialProviders(conf);
 
-    if (null == providerObjList) {
+    if (providerObjList == null) {
       return null;
     }
 
@@ -294,7 +252,7 @@ public class CredentialProviderFactoryShim {
         // Invoke CredentialProvider.getCredentialEntry(String)
         Object credEntryObj = getCredentialEntryMethod.invoke(providerObj, alias);
 
-        if (null == credEntryObj) {
+        if (credEntryObj == null) {
           continue;
         }
 
@@ -302,13 +260,7 @@ public class CredentialProviderFactoryShim {
         Object credential = getCredentialMethod.invoke(credEntryObj);
 
         return (char[]) credential;
-      } catch (IllegalArgumentException e) {
-        log.warn("Failed to get credential for {} from {}", alias, providerObj, e);
-        continue;
-      } catch (IllegalAccessException e) {
-        log.warn("Failed to get credential for {} from {}", alias, providerObj, e);
-        continue;
-      } catch (InvocationTargetException e) {
+      } catch (IllegalArgumentException | InvocationTargetException | IllegalAccessException e) {
         log.warn("Failed to get credential for {} from {}", alias, providerObj, e);
         continue;
       }
@@ -324,19 +276,19 @@ public class CredentialProviderFactoryShim {
   protected static List<String> getAliasesFromHadoopCredentialProvider(Configuration conf) {
     List<Object> providerObjList = getCredentialProviders(conf);
 
-    if (null == providerObjList) {
+    if (providerObjList == null) {
       log.debug("Failed to get CredProviders");
       return Collections.emptyList();
     }
 
     ArrayList<String> aliases = new ArrayList<>();
     for (Object providerObj : providerObjList) {
-      if (null != providerObj) {
+      if (providerObj != null) {
         Object aliasesObj;
         try {
           aliasesObj = getAliasesMethod.invoke(providerObj);
 
-          if (null != aliasesObj && aliasesObj instanceof List) {
+          if (aliasesObj != null && aliasesObj instanceof List) {
             try {
               aliases.addAll((List<String>) aliasesObj);
             } catch (ClassCastException e) {
@@ -346,15 +298,7 @@ public class CredentialProviderFactoryShim {
             }
           }
 
-        } catch (IllegalArgumentException e) {
-          log.warn("Failed to invoke {} on {}", HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME,
-              providerObj, e);
-          continue;
-        } catch (IllegalAccessException e) {
-          log.warn("Failed to invoke {} on {}", HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME,
-              providerObj, e);
-          continue;
-        } catch (InvocationTargetException e) {
+        } catch (IllegalArgumentException | InvocationTargetException | IllegalAccessException e) {
           log.warn("Failed to invoke {} on {}", HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME,
               providerObj, e);
           continue;
@@ -365,20 +309,6 @@ public class CredentialProviderFactoryShim {
     return aliases;
   }
 
-  /**
-   * Create a Hadoop {@link Configuration} with the appropriate members to access
-   * CredentialProviders
-   *
-   * @param credentialProviders
-   *          Comma-separated list of CredentialProvider URLs
-   * @return Configuration to be used for CredentialProvider
-   */
-  public static Configuration getConfiguration(String credentialProviders) {
-    requireNonNull(credentialProviders);
-    return getConfiguration(new Configuration(CachedConfiguration.getInstance()),
-        credentialProviders);
-  }
-
   /**
    * Adds the Credential Provider configuration elements to the provided {@link Configuration}.
    *
@@ -403,20 +333,15 @@ public class CredentialProviderFactoryShim {
    * @param alias
    *          Name of CredentialEntry key
    * @return The credential if found, null otherwise
-   * @throws IOException
-   *           On errors reading a CredentialProvider
    */
-  public static char[] getValueFromCredentialProvider(Configuration conf, String alias)
-      throws IOException {
+  public static char[] getValueFromCredentialProvider(Configuration conf, String alias) {
     requireNonNull(conf);
     requireNonNull(alias);
-
     if (isHadoopCredentialProviderAvailable()) {
       log.trace("Hadoop CredentialProvider is available, attempting to extract value for {}",
           alias);
       return getFromHadoopCredentialProvider(conf, alias);
     }
-
     return null;
   }
 
@@ -427,10 +352,8 @@ public class CredentialProviderFactoryShim {
    *          Configuration for the CredentialProvider
    * @return A list of aliases. An empty list if no CredentialProviders are configured, or the
    *         providers are empty.
-   * @throws IOException
-   *           On errors reading a CredentialProvider
    */
-  public static List<String> getKeys(Configuration conf) throws IOException {
+  public static List<String> getKeys(Configuration conf) {
     requireNonNull(conf);
 
     if (isHadoopCredentialProviderAvailable()) {
@@ -464,12 +387,12 @@ public class CredentialProviderFactoryShim {
     }
 
     List<Object> providers = getCredentialProviders(conf);
-    if (null == providers) {
+    if (providers == null) {
       throw new IOException(
           "Could not fetch any CredentialProviders, is the implementation available?");
     }
 
-    if (1 != providers.size()) {
+    if (providers.size() != 1) {
       log.warn("Found more than one CredentialProvider. Using first provider found");
     }
 
@@ -489,7 +412,7 @@ public class CredentialProviderFactoryShim {
    *          The credential to store
    */
   public static void createEntryInProvider(Object credentialProvider, String name,
-      char[] credential) throws IOException {
+      char[] credential) {
     requireNonNull(credentialProvider);
     requireNonNull(name);
     requireNonNull(credential);
@@ -504,21 +427,14 @@ public class CredentialProviderFactoryShim {
     } catch (IllegalArgumentException e) {
       log.warn("Failed to invoke createCredentialEntry method on CredentialProvider", e);
       return;
-    } catch (IllegalAccessException e) {
-      log.warn("Failed to invoke createCredentialEntry method", e);
-      return;
-    } catch (InvocationTargetException e) {
+    } catch (IllegalAccessException | InvocationTargetException e) {
       log.warn("Failed to invoke createCredentialEntry method", e);
       return;
     }
 
     try {
       flushMethod.invoke(credentialProvider);
-    } catch (IllegalArgumentException e) {
-      log.warn("Failed to invoke flush method on CredentialProvider", e);
-    } catch (IllegalAccessException e) {
-      log.warn("Failed to invoke flush method on CredentialProvider", e);
-    } catch (InvocationTargetException e) {
+    } catch (IllegalArgumentException | InvocationTargetException | IllegalAccessException e) {
       log.warn("Failed to invoke flush method on CredentialProvider", e);
     }
   }
