@@ -24,12 +24,9 @@ import java.util.function.Function;
 import java.util.function.Predicate;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import java.util.stream.Stream;
 
-import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.file.rfile.RFile;
 import org.apache.accumulo.core.util.Pair;
-import org.apache.commons.lang.math.IntRange;
+import org.apache.commons.lang3.Range;
 import org.apache.hadoop.fs.Path;
 
 import com.google.common.base.Preconditions;
@@ -45,18 +42,30 @@ public enum PropertyType {
       "A non-negative integer optionally followed by a unit of time (whitespace"
           + " disallowed), as in 30s.\n"
           + "If no unit of time is specified, seconds are assumed. Valid units"
-          + " are 'ms', 's', 'm', 'h' for milliseconds, seconds, minutes, and hours.\n"
-          + "Examples of valid durations are '600', '30s', '45m', '30000ms', '3d', and '1h'.\n"
+          + " are 'ms', 's', 'm', 'h' for milliseconds, seconds," + " minutes, and" + " hours.\n"
+          + "Examples of valid durations are '600', '30s', '45m', '30000ms'," + " '3d', and '1h'.\n"
           + "Examples of invalid durations are '1w', '1h30m', '1s 200ms', 'ms', '',"
           + " and 'a'.\nUnless otherwise stated, the max value for the duration"
           + " represented in milliseconds is " + Long.MAX_VALUE),
 
-  MEMORY("memory", boundedUnits(0, Long.MAX_VALUE, false, "", "B", "K", "M", "G"),
-      "A positive integer optionally followed by a unit of memory (whitespace"
-          + " disallowed), as in 2G.\n"
-          + "If no unit is specified, bytes are assumed. Valid units are 'B', 'K',"
-          + " 'M', 'G', for bytes, kilobytes, megabytes, and gigabytes.\n"
-          + "Examples of valid memories are '1024', '20B', '100K', '1500M', '2G'.\n"
+  BYTES("bytes", boundedUnits(0, Long.MAX_VALUE, false, "", "B", "K", "M", "G"),
+      "A positive integer optionally followed by a unit of memory (whitespace disallowed).\n"
+          + "If no unit is specified, bytes are assumed. Valid units are 'B',"
+          + " 'K', 'M' or 'G' for bytes, kilobytes, megabytes, gigabytes.\n"
+          + "Examples of valid memories are '1024', '20B', '100K', '1500M', '2G', '20%'.\n"
+          + "Examples of invalid memories are '1M500K', '1M 2K', '1MB', '1.5G',"
+          + " '1,024K', '', and 'a'.\n"
+          + "Unless otherwise stated, the max value for the memory represented in bytes is "
+          + Long.MAX_VALUE),
+
+  MEMORY("memory", boundedUnits(0, Long.MAX_VALUE, false, "", "B", "K", "M", "G", "%"),
+      "A positive integer optionally followed by a unit of memory or a"
+          + " percentage (whitespace disallowed).\n"
+          + "If a percentage is specified, memory will be a percentage of the"
+          + " max memory allocated to a Java process (set by the JVM option -Xmx).\n"
+          + "If no unit is specified, bytes are assumed. Valid units are 'B',"
+          + " 'K', 'M', 'G', '%' for bytes, kilobytes, megabytes, gigabytes, and" + " percentage.\n"
+          + "Examples of valid memories are '1024', '20B', '100K', '1500M', '2G', '20%'.\n"
           + "Examples of invalid memories are '1M500K', '1M 2K', '1MB', '1.5G',"
           + " '1,024K', '', and 'a'.\n"
           + "Unless otherwise stated, the max value for the memory represented in bytes is "
@@ -70,9 +79,8 @@ public enum PropertyType {
           + " 'localhost:2000,www.example.com,10.10.1.1:500' and 'localhost'.\n"
           + "Examples of invalid host lists are '', ':1000', and 'localhost:80000'"),
 
-  PORT("port",
-      x -> Stream.of(new Bounds(1024, 65535), in(true, "0"), new PortRange("\\d{4,5}-\\d{4,5}"))
-          .anyMatch(y -> y.test(x)),
+  @SuppressWarnings("unchecked")
+  PORT("port", or(new Bounds(1024, 65535), in(true, "0"), new PortRange("\\d{4,5}-\\d{4,5}")),
       "An positive integer in the range 1024-65535 (not already in use or"
           + " specified elsewhere in the configuration),\n"
           + "zero to indicate any open ephemeral port, or a range of positive"
@@ -86,18 +94,20 @@ public enum PropertyType {
           + " suffixed with the '%' character, a percentage.\n"
           + "Examples of valid fractions/percentages are '10', '1000%', '0.05',"
           + " '5%', '0.2%', '0.0005'.\n"
-          + "Examples of invalid fractions/percentages are '', '10 percent', 'Hulk Hogan'"),
+          + "Examples of invalid fractions/percentages are '', '10 percent'," + " 'Hulk Hogan'"),
 
   PATH("path", x -> true,
       "A string that represents a filesystem path, which can be either relative"
-          + " or absolute to some directory. The filesystem depends on the property."
-          + " The following environment variables will be substituted: "
-          + Constants.PATH_PROPERTY_ENV_VARS),
+          + " or absolute to some directory. The filesystem depends on the property. "
+          + "Substitutions of the ACCUMULO_HOME environment variable can be done in the system "
+          + "config file using '${env:ACCUMULO_HOME}' or similar."),
 
+  // VFS_CLASSLOADER_CACHE_DIR's default value is a special case, for documentation purposes
   ABSOLUTEPATH("absolute path",
-      x -> x == null || x.trim().isEmpty() || new Path(x.trim()).isAbsolute(),
+      x -> x == null || x.trim().isEmpty() || new Path(x.trim()).isAbsolute()
+          || x.equals(Property.VFS_CLASSLOADER_CACHE_DIR.getDefaultValue()),
       "An absolute filesystem path. The filesystem depends on the property."
-          + " This is the same as path, but enforces that its root is explicitly specified."),
+          + " This is the same as path, but enforces that its root is explicitly" + " specified."),
 
   CLASSNAME("java class", new Matches("[\\w$.]*"),
       "A fully qualified java class name representing a class on the classpath.\n"
@@ -107,12 +117,9 @@ public enum PropertyType {
       "A list of fully qualified java class names representing classes on the classpath.\n"
           + "An example is 'java.lang.String', rather than 'String'"),
 
-  DURABILITY("durability", in(true, null, "none", "log", "flush", "sync"),
+  DURABILITY("durability", in(false, null, "default", "none", "log", "flush", "sync"),
       "One of 'none', 'log', 'flush' or 'sync'."),
 
-  GC_POST_ACTION("gc_post_action", in(true, null, "none", "flush", "compact"),
-      "One of 'none', 'flush', or 'compact'."),
-
   STRING("string", x -> true,
       "An arbitrary string of characters whose format is unspecified and"
           + " interpreted based on the context of the property to which it applies."),
@@ -120,11 +127,7 @@ public enum PropertyType {
   BOOLEAN("boolean", in(false, null, "true", "false"),
       "Has a value of either 'true' or 'false' (case-insensitive)"),
 
-  URI("uri", x -> true, "A valid URI"),
-
-  FILENAME_EXT("file name extension", in(true, RFile.EXTENSION),
-      "One of the currently supported filename extensions for storing table data files. "
-          + "Currently, only " + RFile.EXTENSION + " is supported.");
+  URI("uri", x -> true, "A valid URI");
 
   private String shortname, format;
   // Field is transient because enums are Serializable, but Predicates aren't necessarily,
@@ -167,6 +170,11 @@ public enum PropertyType {
     return predicate.test(value);
   }
 
+  @SuppressWarnings("unchecked")
+  private static Predicate<String> or(final Predicate<String>... others) {
+    return (x) -> Arrays.stream(others).anyMatch(y -> y.test(x));
+  }
+
   private static Predicate<String> in(final boolean caseSensitive, final String... allowedSet) {
     if (caseSensitive) {
       return x -> Arrays.stream(allowedSet)
@@ -299,7 +307,7 @@ public enum PropertyType {
 
   public static class PortRange extends Matches {
 
-    private static final IntRange VALID_RANGE = new IntRange(1024, 65535);
+    private static final Range<Integer> VALID_RANGE = Range.between(1024, 65535);
 
     public PortRange(final String pattern) {
       super(pattern);
@@ -324,7 +332,7 @@ public enum PropertyType {
       if (idx != -1) {
         int low = Integer.parseInt(portRange.substring(0, idx));
         int high = Integer.parseInt(portRange.substring(idx + 1));
-        if (!VALID_RANGE.containsInteger(low) || !VALID_RANGE.containsInteger(high) || low > high) {
+        if (!VALID_RANGE.contains(low) || !VALID_RANGE.contains(high) || low > high) {
           throw new IllegalArgumentException(
               "Invalid port range specified, only 1024 to 65535 supported.");
         }
