@@ -36,11 +36,9 @@ import java.util.Map;
 import java.util.RandomAccess;
 
 import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.file.blockfile.ABlockReader;
-import org.apache.accumulo.core.file.blockfile.ABlockWriter;
-import org.apache.accumulo.core.file.blockfile.BlockFileReader;
-import org.apache.accumulo.core.file.blockfile.BlockFileWriter;
+import org.apache.accumulo.core.file.blockfile.impl.CachableBlockFile;
 import org.apache.accumulo.core.file.blockfile.impl.SeekableByteArrayInputStream;
+import org.apache.accumulo.core.file.rfile.bcfile.BCFile;
 import org.apache.accumulo.core.file.rfile.bcfile.Utils;
 import org.apache.hadoop.io.WritableComparable;
 
@@ -133,7 +131,7 @@ public class MultiLevelIndex {
     }
   }
 
-  private static abstract class SerializedIndexBase<T> extends AbstractList<T>
+  private abstract static class SerializedIndexBase<T> extends AbstractList<T>
       implements RandomAccess {
     protected int[] offsets;
     protected byte[] data;
@@ -222,9 +220,9 @@ public class MultiLevelIndex {
 
     public long sizeInBytes() {
       if (offsets == null) {
-        return indexSize + 4 * numOffsets;
+        return indexSize + 4L * numOffsets;
       } else {
-        return data.length + 4 * offsets.length;
+        return data.length + 4L * offsets.length;
       }
     }
 
@@ -265,7 +263,7 @@ public class MultiLevelIndex {
     private int offset;
     private boolean hasNext;
 
-    private byte data[];
+    private byte[] data;
     private int[] offsetsArray;
     private int numOffsets;
     private int offsetsOffset;
@@ -321,9 +319,9 @@ public class MultiLevelIndex {
         offset = in.readInt();
         hasNext = in.readBoolean();
 
-        ABlockReader abr = (ABlockReader) in;
+        CachableBlockFile.CachedBlockRead abr = (CachableBlockFile.CachedBlockRead) in;
         if (abr.isIndexable()) {
-          // this block is cahced, so avoid copy
+          // this block is cached, so avoid copy
           data = abr.getBuffer();
           // use offset data in serialized form and avoid copy
           numOffsets = abr.readInt();
@@ -384,7 +382,7 @@ public class MultiLevelIndex {
         hasNext = false;
 
         int numIndexEntries = in.readInt();
-        int offsets[] = new int[numIndexEntries];
+        int[] offsets = new int[numIndexEntries];
         for (int i = 0; i < numIndexEntries; i++) {
           offsets[i] = in.readInt();
         }
@@ -402,7 +400,7 @@ public class MultiLevelIndex {
 
     }
 
-    List<IndexEntry> getIndex() {
+    SerializedIndex getIndex() {
       // create SerializedIndex on demand as each has an internal input stream over byte array...
       // keeping a SerializedIndex ref for the object could lead to
       // problems with deep copies.
@@ -509,9 +507,9 @@ public class MultiLevelIndex {
 
     private boolean addedLast = false;
 
-    private BlockFileWriter blockFileWriter;
+    private BCFile.Writer blockFileWriter;
 
-    Writer(BlockFileWriter blockFileWriter, int maxBlockSize) {
+    Writer(BCFile.Writer blockFileWriter, int maxBlockSize) {
       this.blockFileWriter = blockFileWriter;
       this.threshold = maxBlockSize;
       levels = new ArrayList<>();
@@ -535,7 +533,7 @@ public class MultiLevelIndex {
 
       IndexBlock iblock = levels.get(level);
       if ((iblock.getSize() > threshold && iblock.offsets.size() > 1) || last) {
-        ABlockWriter out = blockFileWriter.prepareDataBlock();
+        BCFile.Writer.BlockAppender out = blockFileWriter.prepareDataBlock();
         iblock.setHasNext(!last);
         iblock.write(out);
         out.close();
@@ -586,7 +584,7 @@ public class MultiLevelIndex {
 
   public static class Reader {
     private IndexBlock rootBlock;
-    private BlockFileReader blockStore;
+    private CachableBlockFile.Reader blockStore;
     private int version;
     private int size;
 
@@ -607,12 +605,8 @@ public class MultiLevelIndex {
       }
 
       private Node lookup(Key key) throws IOException {
-        int pos = Collections.binarySearch(indexBlock.getKeyIndex(), key, new Comparator<Key>() {
-          @Override
-          public int compare(Key o1, Key o2) {
-            return o1.compareTo(o2);
-          }
-        });
+        int pos =
+            Collections.binarySearch(indexBlock.getKeyIndex(), key, Comparator.naturalOrder());
 
         if (pos < 0)
           pos = (pos * -1) - 1;
@@ -688,7 +682,7 @@ public class MultiLevelIndex {
       }
     }
 
-    static public class IndexIterator implements ListIterator<IndexEntry> {
+    public static class IndexIterator implements ListIterator<IndexEntry> {
 
       private Node node;
       private ListIterator<IndexEntry> liter;
@@ -803,14 +797,14 @@ public class MultiLevelIndex {
 
     }
 
-    public Reader(BlockFileReader blockStore, int version) {
+    public Reader(CachableBlockFile.Reader blockStore, int version) {
       this.version = version;
       this.blockStore = blockStore;
     }
 
     private IndexBlock getIndexBlock(IndexEntry ie) throws IOException {
       IndexBlock iblock = new IndexBlock();
-      ABlockReader in =
+      CachableBlockFile.CachedBlockRead in =
           blockStore.getMetaBlock(ie.getOffset(), ie.getCompressedSize(), ie.getRawSize());
       iblock.readFields(in, version);
       in.close();
@@ -848,14 +842,14 @@ public class MultiLevelIndex {
         Map<Integer,Long> countsByLevel) throws IOException {
       Long size = sizesByLevel.get(ib.getLevel());
       if (size == null)
-        size = 0l;
+        size = 0L;
 
       Long count = countsByLevel.get(ib.getLevel());
       if (count == null)
-        count = 0l;
+        count = 0L;
 
-      List<IndexEntry> index = ib.getIndex();
-      size += ((SerializedIndex) index).sizeInBytes();
+      SerializedIndex index = ib.getIndex();
+      size += index.sizeInBytes();
       count++;
 
       sizesByLevel.put(ib.getLevel(), size);
@@ -901,7 +895,7 @@ public class MultiLevelIndex {
         sb.append(" RawSize : ");
         sb.append(ie.rawSize);
 
-        out.println(sb.toString());
+        out.println(sb);
 
         if (ib.getLevel() > 0) {
           IndexBlock cib = getIndexBlock(ie);
