@@ -16,13 +16,14 @@
  */
 package org.apache.accumulo.core.metadata;
 
-import org.apache.accumulo.core.client.impl.Namespaces;
+import org.apache.accumulo.core.clientImpl.Namespace;
+import org.apache.accumulo.core.data.TableId;
 
 public class MetadataTable {
 
   public static final String OLD_NAME = "!METADATA";
 
-  public static final String ID = "!0";
-  public static final String NAME = Namespaces.ACCUMULO_NAMESPACE + ".metadata";
+  public static final TableId ID = TableId.of("!0");
+  public static final String NAME = Namespace.ACCUMULO.name() + ".metadata";
 
 }
