@@ -16,7 +16,8 @@
  */
 package org.apache.accumulo.core.metadata;
 
-import org.apache.accumulo.core.client.impl.ClientContext;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.data.TableId;
 
 /**
  * A metadata servicer for user tables.<br>
@@ -24,7 +25,7 @@ import org.apache.accumulo.core.client.impl.ClientContext;
  */
 class ServicerForUserTables extends TableMetadataServicer {
 
-  public ServicerForUserTables(ClientContext context, String tableId) {
+  public ServicerForUserTables(ClientContext context, TableId tableId) {
     super(context, MetadataTable.NAME, tableId);
   }
 
