@@ -18,10 +18,10 @@ package org.apache.accumulo.core.util.ratelimit;
 
 public interface RateLimiter {
   /**
-   * Get current QPS of the rate limiter, with a nonpositive rate indicating no limit.
+   * Get current QPS of the rate limiter, with a non-positive rate indicating no limit.
    */
-  public long getRate();
+  long getRate();
 
   /** Sleep until the specified number of queries are available. */
-  public void acquire(long permits);
+  void acquire(long permits);
 }
