@@ -18,13 +18,13 @@ package org.apache.accumulo.core.client.lexicoder;
 
 import java.util.Date;
 
-import org.apache.accumulo.core.client.lexicoder.impl.AbstractLexicoderTest;
+import org.apache.accumulo.core.clientImpl.lexicoder.AbstractLexicoderTest;
 import org.junit.Test;
 
 public class DateLexicoderTest extends AbstractLexicoderTest {
 
   @Test
-  public void testDecode() throws Exception {
+  public void testDecode() {
     assertDecodes(new DateLexicoder(), new Date());
     assertDecodes(new DateLexicoder(), new Date(0));
     assertDecodes(new DateLexicoder(), new Date(Long.MAX_VALUE));
