@@ -16,13 +16,13 @@
  */
 package org.apache.accumulo.core.client.lexicoder;
 
-import org.apache.accumulo.core.client.lexicoder.impl.AbstractLexicoderTest;
+import org.apache.accumulo.core.clientImpl.lexicoder.AbstractLexicoderTest;
 import org.junit.Test;
 
 public class StringLexicoderTest extends AbstractLexicoderTest {
 
   @Test
-  public void testDecode() throws Exception {
+  public void testDecode() {
     assertDecodes(new StringLexicoder(), "");
     assertDecodes(new StringLexicoder(), "0");
     assertDecodes(new StringLexicoder(), "accumulo");
