@@ -16,14 +16,14 @@
  */
 package org.apache.accumulo.core.client.lexicoder;
 
-import org.apache.accumulo.core.client.lexicoder.impl.AbstractLexicoderTest;
+import org.apache.accumulo.core.clientImpl.lexicoder.AbstractLexicoderTest;
 import org.apache.hadoop.io.Text;
 import org.junit.Test;
 
 public class TextLexicoderTest extends AbstractLexicoderTest {
 
   @Test
-  public void testDecode() throws Exception {
+  public void testDecode() {
     assertDecodes(new TextLexicoder(), new Text(""));
     assertDecodes(new TextLexicoder(), new Text("accumulo"));
   }
