@@ -22,9 +22,6 @@ import java.util.HashSet;
 
 import org.junit.Test;
 
-/**
- *
- */
 public class SecurityErrorCodeTest {
 
   @Test
@@ -35,7 +32,7 @@ public class SecurityErrorCodeTest {
     for (SecurityErrorCode sec : SecurityErrorCode.values())
       secNames1.add(sec.name());
 
-    for (org.apache.accumulo.core.client.impl.thrift.SecurityErrorCode sec : org.apache.accumulo.core.client.impl.thrift.SecurityErrorCode
+    for (org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode sec : org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode
         .values())
       secNames2.add(sec.name());
 
