@@ -25,7 +25,6 @@ import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import org.apache.accumulo.core.file.rfile.RFile;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -142,12 +141,6 @@ public class PropertyTypeTest {
     invalid("", "other");
   }
 
-  @Test
-  public void testTypeGC_POST_ACTION() {
-    valid(null, "none", "flush", "compact");
-    invalid("", "other");
-  }
-
   @Test
   public void testTypeFRACTION() {
     valid(null, "1", "0", "1.0", "25%", "2.5%", "10.2E-3", "10.2E-3%", ".3");
@@ -163,8 +156,14 @@ public class PropertyTypeTest {
   }
 
   @Test
-  public void testTypeMEMORY() {
+  public void testTypeBYTES() {
     valid(null, "1024", "20B", "100K", "1500M", "2G");
+    invalid("1M500K", "1M 2K", "1MB", "1.5G", "1,024K", "", "a", "10%");
+  }
+
+  @Test
+  public void testTypeMEMORY() {
+    valid(null, "1024", "20B", "100K", "1500M", "2G", "10%");
     invalid("1M500K", "1M 2K", "1MB", "1.5G", "1,024K", "", "a");
   }
 
@@ -201,10 +200,4 @@ public class PropertyTypeTest {
     valid(null, "", "hdfs://hostname", "file:///path/", "hdfs://example.com:port/path");
   }
 
-  @Test
-  public void testTypeFILENAME_EXT() {
-    valid(RFile.EXTENSION, "rf");
-    invalid(null, "RF", "map", "", "MAP", "rF", "Rf", " rf ");
-  }
-
 }
