@@ -31,8 +31,8 @@ import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.data.thrift.TRange;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.hadoop.io.Text;
 import org.junit.Test;
 
@@ -40,11 +40,11 @@ public class RangeTest {
   private Range newRange(String k1, String k2) {
     Key ik1 = null;
     if (k1 != null)
-      ik1 = new Key(new Text(k1), 0l);
+      ik1 = new Key(new Text(k1), 0L);
 
     Key ik2 = null;
     if (k2 != null)
-      ik2 = new Key(new Text(k2), 0l);
+      ik2 = new Key(new Text(k2), 0L);
 
     return new Range(ik1, ik2);
   }
@@ -57,7 +57,7 @@ public class RangeTest {
     HashSet<Range> s1 = new HashSet<>(rl);
     HashSet<Range> s2 = new HashSet<>(expected);
 
-    assertTrue("got : " + rl + " expected : " + expected, s1.equals(s2));
+    assertEquals("got : " + rl + " expected : " + expected, s1, s2);
   }
 
   @Test
@@ -227,32 +227,39 @@ public class RangeTest {
   @Test
   public void testMergeOverlapping22() {
 
-    Range ke1 = new KeyExtent("tab1", new Text("Bank"), null).toMetadataRange();
-    Range ke2 = new KeyExtent("tab1", new Text("Fails"), new Text("Bank")).toMetadataRange();
-    Range ke3 = new KeyExtent("tab1", new Text("Sam"), new Text("Fails")).toMetadataRange();
-    Range ke4 = new KeyExtent("tab1", new Text("bails"), new Text("Sam")).toMetadataRange();
-    Range ke5 = new KeyExtent("tab1", null, new Text("bails")).toMetadataRange();
+    Range ke1 = new KeyExtent(TableId.of("tab1"), new Text("Bank"), null).toMetadataRange();
+    Range ke2 =
+        new KeyExtent(TableId.of("tab1"), new Text("Fails"), new Text("Bank")).toMetadataRange();
+    Range ke3 =
+        new KeyExtent(TableId.of("tab1"), new Text("Sam"), new Text("Fails")).toMetadataRange();
+    Range ke4 =
+        new KeyExtent(TableId.of("tab1"), new Text("bails"), new Text("Sam")).toMetadataRange();
+    Range ke5 = new KeyExtent(TableId.of("tab1"), null, new Text("bails")).toMetadataRange();
 
     List<Range> rl = newRangeList(ke1, ke2, ke3, ke4, ke5);
-    List<Range> expected = newRangeList(new KeyExtent("tab1", null, null).toMetadataRange());
+    List<Range> expected =
+        newRangeList(new KeyExtent(TableId.of("tab1"), null, null).toMetadataRange());
     check(Range.mergeOverlapping(rl), expected);
 
     rl = newRangeList(ke1, ke2, ke4, ke5);
-    expected = newRangeList(new KeyExtent("tab1", new Text("Fails"), null).toMetadataRange(),
-        new KeyExtent("tab1", null, new Text("Sam")).toMetadataRange());
+    expected =
+        newRangeList(new KeyExtent(TableId.of("tab1"), new Text("Fails"), null).toMetadataRange(),
+            new KeyExtent(TableId.of("tab1"), null, new Text("Sam")).toMetadataRange());
     check(Range.mergeOverlapping(rl), expected);
 
     rl = newRangeList(ke2, ke3, ke4, ke5);
-    expected = newRangeList(new KeyExtent("tab1", null, new Text("Bank")).toMetadataRange());
+    expected =
+        newRangeList(new KeyExtent(TableId.of("tab1"), null, new Text("Bank")).toMetadataRange());
     check(Range.mergeOverlapping(rl), expected);
 
     rl = newRangeList(ke1, ke2, ke3, ke4);
-    expected = newRangeList(new KeyExtent("tab1", new Text("bails"), null).toMetadataRange());
+    expected =
+        newRangeList(new KeyExtent(TableId.of("tab1"), new Text("bails"), null).toMetadataRange());
     check(Range.mergeOverlapping(rl), expected);
 
     rl = newRangeList(ke2, ke3, ke4);
-    expected =
-        newRangeList(new KeyExtent("tab1", new Text("bails"), new Text("Bank")).toMetadataRange());
+    expected = newRangeList(
+        new KeyExtent(TableId.of("tab1"), new Text("bails"), new Text("Bank")).toMetadataRange());
 
     check(Range.mergeOverlapping(rl), expected);
   }
@@ -615,7 +622,7 @@ public class RangeTest {
   private void runClipTest(Range fence, Range range) {
     try {
       fence.clip(range);
-      assertFalse(true);
+      fail();
     } catch (IllegalArgumentException e) {
 
     }
@@ -764,15 +771,15 @@ public class RangeTest {
     assertFalse(r.contains(new Key("abc", "def", "ghj")));
 
     r = Range.exact("abc", "def", "ghi", "j&k");
-    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7l)));
+    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7L)));
     assertFalse(r.contains(new Key("abc", "def", "ghi", "j&kl")));
     assertFalse(r.contains(new Key("abc", "def", "ghi", "j&j")));
     assertFalse(r.contains(new Key("abc", "def", "ghi", "j&l")));
 
-    r = Range.exact("abc", "def", "ghi", "j&k", 7l);
-    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7l)));
-    assertFalse(r.contains(new Key("abc", "def", "ghi", "j&k", 6l)));
-    assertFalse(r.contains(new Key("abc", "def", "ghi", "j&k", 8l)));
+    r = Range.exact("abc", "def", "ghi", "j&k", 7L);
+    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7L)));
+    assertFalse(r.contains(new Key("abc", "def", "ghi", "j&k", 6L)));
+    assertFalse(r.contains(new Key("abc", "def", "ghi", "j&k", 8L)));
   }
 
   @Test
@@ -797,7 +804,7 @@ public class RangeTest {
     assertFalse(r.contains(new Key("abc", "def", "ghj")));
 
     r = Range.prefix("abc", "def", "ghi", "j&k");
-    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7l)));
+    assertTrue(r.contains(new Key("abc", "def", "ghi", "j&k", 7L)));
     assertTrue(r.contains(new Key("abc", "def", "ghi", "j&kl")));
     assertFalse(r.contains(new Key("abc", "def", "ghi", "j&j")));
     assertFalse(r.contains(new Key("abc", "def", "ghi", "j&l")));
@@ -874,15 +881,12 @@ public class RangeTest {
     r.write(dos);
     dos.close();
     ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
-    DataInputStream dis = new DataInputStream(bais);
     Range r2 = new Range();
-    try {
+    try (DataInputStream dis = new DataInputStream(bais)) {
       r2.readFields(dis);
       fail("readFields allowed invalid range");
     } catch (InvalidObjectException exc) {
       /* good! */
-    } finally {
-      dis.close();
     }
   }
 
