@@ -18,13 +18,29 @@
 package org.apache.accumulo.core.file.blockfile.cache;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
+import java.security.SecureRandom;
 import java.util.Arrays;
-import java.util.EnumSet;
 import java.util.Random;
 
-import org.apache.accumulo.core.file.blockfile.cache.LruBlockCache.Options;
+import org.apache.accumulo.core.conf.ConfigurationCopy;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
+import org.apache.accumulo.core.conf.Property;
+import org.apache.accumulo.core.file.blockfile.cache.impl.BlockCacheConfiguration;
+import org.apache.accumulo.core.file.blockfile.cache.impl.BlockCacheManagerFactory;
+import org.apache.accumulo.core.file.blockfile.cache.impl.ClassSize;
+import org.apache.accumulo.core.file.blockfile.cache.lru.CachedBlock;
+import org.apache.accumulo.core.file.blockfile.cache.lru.HeapSize;
+import org.apache.accumulo.core.file.blockfile.cache.lru.LruBlockCache;
+import org.apache.accumulo.core.file.blockfile.cache.lru.LruBlockCacheConfiguration;
+import org.apache.accumulo.core.file.blockfile.cache.lru.LruBlockCacheManager;
+import org.apache.accumulo.core.spi.cache.BlockCacheManager;
+import org.apache.accumulo.core.spi.cache.CacheEntry;
+import org.apache.accumulo.core.spi.cache.CacheType;
 import org.junit.Test;
 
 /**
@@ -36,13 +52,57 @@ import org.junit.Test;
  */
 public class TestLruBlockCache {
 
+  @Test
+  public void testConfiguration() {
+    ConfigurationCopy cc = new ConfigurationCopy();
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(1019));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(1000023));
+    cc.set(Property.TSERV_DATACACHE_SIZE, Long.toString(1000027));
+    cc.set(Property.TSERV_SUMMARYCACHE_SIZE, Long.toString(1000029));
+
+    LruBlockCacheConfiguration.builder(CacheType.INDEX).useEvictionThread(false).minFactor(0.93f)
+        .acceptableFactor(0.97f).singleFactor(0.20f).multiFactor(0.30f).memoryFactor(0.50f)
+        .mapConcurrencyLevel(5).buildMap().forEach(cc::set);
+
+    String defaultPrefix = BlockCacheManager.CACHE_PROPERTY_BASE
+        + LruBlockCacheConfiguration.PROPERTY_PREFIX + ".default.";
+
+    // this should be overridden by cache type specific setting
+    cc.set(defaultPrefix + LruBlockCacheConfiguration.MEMORY_FACTOR_PROPERTY, "0.6");
+
+    // this is not set for the cache type, so should fall back to default
+    cc.set(defaultPrefix + LruBlockCacheConfiguration.MAP_LOAD_PROPERTY, "0.53");
+
+    BlockCacheConfiguration bcc = new BlockCacheConfiguration(cc);
+    LruBlockCacheConfiguration lbcc = new LruBlockCacheConfiguration(bcc, CacheType.INDEX);
+
+    assertFalse(lbcc.isUseEvictionThread());
+    assertEquals(0.93f, lbcc.getMinFactor(), 0.0000001);
+    assertEquals(0.97f, lbcc.getAcceptableFactor(), 0.0000001);
+    assertEquals(0.20f, lbcc.getSingleFactor(), 0.0000001);
+    assertEquals(0.30f, lbcc.getMultiFactor(), 0.0000001);
+    assertEquals(0.50f, lbcc.getMemoryFactor(), 0.0000001);
+    assertEquals(0.53f, lbcc.getMapLoadFactor(), 0.0000001);
+    assertEquals(5, lbcc.getMapConcurrencyLevel());
+    assertEquals(1019, lbcc.getBlockSize());
+    assertEquals(1000023, lbcc.getMaxSize());
+  }
+
   @Test
   public void testBackgroundEvictionThread() throws Exception {
 
     long maxSize = 100000;
     long blockSize = calculateBlockSizeDefault(maxSize, 9); // room for 9, will evict
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize);
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    manager.start(new BlockCacheConfiguration(cc));
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] blocks = generateFixedBlocks(10, blockSize, "block");
 
@@ -59,6 +119,8 @@ public class TestLruBlockCache {
     }
     // A single eviction run should have occurred
     assertEquals(cache.getEvictionCount(), 1);
+
+    manager.stop();
   }
 
   @Test
@@ -67,7 +129,14 @@ public class TestLruBlockCache {
     long maxSize = 1000000;
     long blockSize = calculateBlockSizeDefault(maxSize, 101);
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize);
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    manager.start(new BlockCacheConfiguration(cc));
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] blocks = generateRandomBlocks(100, blockSize);
 
@@ -75,7 +144,7 @@ public class TestLruBlockCache {
 
     // Confirm empty
     for (Block block : blocks) {
-      assertTrue(cache.getBlock(block.blockName) == null);
+      assertNull(cache.getBlock(block.blockName));
     }
 
     // Add blocks
@@ -90,7 +159,7 @@ public class TestLruBlockCache {
     // Check if all blocks are properly cached and retrieved
     for (Block block : blocks) {
       CacheEntry ce = cache.getBlock(block.blockName);
-      assertTrue(ce != null);
+      assertNotNull(ce);
       assertEquals(ce.getBuffer().length, block.buf.length);
     }
 
@@ -100,7 +169,7 @@ public class TestLruBlockCache {
     // Check if all blocks are properly cached and retrieved
     for (Block block : blocks) {
       CacheEntry ce = cache.getBlock(block.blockName);
-      assertTrue(ce != null);
+      assertNotNull(ce);
       assertEquals(ce.getBuffer().length, block.buf.length);
     }
 
@@ -109,6 +178,7 @@ public class TestLruBlockCache {
     // Thread t = new LruBlockCache.StatisticsThread(cache);
     // t.start();
     // t.join();
+    manager.stop();
   }
 
   @Test
@@ -117,7 +187,17 @@ public class TestLruBlockCache {
     long maxSize = 100000;
     long blockSize = calculateBlockSizeDefault(maxSize, 10);
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize, EnumSet.noneOf(Options.class));
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    LruBlockCacheConfiguration.builder(CacheType.INDEX).useEvictionThread(false).buildMap()
+        .forEach(cc::set);
+    manager.start(new BlockCacheConfiguration(cc));
+
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] blocks = generateFixedBlocks(10, blockSize, "block");
 
@@ -133,20 +213,22 @@ public class TestLruBlockCache {
     assertEquals(1, cache.getEvictionCount());
 
     // Our expected size overruns acceptable limit
-    assertTrue(expectedCacheSize > (maxSize * LruBlockCache.DEFAULT_ACCEPTABLE_FACTOR));
+    assertTrue(
+        expectedCacheSize > (maxSize * LruBlockCacheConfiguration.DEFAULT_ACCEPTABLE_FACTOR));
 
     // But the cache did not grow beyond max
     assertTrue(cache.heapSize() < maxSize);
 
     // And is still below the acceptable limit
-    assertTrue(cache.heapSize() < (maxSize * LruBlockCache.DEFAULT_ACCEPTABLE_FACTOR));
+    assertTrue(cache.heapSize() < (maxSize * LruBlockCacheConfiguration.DEFAULT_ACCEPTABLE_FACTOR));
 
     // All blocks except block 0 and 1 should be in the cache
-    assertTrue(cache.getBlock(blocks[0].blockName) == null);
-    assertTrue(cache.getBlock(blocks[1].blockName) == null);
+    assertNull(cache.getBlock(blocks[0].blockName));
+    assertNull(cache.getBlock(blocks[1].blockName));
     for (int i = 2; i < blocks.length; i++) {
       assertTrue(Arrays.equals(cache.getBlock(blocks[i].blockName).getBuffer(), blocks[i].buf));
     }
+    manager.stop();
   }
 
   @Test
@@ -155,13 +237,17 @@ public class TestLruBlockCache {
     long maxSize = 100000;
     long blockSize = calculateBlockSizeDefault(maxSize, 10);
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize, EnumSet.noneOf(Options.class),
-        (int) Math.ceil(1.2 * maxSize / blockSize), LruBlockCache.DEFAULT_LOAD_FACTOR,
-        LruBlockCache.DEFAULT_CONCURRENCY_LEVEL, 0.98f, // min
-        0.99f, // acceptable
-        0.25f, // single
-        0.50f, // multi
-        0.25f);// memory
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    LruBlockCacheConfiguration.builder(CacheType.INDEX).useEvictionThread(false).minFactor(0.98f)
+        .acceptableFactor(0.99f).singleFactor(0.25f).multiFactor(0.50f).memoryFactor(0.25f)
+        .buildMap().forEach(cc::set);
+    manager.start(new BlockCacheConfiguration(cc));
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] singleBlocks = generateFixedBlocks(5, 10000, "single");
     Block[] multiBlocks = generateFixedBlocks(5, 10000, "multi");
@@ -188,20 +274,22 @@ public class TestLruBlockCache {
     assertEquals(cache.getEvictedCount(), 2);
 
     // Our expected size overruns acceptable limit
-    assertTrue(expectedCacheSize > (maxSize * LruBlockCache.DEFAULT_ACCEPTABLE_FACTOR));
+    assertTrue(
+        expectedCacheSize > (maxSize * LruBlockCacheConfiguration.DEFAULT_ACCEPTABLE_FACTOR));
 
     // But the cache did not grow beyond max
     assertTrue(cache.heapSize() <= maxSize);
 
     // And is now below the acceptable limit
-    assertTrue(cache.heapSize() <= (maxSize * LruBlockCache.DEFAULT_ACCEPTABLE_FACTOR));
+    assertTrue(
+        cache.heapSize() <= (maxSize * LruBlockCacheConfiguration.DEFAULT_ACCEPTABLE_FACTOR));
 
     // We expect fairness across the two priorities.
     // This test makes multi go barely over its limit, in-memory
     // empty, and the rest in single. Two single evictions and
     // one multi eviction expected.
-    assertTrue(cache.getBlock(singleBlocks[0].blockName) == null);
-    assertTrue(cache.getBlock(multiBlocks[0].blockName) == null);
+    assertNull(cache.getBlock(singleBlocks[0].blockName));
+    assertNull(cache.getBlock(multiBlocks[0].blockName));
 
     // And all others to be cached
     for (int i = 1; i < 4; i++) {
@@ -210,6 +298,7 @@ public class TestLruBlockCache {
       assertTrue(
           Arrays.equals(cache.getBlock(multiBlocks[i].blockName).getBuffer(), multiBlocks[i].buf));
     }
+    manager.stop();
   }
 
   @Test
@@ -218,13 +307,17 @@ public class TestLruBlockCache {
     long maxSize = 100000;
     long blockSize = calculateBlockSize(maxSize, 10);
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize, EnumSet.noneOf(Options.class),
-        (int) Math.ceil(1.2 * maxSize / blockSize), LruBlockCache.DEFAULT_LOAD_FACTOR,
-        LruBlockCache.DEFAULT_CONCURRENCY_LEVEL, 0.98f, // min
-        0.99f, // acceptable
-        0.33f, // single
-        0.33f, // multi
-        0.34f);// memory
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    LruBlockCacheConfiguration.builder(CacheType.INDEX).useEvictionThread(false).minFactor(0.98f)
+        .acceptableFactor(0.99f).singleFactor(0.33f).multiFactor(0.33f).memoryFactor(0.34f)
+        .buildMap().forEach(cc::set);
+    manager.start(new BlockCacheConfiguration(cc));
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] singleBlocks = generateFixedBlocks(5, blockSize, "single");
     Block[] multiBlocks = generateFixedBlocks(5, blockSize, "multi");
@@ -264,7 +357,7 @@ public class TestLruBlockCache {
     assertEquals(1, cache.getEvictedCount());
 
     // Verify oldest single block is the one evicted
-    assertEquals(null, cache.getBlock(singleBlocks[0].blockName));
+    assertNull(cache.getBlock(singleBlocks[0].blockName));
 
     // Change the oldest remaining single block to a multi
     cache.getBlock(singleBlocks[1].blockName);
@@ -277,7 +370,7 @@ public class TestLruBlockCache {
     assertEquals(2, cache.getEvictedCount());
 
     // Oldest multi block should be evicted now
-    assertEquals(null, cache.getBlock(multiBlocks[0].blockName));
+    assertNull(cache.getBlock(multiBlocks[0].blockName));
 
     // Insert another memory block
     cache.cacheBlock(memoryBlocks[3].blockName, memoryBlocks[3].buf, true);
@@ -287,7 +380,7 @@ public class TestLruBlockCache {
     assertEquals(3, cache.getEvictedCount());
 
     // Oldest memory block should be evicted now
-    assertEquals(null, cache.getBlock(memoryBlocks[0].blockName));
+    assertNull(cache.getBlock(memoryBlocks[0].blockName));
 
     // Add a block that is twice as big (should force two evictions)
     Block[] bigBlocks = generateFixedBlocks(3, blockSize * 3, "big");
@@ -298,9 +391,9 @@ public class TestLruBlockCache {
     assertEquals(6, cache.getEvictedCount());
 
     // Expect three remaining singles to be evicted
-    assertEquals(null, cache.getBlock(singleBlocks[2].blockName));
-    assertEquals(null, cache.getBlock(singleBlocks[3].blockName));
-    assertEquals(null, cache.getBlock(singleBlocks[4].blockName));
+    assertNull(cache.getBlock(singleBlocks[2].blockName));
+    assertNull(cache.getBlock(singleBlocks[3].blockName));
+    assertNull(cache.getBlock(singleBlocks[4].blockName));
 
     // Make the big block a multi block
     cache.getBlock(bigBlocks[0].blockName);
@@ -313,9 +406,9 @@ public class TestLruBlockCache {
     assertEquals(9, cache.getEvictedCount());
 
     // Expect three remaining multis to be evicted
-    assertEquals(null, cache.getBlock(singleBlocks[1].blockName));
-    assertEquals(null, cache.getBlock(multiBlocks[1].blockName));
-    assertEquals(null, cache.getBlock(multiBlocks[2].blockName));
+    assertNull(cache.getBlock(singleBlocks[1].blockName));
+    assertNull(cache.getBlock(multiBlocks[1].blockName));
+    assertNull(cache.getBlock(multiBlocks[2].blockName));
 
     // Cache a big memory block
     cache.cacheBlock(bigBlocks[2].blockName, bigBlocks[2].buf, true);
@@ -325,10 +418,11 @@ public class TestLruBlockCache {
     assertEquals(12, cache.getEvictedCount());
 
     // Expect three remaining in-memory to be evicted
-    assertEquals(null, cache.getBlock(memoryBlocks[1].blockName));
-    assertEquals(null, cache.getBlock(memoryBlocks[2].blockName));
-    assertEquals(null, cache.getBlock(memoryBlocks[3].blockName));
+    assertNull(cache.getBlock(memoryBlocks[1].blockName));
+    assertNull(cache.getBlock(memoryBlocks[2].blockName));
+    assertNull(cache.getBlock(memoryBlocks[3].blockName));
 
+    manager.stop();
   }
 
   // test scan resistance
@@ -338,13 +432,17 @@ public class TestLruBlockCache {
     long maxSize = 100000;
     long blockSize = calculateBlockSize(maxSize, 10);
 
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize, EnumSet.noneOf(Options.class),
-        (int) Math.ceil(1.2 * maxSize / blockSize), LruBlockCache.DEFAULT_LOAD_FACTOR,
-        LruBlockCache.DEFAULT_CONCURRENCY_LEVEL, 0.66f, // min
-        0.99f, // acceptable
-        0.33f, // single
-        0.33f, // multi
-        0.34f);// memory
+    DefaultConfiguration dc = DefaultConfiguration.getInstance();
+    ConfigurationCopy cc = new ConfigurationCopy(dc);
+    cc.set(Property.TSERV_CACHE_MANAGER_IMPL, LruBlockCacheManager.class.getName());
+    BlockCacheManager manager = BlockCacheManagerFactory.getInstance(cc);
+    cc.set(Property.TSERV_DEFAULT_BLOCKSIZE, Long.toString(blockSize));
+    cc.set(Property.TSERV_INDEXCACHE_SIZE, Long.toString(maxSize));
+    LruBlockCacheConfiguration.builder(CacheType.INDEX).useEvictionThread(false).minFactor(0.66f)
+        .acceptableFactor(0.99f).singleFactor(0.33f).multiFactor(0.33f).memoryFactor(0.34f)
+        .buildMap().forEach(cc::set);
+    manager.start(new BlockCacheConfiguration(cc));
+    LruBlockCache cache = (LruBlockCache) manager.getBlockCache(CacheType.INDEX);
 
     Block[] singleBlocks = generateFixedBlocks(20, blockSize, "single");
     Block[] multiBlocks = generateFixedBlocks(5, blockSize, "multi");
@@ -367,10 +465,10 @@ public class TestLruBlockCache {
     assertEquals(4, cache.getEvictedCount());
 
     // Should have been taken off equally from single and multi
-    assertEquals(null, cache.getBlock(singleBlocks[0].blockName));
-    assertEquals(null, cache.getBlock(singleBlocks[1].blockName));
-    assertEquals(null, cache.getBlock(multiBlocks[0].blockName));
-    assertEquals(null, cache.getBlock(multiBlocks[1].blockName));
+    assertNull(cache.getBlock(singleBlocks[0].blockName));
+    assertNull(cache.getBlock(singleBlocks[1].blockName));
+    assertNull(cache.getBlock(multiBlocks[0].blockName));
+    assertNull(cache.getBlock(multiBlocks[1].blockName));
 
     // Let's keep "scanning" by adding single blocks. From here on we only
     // expect evictions from the single bucket.
@@ -390,69 +488,7 @@ public class TestLruBlockCache {
     // Should now have 7 total blocks
     assertEquals(7, cache.size());
 
-  }
-
-  // test setMaxSize
-  @Test
-  public void testResizeBlockCache() throws Exception {
-
-    long maxSize = 300000;
-    long blockSize = calculateBlockSize(maxSize, 31);
-
-    LruBlockCache cache = new LruBlockCache(maxSize, blockSize, EnumSet.noneOf(Options.class),
-        (int) Math.ceil(1.2 * maxSize / blockSize), LruBlockCache.DEFAULT_LOAD_FACTOR,
-        LruBlockCache.DEFAULT_CONCURRENCY_LEVEL, 0.98f, // min
-        0.99f, // acceptable
-        0.33f, // single
-        0.33f, // multi
-        0.34f);// memory
-
-    Block[] singleBlocks = generateFixedBlocks(10, blockSize, "single");
-    Block[] multiBlocks = generateFixedBlocks(10, blockSize, "multi");
-    Block[] memoryBlocks = generateFixedBlocks(10, blockSize, "memory");
-
-    // Add all blocks from all priorities
-    for (int i = 0; i < 10; i++) {
-
-      // Just add single blocks
-      cache.cacheBlock(singleBlocks[i].blockName, singleBlocks[i].buf);
-
-      // Add and get multi blocks
-      cache.cacheBlock(multiBlocks[i].blockName, multiBlocks[i].buf);
-      cache.getBlock(multiBlocks[i].blockName);
-
-      // Add memory blocks as such
-      cache.cacheBlock(memoryBlocks[i].blockName, memoryBlocks[i].buf, true);
-    }
-
-    // Do not expect any evictions yet
-    assertEquals(0, cache.getEvictionCount());
-
-    // Resize to half capacity plus an extra block (otherwise we evict an extra)
-    cache.setMaxSize((long) (maxSize * 0.5f));
-
-    // Should have run a single eviction
-    assertEquals(1, cache.getEvictionCount());
-
-    // And we expect 1/2 of the blocks to be evicted
-    assertEquals(15, cache.getEvictedCount());
-
-    // And the oldest 5 blocks from each category should be gone
-    for (int i = 0; i < 5; i++) {
-      assertEquals(null, cache.getBlock(singleBlocks[i].blockName));
-      assertEquals(null, cache.getBlock(multiBlocks[i].blockName));
-      assertEquals(null, cache.getBlock(memoryBlocks[i].blockName));
-    }
-
-    // And the newest 5 blocks should still be accessible
-    for (int i = 5; i < 10; i++) {
-      assertTrue(Arrays.equals(singleBlocks[i].buf,
-          cache.getBlock(singleBlocks[i].blockName).getBuffer()));
-      assertTrue(
-          Arrays.equals(multiBlocks[i].buf, cache.getBlock(multiBlocks[i].blockName).getBuffer()));
-      assertTrue(Arrays.equals(memoryBlocks[i].buf,
-          cache.getBlock(memoryBlocks[i].blockName).getBuffer()));
-    }
+    manager.stop();
   }
 
   private Block[] generateFixedBlocks(int numBlocks, int size, String pfx) {
@@ -469,7 +505,7 @@ public class TestLruBlockCache {
 
   private Block[] generateRandomBlocks(int numBlocks, long maxSize) {
     Block[] blocks = new Block[numBlocks];
-    Random r = new Random();
+    Random r = new SecureRandom();
     for (int i = 0; i < numBlocks; i++) {
       blocks[i] = new Block("block" + i, r.nextInt((int) maxSize) + 1);
     }
@@ -481,7 +517,8 @@ public class TestLruBlockCache {
     int numEntries = (int) Math.ceil((1.2) * maxSize / roughBlockSize);
     long totalOverhead = LruBlockCache.CACHE_FIXED_OVERHEAD + ClassSize.CONCURRENT_HASHMAP
         + (numEntries * ClassSize.CONCURRENT_HASHMAP_ENTRY)
-        + (LruBlockCache.DEFAULT_CONCURRENCY_LEVEL * ClassSize.CONCURRENT_HASHMAP_SEGMENT);
+        + (LruBlockCacheConfiguration.DEFAULT_CONCURRENCY_LEVEL
+            * ClassSize.CONCURRENT_HASHMAP_SEGMENT);
     long negateBlockSize = totalOverhead / numEntries;
     negateBlockSize += CachedBlock.PER_BLOCK_OVERHEAD;
     return ClassSize.align((long) Math.floor((roughBlockSize - negateBlockSize) * 0.99f));
@@ -492,16 +529,17 @@ public class TestLruBlockCache {
     int numEntries = (int) Math.ceil((1.2) * maxSize / roughBlockSize);
     long totalOverhead = LruBlockCache.CACHE_FIXED_OVERHEAD + ClassSize.CONCURRENT_HASHMAP
         + (numEntries * ClassSize.CONCURRENT_HASHMAP_ENTRY)
-        + (LruBlockCache.DEFAULT_CONCURRENCY_LEVEL * ClassSize.CONCURRENT_HASHMAP_SEGMENT);
+        + (LruBlockCacheConfiguration.DEFAULT_CONCURRENCY_LEVEL
+            * ClassSize.CONCURRENT_HASHMAP_SEGMENT);
     long negateBlockSize = totalOverhead / numEntries;
     negateBlockSize += CachedBlock.PER_BLOCK_OVERHEAD;
-    return ClassSize.align((long) Math
-        .floor((roughBlockSize - negateBlockSize) * LruBlockCache.DEFAULT_ACCEPTABLE_FACTOR));
+    return ClassSize.align((long) Math.floor(
+        (roughBlockSize - negateBlockSize) * LruBlockCacheConfiguration.DEFAULT_ACCEPTABLE_FACTOR));
   }
 
   private static class Block implements HeapSize {
     String blockName;
-    byte buf[];
+    byte[] buf;
 
     Block(String blockName, int size) {
       this.blockName = blockName;
