@@ -32,8 +32,6 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
@@ -42,20 +40,15 @@ import org.junit.rules.TemporaryFolder;
 
 import com.google.common.util.concurrent.AtomicLongMap;
 
-/**
- *
- */
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
+@SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 public class RFileMetricsTest {
 
   @Rule
   public TemporaryFolder tempFolder =
       new TemporaryFolder(new File(System.getProperty("user.dir") + "/target"));
 
-  static {
-    Logger.getLogger(org.apache.hadoop.io.compress.CodecPool.class).setLevel(Level.OFF);
-    Logger.getLogger(org.apache.hadoop.util.NativeCodeLoader.class).setLevel(Level.OFF);
-  }
-
   private TestRFile trf = null;
 
   @Before
@@ -526,20 +519,20 @@ public class RFileMetricsTest {
 
     for (int row = 0; row < 1100; row++) {
       String rs = String.format("%06x", row);
-      trf.writer.append(new Key(rs, fam1, "q4", "A", 42l), new Value("v".getBytes()));
-      trf.writer.append(new Key(rs, fam2, "q4", "A|B", 42l), new Value("v".getBytes()));
+      trf.writer.append(new Key(rs, fam1, "q4", "A", 42L), new Value("v".getBytes()));
+      trf.writer.append(new Key(rs, fam2, "q4", "A|B", 42L), new Value("v".getBytes()));
     }
 
     trf.writer.startDefaultLocalityGroup();
 
-    String vis[] = new String[] {"A", "A&B", "A|C", "B&C", "Boo"};
+    String[] vis = {"A", "A&B", "A|C", "B&C", "Boo"};
 
     int fam = 0;
     for (int row = 0; row < 1000; row++) {
       String rs = String.format("%06x", row);
       for (int v = 0; v < 5; v++) {
         String fs = String.format("%06x", fam++);
-        trf.writer.append(new Key(rs, fs, "q4", vis[v], 42l), new Value("v".getBytes()));
+        trf.writer.append(new Key(rs, fs, "q4", vis[v], 42L), new Value("v".getBytes()));
       }
     }
 
@@ -552,18 +545,18 @@ public class RFileMetricsTest {
     Map<String,Long> expected = new HashMap<>();
     Map<String,Long> expectedBlocks = new HashMap<>();
     for (String v : vis) {
-      expected.put(v, 1000l);
-      expectedBlocks.put(v, 71l);
+      expected.put(v, 1000L);
+      expectedBlocks.put(v, 71L);
     }
     assertEquals(expected, vmg.metric.get(null).asMap());
     assertEquals(expectedBlocks, vmg.blocks.get(null).asMap());
 
     expected.clear();
     expectedBlocks.clear();
-    expected.put("A", 1100l);
-    expected.put("A|B", 1100l);
-    expectedBlocks.put("A", 32l);
-    expectedBlocks.put("A|B", 32l);
+    expected.put("A", 1100L);
+    expected.put("A|B", 1100L);
+    expectedBlocks.put("A", 32L);
+    expectedBlocks.put("A|B", 32L);
     assertEquals(expected, vmg.metric.get("lg1").asMap());
     assertEquals(expectedBlocks, vmg.blocks.get("lg1").asMap());
 
