@@ -31,6 +31,7 @@ import java.util.List;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.client.IteratorSetting;
+import org.apache.accumulo.core.client.lexicoder.Encoder;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
@@ -48,7 +49,7 @@ import org.apache.accumulo.core.iterators.LongCombiner.VarLenEncoder;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.SortedMapIterator;
 import org.apache.accumulo.core.iterators.TypedValueCombiner;
-import org.apache.accumulo.core.iterators.TypedValueCombiner.Encoder;
+import org.apache.accumulo.core.iterators.ValueFormatException;
 import org.apache.accumulo.core.iterators.system.MultiIterator;
 import org.apache.hadoop.io.Text;
 import org.apache.log4j.Logger;
@@ -121,9 +122,9 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that do not aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -186,9 +187,9 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -248,13 +249,13 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     // keys that do not aggregate
-    newKeyValue(tm1, 2, 2, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 2, 2, 1, 2, false, 3l, encoder);
+    newKeyValue(tm1, 2, 2, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 2, 2, 1, 2, false, 3L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -314,13 +315,13 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     // keys that do not aggregate
-    newKeyValue(tm1, 2, 2, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 2, 2, 1, 2, false, 3l, encoder);
+    newKeyValue(tm1, 2, 2, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 2, 2, 1, 2, false, 3L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -382,16 +383,16 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that do not aggregate
-    newKeyValue(tm1, 0, 0, 1, 1, false, 7l, encoder);
+    newKeyValue(tm1, 0, 0, 1, 1, false, 7L, encoder);
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     // keys that do not aggregate
-    newKeyValue(tm1, 2, 2, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 2, 2, 1, 2, false, 3l, encoder);
+    newKeyValue(tm1, 2, 2, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 2, 2, 1, 2, false, 3L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -485,13 +486,13 @@ public class CombinerTest {
     // the exact same keys w/ different values
 
     TreeMap<Key,Value> tm1 = new TreeMap<>();
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
 
     TreeMap<Key,Value> tm2 = new TreeMap<>();
-    newKeyValue(tm2, 1, 1, 1, 1, false, 3l, encoder);
+    newKeyValue(tm2, 1, 1, 1, 1, false, 3L, encoder);
 
     TreeMap<Key,Value> tm3 = new TreeMap<>();
-    newKeyValue(tm3, 1, 1, 1, 1, false, 4l, encoder);
+    newKeyValue(tm3, 1, 1, 1, 1, false, 4L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -519,9 +520,9 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 2l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 2L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -547,9 +548,9 @@ public class CombinerTest {
 
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
-    newKeyValue(tm1, 1, 1, 1, 2, true, 0l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 4l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 4, false, 3l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, true, 0L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 4L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 4, false, 3L, encoder);
 
     Combiner ai = new SummingCombiner();
 
@@ -574,7 +575,7 @@ public class CombinerTest {
     assertFalse(ai.hasTop());
 
     tm1 = new TreeMap<>();
-    newKeyValue(tm1, 1, 1, 1, 2, true, 0l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, true, 0L, encoder);
     ai = new SummingCombiner();
     ai.init(new SortedMapIterator(tm1), is.getOptions(), SCAN_IE);
 
@@ -643,9 +644,9 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, 4l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, 3l, encoder);
-    newKeyValue(tm1, 1, 1, 1, 3, false, 2l, encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, 4L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, 3L, encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, 2L, encoder);
 
     Combiner ai = new MaxCombiner();
 
@@ -700,8 +701,8 @@ public class CombinerTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
     // keys that aggregate
-    newKeyValue(tm1, 1, 1, 1, 1, false, nal(1l, 2l), encoder);
-    newKeyValue(tm1, 1, 1, 1, 2, false, nal(3l, 4l, 5l), encoder);
+    newKeyValue(tm1, 1, 1, 1, 1, false, nal(1L, 2L), encoder);
+    newKeyValue(tm1, 1, 1, 1, 2, false, nal(3L, 4L, 5L), encoder);
     newKeyValue(tm1, 1, 1, 1, 3, false, nal(), encoder);
 
     Combiner ai = new SummingArrayCombiner();
@@ -715,7 +716,7 @@ public class CombinerTest {
 
     assertTrue(ai.hasTop());
     assertEquals(newKey(1, 1, 1, 3), ai.getTopKey());
-    assertBytesEqual(encoder.encode(nal(4l, 6l, 5l)), ai.getTopValue().get());
+    assertBytesEqual(encoder.encode(nal(4L, 6L, 5L)), ai.getTopValue().get());
 
     ai.next();
 
@@ -730,7 +731,7 @@ public class CombinerTest {
 
     assertTrue(ai.hasTop());
     assertEquals(newKey(1, 1, 1, 3), ai.getTopKey());
-    assertBytesEqual(encoder.encode(nal(4l, 6l, 5l)), ai.getTopValue().get());
+    assertBytesEqual(encoder.encode(nal(4L, 6L, 5L)), ai.getTopValue().get());
 
     ai.next();
 
@@ -745,7 +746,7 @@ public class CombinerTest {
 
     assertTrue(ai.hasTop());
     assertEquals(newKey(1, 1, 1, 3), ai.getTopKey());
-    assertBytesEqual(encoder.encode(nal(4l, 6l, 5l)), ai.getTopValue().get());
+    assertBytesEqual(encoder.encode(nal(4L, 6L, 5L)), ai.getTopValue().get());
 
     ai.next();
 
@@ -781,7 +782,7 @@ public class CombinerTest {
       return new ArrayList<>();
     }
 
-    public List<Long> decode(byte[] b, int offset, int len) {
+    public List<Long> decode() {
       return new ArrayList<>();
     }
 
@@ -798,26 +799,26 @@ public class CombinerTest {
   public void testEncoders() {
     TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, Long.MAX_VALUE);
     TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, Long.MIN_VALUE);
-    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, 42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, -42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, 0l);
+    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, 42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, -42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.FIXED_LEN_ENCODER, 0L);
     TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, Long.MAX_VALUE);
     TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, Long.MIN_VALUE);
-    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, 42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, -42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, 0l);
+    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, 42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, -42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.VAR_LEN_ENCODER, 0L);
     TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, Long.MAX_VALUE);
     TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, Long.MIN_VALUE);
-    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, 42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, -42l);
-    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, 0l);
+    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, 42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, -42L);
+    TypedValueCombiner.testEncoder(SummingCombiner.STRING_ENCODER, 0L);
 
     TypedValueCombiner.testEncoder(SummingArrayCombiner.FIXED_LONG_ARRAY_ENCODER,
-        Arrays.asList(0l, -1l, 10l, Long.MAX_VALUE, Long.MIN_VALUE));
+        Arrays.asList(0L, -1L, 10L, Long.MAX_VALUE, Long.MIN_VALUE));
     TypedValueCombiner.testEncoder(SummingArrayCombiner.VAR_LONG_ARRAY_ENCODER,
-        Arrays.asList(0l, -1l, 10l, Long.MAX_VALUE, Long.MIN_VALUE));
+        Arrays.asList(0L, -1L, 10L, Long.MAX_VALUE, Long.MIN_VALUE));
     TypedValueCombiner.testEncoder(SummingArrayCombiner.STRING_ARRAY_ENCODER,
-        Arrays.asList(0l, -1l, 10l, Long.MAX_VALUE, Long.MIN_VALUE));
+        Arrays.asList(0L, -1L, 10L, Long.MAX_VALUE, Long.MIN_VALUE));
   }
 
   @Test
@@ -894,7 +895,7 @@ public class CombinerTest {
 
     String logMsgs = writer.toString();
     if (expectedLog == null) {
-      assertTrue("Expected 0 length log message, but got : " + logMsgs, logMsgs.length() == 0);
+      assertEquals("Expected 0 length log message, but got : " + logMsgs, 0, logMsgs.length());
     } else {
       logMsgs = logMsgs.replace('\n', ' ');
       assertTrue("Did not match pattern [" + expectedLog + "] in [" + logMsgs + "]",
@@ -912,15 +913,15 @@ public class CombinerTest {
     IteratorEnvironment fullMajcIe = new CombinerIteratorEnvironment(IteratorScope.majc, true);
 
     // keys that aggregate
-    newKeyValue(input, 1, 1, 1, 1, false, 4l, encoder);
-    newKeyValue(input, 1, 1, 1, 2, true, 0l, encoder);
-    newKeyValue(input, 1, 1, 1, 3, false, 2l, encoder);
-    newKeyValue(input, 1, 1, 1, 4, false, 9l, encoder);
+    newKeyValue(input, 1, 1, 1, 1, false, 4L, encoder);
+    newKeyValue(input, 1, 1, 1, 2, true, 0L, encoder);
+    newKeyValue(input, 1, 1, 1, 3, false, 2L, encoder);
+    newKeyValue(input, 1, 1, 1, 4, false, 9L, encoder);
 
     TreeMap<Key,Value> expected = new TreeMap<>();
-    newKeyValue(expected, 1, 1, 1, 1, false, 4l, encoder);
-    newKeyValue(expected, 1, 1, 1, 2, true, 0l, encoder);
-    newKeyValue(expected, 1, 1, 1, 4, false, 11l, encoder);
+    newKeyValue(expected, 1, 1, 1, 1, false, 4L, encoder);
+    newKeyValue(expected, 1, 1, 1, 2, true, 0L, encoder);
+    newKeyValue(expected, 1, 1, 1, 4, false, 11L, encoder);
 
     runDeleteHandlingTest(input, input, true, paritalMajcIe);
     runDeleteHandlingTest(input, expected, true, fullMajcIe);
@@ -936,4 +937,51 @@ public class CombinerTest {
     runDeleteHandlingTest(input, expected, null, fullMajcIe,
         ".*ERROR.*SummingCombiner.*ACCUMULO-2232.*");
   }
+
+  /**
+   * Tests the Lossy option will ignore errors in TypedValueCombiner. Uses SummingArrayCombiner to
+   * generate error.
+   */
+  @Test
+  public void testLossyOption() throws IOException {
+    Encoder<List<Long>> encoder = new SummingArrayCombiner.VarLongArrayEncoder();
+
+    TreeMap<Key,Value> tm1 = new TreeMap<>();
+
+    // keys that aggregate
+    tm1.put(newKey(1, 1, 1, 1, false), new Value("badValue"));
+    newKeyValue(tm1, 1, 1, 1, 2, false, nal(3L, 4L, 5L), encoder);
+    newKeyValue(tm1, 1, 1, 1, 3, false, nal(), encoder);
+
+    SummingArrayCombiner summingArrayCombiner = new SummingArrayCombiner();
+    IteratorSetting iteratorSetting = new IteratorSetting(1, SummingArrayCombiner.class);
+    SummingArrayCombiner.setEncodingType(iteratorSetting, SummingArrayCombiner.Type.VARLEN);
+    Combiner.setColumns(iteratorSetting,
+        Collections.singletonList(new IteratorSetting.Column("cf001")));
+
+    // lossy = true so ignore bad value
+    TypedValueCombiner.setLossyness(iteratorSetting, true);
+    assertTrue(summingArrayCombiner.validateOptions(iteratorSetting.getOptions()));
+
+    summingArrayCombiner.init(new SortedMapIterator(tm1), iteratorSetting.getOptions(), SCAN_IE);
+    summingArrayCombiner.seek(new Range(), EMPTY_COL_FAMS, false);
+
+    assertTrue(summingArrayCombiner.hasTop());
+    assertEquals(newKey(1, 1, 1, 3), summingArrayCombiner.getTopKey());
+    assertBytesEqual(encoder.encode(nal(3L, 4L, 5L)), summingArrayCombiner.getTopValue().get());
+
+    summingArrayCombiner.next();
+
+    assertFalse(summingArrayCombiner.hasTop());
+
+    // lossy = false throw error for bad value
+    TypedValueCombiner.setLossyness(iteratorSetting, false);
+    assertTrue(summingArrayCombiner.validateOptions(iteratorSetting.getOptions()));
+
+    summingArrayCombiner.init(new SortedMapIterator(tm1), iteratorSetting.getOptions(), SCAN_IE);
+    try {
+      summingArrayCombiner.seek(new Range(), EMPTY_COL_FAMS, false);
+      fail("ValueFormatException should have been thrown");
+    } catch (ValueFormatException e) {}
+  }
 }
