@@ -20,6 +20,7 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
+import java.security.SecureRandom;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
@@ -68,7 +69,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testAllRowsFullSlice() throws Exception {
+  public void testAllRowsFullSlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     loadKvs(foundKvs, EMPTY_OPTS, INFINITY);
     for (int i = 0; i < LR_DIM; i++) {
@@ -82,7 +83,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testSingleRowFullSlice() throws Exception {
+  public void testSingleRowFullSlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     int rowId = LR_DIM / 2;
     loadKvs(foundKvs, EMPTY_OPTS, Range.exact(new Text(LONG_LEX.encode((long) rowId))));
@@ -103,7 +104,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testAllRowsSlice() throws Exception {
+  public void testAllRowsSlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = 20;
     long sliceMinCq = 30;
@@ -136,7 +137,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testSingleColumnSlice() throws Exception {
+  public void testSingleColumnSlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = 20;
     long sliceMinCq = 20;
@@ -165,7 +166,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testSingleColumnSliceByExclude() throws Exception {
+  public void testSingleColumnSliceByExclude() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = 20;
     long sliceMinCq = 20;
@@ -196,7 +197,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testAllCfsCqSlice() throws Exception {
+  public void testAllCfsCqSlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCq = 10;
     long sliceMaxCq = 30;
@@ -221,7 +222,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testSliceCfsAllCqs() throws Exception {
+  public void testSliceCfsAllCqs() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = 10;
     long sliceMaxCf = 30;
@@ -246,7 +247,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testEmptySlice() throws Exception {
+  public void testEmptySlice() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = LR_DIM + 1;
     long sliceMinCq = LR_DIM + 1;
@@ -307,7 +308,7 @@ public abstract class TestCfCqSlice {
   }
 
   @Test
-  public void testSeekMinExclusive() throws Exception {
+  public void testSeekMinExclusive() {
     boolean[][][] foundKvs = new boolean[LR_DIM][LR_DIM][LR_DIM];
     long sliceMinCf = 20;
     long sliceMinCq = 30;
@@ -323,7 +324,7 @@ public abstract class TestCfCqSlice {
     opts.put(CfCqSliceOpts.OPT_MIN_CQ, new String(LONG_LEX.encode(sliceMinCq), UTF_8));
     opts.put(CfCqSliceOpts.OPT_MAX_CF, new String(LONG_LEX.encode(sliceMaxCf), UTF_8));
     opts.put(CfCqSliceOpts.OPT_MAX_CQ, new String(LONG_LEX.encode(sliceMaxCq), UTF_8));
-    Range startsAtMinCf = new Range(new Key(LONG_LEX.encode(0l), LONG_LEX.encode(sliceMinCf),
+    Range startsAtMinCf = new Range(new Key(LONG_LEX.encode(0L), LONG_LEX.encode(sliceMinCf),
         LONG_LEX.encode(sliceMinCq), new byte[] {}, Long.MAX_VALUE), null);
     loadKvs(foundKvs, opts, startsAtMinCf);
     for (int i = 0; i < LR_DIM; i++) {
@@ -376,7 +377,7 @@ public abstract class TestCfCqSlice {
       skvi.init(parent, options, null);
       skvi.seek(range, EMPTY_CF_SET, false);
 
-      Random random = new Random();
+      Random random = new SecureRandom();
 
       while (skvi.hasTop()) {
         Key k = skvi.getTopKey();
