@@ -20,6 +20,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -34,7 +35,6 @@ import java.util.SortedMap;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.client.IteratorSetting;
-import org.apache.accumulo.core.client.impl.BaseIteratorEnvironment;
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
@@ -67,7 +67,7 @@ public class TransformingIteratorTest {
   private TreeMap<Key,Value> data = new TreeMap<>();
 
   @Before
-  public void createData() throws Exception {
+  public void createData() {
     data.clear();
     generateRow(data, "row1");
     generateRow(data, "row2");
@@ -163,7 +163,7 @@ public class TransformingIteratorTest {
   public void testVisbilityFiltering() throws Exception {
     // Should return nothing since we produced visibilities that can't be seen
     setUpTransformIterator(BadVisKeyTransformingIterator.class);
-    checkExpected(new TreeMap<Key,Value>());
+    checkExpected(new TreeMap<>());
 
     // Do a "reverse" on the visibility (vis1 -> vis2, vis2 -> vis3, vis3 -> vis0)
     // Source data has vis1, vis2, vis3 so vis0 is a new one that is introduced.
@@ -188,11 +188,11 @@ public class TransformingIteratorTest {
     // illegal visibility created by transform should be filtered on scan, even if evaluation is
     // done
     setUpTransformIterator(IllegalVisKeyTransformingIterator.class, false);
-    checkExpected(new TreeMap<Key,Value>());
+    checkExpected(new TreeMap<>());
 
-    // ensure illegal vis is supressed when evaluations is done
+    // ensure illegal vis is suppressed when evaluations is done
     setUpTransformIterator(IllegalVisKeyTransformingIterator.class);
-    checkExpected(new TreeMap<Key,Value>());
+    checkExpected(new TreeMap<>());
   }
 
   @Test
@@ -240,11 +240,11 @@ public class TransformingIteratorTest {
     // Set a range that's after all data and make sure we don't
     // somehow return something.
     setUpTransformIterator(ColFamReversingKeyTransformingIterator.class);
-    checkExpected(new Range(new Key("row4"), null), new TreeMap<Key,Value>());
+    checkExpected(new Range(new Key("row4"), null), new TreeMap<>());
   }
 
   @Test
-  public void testReplaceKeyParts() throws Exception {
+  public void testReplaceKeyParts() {
     TransformingIterator it = new IdentityKeyTransformingIterator();
     Key originalKey = new Key("r", "cf", "cq", "cv", 42);
     originalKey.setDeleted(true);
@@ -308,7 +308,7 @@ public class TransformingIteratorTest {
         new Text[] {new Text("foo"), new Text("dog"), new Text("cat")});
     iiIter.init(titer, iicfg.getOptions(), null);
 
-    iiIter.seek(new Range(), new HashSet<ByteSequence>(), false);
+    iiIter.seek(new Range(), new HashSet<>(), false);
 
     assertTrue(iiIter.hasTop());
     Key docKey = iiIter.getTopKey();
@@ -337,8 +337,8 @@ public class TransformingIteratorTest {
 
   @Test
   public void testCompactionDoesntFilterVisibilities() throws Exception {
-    // In scan mode, this should return nothing since it produces visibilites
-    // the user can't see. In compaction mode, however, the visibilites
+    // In scan mode, this should return nothing since it produces visibilities
+    // the user can't see. In compaction mode, however, the visibilities
     // should still show up.
     setUpTransformIterator(BadVisCompactionKeyTransformingIterator.class);
 
@@ -366,8 +366,8 @@ public class TransformingIteratorTest {
   public void testCompactionAndIllegalVisibility() throws Exception {
     setUpTransformIterator(IllegalVisCompactionKeyTransformingIterator.class);
     try {
-      checkExpected(new TreeMap<Key,Value>());
-      assertTrue(false);
+      checkExpected(new TreeMap<>());
+      fail();
     } catch (Exception e) {
 
     }
@@ -377,7 +377,7 @@ public class TransformingIteratorTest {
   public void testDupes() throws Exception {
     setUpTransformIterator(DupeTransformingIterator.class);
 
-    titer.seek(new Range(), new HashSet<ByteSequence>(), false);
+    titer.seek(new Range(), new HashSet<>(), false);
 
     int count = 0;
     while (titer.hasTop()) {
@@ -386,7 +386,7 @@ public class TransformingIteratorTest {
       assertEquals("cf1", key.getColumnFamily().toString());
       assertEquals("cq1", key.getColumnQualifier().toString());
       assertEquals("", key.getColumnVisibility().toString());
-      assertEquals(5l, key.getTimestamp());
+      assertEquals(5L, key.getTimestamp());
       count++;
     }
 
@@ -411,14 +411,14 @@ public class TransformingIteratorTest {
     opts.put(TransformingIterator.MAX_BUFFER_SIZE_OPT, "A,B");
     try {
       ti.validateOptions(opts);
-      assertFalse(true);
+      fail();
     } catch (IllegalArgumentException e) {}
 
     opts.clear();
     opts.put(TransformingIterator.AUTH_OPT, Authorizations.HEADER + "~~~~");
     try {
       ti.validateOptions(opts);
-      assertFalse(true);
+      fail();
     } catch (IllegalArgumentException e) {}
 
   }
@@ -431,7 +431,7 @@ public class TransformingIteratorTest {
   }
 
   private void checkExpected(Range range, TreeMap<Key,Value> expectedEntries) throws IOException {
-    checkExpected(range, new HashSet<ByteSequence>(), expectedEntries);
+    checkExpected(range, new HashSet<>(), expectedEntries);
   }
 
   private void checkExpected(TreeMap<Key,Value> expectedEntries, String... fa) throws IOException {
@@ -580,7 +580,7 @@ public class TransformingIteratorTest {
 
   }
 
-  public static abstract class ReversingKeyTransformingIterator extends TransformingIterator {
+  public abstract static class ReversingKeyTransformingIterator extends TransformingIterator {
 
     @Override
     protected void transformRange(SortedKeyValueIterator<Key,Value> input, KVBuffer output)
@@ -744,7 +744,7 @@ public class TransformingIteratorTest {
     }
   }
 
-  private static class MajCIteratorEnvironmentAdapter extends BaseIteratorEnvironment {
+  private static class MajCIteratorEnvironmentAdapter implements IteratorEnvironment {
     @Override
     public IteratorScope getIteratorScope() {
       return IteratorScope.majc;
