@@ -16,13 +16,15 @@
  */
 package org.apache.accumulo.server.fs;
 
+import java.security.SecureRandom;
 import java.util.Random;
 
 public class RandomVolumeChooser implements VolumeChooser {
-  private final Random random = new Random();
+  protected final Random random = new SecureRandom();
 
   @Override
-  public String choose(VolumeChooserEnvironment env, String[] options) {
+  public String choose(VolumeChooserEnvironment env, String[] options)
+      throws VolumeChooserException {
     return options[random.nextInt(options.length)];
   }
 }
