@@ -19,6 +19,7 @@ package org.apache.accumulo.server.fs;
 import static java.util.Objects.requireNonNull;
 
 import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.net.URI;
 import java.util.Collection;
 import java.util.Collections;
@@ -31,17 +32,16 @@ import java.util.Map.Entry;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.file.rfile.RFile;
-import org.apache.accumulo.core.util.CachedConfiguration;
 import org.apache.accumulo.core.volume.NonConfiguredVolume;
 import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.core.volume.VolumeConfiguration;
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.NotImplementedException;
-import org.apache.commons.lang.StringUtils;
+import org.apache.accumulo.server.fs.VolumeChooser.VolumeChooserException;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.ContentSummary;
 import org.apache.hadoop.fs.CreateFlag;
@@ -57,7 +57,6 @@ import org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Optional;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.Multimap;
 
@@ -71,18 +70,31 @@ public class VolumeManagerImpl implements VolumeManager {
   private final Multimap<URI,Volume> volumesByFileSystemUri;
   private final Volume defaultVolume;
   private final VolumeChooser chooser;
+  private final Configuration hadoopConf;
 
   protected VolumeManagerImpl(Map<String,Volume> volumes, Volume defaultVolume,
-      AccumuloConfiguration conf) {
+      AccumuloConfiguration conf, Configuration hadoopConf) {
     this.volumesByName = volumes;
     this.defaultVolume = defaultVolume;
     // We may have multiple directories used in a single FileSystem (e.g. testing)
     this.volumesByFileSystemUri = HashMultimap.create();
     invertVolumesByFileSystem(volumesByName, volumesByFileSystemUri);
     ensureSyncIsEnabled();
-    // Keep in sync with default type in the property definition.
-    chooser = Property.createInstanceFromPropertyName(conf, Property.GENERAL_VOLUME_CHOOSER,
-        VolumeChooser.class, new PerTableVolumeChooser());
+    // if they supplied a property and we cannot load it, then fail hard
+    VolumeChooser chooser1;
+    try {
+      chooser1 = Property.createInstanceFromPropertyName(conf, Property.GENERAL_VOLUME_CHOOSER,
+          VolumeChooser.class, null);
+    } catch (NullPointerException npe) {
+      chooser1 = null;
+      // null chooser handled below
+    }
+    if (chooser1 == null) {
+      throw new VolumeChooserException(
+          "Failed to load volume chooser specified by " + Property.GENERAL_VOLUME_CHOOSER);
+    }
+    chooser = chooser1;
+    this.hadoopConf = hadoopConf;
   }
 
   private void invertVolumesByFileSystem(Map<String,Volume> forward,
@@ -94,14 +106,15 @@ public class VolumeManagerImpl implements VolumeManager {
 
   public static org.apache.accumulo.server.fs.VolumeManager getLocal(String localBasePath)
       throws IOException {
-    AccumuloConfiguration accConf = DefaultConfiguration.getDefaultConfiguration();
-    Volume defaultLocalVolume = VolumeConfiguration
-        .create(FileSystem.getLocal(CachedConfiguration.getInstance()), localBasePath);
+    AccumuloConfiguration accConf = DefaultConfiguration.getInstance();
+    Configuration hadoopConf = new Configuration();
+    Volume defaultLocalVolume =
+        VolumeConfiguration.create(FileSystem.getLocal(hadoopConf), localBasePath);
 
     // The default volume gets placed in the map, but local filesystem is only used for testing
     // purposes
     return new VolumeManagerImpl(Collections.singletonMap(DEFAULT, defaultLocalVolume),
-        defaultLocalVolume, accConf);
+        defaultLocalVolume, accConf, hadoopConf);
   }
 
   @Override
@@ -181,7 +194,7 @@ public class VolumeManagerImpl implements VolumeManager {
     blockSize = correctBlockSize(fs.getConf(), blockSize);
     bufferSize = correctBufferSize(fs.getConf(), bufferSize);
     EnumSet<CreateFlag> set = EnumSet.of(CreateFlag.SYNC_BLOCK, CreateFlag.CREATE);
-    log.debug("creating " + logPath + " with CreateFlag set: " + set);
+    log.debug("creating {} with CreateFlag set: {}", logPath, set);
     try {
       return fs.create(logPath, FsPermission.getDefault(), set, bufferSize, replication, blockSize,
           null);
@@ -227,9 +240,8 @@ public class VolumeManagerImpl implements VolumeManager {
           synchronized (WARNED_ABOUT_SYNCONCLOSE) {
             if (!WARNED_ABOUT_SYNCONCLOSE.contains(entry.getKey())) {
               WARNED_ABOUT_SYNCONCLOSE.add(entry.getKey());
-              log.warn(DFS_DATANODE_SYNCONCLOSE + " set to false in"
-                  + " hdfs-site.xml: data loss is possible on hard system reset or"
-                  + " power loss");
+              log.warn("{} set to false in hdfs-site.xml: data loss is possible"
+                  + " on hard system reset or power loss", DFS_DATANODE_SYNCONCLOSE);
             }
           }
         }
@@ -251,22 +263,22 @@ public class VolumeManagerImpl implements VolumeManager {
   public Volume getVolumeByPath(Path path) {
     if (path.toString().contains(":")) {
       try {
-        FileSystem desiredFs = path.getFileSystem(CachedConfiguration.getInstance());
+        FileSystem desiredFs = path.getFileSystem(hadoopConf);
         URI desiredFsUri = desiredFs.getUri();
         Collection<Volume> candidateVolumes = volumesByFileSystemUri.get(desiredFsUri);
-        if (null != candidateVolumes) {
+        if (candidateVolumes != null) {
           for (Volume candidateVolume : candidateVolumes) {
             if (candidateVolume.isValidPath(path)) {
               return candidateVolume;
             }
           }
         } else {
-          log.debug("Could not determine volume for Path: " + path);
+          log.debug("Could not determine volume for Path: {}", path);
         }
 
         return new NonConfiguredVolume(desiredFs);
       } catch (IOException ex) {
-        throw new RuntimeException(ex);
+        throw new UncheckedIOException(ex);
       }
     }
 
@@ -304,7 +316,7 @@ public class VolumeManagerImpl implements VolumeManager {
     FileSystem source = srcVolume.getFileSystem();
     FileSystem dest = destVolume.getFileSystem();
     if (source != dest) {
-      throw new NotImplementedException(
+      throw new UnsupportedOperationException(
           "Cannot rename files across volumes: " + path + " -> " + newPath);
     }
     return source.rename(path, newPath);
@@ -323,21 +335,7 @@ public class VolumeManagerImpl implements VolumeManager {
     return v.getFileSystem().getDefaultReplication(path);
   }
 
-  @Override
-  public boolean isFile(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().isFile(path);
-  }
-
-  public static VolumeManager get() throws IOException {
-    AccumuloConfiguration conf = SiteConfiguration.getInstance();
-    return get(conf);
-  }
-
-  static private final String DEFAULT = "";
-
-  public static VolumeManager get(AccumuloConfiguration conf) throws IOException {
-    return get(conf, CachedConfiguration.getInstance());
-  }
+  private static final String DEFAULT = "";
 
   public static VolumeManager get(AccumuloConfiguration conf, final Configuration hadoopConf)
       throws IOException {
@@ -361,8 +359,8 @@ public class VolumeManagerImpl implements VolumeManager {
       }
     }
 
-    return new VolumeManagerImpl(volumes, VolumeConfiguration.getDefaultVolume(hadoopConf, conf),
-        conf);
+    Volume defaultVolume = VolumeConfiguration.getDefaultVolume(hadoopConf, conf);
+    return new VolumeManagerImpl(volumes, defaultVolume, conf, hadoopConf);
   }
 
   @Override
@@ -393,14 +391,14 @@ public class VolumeManagerImpl implements VolumeManager {
     // TODO sanity check col fam
     String relPath = key.getColumnQualifierData().toString();
     byte[] tableId = KeyExtent.tableOfMetadataRow(key.getRow());
-    return getFullPath(new String(tableId), relPath);
+    return getFullPath(TableId.of(new String(tableId)), relPath);
   }
 
   @Override
   public Path matchingFileSystem(Path source, String[] options) {
     try {
-      if (ViewFSUtils.isViewFS(source, CachedConfiguration.getInstance())) {
-        return ViewFSUtils.matchingFileSystem(source, options, CachedConfiguration.getInstance());
+      if (ViewFSUtils.isViewFS(source, hadoopConf)) {
+        return ViewFSUtils.matchingFileSystem(source, options, hadoopConf);
       }
     } catch (IOException e) {
       throw new RuntimeException(e);
@@ -420,14 +418,14 @@ public class VolumeManagerImpl implements VolumeManager {
   }
 
   @Override
-  public Path getFullPath(String tableId, String path) {
+  public Path getFullPath(TableId tableId, String path) {
     if (path.contains(":"))
       return new Path(path);
 
     if (path.startsWith("../"))
       path = path.substring(2);
     else if (path.startsWith("/"))
-      path = "/" + tableId + path;
+      path = "/" + tableId.canonical() + path;
     else
       throw new IllegalArgumentException("Unexpected path prefix " + path);
 
@@ -454,7 +452,7 @@ public class VolumeManagerImpl implements VolumeManager {
     // ACCUMULO-2974 To ensure that a proper absolute path is created, the caller needs to include
     // the table ID
     // in the relative path. Fail when this doesn't appear to happen.
-    if (FileType.TABLE == fileType) {
+    if (fileType == FileType.TABLE) {
       // Trailing slash doesn't create an additional element
       String[] pathComponents = StringUtils.split(path, Path.SEPARATOR_CHAR);
 
@@ -484,20 +482,17 @@ public class VolumeManagerImpl implements VolumeManager {
     return getVolumeByPath(dir).getFileSystem().getContentSummary(dir);
   }
 
-  // Only used as a fall back if the configured chooser misbehaves.
-  private final VolumeChooser failsafeChooser = new RandomVolumeChooser();
-
   @Override
-  public String choose(Optional<String> tableId, String[] options) {
-    final VolumeChooserEnvironment env = new VolumeChooserEnvironment(tableId);
-    final String choice = chooser.choose(env, options);
+  public String choose(VolumeChooserEnvironment env, String[] options) {
+    final String choice;
+    choice = chooser.choose(env, options);
+
     if (!(ArrayUtils.contains(options, choice))) {
-      log.error("The configured volume chooser, '" + chooser.getClass()
-          + "', or one of its delegates returned a volume not in the set of"
-          + " options provided; will continue by relying on a RandomVolumeChooser."
-          + " You should investigate and correct the named chooser.");
-      return failsafeChooser.choose(env, options);
+      String msg = "The configured volume chooser, '" + chooser.getClass()
+          + "', or one of its delegates returned a volume not in the set of options provided";
+      throw new VolumeChooserException(msg);
     }
+
     return choice;
   }
 
