@@ -31,31 +31,23 @@ import java.util.Map.Entry;
 import java.util.Objects;
 import java.util.Set;
 import java.util.SortedMap;
+import java.util.function.Function;
 
-import org.apache.accumulo.core.client.IsolatedScanner;
-import org.apache.accumulo.core.client.RowIterator;
-import org.apache.accumulo.core.client.Scanner;
-import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
-import org.apache.accumulo.core.metadata.MetadataTable;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
-import org.apache.accumulo.core.security.Authorizations;
+import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.util.ComparablePair;
 import org.apache.accumulo.core.util.MapCounter;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.server.master.state.TServerInstance;
 import org.apache.accumulo.server.master.state.TabletMigration;
-import org.apache.commons.lang.mutable.MutableInt;
-import org.gaul.modernizer_maven_annotations.SuppressModernizer;
+import org.apache.commons.lang3.mutable.MutableInt;
 
-import com.google.common.base.Function;
 import com.google.common.collect.HashBasedTable;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.Iterators;
 import com.google.common.collect.Multimap;
-import com.google.common.collect.Table;
 
 /**
  * A balancer that evenly spreads groups of tablets across all tablet server. This balancer
@@ -70,24 +62,35 @@ import com.google.common.collect.Table;
  * To use this balancer you must extend it and implement {@link #getPartitioner()}. See
  * {@link RegexGroupBalancer} as an example.
  */
-
 public abstract class GroupBalancer extends TabletBalancer {
 
-  private final String tableId;
+  private final TableId tableId;
   private long lastRun = 0;
 
   /**
    * @return A function that groups tablets into named groups.
    */
-  @SuppressModernizer
   protected abstract Function<KeyExtent,String> getPartitioner();
 
-  public GroupBalancer(String tableId) {
+  public GroupBalancer(TableId tableId) {
     this.tableId = tableId;
   }
 
   protected Iterable<Pair<KeyExtent,Location>> getLocationProvider() {
-    return new MetadataLocationProvider();
+    return () -> {
+      try {
+        return TabletsMetadata.builder().forTable(tableId).fetchLocation().fetchPrev()
+            .build(context).stream().map(tm -> {
+              Location loc = Location.NONE;
+              if (tm.hasCurrent()) {
+                loc = new Location(new TServerInstance(tm.getLocation()));
+              }
+              return new Pair<>(tm.getExtent(), loc);
+            }).iterator();
+      } catch (Exception e) {
+        throw new RuntimeException(e);
+      }
+    };
   }
 
   /**
@@ -189,7 +192,7 @@ public abstract class GroupBalancer extends TabletBalancer {
     // possibly have 2 tablets from a group. Below is an illustration of an ideal balancing of extra
     // tablets. To understand the illustration, the first column
     // shows tserver T1 with 2 tablets from G1, 1 tablet from G2, and two tablets from G3. EE means
-    // empty, put it there so eclipse formating would not mess up
+    // empty, put it there so eclipse formatting would not mess up
     // table.
     //
     // T1 | T2 | T3 | T4 | T5 | T6
@@ -251,9 +254,9 @@ public abstract class GroupBalancer extends TabletBalancer {
 
     int totalExtra = 0;
     for (String group : groupCounts.keySet()) {
-      long groupCount = groupCounts.get(group);
+      int groupCount = groupCounts.getInt(group);
       totalExtra += groupCount % current.size();
-      expectedCounts.put(group, (int) (groupCount / current.size()));
+      expectedCounts.put(group, (groupCount / current.size()));
     }
 
     // The number of extra tablets from all groups that each tserver must have.
@@ -469,7 +472,7 @@ public abstract class GroupBalancer extends TabletBalancer {
 
   private static class Moves {
 
-    private final Table<TServerInstance,String,List<Move>> moves = HashBasedTable.create();
+    private final HashBasedTable<TServerInstance,String,List<Move>> moves = HashBasedTable.create();
     private int totalMoves = 0;
 
     public void move(String group, int num, TserverGroupInfo src, TserverGroupInfo dest) {
@@ -517,7 +520,7 @@ public abstract class GroupBalancer extends TabletBalancer {
 
   private void balanceExtraExtra(Map<TServerInstance,TserverGroupInfo> tservers, int maxExtraGroups,
       Moves moves) {
-    Table<String,TServerInstance,TserverGroupInfo> surplusExtra = HashBasedTable.create();
+    HashBasedTable<String,TServerInstance,TserverGroupInfo> surplusExtra = HashBasedTable.create();
     for (TserverGroupInfo tgi : tservers.values()) {
       Map<String,Integer> extras = tgi.getExtras();
       if (extras.size() > maxExtraGroups) {
@@ -641,7 +644,7 @@ public abstract class GroupBalancer extends TabletBalancer {
   private void balanceExtraExpected(Map<TServerInstance,TserverGroupInfo> tservers,
       int expectedExtra, Moves moves) {
 
-    Table<String,TServerInstance,TserverGroupInfo> extraSurplus = HashBasedTable.create();
+    HashBasedTable<String,TServerInstance,TserverGroupInfo> extraSurplus = HashBasedTable.create();
 
     for (TserverGroupInfo tgi : tservers.values()) {
       Map<String,Integer> extras = tgi.getExtras();
@@ -773,48 +776,4 @@ public abstract class GroupBalancer extends TabletBalancer {
       }
     }
   }
-
-  @SuppressModernizer
-  static class LocationFunction
-      implements Function<Iterator<Entry<Key,Value>>,Pair<KeyExtent,Location>> {
-    @Override
-    public Pair<KeyExtent,Location> apply(Iterator<Entry<Key,Value>> input) {
-      Location loc = Location.NONE;
-      KeyExtent extent = null;
-      while (input.hasNext()) {
-        Entry<Key,Value> entry = input.next();
-        if (entry.getKey().getColumnFamily()
-            .equals(MetadataSchema.TabletsSection.CurrentLocationColumnFamily.NAME)) {
-          loc = new Location(
-              new TServerInstance(entry.getValue(), entry.getKey().getColumnQualifier()));
-        } else if (MetadataSchema.TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN
-            .hasColumns(entry.getKey())) {
-          extent = new KeyExtent(entry.getKey().getRow(), entry.getValue());
-        }
-      }
-
-      return new Pair<>(extent, loc);
-    }
-
-  }
-
-  class MetadataLocationProvider implements Iterable<Pair<KeyExtent,Location>> {
-
-    @Override
-    public Iterator<Pair<KeyExtent,Location>> iterator() {
-      try {
-        Scanner scanner = new IsolatedScanner(
-            context.getConnector().createScanner(MetadataTable.NAME, Authorizations.EMPTY));
-        scanner.fetchColumnFamily(MetadataSchema.TabletsSection.CurrentLocationColumnFamily.NAME);
-        MetadataSchema.TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.fetch(scanner);
-        scanner.setRange(MetadataSchema.TabletsSection.getRange(tableId));
-
-        RowIterator rowIter = new RowIterator(scanner);
-
-        return Iterators.transform(rowIter, new LocationFunction());
-      } catch (Exception e) {
-        throw new RuntimeException(e);
-      }
-    }
-  }
 }
