@@ -19,12 +19,13 @@ package org.apache.accumulo.server.master.state;
 import java.util.Collection;
 import java.util.Set;
 
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.master.thrift.MasterState;
 
 public interface CurrentState {
 
-  Set<String> onlineTables();
+  Set<TableId> onlineTables();
 
   Set<TServerInstance> onlineTabletServers();
 
