@@ -31,27 +31,24 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.Scanner;
+import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.SortedKeyIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.util.NamingThreadFactory;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
 import org.apache.accumulo.fate.util.LoggingRunnable;
 import org.apache.accumulo.fate.zookeeper.IZooReaderWriter;
-import org.apache.accumulo.server.AccumuloServerContext;
-import org.apache.accumulo.server.client.HdfsZooInstance;
-import org.apache.accumulo.server.conf.ServerConfigurationFactory;
+import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.util.MetadataTableUtil;
-import org.apache.accumulo.server.zookeeper.ZooReaderWriter;
-import org.apache.commons.collections.map.LRUMap;
+import org.apache.commons.collections4.map.LRUMap;
 import org.apache.hadoop.io.Text;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -60,7 +57,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
 
   private static final Logger log = LoggerFactory.getLogger(ProblemReports.class);
 
-  private final LRUMap problemReports = new LRUMap(1000);
+  private final LRUMap<ProblemReport,Long> problemReports = new LRUMap<>(1000);
 
   /**
    * use a thread pool so that reporting a problem never blocks
@@ -70,11 +67,11 @@ public class ProblemReports implements Iterable<ProblemReport> {
    * is reporting lots of problems, but problem reports can not be processed
    */
   private ExecutorService reportExecutor = new ThreadPoolExecutor(0, 1, 60, TimeUnit.SECONDS,
-      new LinkedBlockingQueue<Runnable>(500), new NamingThreadFactory("acu-problem-reporter"));
+      new LinkedBlockingQueue<>(500), new NamingThreadFactory("acu-problem-reporter"));
 
-  private final AccumuloServerContext context;
+  private final ServerContext context;
 
-  public ProblemReports(AccumuloServerContext context) {
+  public ProblemReports(ServerContext context) {
     this.context = context;
   }
 
@@ -93,19 +90,19 @@ public class ProblemReports implements Iterable<ProblemReport> {
       @Override
       public void run() {
 
-        log.debug("Filing problem report " + pr.getTableName() + " " + pr.getProblemType() + " "
-            + pr.getResource());
+        log.debug("Filing problem report {} {} {}", pr.getTableId(), pr.getProblemType(),
+            pr.getResource());
 
         try {
-          if (isMeta(pr.getTableName())) {
+          if (isMeta(pr.getTableId())) {
             // file report in zookeeper
-            pr.saveToZooKeeper();
+            pr.saveToZooKeeper(context);
           } else {
             // file report in metadata table
             pr.saveToMetadataTable(context);
           }
         } catch (Exception e) {
-          log.error("Failed to file problem report " + pr.getTableName() + " " + pr.getProblemType()
+          log.error("Failed to file problem report " + pr.getTableId() + " " + pr.getProblemType()
               + " " + pr.getResource(), e);
         }
       }
@@ -115,20 +112,20 @@ public class ProblemReports implements Iterable<ProblemReport> {
     try {
       reportExecutor.execute(new LoggingRunnable(log, r));
     } catch (RejectedExecutionException ree) {
-      log.error("Failed to report problem {} {} {} {}", pr.getTableName(), pr.getProblemType(),
+      log.error("Failed to report problem {} {} {} {}", pr.getTableId(), pr.getProblemType(),
           pr.getResource(), ree.getMessage());
     }
 
   }
 
-  public void printProblems() throws Exception {
+  public void printProblems() {
     for (ProblemReport pr : this) {
-      System.out.println(pr.getTableName() + " " + pr.getProblemType() + " " + pr.getResource()
-          + " " + pr.getException());
+      System.out.println(pr.getTableId() + " " + pr.getProblemType() + " " + pr.getResource() + " "
+          + pr.getException());
     }
   }
 
-  public void deleteProblemReport(String table, ProblemType pType, String resource) {
+  public void deleteProblemReport(TableId table, ProblemType pType, String resource) {
     final ProblemReport pr = new ProblemReport(table, pType, resource, null);
 
     Runnable r = new Runnable() {
@@ -136,15 +133,15 @@ public class ProblemReports implements Iterable<ProblemReport> {
       @Override
       public void run() {
         try {
-          if (isMeta(pr.getTableName())) {
+          if (isMeta(pr.getTableId())) {
             // file report in zookeeper
-            pr.removeFromZooKeeper();
+            pr.removeFromZooKeeper(context);
           } else {
             // file report in metadata table
             pr.removeFromMetadataTable(context);
           }
         } catch (Exception e) {
-          log.error("Failed to delete problem report {} {} {}", pr.getTableName(),
+          log.error("Failed to delete problem report {} {} {}", pr.getTableId(),
               pr.getProblemType(), pr.getResource(), e);
         }
       }
@@ -153,25 +150,24 @@ public class ProblemReports implements Iterable<ProblemReport> {
     try {
       reportExecutor.execute(new LoggingRunnable(log, r));
     } catch (RejectedExecutionException ree) {
-      log.error("Failed to delete problem report {} {} {} {}", pr.getTableName(),
-          pr.getProblemType(), pr.getResource(), ree.getMessage());
+      log.error("Failed to delete problem report {} {} {} {}", pr.getTableId(), pr.getProblemType(),
+          pr.getResource(), ree.getMessage());
     }
   }
 
   private static ProblemReports instance;
 
-  public void deleteProblemReports(String table) throws Exception {
+  public void deleteProblemReports(TableId table) throws Exception {
 
     if (isMeta(table)) {
       Iterator<ProblemReport> pri = iterator(table);
       while (pri.hasNext()) {
-        pri.next().removeFromZooKeeper();
+        pri.next().removeFromZooKeeper(context);
       }
       return;
     }
 
-    Connector connector = context.getConnector();
-    Scanner scanner = connector.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
+    Scanner scanner = context.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
     scanner.addScanIterator(new IteratorSetting(1, "keys-only", SortedKeyIterator.class));
 
     scanner.setRange(new Range(new Text("~err_" + table)));
@@ -188,16 +184,16 @@ public class ProblemReports implements Iterable<ProblemReport> {
       MetadataTableUtil.getMetadataTable(context).update(delMut);
   }
 
-  private static boolean isMeta(String tableId) {
+  private static boolean isMeta(TableId tableId) {
     return tableId.equals(MetadataTable.ID) || tableId.equals(RootTable.ID);
   }
 
-  public Iterator<ProblemReport> iterator(final String table) {
+  public Iterator<ProblemReport> iterator(final TableId table) {
     try {
 
       return new Iterator<ProblemReport>() {
 
-        IZooReaderWriter zoo = ZooReaderWriter.getInstance();
+        IZooReaderWriter zoo = context.getZooReaderWriter();
         private int iter1Count = 0;
         private Iterator<String> iter1;
 
@@ -206,8 +202,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
             try {
               List<String> children;
               if (table == null || isMeta(table)) {
-                children =
-                    zoo.getChildren(ZooUtil.getRoot(context.getInstance()) + Constants.ZPROBLEMS);
+                children = zoo.getChildren(context.getZooKeeperRoot() + Constants.ZPROBLEMS);
               } else {
                 children = Collections.emptyList();
               }
@@ -226,9 +221,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
           if (iter2 == null) {
             try {
               if ((table == null || !isMeta(table)) && iter1Count == 0) {
-                Connector connector = context.getConnector();
-                Scanner scanner = connector.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
-
+                Scanner scanner = context.createScanner(MetadataTable.NAME, Authorizations.EMPTY);
                 scanner.setTimeout(3, TimeUnit.SECONDS);
 
                 if (table == null) {
@@ -256,12 +249,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
           if (getIter1().hasNext()) {
             return true;
           }
-
-          if (getIter2().hasNext()) {
-            return true;
-          }
-
-          return false;
+          return getIter2().hasNext();
         }
 
         @Override
@@ -269,7 +257,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
           try {
             if (getIter1().hasNext()) {
               iter1Count++;
-              return ProblemReport.decodeZooKeeperEntry(getIter1().next());
+              return ProblemReport.decodeZooKeeperEntry(context, getIter1().next());
             }
 
             if (getIter2().hasNext()) {
@@ -299,7 +287,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
     return iterator(null);
   }
 
-  public static synchronized ProblemReports getInstance(AccumuloServerContext context) {
+  public static synchronized ProblemReports getInstance(ServerContext context) {
     if (instance == null) {
       instance = new ProblemReports(context);
     }
@@ -307,21 +295,20 @@ public class ProblemReports implements Iterable<ProblemReport> {
     return instance;
   }
 
-  public static void main(String args[]) throws Exception {
-    getInstance(
-        new AccumuloServerContext(new ServerConfigurationFactory(HdfsZooInstance.getInstance())))
-        .printProblems();
+  public static void main(String[] args) {
+    ServerContext context = new ServerContext(new SiteConfiguration());
+    getInstance(context).printProblems();
   }
 
-  public Map<String,Map<ProblemType,Integer>> summarize() {
+  public Map<TableId,Map<ProblemType,Integer>> summarize() {
 
-    TreeMap<String,Map<ProblemType,Integer>> summary = new TreeMap<>();
+    TreeMap<TableId,Map<ProblemType,Integer>> summary = new TreeMap<>();
 
     for (ProblemReport pr : this) {
-      Map<ProblemType,Integer> tableProblems = summary.get(pr.getTableName());
+      Map<ProblemType,Integer> tableProblems = summary.get(pr.getTableId());
       if (tableProblems == null) {
         tableProblems = new EnumMap<>(ProblemType.class);
-        summary.put(pr.getTableName(), tableProblems);
+        summary.put(pr.getTableId(), tableProblems);
       }
 
       Integer count = tableProblems.get(pr.getProblemType());
