@@ -16,7 +16,7 @@
  */
 package org.apache.accumulo.server.replication;
 
-import org.apache.accumulo.core.client.Connector;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 
 /**
@@ -27,15 +27,15 @@ public interface WorkAssigner {
   /**
    * @return The name for this WorkAssigner
    */
-  public String getName();
+  String getName();
 
   /**
    * Configure the WorkAssigner implementation
    */
-  public void configure(AccumuloConfiguration conf, Connector conn);
+  void configure(AccumuloConfiguration conf, AccumuloClient client);
 
   /**
    * Assign work for replication
    */
-  public void assignWork();
+  void assignWork();
 }
