@@ -41,9 +41,10 @@ import org.apache.accumulo.core.util.Daemon;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.SimpleThreadPool;
 import org.apache.accumulo.fate.util.LoggingRunnable;
-import org.apache.accumulo.server.AccumuloServerContext;
+import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.util.Halt;
 import org.apache.accumulo.server.util.time.SimpleTimer;
+import org.apache.hadoop.metrics2.MetricsSystem;
 import org.apache.hadoop.security.SaslRpcServer;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.thrift.TProcessor;
@@ -51,6 +52,7 @@ import org.apache.thrift.TProcessorFactory;
 import org.apache.thrift.protocol.TProtocolFactory;
 import org.apache.thrift.server.TServer;
 import org.apache.thrift.server.TThreadPoolServer;
+import org.apache.thrift.server.TThreadedSelectorServer;
 import org.apache.thrift.transport.TNonblockingServerSocket;
 import org.apache.thrift.transport.TSSLTransportFactory;
 import org.apache.thrift.transport.TSaslServerTransport;
@@ -114,9 +116,9 @@ public class TServerUtils {
    * @throws UnknownHostException
    *           when we don't know our own address
    */
-  public static ServerAddress startServer(AccumuloServerContext service, String hostname,
-      Property portHintProperty, TProcessor processor, String serverName, String threadName,
-      Property portSearchProperty, Property minThreadProperty,
+  public static ServerAddress startServer(MetricsSystem metricsSystem, ServerContext service,
+      String hostname, Property portHintProperty, TProcessor processor, String serverName,
+      String threadName, Property portSearchProperty, Property minThreadProperty,
       Property timeBetweenThreadChecksProperty, Property maxMessageSizeProperty)
       throws UnknownHostException {
     final AccumuloConfiguration config = service.getConfiguration();
@@ -124,32 +126,37 @@ public class TServerUtils {
     final int[] portHint = config.getPort(portHintProperty);
 
     int minThreads = 2;
-    if (minThreadProperty != null)
+    if (minThreadProperty != null) {
       minThreads = config.getCount(minThreadProperty);
+    }
 
     long timeBetweenThreadChecks = 1000;
-    if (timeBetweenThreadChecksProperty != null)
+    if (timeBetweenThreadChecksProperty != null) {
       timeBetweenThreadChecks = config.getTimeInMillis(timeBetweenThreadChecksProperty);
+    }
 
     long maxMessageSize = 10 * 1000 * 1000;
-    if (maxMessageSizeProperty != null)
-      maxMessageSize = config.getMemoryInBytes(maxMessageSizeProperty);
+    if (maxMessageSizeProperty != null) {
+      maxMessageSize = config.getAsBytes(maxMessageSizeProperty);
+    }
 
     boolean portSearch = false;
-    if (portSearchProperty != null)
+    if (portSearchProperty != null) {
       portSearch = config.getBoolean(portSearchProperty);
+    }
 
     final int simpleTimerThreadpoolSize =
         config.getCount(Property.GENERAL_SIMPLETIMER_THREADPOOL_SIZE);
     final ThriftServerType serverType = service.getThriftServerType();
 
-    if (ThriftServerType.SASL == serverType) {
+    if (serverType == ThriftServerType.SASL) {
       processor = updateSaslProcessor(serverType, processor);
     }
 
     // create the TimedProcessor outside the port search loop so we don't try to register the same
     // metrics mbean more than once
-    TimedProcessor timedProcessor = new TimedProcessor(config, processor, serverName, threadName);
+    TimedProcessor timedProcessor =
+        new TimedProcessor(metricsSystem, config, processor, serverName, threadName);
 
     HostAndPort[] addresses = getHostAndPorts(hostname, portHint);
     try {
@@ -162,8 +169,7 @@ public class TServerUtils {
         HostAndPort last = addresses[addresses.length - 1];
         // Attempt to allocate a port outside of the specified port property
         // Search sequentially over the next 1000 ports
-        for (int i = last.getPort() + 1; i < last.getPort() + 1001; i++) {
-          int port = i;
+        for (int port = last.getPort() + 1; port < last.getPort() + 1001; port++) {
           if (port > 65535) {
             break;
           }
@@ -187,13 +193,49 @@ public class TServerUtils {
   }
 
   /**
-   * Create a NonBlockingServer with a custom thread pool that can dynamically resize itself.
+   * Create a non blocking server with multiple select threads and a custom thread pool that can
+   * dynamically resize itself.
    */
-  public static ServerAddress createNonBlockingServer(HostAndPort address, TProcessor processor,
-      TProtocolFactory protocolFactory, final String serverName, String threadName,
+  public static ServerAddress createThreadedSelectorServer(HostAndPort address,
+      TProcessor processor, TProtocolFactory protocolFactory, final String serverName,
       final int numThreads, final int numSTThreads, long timeBetweenThreadChecks,
       long maxMessageSize) throws TTransportException {
 
+    final TNonblockingServerSocket transport =
+        new TNonblockingServerSocket(new InetSocketAddress(address.getHost(), address.getPort()));
+
+    TThreadedSelectorServer.Args options = new TThreadedSelectorServer.Args(transport);
+
+    options.selectorThreads = Math.max(2, Runtime.getRuntime().availableProcessors() / 4);
+    log.info("selectorThreads : " + options.selectorThreads);
+    options.protocolFactory(protocolFactory);
+    options.transportFactory(ThriftUtil.transportFactory(maxMessageSize));
+    options.maxReadBufferBytes = maxMessageSize;
+    options.stopTimeoutVal(5);
+
+    // Create our own very special thread pool.
+    ThreadPoolExecutor pool =
+        createSelfResizingThreadPool(serverName, numThreads, numSTThreads, timeBetweenThreadChecks);
+
+    options.executorService(pool);
+    options.processorFactory(new TProcessorFactory(processor));
+
+    if (address.getPort() == 0) {
+      address = HostAndPort.fromParts(address.getHost(), transport.getPort());
+    }
+
+    return new ServerAddress(new CustomThreadedSelectorServer(options), address);
+  }
+
+  /**
+   * Create a NonBlockingServer with a single select threads and a custom thread pool that can
+   * dynamically resize itself.
+   */
+  public static ServerAddress createNonBlockingServer(HostAndPort address, TProcessor processor,
+      TProtocolFactory protocolFactory, final String serverName, final int numThreads,
+      final int numSTThreads, long timeBetweenThreadChecks, long maxMessageSize)
+      throws TTransportException {
+
     final TNonblockingServerSocket transport =
         new TNonblockingServerSocket(new InetSocketAddress(address.getHost(), address.getPort()));
     final CustomNonBlockingServer.Args options = new CustomNonBlockingServer.Args(transport);
@@ -236,24 +278,21 @@ public class TServerUtils {
       final int executorThreads, int simpleTimerThreads, long timeBetweenThreadChecks) {
     final ThreadPoolExecutor pool = new SimpleThreadPool(executorThreads, "ClientPool");
     // periodically adjust the number of threads we need by checking how busy our threads are
-    SimpleTimer.getInstance(simpleTimerThreads).schedule(new Runnable() {
-      @Override
-      public void run() {
-        // there is a minor race condition between sampling the current state of the thread pool and
-        // adjusting it
-        // however, this isn't really an issue, since it adjusts periodically anyway
-        if (pool.getCorePoolSize() <= pool.getActiveCount()) {
-          int larger = pool.getCorePoolSize() + Math.min(pool.getQueue().size(), 2);
-          log.info("Increasing server thread pool size on {} to {}", serverName, larger);
-          pool.setMaximumPoolSize(larger);
-          pool.setCorePoolSize(larger);
-        } else {
-          if (pool.getCorePoolSize() > pool.getActiveCount() + 3) {
-            int smaller = Math.max(executorThreads, pool.getCorePoolSize() - 1);
-            if (smaller != pool.getCorePoolSize()) {
-              log.info("Decreasing server thread pool size on {} to {}", serverName, smaller);
-              pool.setCorePoolSize(smaller);
-            }
+    SimpleTimer.getInstance(simpleTimerThreads).schedule(() -> {
+      // there is a minor race condition between sampling the current state of the thread pool and
+      // adjusting it
+      // however, this isn't really an issue, since it adjusts periodically anyway
+      if (pool.getCorePoolSize() <= pool.getActiveCount()) {
+        int larger = pool.getCorePoolSize() + Math.min(pool.getQueue().size(), 2);
+        log.info("Increasing server thread pool size on {} to {}", serverName, larger);
+        pool.setMaximumPoolSize(larger);
+        pool.setCorePoolSize(larger);
+      } else {
+        if (pool.getCorePoolSize() > pool.getActiveCount() + 3) {
+          int smaller = Math.max(executorThreads, pool.getCorePoolSize() - 1);
+          if (smaller != pool.getCorePoolSize()) {
+            log.info("Decreasing server thread pool size on {} to {}", serverName, smaller);
+            pool.setCorePoolSize(smaller);
           }
         }
       }
@@ -262,7 +301,7 @@ public class TServerUtils {
   }
 
   /**
-   * Creates a TTheadPoolServer for normal unsecure operation. Useful for comparing performance
+   * Creates a TThreadPoolServer for normal unsecure operation. Useful for comparing performance
    * against SSL or SASL transports.
    *
    * @param address
@@ -277,7 +316,9 @@ public class TServerUtils {
       TProtocolFactory protocolFactory, long maxMessageSize, String serverName, int numThreads,
       int numSimpleTimerThreads, long timeBetweenThreadChecks) throws TTransportException {
 
-    TServerSocket transport = new TServerSocket(address.getPort());
+    InetSocketAddress isa = new InetSocketAddress(address.getHost(), address.getPort());
+    // Must use an ISA, providing only a port would ignore the hostname given
+    TServerSocket transport = new TServerSocket(isa);
     ThreadPoolExecutor pool = createSelfResizingThreadPool(serverName, numThreads,
         numSimpleTimerThreads, timeBetweenThreadChecks);
     TThreadPoolServer server = createTThreadPoolServer(transport, processor,
@@ -293,23 +334,6 @@ public class TServerUtils {
 
   }
 
-  /**
-   * Create a {@link TThreadPoolServer} with the provided transport, processor and transport
-   * factory.
-   *
-   * @param transport
-   *          Server transport
-   * @param processor
-   *          Processor implementation
-   * @param transportFactory
-   *          Transport factory
-   * @return A configured {@link TThreadPoolServer}
-   */
-  public static TThreadPoolServer createTThreadPoolServer(TServerTransport transport,
-      TProcessor processor, TTransportFactory transportFactory, TProtocolFactory protocolFactory) {
-    return createTThreadPoolServer(transport, processor, transportFactory, protocolFactory, null);
-  }
-
   /**
    * Create a {@link TThreadPoolServer} with the provided server transport, processor and transport
    * factory.
@@ -328,7 +352,7 @@ public class TServerUtils {
     options.protocolFactory(protocolFactory);
     options.transportFactory(transportFactory);
     options.processorFactory(new ClientInfoProcessorFactory(clientAddress, processor));
-    if (null != service) {
+    if (service != null) {
       options.executorService(service);
     }
     return new TThreadPoolServer(options);
@@ -425,7 +449,7 @@ public class TServerUtils {
 
   public static ServerAddress createSaslThreadPoolServer(HostAndPort address, TProcessor processor,
       TProtocolFactory protocolFactory, long socketTimeout, SaslServerConnectionParams params,
-      final String serverName, String threadName, final int numThreads, final int numSTThreads,
+      final String serverName, final int numThreads, final int numSTThreads,
       long timeBetweenThreadChecks) throws TTransportException {
     // We'd really prefer to use THsHaServer (or similar) to avoid 1 RPC == 1 Thread that the
     // TThreadPoolServer does,
@@ -434,7 +458,9 @@ public class TServerUtils {
     // when the server does an accept() to (presumably) wake up the eventing system.
     log.info("Creating SASL thread pool thrift server on listening on {}:{}", address.getHost(),
         address.getPort());
-    TServerSocket transport = new TServerSocket(address.getPort(), (int) socketTimeout);
+    InetSocketAddress isa = new InetSocketAddress(address.getHost(), address.getPort());
+    // Must use an ISA, providing only a port would ignore the hostname given
+    TServerSocket transport = new TServerSocket(isa, (int) socketTimeout);
 
     String hostname, fqdn;
     try {
@@ -458,8 +484,8 @@ public class TServerUtils {
     // their configuration.
     if (!hostname.equals(fqdn)) {
       log.error("Expected hostname of '{}' but got '{}'. Ensure the entries in"
-          + " the Accumulo hosts files (e.g. masters, slaves) are the FQDN for each"
-          + " host when using SASL.", fqdn, hostname);
+          + " the Accumulo hosts files (e.g. masters, tservers) are the FQDN for"
+          + " each host when using SASL.", fqdn, hostname);
       transport.close();
       throw new RuntimeException("SASL requires that the address the thrift"
           + " server listens on is the same as the FQDN for this host");
@@ -485,7 +511,7 @@ public class TServerUtils {
     saslTransportFactory.addServerDefinition(ThriftUtil.GSSAPI, params.getKerberosServerPrimary(),
         hostname, params.getSaslProperties(), new SaslRpcServer.SaslGssCallbackHandler());
 
-    if (null != params.getSecretManager()) {
+    if (params.getSecretManager() != null) {
       log.info("Adding DIGEST-MD5 server definition for delegation tokens");
       saslTransportFactory.addServerDefinition(ThriftUtil.DIGEST_MD5,
           params.getKerberosServerPrimary(), hostname, params.getSaslProperties(),
@@ -514,19 +540,20 @@ public class TServerUtils {
     return new ServerAddress(server, address);
   }
 
-  public static ServerAddress startTServer(AccumuloConfiguration conf, ThriftServerType serverType,
-      TProcessor processor, String serverName, String threadName, int numThreads, int numSTThreads,
-      long timeBetweenThreadChecks, long maxMessageSize, SslConnectionParams sslParams,
-      SaslServerConnectionParams saslParams, long serverSocketTimeout, HostAndPort... addresses)
-      throws TTransportException {
+  public static ServerAddress startTServer(MetricsSystem metricsSystem, AccumuloConfiguration conf,
+      ThriftServerType serverType, TProcessor processor, String serverName, String threadName,
+      int numThreads, int numSTThreads, long timeBetweenThreadChecks, long maxMessageSize,
+      SslConnectionParams sslParams, SaslServerConnectionParams saslParams,
+      long serverSocketTimeout, HostAndPort... addresses) throws TTransportException {
 
-    if (ThriftServerType.SASL == serverType) {
+    if (serverType == ThriftServerType.SASL) {
       processor = updateSaslProcessor(serverType, processor);
     }
 
-    return startTServer(serverType, new TimedProcessor(conf, processor, serverName, threadName),
-        serverName, threadName, numThreads, numSTThreads, timeBetweenThreadChecks, maxMessageSize,
-        sslParams, saslParams, serverSocketTimeout, addresses);
+    return startTServer(serverType,
+        new TimedProcessor(metricsSystem, conf, processor, serverName, threadName), serverName,
+        threadName, numThreads, numSTThreads, timeBetweenThreadChecks, maxMessageSize, sslParams,
+        saslParams, serverSocketTimeout, addresses);
   }
 
   /**
@@ -575,42 +602,44 @@ public class TServerUtils {
             break;
           case SASL:
             log.debug("Instantiating SASL Thrift server");
-            serverAddress = createSaslThreadPoolServer(address, processor, protocolFactory,
-                serverSocketTimeout, saslParams, serverName, threadName, numThreads, numSTThreads,
-                timeBetweenThreadChecks);
+            serverAddress =
+                createSaslThreadPoolServer(address, processor, protocolFactory, serverSocketTimeout,
+                    saslParams, serverName, numThreads, numSTThreads, timeBetweenThreadChecks);
             break;
           case THREADPOOL:
             log.debug("Instantiating unsecure TThreadPool Thrift server");
             serverAddress = createBlockingServer(address, processor, protocolFactory,
                 maxMessageSize, serverName, numThreads, numSTThreads, timeBetweenThreadChecks);
             break;
-          case CUSTOM_HS_HA: // Intentional passthrough -- Our custom wrapper around HsHa is the
-                             // default
-          default:
-            log.debug("Instantiating default, unsecure custom half-async Thrift server");
+          case THREADED_SELECTOR:
+            log.debug("Instantiating default, unsecure Threaded selector Thrift server");
+            serverAddress = createThreadedSelectorServer(address, processor, protocolFactory,
+                serverName, numThreads, numSTThreads, timeBetweenThreadChecks, maxMessageSize);
+            break;
+          case CUSTOM_HS_HA:
+            log.debug("Instantiating unsecure custom half-async Thrift server");
             serverAddress = createNonBlockingServer(address, processor, protocolFactory, serverName,
-                threadName, numThreads, numSTThreads, timeBetweenThreadChecks, maxMessageSize);
+                numThreads, numSTThreads, timeBetweenThreadChecks, maxMessageSize);
+            break;
+          default:
+            throw new IllegalArgumentException("Unknown server type " + serverType);
         }
         break;
       } catch (TTransportException e) {
-        log.warn("Error attempting to create server at {}. Error: {}", address.toString(),
-            e.getMessage());
+        log.warn("Error attempting to create server at {}. Error: {}", address, e.getMessage());
       }
     }
-    if (null == serverAddress) {
+    if (serverAddress == null) {
       throw new TTransportException(
           "Unable to create server on addresses: " + Arrays.toString(addresses));
     }
 
     final TServer finalServer = serverAddress.server;
-    Runnable serveTask = new Runnable() {
-      @Override
-      public void run() {
-        try {
-          finalServer.serve();
-        } catch (Error e) {
-          Halt.halt("Unexpected error in TThreadPoolServer " + e + ", halting.", 1);
-        }
+    Runnable serveTask = () -> {
+      try {
+        finalServer.serve();
+      } catch (Error e) {
+        Halt.halt("Unexpected error in TThreadPoolServer " + e + ", halting.", 1);
       }
     };
 
@@ -639,8 +668,9 @@ public class TServerUtils {
    *          The TServer to stop
    */
   public static void stopTServer(TServer s) {
-    if (s == null)
+    if (s == null) {
       return;
+    }
     s.stop();
     try {
       Field f = s.getClass().getDeclaredField("executorService_");
@@ -660,7 +690,7 @@ public class TServerUtils {
    * @return A {@link UGIAssumingProcessor} which wraps the provided processor
    */
   private static TProcessor updateSaslProcessor(ThriftServerType serverType, TProcessor processor) {
-    checkArgument(ThriftServerType.SASL == serverType);
+    checkArgument(serverType == ThriftServerType.SASL);
 
     // Wrap the provided processor in our special processor which proxies the provided UGI on the
     // logged-in UGI
