@@ -16,14 +16,13 @@
  */
 package org.apache.accumulo.server.tables;
 
-import java.util.Map;
-
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.master.state.tables.TableState;
 
 public interface TableObserver {
-  void initialize(Map<String,TableState> tableIdToStateMap);
+  void initialize();
 
-  void stateChanged(String tableId, TableState tState);
+  void stateChanged(TableId tableId, TableState tState);
 
   void sessionExpired();
 }
