@@ -18,6 +18,9 @@ package org.apache.accumulo.server;
 
 import static org.junit.Assert.assertEquals;
 
+import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
+import org.apache.accumulo.core.conf.Property;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -25,7 +28,7 @@ public class ServerOptsTest {
   private ServerOpts opts;
 
   @Before
-  public void setUp() throws Exception {
+  public void setUp() {
     opts = new ServerOpts();
   }
 
@@ -40,4 +43,13 @@ public class ServerOptsTest {
     opts.parseArgs(ServerOptsTest.class.getName(), new String[] {});
     assertEquals("0.0.0.0", opts.getAddress());
   }
+
+  @Test
+  public void testOverrideConfig() {
+    AccumuloConfiguration defaults = DefaultConfiguration.getInstance();
+    assertEquals("localhost:2181", defaults.get(Property.INSTANCE_ZK_HOST));
+    opts.parseArgs(ServerOptsTest.class.getName(),
+        new String[] {"-o", "instance.zookeeper.host=test:123"});
+    assertEquals("test:123", opts.getSiteConfiguration().get(Property.INSTANCE_ZK_HOST));
+  }
 }
