@@ -21,7 +21,6 @@ import static org.easymock.EasyMock.anyObject;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.eq;
 import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.expectLastCall;
 import static org.easymock.EasyMock.replay;
 import static org.easymock.EasyMock.verify;
 import static org.junit.Assert.assertEquals;
@@ -31,31 +30,30 @@ import static org.junit.Assert.assertTrue;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.UUID;
+import java.util.function.Predicate;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.Instance;
-import org.apache.accumulo.core.client.impl.Namespaces;
+import org.apache.accumulo.core.clientImpl.Namespace;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationObserver;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
+import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.fate.zookeeper.ZooCache;
 import org.apache.accumulo.fate.zookeeper.ZooCacheFactory;
-import org.gaul.modernizer_maven_annotations.SuppressModernizer;
+import org.apache.accumulo.fate.zookeeper.ZooUtil;
+import org.apache.accumulo.server.ServerContext;
 import org.junit.Before;
 import org.junit.Test;
 
-import com.google.common.base.Predicate;
-import com.google.common.base.Predicates;
-
 public class NamespaceConfigurationTest {
-  private static final String NSID = "namespace";
+  private static final NamespaceId NSID = NamespaceId.of("namespace");
   private static final String ZOOKEEPERS = "localhost";
   private static final int ZK_SESSION_TIMEOUT = 120000;
 
   private String iid;
-  private Instance instance;
+  private ServerContext context;
   private AccumuloConfiguration parent;
   private ZooCacheFactory zcf;
   private ZooCache zc;
@@ -64,16 +62,18 @@ public class NamespaceConfigurationTest {
   @Before
   public void setUp() {
     iid = UUID.randomUUID().toString();
-    instance = createMock(Instance.class);
+
+    context = createMock(ServerContext.class);
     parent = createMock(AccumuloConfiguration.class);
 
-    expect(instance.getInstanceID()).andReturn(iid);
-    expectLastCall().anyTimes();
-    expect(instance.getZooKeepers()).andReturn(ZOOKEEPERS);
-    expect(instance.getZooKeepersSessionTimeOut()).andReturn(ZK_SESSION_TIMEOUT);
-    replay(instance);
+    expect(context.getProperties()).andReturn(new Properties());
+    expect(context.getZooKeeperRoot()).andReturn("/accumulo/" + iid).anyTimes();
+    expect(context.getInstanceID()).andReturn(iid).anyTimes();
+    expect(context.getZooKeepers()).andReturn(ZOOKEEPERS).anyTimes();
+    expect(context.getZooKeepersSessionTimeOut()).andReturn(ZK_SESSION_TIMEOUT).anyTimes();
+    replay(context);
 
-    c = new NamespaceConfiguration(NSID, instance, parent);
+    c = new NamespaceConfiguration(NSID, context, parent);
     zcf = createMock(ZooCacheFactory.class);
     c.setZooCacheFactory(zcf);
 
@@ -111,20 +111,18 @@ public class NamespaceConfigurationTest {
 
   @Test
   public void testGet_SkipParentIfAccumuloNS() {
-    c = new NamespaceConfiguration(Namespaces.ACCUMULO_NAMESPACE_ID, instance, parent);
+    c = new NamespaceConfiguration(Namespace.ACCUMULO.id(), context, parent);
     c.setZooCacheFactory(zcf);
     Property p = Property.INSTANCE_SECRET;
-    expect(zc.get(ZooUtil.getRoot(iid) + Constants.ZNAMESPACES + "/"
-        + Namespaces.ACCUMULO_NAMESPACE_ID + Constants.ZNAMESPACE_CONF + "/" + p.getKey()))
-        .andReturn(null);
+    expect(zc.get(ZooUtil.getRoot(iid) + Constants.ZNAMESPACES + "/" + Namespace.ACCUMULO.id()
+        + Constants.ZNAMESPACE_CONF + "/" + p.getKey())).andReturn(null);
     replay(zc);
     assertNull(c.get(Property.INSTANCE_SECRET));
   }
 
   @Test
-  @SuppressModernizer
   public void testGetProperties() {
-    Predicate<String> all = Predicates.alwaysTrue();
+    Predicate<String> all = x -> true;
     Map<String,String> props = new java.util.HashMap<>();
     parent.getProperties(props, all);
     replay(parent);
@@ -133,7 +131,7 @@ public class NamespaceConfigurationTest {
     children.add("ding");
     expect(zc.getChildren(
         ZooUtil.getRoot(iid) + Constants.ZNAMESPACES + "/" + NSID + Constants.ZNAMESPACE_CONF))
-        .andReturn(children);
+            .andReturn(children);
     expect(zc.get(ZooUtil.getRoot(iid) + Constants.ZNAMESPACES + "/" + NSID
         + Constants.ZNAMESPACE_CONF + "/" + "foo")).andReturn("bar".getBytes(UTF_8));
     expect(zc.get(ZooUtil.getRoot(iid) + Constants.ZNAMESPACES + "/" + NSID
