@@ -29,29 +29,28 @@ import static org.junit.Assert.assertTrue;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.UUID;
+import java.util.function.Predicate;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.Instance;
 import org.apache.accumulo.core.conf.ConfigurationObserver;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.fate.zookeeper.ZooCache;
 import org.apache.accumulo.fate.zookeeper.ZooCacheFactory;
-import org.gaul.modernizer_maven_annotations.SuppressModernizer;
+import org.apache.accumulo.fate.zookeeper.ZooUtil;
+import org.apache.accumulo.server.ServerContext;
 import org.junit.Before;
 import org.junit.Test;
 
-import com.google.common.base.Predicate;
-import com.google.common.base.Predicates;
-
 public class TableConfigurationTest {
-  private static final String TID = "table";
+  private static final TableId TID = TableId.of("table");
   private static final String ZOOKEEPERS = "localhost";
   private static final int ZK_SESSION_TIMEOUT = 120000;
 
   private String iid;
-  private Instance instance;
+  private ServerContext context;
   private NamespaceConfiguration parent;
   private ZooCacheFactory zcf;
   private ZooCache zc;
@@ -60,21 +59,25 @@ public class TableConfigurationTest {
   @Before
   public void setUp() {
     iid = UUID.randomUUID().toString();
-    instance = createMock(Instance.class);
-    expect(instance.getInstanceID()).andReturn(iid).anyTimes();
-    expect(instance.getZooKeepers()).andReturn(ZOOKEEPERS);
-    expect(instance.getZooKeepersSessionTimeOut()).andReturn(ZK_SESSION_TIMEOUT);
-    replay(instance);
+    context = createMock(ServerContext.class);
+    ServerConfigurationFactory scf = createMock(ServerConfigurationFactory.class);
+    expect(context.getServerConfFactory()).andReturn(scf);
+    expect(context.getProperties()).andReturn(new Properties()).anyTimes();
+    expect(context.getInstanceID()).andReturn(iid).anyTimes();
+    expect(context.getZooKeeperRoot()).andReturn("/accumulo/" + iid).anyTimes();
+    expect(context.getZooKeepers()).andReturn(ZOOKEEPERS).anyTimes();
+    expect(context.getZooKeepersSessionTimeOut()).andReturn(ZK_SESSION_TIMEOUT).anyTimes();
+    replay(context);
 
     parent = createMock(NamespaceConfiguration.class);
-    c = new TableConfiguration(instance, TID, parent);
+    c = new TableConfiguration(context, TID, parent);
     zcf = createMock(ZooCacheFactory.class);
     c.setZooCacheFactory(zcf);
 
     zc = createMock(ZooCache.class);
     expect(
         zcf.getZooCache(eq(ZOOKEEPERS), eq(ZK_SESSION_TIMEOUT), anyObject(TableConfWatcher.class)))
-        .andReturn(zc);
+            .andReturn(zc);
     replay(zcf);
   }
 
@@ -105,9 +108,8 @@ public class TableConfigurationTest {
   }
 
   @Test
-  @SuppressModernizer
   public void testGetProperties() {
-    Predicate<String> all = Predicates.alwaysTrue();
+    Predicate<String> all = x -> true;
     Map<String,String> props = new java.util.HashMap<>();
     parent.getProperties(props, all);
     replay(parent);
@@ -116,10 +118,10 @@ public class TableConfigurationTest {
     children.add("ding");
     expect(zc
         .getChildren(ZooUtil.getRoot(iid) + Constants.ZTABLES + "/" + TID + Constants.ZTABLE_CONF))
-        .andReturn(children);
+            .andReturn(children);
     expect(zc.get(
         ZooUtil.getRoot(iid) + Constants.ZTABLES + "/" + TID + Constants.ZTABLE_CONF + "/" + "foo"))
-        .andReturn("bar".getBytes(UTF_8));
+            .andReturn("bar".getBytes(UTF_8));
     expect(zc.get(ZooUtil.getRoot(iid) + Constants.ZTABLES + "/" + TID + Constants.ZTABLE_CONF + "/"
         + "ding")).andReturn("dong".getBytes(UTF_8));
     replay(zc);
