@@ -16,6 +16,9 @@
  */
 package org.apache.accumulo.server.master.balancer;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.easymock.EasyMock.expect;
+import static org.easymock.EasyMock.replay;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
@@ -30,35 +33,48 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedMap;
+import java.util.function.Predicate;
 import java.util.regex.Pattern;
 
-import org.apache.accumulo.core.client.impl.thrift.ThriftSecurityException;
+import org.apache.accumulo.core.clientImpl.Namespace;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.data.thrift.TKeyExtent;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
 import org.apache.accumulo.core.tabletserver.thrift.TabletStats;
 import org.apache.accumulo.fate.util.UtilWaitThread;
+import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.conf.NamespaceConfiguration;
+import org.apache.accumulo.server.conf.ServerConfigurationFactory;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.master.state.TServerInstance;
 import org.apache.accumulo.server.master.state.TabletMigration;
-import org.apache.thrift.TException;
-import org.gaul.modernizer_maven_annotations.SuppressModernizer;
 import org.junit.Test;
 
-import com.google.common.base.Predicate;
-
 public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalancerTest {
 
+  public void init() {
+    ServerContext context1 = createMockContext();
+    replay(context1);
+    final TestServerConfigurationFactory factory = new TestServerConfigurationFactory(context1);
+    initFactory(factory);
+  }
+
+  private void initFactory(ServerConfigurationFactory factory) {
+    ServerContext context = createMockContext();
+    expect(context.getServerConfFactory()).andReturn(factory).anyTimes();
+    replay(context);
+    init(context);
+  }
+
   @Test
   public void testInit() {
-    init(factory);
+    init();
     assertEquals("OOB check interval value is incorrect", 7000, this.getOobCheckMillis());
-    @SuppressWarnings("deprecation")
-    long poolRecheckMillis = this.getPoolRecheckMillis();
-    assertEquals("Pool check interval value is incorrect", 0, poolRecheckMillis);
     assertEquals("Max migrations is incorrect", 4, this.getMaxMigrations());
     assertEquals("Max outstanding migrations is incorrect", 10, this.getMaxOutstandingMigrations());
     assertFalse(isIpBasedRegex());
@@ -68,7 +84,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     assertEquals(Pattern.compile("r01.*").pattern(), patterns.get(FOO.getTableName()).pattern());
     assertTrue(patterns.containsKey(BAR.getTableName()));
     assertEquals(Pattern.compile("r02.*").pattern(), patterns.get(BAR.getTableName()).pattern());
-    Map<String,String> tids = this.getTableIdToTableName();
+    Map<TableId,String> tids = this.getTableIdToTableName();
     assertEquals(3, tids.size());
     assertTrue(tids.containsKey(FOO.getId()));
     assertEquals(FOO.getTableName(), tids.get(FOO.getId()));
@@ -76,12 +92,12 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     assertEquals(BAR.getTableName(), tids.get(BAR.getId()));
     assertTrue(tids.containsKey(BAZ.getId()));
     assertEquals(BAZ.getTableName(), tids.get(BAZ.getId()));
-    assertEquals(false, this.isIpBasedRegex());
+    assertFalse(this.isIpBasedRegex());
   }
 
   @Test
   public void testBalance() {
-    init(factory);
+    init();
     Set<KeyExtent> migrations = new HashSet<>();
     List<TabletMigration> migrationsOut = new ArrayList<>();
     long wait = this.balance(Collections.unmodifiableSortedMap(createCurrent(15)), migrations,
@@ -127,7 +143,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
   @Test
   public void testBalanceWithTooManyOutstandingMigrations() {
     List<TabletMigration> migrationsOut = new ArrayList<>();
-    init(factory);
+    init();
     // lets say we already have migrations ongoing for the FOO and BAR table extends (should be 5 of
     // each of them) for a total of 10
     Set<KeyExtent> migrations = new HashSet<>();
@@ -142,7 +158,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testSplitCurrentByRegexUsingHostname() {
-    init(factory);
+    init();
     Map<String,SortedMap<TServerInstance,TabletServerStatus>> groups =
         this.splitCurrentByRegex(createCurrent(15));
     assertEquals(3, groups.size());
@@ -174,10 +190,15 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testSplitCurrentByRegexUsingOverlappingPools() {
-    init(new TestServerConfigurationFactory(instance) {
+    ServerContext context = createMockContext();
+    replay(context);
+    initFactory(new TestServerConfigurationFactory(context) {
+
       @Override
-      public TableConfiguration getTableConfiguration(String tableId) {
-        return new TableConfiguration(getInstance(), tableId, null) {
+      public TableConfiguration getTableConfiguration(TableId tableId) {
+        NamespaceConfiguration defaultConf = new NamespaceConfiguration(Namespace.DEFAULT.id(),
+            this.context, DefaultConfiguration.getInstance());
+        return new TableConfiguration(this.context, tableId, defaultConf) {
           HashMap<String,String> tableProperties = new HashMap<>();
           {
             tableProperties
@@ -195,7 +216,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
           @Override
           public void getProperties(Map<String,String> props, Predicate<String> filter) {
             for (Entry<String,String> e : tableProperties.entrySet()) {
-              if (filter.apply(e.getKey())) {
+              if (filter.test(e.getKey())) {
                 props.put(e.getKey(), e.getValue());
               }
             }
@@ -252,9 +273,11 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testSplitCurrentByRegexUsingIP() {
-    init(new TestServerConfigurationFactory(instance) {
+    ServerContext context = createMockContext();
+    replay(context);
+    initFactory(new TestServerConfigurationFactory(context) {
       @Override
-      public synchronized AccumuloConfiguration getConfiguration() {
+      public synchronized AccumuloConfiguration getSystemConfiguration() {
         HashMap<String,String> props = new HashMap<>();
         props.put(HostRegexTableLoadBalancer.HOST_BALANCER_OOB_CHECK_KEY, "30s");
         props.put(HostRegexTableLoadBalancer.HOST_BALANCER_REGEX_USING_IPS_KEY, "true");
@@ -262,8 +285,10 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
       }
 
       @Override
-      public TableConfiguration getTableConfiguration(String tableId) {
-        return new TableConfiguration(getInstance(), tableId, null) {
+      public TableConfiguration getTableConfiguration(TableId tableId) {
+        NamespaceConfiguration defaultConf = new NamespaceConfiguration(Namespace.DEFAULT.id(),
+            this.context, DefaultConfiguration.getInstance());
+        return new TableConfiguration(context, tableId, defaultConf) {
           HashMap<String,String> tableProperties = new HashMap<>();
           {
             tableProperties.put(
@@ -280,10 +305,9 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
           }
 
           @Override
-          @SuppressModernizer
           public void getProperties(Map<String,String> props, Predicate<String> filter) {
             for (Entry<String,String> e : tableProperties.entrySet()) {
-              if (filter.apply(e.getKey())) {
+              if (filter.test(e.getKey())) {
                 props.put(e.getKey(), e.getValue());
               }
             }
@@ -328,7 +352,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testAllUnassigned() {
-    init(factory);
+    init();
     Map<KeyExtent,TServerInstance> assignments = new HashMap<>();
     Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
     for (List<KeyExtent> extents : tableExtents.values()) {
@@ -360,7 +384,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testAllAssigned() {
-    init(factory);
+    init();
     Map<KeyExtent,TServerInstance> assignments = new HashMap<>();
     Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
     this.getAssignments(Collections.unmodifiableSortedMap(allTabletServers),
@@ -370,7 +394,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testPartiallyAssigned() {
-    init(factory);
+    init();
     Map<KeyExtent,TServerInstance> assignments = new HashMap<>();
     Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
     int i = 0;
@@ -406,7 +430,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testUnassignedWithNoTServers() {
-    init(factory);
+    init();
     Map<KeyExtent,TServerInstance> assignments = new HashMap<>();
     Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
     for (KeyExtent ke : tableExtents.get(BAR.getTableName())) {
@@ -439,7 +463,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testUnassignedWithNoDefaultPool() {
-    init(factory);
+    init();
     Map<KeyExtent,TServerInstance> assignments = new HashMap<>();
     Map<KeyExtent,TServerInstance> unassigned = new HashMap<>();
     for (KeyExtent ke : tableExtents.get(BAR.getTableName())) {
@@ -477,7 +501,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
 
   @Test
   public void testOutOfBoundsTablets() {
-    init(factory);
+    init();
     // Wait to trigger the out of bounds check which will call our version of
     // getOnlineTabletsForTable
     UtilWaitThread.sleep(11000);
@@ -488,14 +512,13 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
   }
 
   @Override
-  public List<TabletStats> getOnlineTabletsForTable(TServerInstance tserver, String tableId)
-      throws ThriftSecurityException, TException {
+  public List<TabletStats> getOnlineTabletsForTable(TServerInstance tserver, TableId tableId) {
     // Report incorrect information so that balance will create an assignment
     List<TabletStats> tablets = new ArrayList<>();
     if (tableId.equals(BAR.getId()) && tserver.host().equals("192.168.0.1")) {
       // Report that we have a bar tablet on this server
       TKeyExtent tke = new TKeyExtent();
-      tke.setTable(BAR.getId().getBytes());
+      tke.setTable(BAR.getId().canonical().getBytes(UTF_8));
       tke.setEndRow("11".getBytes());
       tke.setPrevEndRow("10".getBytes());
       TabletStats ts = new TabletStats();
@@ -504,7 +527,7 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
     } else if (tableId.equals(FOO.getId()) && tserver.host().equals("192.168.0.6")) {
       // Report that we have a foo tablet on this server
       TKeyExtent tke = new TKeyExtent();
-      tke.setTable(FOO.getId().getBytes());
+      tke.setTable(FOO.getId().canonical().getBytes(UTF_8));
       tke.setEndRow("1".getBytes());
       tke.setPrevEndRow("0".getBytes());
       TabletStats ts = new TabletStats();
