@@ -16,14 +16,11 @@
  */
 package org.apache.accumulo.server.replication.proto;
 
-import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
 
 import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.junit.Test;
 
-/**
- *
- */
 public class StatusTest {
 
   @Test
@@ -33,7 +30,7 @@ public class StatusTest {
     Status unreplicated = Status.newBuilder().setBegin(0).setEnd(0).setInfiniteEnd(true)
         .setClosed(false).build();
 
-    assertFalse(replicated.equals(unreplicated));
+    assertNotEquals(replicated, unreplicated);
   }
 
 }
