@@ -35,9 +35,9 @@ import java.util.List;
 import javax.crypto.KeyGenerator;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.fate.zookeeper.ZooUtil;
 import org.apache.accumulo.fate.zookeeper.ZooUtil.NodeExistsPolicy;
-import org.apache.accumulo.server.zookeeper.ZooReaderWriter;
 import org.apache.zookeeper.KeeperException.AuthFailedException;
 import org.apache.zookeeper.data.ACL;
 import org.apache.zookeeper.data.Id;
@@ -77,7 +77,7 @@ public class ZooAuthenticationKeyDistributorTest {
     expect(zrw.exists(baseNode)).andReturn(false);
     expect(
         zrw.putPrivatePersistentData(eq(baseNode), aryEq(new byte[0]), eq(NodeExistsPolicy.FAIL)))
-        .andThrow(new AuthFailedException());
+            .andThrow(new AuthFailedException());
 
     replay(zrw);
 
@@ -93,8 +93,7 @@ public class ZooAuthenticationKeyDistributorTest {
 
     // Attempt to create the directory and fail
     expect(zrw.exists(baseNode)).andReturn(false);
-    expect(
-        zrw.putPrivatePersistentData(eq(baseNode), (byte[]) anyObject(), eq(NodeExistsPolicy.FAIL)))
+    expect(zrw.putPrivatePersistentData(eq(baseNode), anyObject(), eq(NodeExistsPolicy.FAIL)))
         .andReturn(true);
 
     replay(zrw);
@@ -108,7 +107,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testInitializedNotCalledAdvertise() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    distributor.advertise(new AuthenticationKey(1, 0l, 5l, keyGen.generateKey()));
+    distributor.advertise(new AuthenticationKey(1, 0L, 5L, keyGen.generateKey()));
   }
 
   @Test(expected = IllegalStateException.class)
@@ -122,7 +121,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testInitializedNotCalledRemove() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    distributor.remove(new AuthenticationKey(1, 0l, 5l, keyGen.generateKey()));
+    distributor.remove(new AuthenticationKey(1, 0L, 5L, keyGen.generateKey()));
   }
 
   @Test(expected = IllegalStateException.class)
@@ -132,7 +131,7 @@ public class ZooAuthenticationKeyDistributorTest {
 
     // Attempt to create the directory and fail
     expect(zrw.exists(baseNode)).andReturn(true);
-    expect(zrw.getACL(eq(baseNode), anyObject(Stat.class))).andReturn(Collections.<ACL>emptyList());
+    expect(zrw.getACL(eq(baseNode), anyObject(Stat.class))).andReturn(Collections.emptyList());
 
     replay(zrw);
 
@@ -166,7 +165,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testAdvertiseKey() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    AuthenticationKey key = new AuthenticationKey(1, 0l, 10l, keyGen.generateKey());
+    AuthenticationKey key = new AuthenticationKey(1, 0L, 10L, keyGen.generateKey());
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
     key.write(new DataOutputStream(baos));
     byte[] serialized = baos.toByteArray();
@@ -192,7 +191,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testAlreadyAdvertisedKey() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    AuthenticationKey key = new AuthenticationKey(1, 0l, 10l, keyGen.generateKey());
+    AuthenticationKey key = new AuthenticationKey(1, 0L, 10L, keyGen.generateKey());
     String path = baseNode + "/" + key.getKeyId();
 
     // Attempt to create the directory and fail
@@ -213,7 +212,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testRemoveKey() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    AuthenticationKey key = new AuthenticationKey(1, 0l, 10l, keyGen.generateKey());
+    AuthenticationKey key = new AuthenticationKey(1, 0L, 10L, keyGen.generateKey());
     String path = baseNode + "/" + key.getKeyId();
 
     // Attempt to create the directory and fail
@@ -236,7 +235,7 @@ public class ZooAuthenticationKeyDistributorTest {
   public void testRemoveMissingKey() throws Exception {
     ZooAuthenticationKeyDistributor distributor =
         new ZooAuthenticationKeyDistributor(zrw, baseNode);
-    AuthenticationKey key = new AuthenticationKey(1, 0l, 10l, keyGen.generateKey());
+    AuthenticationKey key = new AuthenticationKey(1, 0L, 10L, keyGen.generateKey());
     String path = baseNode + "/" + key.getKeyId();
 
     // Attempt to create the directory and fail
@@ -262,7 +261,7 @@ public class ZooAuthenticationKeyDistributorTest {
     List<String> children = new ArrayList<>(5);
     for (int i = 1; i < 6; i++) {
       children.add(Integer.toString(i));
-      AuthenticationKey key = new AuthenticationKey(i, 0l, 10l, keyGen.generateKey());
+      AuthenticationKey key = new AuthenticationKey(i, 0L, 10L, keyGen.generateKey());
       keys.add(key);
       ByteArrayOutputStream baos = new ByteArrayOutputStream();
       key.write(new DataOutputStream(baos));
