@@ -16,8 +16,6 @@
  */
 package org.apache.accumulo.gc;
 
-import java.io.IOException;
-
 import org.apache.accumulo.start.spi.KeywordExecutable;
 
 import com.google.auto.service.AutoService;
@@ -30,7 +28,17 @@ public class GCExecutable implements KeywordExecutable {
   }
 
   @Override
-  public void execute(final String[] args) throws IOException {
+  public UsageGroup usageGroup() {
+    return UsageGroup.PROCESS;
+  }
+
+  @Override
+  public String description() {
+    return "Starts Accumulo garbage collector";
+  }
+
+  @Override
+  public void execute(final String[] args) throws Exception {
     SimpleGarbageCollector.main(args);
   }
 }
