@@ -24,37 +24,25 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.ScanFileColumnFamily;
-import org.apache.accumulo.core.trace.Span;
-import org.apache.accumulo.core.trace.Trace;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.gc.GarbageCollectionEnvironment.Reference;
 import org.apache.accumulo.server.ServerConstants;
 import org.apache.accumulo.server.replication.StatusUtil;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
-import org.apache.hadoop.io.Text;
+import org.apache.htrace.Trace;
+import org.apache.htrace.TraceScope;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
 import com.google.common.collect.Iterators;
 import com.google.common.collect.PeekingIterator;
 
-/**
- *
- */
 public class GarbageCollectionAlgorithm {
 
   private static final Logger log = LoggerFactory.getLogger(GarbageCollectionAlgorithm.class);
@@ -126,7 +114,7 @@ public class GarbageCollectionAlgorithm {
       try {
         relPath = makeRelative(candidate, 0);
       } catch (IllegalArgumentException iae) {
-        log.warn("Ignoring invalid deletion candidate " + candidate);
+        log.warn("Ignoring invalid deletion candidate {}", candidate);
         continue;
       }
       ret.put(relPath, candidate);
@@ -136,8 +124,7 @@ public class GarbageCollectionAlgorithm {
   }
 
   private void confirmDeletes(GarbageCollectionEnvironment gce,
-      SortedMap<String,String> candidateMap)
-      throws TableNotFoundException, AccumuloException, AccumuloSecurityException {
+      SortedMap<String,String> candidateMap) throws TableNotFoundException {
     boolean checkForBulkProcessingFiles = false;
     Iterator<String> relativePaths = candidateMap.keySet().iterator();
     while (!checkForBulkProcessingFiles && relativePaths.hasNext())
@@ -169,71 +156,51 @@ public class GarbageCollectionAlgorithm {
         }
 
         if (count > 0)
-          log.debug("Folder has bulk processing flag: " + blipPath);
+          log.debug("Folder has bulk processing flag: {}", blipPath);
       }
 
     }
 
-    // it is important that the tracker is closed before performing deletes so that last row is
-    // checked
-    try (MetadataRowReadTracker readTracker = new MetadataRowReadTracker()) {
-      Iterator<Entry<Key,Value>> iter = gce.getReferenceIterator();
-      while (iter.hasNext()) {
-        Entry<Key,Value> entry = iter.next();
-        Key key = entry.getKey();
+    Iterator<Reference> iter = gce.getReferences().iterator();
+    while (iter.hasNext()) {
+      Reference ref = iter.next();
 
-        // check that dir entry was read for the row. If not, the metadata information may not be
-        // complete. Abort the gc cycle.
-        readTracker.trackRow(key.getRow());
+      if (!ref.isDir) {
 
-        Text cft = key.getColumnFamily();
+        String reference = ref.ref;
+        if (reference.startsWith("/")) {
+          reference = "/" + ref.id + reference;
+        } else if (!reference.contains(":") && !reference.startsWith("../")) {
+          throw new RuntimeException("Bad file reference " + reference);
+        }
 
-        if (cft.equals(DataFileColumnFamily.NAME) || cft.equals(ScanFileColumnFamily.NAME)) {
-          String cq = key.getColumnQualifier().toString();
+        reference = makeRelative(reference, 3);
 
-          String reference = cq;
-          if (cq.startsWith("/")) {
-            String tableID = new String(KeyExtent.tableOfMetadataRow(key.getRow()));
-            reference = "/" + tableID + cq;
-          } else if (!cq.contains(":") && !cq.startsWith("../")) {
-            throw new RuntimeException("Bad file reference " + cq);
-          }
+        // WARNING: This line is EXTREMELY IMPORTANT.
+        // You MUST REMOVE candidates that are still in use
+        if (candidateMap.remove(reference) != null)
+          log.debug("Candidate was still in use: {}", reference);
 
-          reference = makeRelative(reference, 3);
+        String dir = reference.substring(0, reference.lastIndexOf('/'));
+        if (candidateMap.remove(dir) != null)
+          log.debug("Candidate was still in use: {}", reference);
 
-          // WARNING: This line is EXTREMELY IMPORTANT.
-          // You MUST REMOVE candidates that are still in use
-          if (candidateMap.remove(reference) != null)
-            log.debug("Candidate was still in use: " + reference);
+      } else {
+        String tableID = ref.id.toString();
+        String dir = ref.ref;
+        if (!dir.contains(":")) {
+          if (!dir.startsWith("/"))
+            throw new RuntimeException("Bad directory " + dir);
+          dir = "/" + tableID + dir;
+        }
 
-          String dir = reference.substring(0, reference.lastIndexOf('/'));
-          if (candidateMap.remove(dir) != null)
-            log.debug("Candidate was still in use: " + reference);
+        dir = makeRelative(dir, 2);
 
-        } else if (TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.hasColumns(key)) {
-          readTracker.markDirSeen();
-          String tableID = new String(KeyExtent.tableOfMetadataRow(key.getRow()));
-          String dir = entry.getValue().toString();
-          if (!dir.contains(":")) {
-            if (!dir.startsWith("/"))
-              throw new RuntimeException("Bad directory " + dir);
-            dir = "/" + tableID + dir;
-          }
-
-          dir = makeRelative(dir, 2);
-
-          if (candidateMap.remove(dir) != null) {
-            log.debug("Candidate was still in use: " + dir);
-          }
-        } else if (TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.hasColumns(key)) {
-          readTracker.markPrevRowSeen();
-        } else
-          throw new RuntimeException(
-              "Scanner over metadata table returned unexpected column : " + entry.getKey());
+        if (candidateMap.remove(dir) != null)
+          log.debug("Candidate was still in use: {}", dir);
       }
-      // the tracker is closed at the end of this block; it will check the last row
-      // in its close method as its final action
     }
+
     confirmDeletesFromReplication(gce.getReplicationNeededIterator(),
         candidateMap.entrySet().iterator());
   }
@@ -273,67 +240,54 @@ public class GarbageCollectionAlgorithm {
 
   private void cleanUpDeletedTableDirs(GarbageCollectionEnvironment gce,
       SortedMap<String,String> candidateMap) throws IOException {
-    HashSet<String> tableIdsWithDeletes = new HashSet<>();
+    HashSet<TableId> tableIdsWithDeletes = new HashSet<>();
 
     // find the table ids that had dirs deleted
     for (String delete : candidateMap.keySet()) {
       String[] tokens = delete.split("/");
       if (tokens.length == 2) {
         // its a directory
-        String tableId = delete.split("/")[0];
+        TableId tableId = TableId.of(delete.split("/")[0]);
         tableIdsWithDeletes.add(tableId);
       }
     }
 
-    Set<String> tableIdsInZookeeper = gce.getTableIDs();
+    Set<TableId> tableIdsInZookeeper = gce.getTableIDs();
 
     tableIdsWithDeletes.removeAll(tableIdsInZookeeper);
 
     // tableIdsWithDeletes should now contain the set of deleted tables that had dirs deleted
 
-    for (String delTableId : tableIdsWithDeletes) {
+    for (TableId delTableId : tableIdsWithDeletes) {
       gce.deleteTableDirIfEmpty(delTableId);
     }
 
   }
 
   private boolean getCandidates(GarbageCollectionEnvironment gce, String lastCandidate,
-      List<String> candidates)
-      throws TableNotFoundException, AccumuloException, AccumuloSecurityException {
-    Span candidatesSpan = Trace.start("getCandidates");
-    try {
+      List<String> candidates) throws TableNotFoundException {
+    try (TraceScope candidatesSpan = Trace.startSpan("getCandidates")) {
       return gce.getCandidates(lastCandidate, candidates);
-    } finally {
-      candidatesSpan.stop();
     }
   }
 
   private void confirmDeletesTrace(GarbageCollectionEnvironment gce,
-      SortedMap<String,String> candidateMap)
-      throws TableNotFoundException, AccumuloException, AccumuloSecurityException {
-    Span confirmDeletesSpan = Trace.start("confirmDeletes");
-    try {
+      SortedMap<String,String> candidateMap) throws TableNotFoundException {
+    try (TraceScope confirmDeletesSpan = Trace.startSpan("confirmDeletes")) {
       confirmDeletes(gce, candidateMap);
-    } finally {
-      confirmDeletesSpan.stop();
     }
   }
 
   private void deleteConfirmed(GarbageCollectionEnvironment gce,
-      SortedMap<String,String> candidateMap)
-      throws IOException, AccumuloException, AccumuloSecurityException, TableNotFoundException {
-    Span deleteSpan = Trace.start("deleteFiles");
-    try {
+      SortedMap<String,String> candidateMap) throws IOException, TableNotFoundException {
+    try (TraceScope deleteSpan = Trace.startSpan("deleteFiles")) {
       gce.delete(candidateMap);
-    } finally {
-      deleteSpan.stop();
     }
 
     cleanUpDeletedTableDirs(gce, candidateMap);
   }
 
-  public void collect(GarbageCollectionEnvironment gce)
-      throws TableNotFoundException, AccumuloException, AccumuloSecurityException, IOException {
+  public void collect(GarbageCollectionEnvironment gce) throws TableNotFoundException, IOException {
 
     String lastCandidate = "";
 
@@ -359,83 +313,4 @@ public class GarbageCollectionAlgorithm {
       deleteConfirmed(gce, candidateMap);
     }
   }
-
-  /**
-   * Track metadata rows read to help validate that gc scan has complete information to make a
-   * decision on deleting files
-   */
-  private static class MetadataRowReadTracker implements AutoCloseable {
-    private boolean hasDir = false;
-    private boolean hasPrevRow = false;
-    private Text row;
-
-    private boolean closed = false;
-
-    public MetadataRowReadTracker() {
-      this.row = null;
-    }
-
-    private void validate() {
-      Preconditions.checkState(hasDir && hasPrevRow,
-          "May not have fully read metadata for row, aborting this run. Validation results: %s",
-          this);
-    }
-
-    /**
-     * Initializes row tracking for the provided row. If a previous row was being tracked, it is
-     * checked that all expected metadata fields have been marked as seen. If all fields have not
-     * been marked seen, an IllegalStateException is thrown to halt further processing.
-     *
-     * @param candidate
-     *          check current row, initialize a new row to track
-     */
-    public void trackRow(final Text candidate) {
-      Preconditions.checkState(!closed);
-      Objects.requireNonNull(candidate);
-      if (row == null) {
-        row = candidate; // first row seen
-      } else if (!row.equals(candidate)) {
-        // row changed, validate previous
-        validate();
-        // start tracking the next row
-        hasPrevRow = false;
-        hasDir = false;
-        row = candidate;
-      }
-    }
-
-    /**
-     * Mark that the dir metadata entry seen for the current row being tracked.
-     */
-    public void markDirSeen() {
-      Preconditions.checkState(!closed);
-      hasDir = true;
-    }
-
-    /**
-     * Mark that the prevRow metadata entry seen for the current row being tracked.
-     */
-    public void markPrevRowSeen() {
-      Preconditions.checkState(!closed);
-      hasPrevRow = true;
-    }
-
-    /**
-     * Check that the final row processed is complete and then close tracker to additional
-     * processing.
-     */
-    @Override
-    public void close() {
-      if (!closed && row != null) {
-        validate();
-      }
-      closed = true;
-    }
-
-    @Override
-    public String toString() {
-      return "MetadataReadTracker{row=" + row + ", hasDir=" + hasDir + ", hasPrevRow=" + hasPrevRow
-          + '}';
-    }
-  }
 }
