@@ -17,7 +17,6 @@
 package org.apache.accumulo.gc;
 
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 
 import java.util.ArrayList;
@@ -31,35 +30,24 @@ import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
 import java.util.TreeSet;
+import java.util.stream.Stream;
 
-import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.metadata.schema.DataFileValue;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.server.replication.StatusUtil;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
-import org.apache.hadoop.io.Text;
 import org.junit.Test;
 
-/**
- *
- */
 public class GarbageCollectionTest {
   static class TestGCE implements GarbageCollectionEnvironment {
     TreeSet<String> candidates = new TreeSet<>();
     ArrayList<String> blips = new ArrayList<>();
-    Map<Key,Value> references = new TreeMap<>();
-    HashSet<String> tableIds = new HashSet<>();
+    Map<String,Reference> references = new TreeMap<>();
+    HashSet<TableId> tableIds = new HashSet<>();
 
     ArrayList<String> deletes = new ArrayList<>();
-    ArrayList<String> tablesDirsToDelete = new ArrayList<>();
+    ArrayList<TableId> tablesDirsToDelete = new ArrayList<>();
     TreeMap<String,Status> filesToReplicate = new TreeMap<>();
 
-    public TestGCE() {}
-
     @Override
     public boolean getCandidates(String continuePoint, List<String> ret) {
       Iterator<String> iter = candidates.tailSet(continuePoint, false).iterator();
@@ -76,12 +64,12 @@ public class GarbageCollectionTest {
     }
 
     @Override
-    public Iterator<Entry<Key,Value>> getReferenceIterator() {
-      return references.entrySet().iterator();
+    public Stream<Reference> getReferences() {
+      return references.values().stream();
     }
 
     @Override
-    public Set<String> getTableIDs() {
+    public Set<TableId> getTableIDs() {
       return tableIds;
     }
 
@@ -92,68 +80,25 @@ public class GarbageCollectionTest {
     }
 
     @Override
-    public void deleteTableDirIfEmpty(String tableID) {
+    public void deleteTableDirIfEmpty(TableId tableID) {
       tablesDirsToDelete.add(tableID);
     }
 
-    public Key newFileReferenceKey(String tableId, String endRow, String file) {
-      String row = new KeyExtent(tableId, endRow == null ? null : new Text(endRow), null)
-          .getMetadataEntry().toString();
-      String cf = MetadataSchema.TabletsSection.DataFileColumnFamily.NAME.toString();
-      String cq = file;
-      Key key = new Key(row, cf, cq);
-      return key;
-    }
-
     public void addFileReference(String tableId, String endRow, String file) {
-      Key key = newFileReferenceKey(tableId, endRow, file);
-      Value val = new Value(new DataFileValue(0, 0).encode());
-      references.put(key, val);
+      references.put(tableId + ":" + endRow + ":" + file,
+          new Reference(TableId.of(tableId), file, false));
     }
 
     public void removeFileReference(String tableId, String endRow, String file) {
-      references.remove(newFileReferenceKey(tableId, endRow, file));
-    }
-
-    Key newDirReferenceKey(String tableId, String endRow) {
-      String row = new KeyExtent(tableId, endRow == null ? null : new Text(endRow), null)
-          .getMetadataEntry().toString();
-      String cf = MetadataSchema.TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN
-          .getColumnFamily().toString();
-      String cq = MetadataSchema.TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN
-          .getColumnQualifier().toString();
-      Key key = new Key(row, cf, cq);
-      return key;
+      references.remove(tableId + ":" + endRow + ":" + file);
     }
 
     public void addDirReference(String tableId, String endRow, String dir) {
-      Key key = newDirReferenceKey(tableId, endRow);
-      Value val = new Value(dir.getBytes());
-      references.put(key, val);
-    }
-
-    public Key newPrevRowKey(String tableId, String endRow) {
-      String row = new KeyExtent(tableId, endRow == null ? null : new Text(endRow), null)
-          .getMetadataEntry().toString();
-      String cf = MetadataSchema.TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.getColumnFamily()
-          .toString();
-      String cq = MetadataSchema.TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN
-          .getColumnQualifier().toString();
-      return new Key(row, cf, cq);
-    }
-
-    public void addPrevRowReference(String tableId, String endRow) {
-      Key key = newPrevRowKey(tableId, endRow);
-      Value val = new Value();
-      references.put(key, val);
+      references.put(tableId + ":" + endRow, new Reference(TableId.of(tableId), dir, true));
     }
 
     public void removeDirReference(String tableId, String endRow) {
-      references.remove(newDirReferenceKey(tableId, endRow));
-    }
-
-    public void removePrevRowReference(String tableId, String endRow) {
-      references.remove(newPrevRowKey(tableId, endRow));
+      references.remove(tableId + ":" + endRow);
     }
 
     @Override
@@ -163,8 +108,7 @@ public class GarbageCollectionTest {
     public void incrementInUseStat(long i) {}
 
     @Override
-    public Iterator<Entry<String,Status>> getReplicationNeededIterator()
-        throws AccumuloException, AccumuloSecurityException {
+    public Iterator<Entry<String,Status>> getReplicationNeededIterator() {
       return filesToReplicate.entrySet().iterator();
     }
   }
@@ -190,11 +134,6 @@ public class GarbageCollectionTest {
     gce.addFileReference("4", null, "hdfs://foo.com:6000/accumulo/tables/4/t0//F002.rf");
     gce.addFileReference("5", null, "hdfs://foo.com:6000/accumulo/tables/5/t0/F005.rf");
 
-    gce.addDirReference("4", null, "hdfs://foo.com:6000/accumulo/tables/4/t0");
-    gce.addPrevRowReference("4", null);
-    gce.addDirReference("5", null, "hdfs://foo.com:6000/accumulo/tables/4/t0");
-    gce.addPrevRowReference("5", null);
-
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
 
     gca.collect(gce);
@@ -236,16 +175,8 @@ public class GarbageCollectionTest {
     gce.addFileReference("4", null, "/t0/F000.rf");
     gce.addFileReference("4", null, "/t0/F001.rf");
     gce.addFileReference("4", null, "/t0/F002.rf");
-    gce.addDirReference("4", null, "hdfs://foo.com:6000/accumulo/tables/4/t0");
-    gce.addPrevRowReference("4", null);
-
     gce.addFileReference("5", null, "../4/t0/F000.rf");
-    gce.addDirReference("5", null, "hdfs://foo.com:6000/accumulo/tables/4/t0");
-    gce.addPrevRowReference("5", null);
-
     gce.addFileReference("6", null, "hdfs://foo.com:6000/accumulo/tables/4/t0/F000.rf");
-    gce.addDirReference("6", null, "hdfs://foo.com:6000/accumulo/tables/4/t0");
-    gce.addPrevRowReference("6", null);
 
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
 
@@ -345,37 +276,18 @@ public class GarbageCollectionTest {
     gce.candidates.add("hdfs://foo:6000/accumulo/tables/d/t-0");
 
     gce.addDirReference("4", null, "/t-0");
-    gce.addPrevRowReference("4", null);
-    gce.addDirReference("5", null, "hdfs://foo.com:6000/accumulo/tables/5/t-0");
-    gce.addPrevRowReference("5", null);
+    gce.addDirReference("5", null, "/t-0");
     gce.addDirReference("6", null, "hdfs://foo.com:6000/accumulo/tables/6/t-0");
-    gce.addPrevRowReference("6", null);
     gce.addDirReference("7", null, "hdfs://foo.com:6000/accumulo/tables/7/t-0");
-    gce.addPrevRowReference("7", null);
 
     gce.addFileReference("8", "m", "/t-0/F00.rf");
-    gce.addDirReference("8", "m", "/t-0");
-    gce.addPrevRowReference("8", "m");
-
     gce.addFileReference("9", "m", "/t-0/F00.rf");
-    gce.addDirReference("9", "m", "/t-0");
-    gce.addPrevRowReference("9", "m");
 
     gce.addFileReference("a", "m", "hdfs://foo.com:6000/accumulo/tables/a/t-0/F00.rf");
-    gce.addDirReference("a", "m", "hdfs://foo.com:6000/accumulo/tables/a/t-0");
-    gce.addPrevRowReference("a", "m");
-
     gce.addFileReference("b", "m", "hdfs://foo.com:6000/accumulo/tables/b/t-0/F00.rf");
-    gce.addDirReference("b", "m", "hdfs://foo.com:6000/accumulo/tables/b/t-0");
-    gce.addPrevRowReference("b", "m");
 
     gce.addFileReference("e", "m", "../c/t-0/F00.rf");
-    gce.addDirReference("e", "m", "hdfs://foo.com:6000/accumulo/tables/c/t-0");
-    gce.addPrevRowReference("e", "m");
-
     gce.addFileReference("f", "m", "../d/t-0/F00.rf");
-    gce.addDirReference("f", "m", "hdfs://foo.com:6000/accumulo/tables/d/t-0");
-    gce.addPrevRowReference("f", "m");
 
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
 
@@ -385,49 +297,24 @@ public class GarbageCollectionTest {
 
     // Removing the dir reference for a table will delete all tablet directories
     gce.removeDirReference("5", null);
-    gce.removePrevRowReference("5", null);
-
     gca.collect(gce);
     assertRemoved(gce, "hdfs://foo.com:6000/accumulo/tables/5/t-0");
 
     gce.removeDirReference("4", null);
-    gce.removePrevRowReference("4", null);
-
     gca.collect(gce);
     assertRemoved(gce, "/4/t-0");
 
     gce.removeDirReference("6", null);
-    gce.removePrevRowReference("6", null);
     gce.removeDirReference("7", null);
-    gce.removePrevRowReference("7", null);
-
     gca.collect(gce);
     assertRemoved(gce, "/6/t-0", "hdfs://foo:6000/accumulo/tables/7/t-0/");
 
     gce.removeFileReference("8", "m", "/t-0/F00.rf");
-    gce.removeDirReference("8", "m");
-    gce.removePrevRowReference("8", "m");
-
     gce.removeFileReference("9", "m", "/t-0/F00.rf");
-    gce.removeDirReference("9", "m");
-    gce.removePrevRowReference("9", "m");
-
     gce.removeFileReference("a", "m", "hdfs://foo.com:6000/accumulo/tables/a/t-0/F00.rf");
-    gce.removeDirReference("a", "m");
-    gce.removePrevRowReference("a", "m");
-
     gce.removeFileReference("b", "m", "hdfs://foo.com:6000/accumulo/tables/b/t-0/F00.rf");
-    gce.removeDirReference("b", "m");
-    gce.removePrevRowReference("b", "m");
-
     gce.removeFileReference("e", "m", "../c/t-0/F00.rf");
-    gce.removeDirReference("e", "m");
-    gce.removePrevRowReference("e", "m");
-
     gce.removeFileReference("f", "m", "../d/t-0/F00.rf");
-    gce.removeDirReference("f", "m");
-    gce.removePrevRowReference("f", "m");
-
     gca.collect(gce);
     assertRemoved(gce, "/8/t-0", "hdfs://foo:6000/accumulo/tables/9/t-0", "/a/t-0",
         "hdfs://foo:6000/accumulo/tables/b/t-0", "/c/t-0", "hdfs://foo:6000/accumulo/tables/d/t-0");
@@ -453,37 +340,18 @@ public class GarbageCollectionTest {
     gce.candidates.add("hdfs://foo:6000/user/foo/tables/d/t-0");
 
     gce.addDirReference("4", null, "/t-0");
-    gce.addPrevRowReference("4", null);
     gce.addDirReference("5", null, "/t-0");
-    gce.addPrevRowReference("5", null);
     gce.addDirReference("6", null, "hdfs://foo.com:6000/user/foo/tables/6/t-0");
-    gce.addPrevRowReference("6", null);
     gce.addDirReference("7", null, "hdfs://foo.com:6000/user/foo/tables/7/t-0");
-    gce.addPrevRowReference("7", null);
 
     gce.addFileReference("8", "m", "/t-0/F00.rf");
-    gce.addDirReference("8", "m", "hdfs://foo.com:6000/user/foo/tables/8/t-0");
-    gce.addPrevRowReference("8", "m");
-
     gce.addFileReference("9", "m", "/t-0/F00.rf");
-    gce.addDirReference("9", "m", "hdfs://foo.com:6000/user/foo/tables/9/t-0");
-    gce.addPrevRowReference("9", "m");
 
     gce.addFileReference("a", "m", "hdfs://foo.com:6000/user/foo/tables/a/t-0/F00.rf");
-    gce.addDirReference("a", "m", "hdfs://foo.com:6000/user/foo/tables/a/t-0");
-    gce.addPrevRowReference("a", "m");
-
     gce.addFileReference("b", "m", "hdfs://foo.com:6000/user/foo/tables/b/t-0/F00.rf");
-    gce.addDirReference("b", "m", "hdfs://foo.com:6000/user/foo/tables/b/t-0");
-    gce.addPrevRowReference("b", "m");
 
     gce.addFileReference("e", "m", "../c/t-0/F00.rf");
-    gce.addDirReference("e", "m", "hdfs://foo.com:6000/user/foo/tables/c/t-0");
-    gce.addPrevRowReference("e", "m");
-
     gce.addFileReference("f", "m", "../d/t-0/F00.rf");
-    gce.addDirReference("f", "m", "hdfs://foo.com:6000/user/foo/tables/d/t-0");
-    gce.addPrevRowReference("f", "m");
 
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
 
@@ -493,48 +361,24 @@ public class GarbageCollectionTest {
 
     // Removing the dir reference for a table will delete all tablet directories
     gce.removeDirReference("5", null);
-    gce.removePrevRowReference("5", null);
     gca.collect(gce);
     assertRemoved(gce, "hdfs://foo.com:6000/user/foo/tables/5/t-0");
 
     gce.removeDirReference("4", null);
-    gce.removePrevRowReference("4", null);
     gca.collect(gce);
     assertRemoved(gce, "/4/t-0");
 
     gce.removeDirReference("6", null);
-    gce.removePrevRowReference("6", null);
-
     gce.removeDirReference("7", null);
-    gce.removePrevRowReference("7", null);
-
     gca.collect(gce);
     assertRemoved(gce, "/6/t-0", "hdfs://foo:6000/user/foo/tables/7/t-0/");
 
     gce.removeFileReference("8", "m", "/t-0/F00.rf");
-    gce.removeDirReference("8", "m");
-    gce.removePrevRowReference("8", "m");
-
     gce.removeFileReference("9", "m", "/t-0/F00.rf");
-    gce.removeDirReference("9", "m");
-    gce.removePrevRowReference("9", "m");
-
     gce.removeFileReference("a", "m", "hdfs://foo.com:6000/user/foo/tables/a/t-0/F00.rf");
-    gce.removeDirReference("a", "m");
-    gce.removePrevRowReference("a", "m");
-
     gce.removeFileReference("b", "m", "hdfs://foo.com:6000/user/foo/tables/b/t-0/F00.rf");
-    gce.removeDirReference("b", "m");
-    gce.removePrevRowReference("b", "m");
-
     gce.removeFileReference("e", "m", "../c/t-0/F00.rf");
-    gce.removeDirReference("e", "m");
-    gce.removePrevRowReference("e", "m");
-
     gce.removeFileReference("f", "m", "../d/t-0/F00.rf");
-    gce.removeDirReference("f", "m");
-    gce.removePrevRowReference("f", "m");
-
     gca.collect(gce);
     assertRemoved(gce, "/8/t-0", "hdfs://foo:6000/user/foo/tables/9/t-0", "/a/t-0",
         "hdfs://foo:6000/user/foo/tables/b/t-0", "/c/t-0", "hdfs://foo:6000/user/foo/tables/d/t-0");
@@ -593,8 +437,8 @@ public class GarbageCollectionTest {
   @Test
   public void testBadDeletes() throws Exception {
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-    TestGCE gce = new TestGCE();
 
+    TestGCE gce = new TestGCE();
     gce.candidates.add("");
     gce.candidates.add("A");
     gce.candidates.add("/");
@@ -615,13 +459,12 @@ public class GarbageCollectionTest {
 
   @Test
   public void test() throws Exception {
+
     GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
 
     TestGCE gce = new TestGCE();
-
     gce.candidates.add("/1636/default_tablet");
     gce.addDirReference("1636", null, "/default_tablet");
-    gce.addPrevRowReference("1636", null);
     gca.collect(gce);
     assertRemoved(gce);
 
@@ -639,7 +482,6 @@ public class GarbageCollectionTest {
     gce = new TestGCE();
     gce.addFileReference("1636", null, "../9/default_tablet/someFile");
     gce.addDirReference("1636", null, "/default_tablet");
-    gce.addPrevRowReference("1636", null);
     gce.candidates.add("/9/default_tablet/someFile");
     gca.collect(gce);
     assertRemoved(gce);
@@ -670,7 +512,7 @@ public class GarbageCollectionTest {
 
     TestGCE gce = new TestGCE();
 
-    gce.tableIds.add("4");
+    gce.tableIds.add(TableId.of("4"));
 
     gce.candidates.add("/4/t-0");
     gce.candidates.add("/4/t-0/F002.rf");
@@ -679,13 +521,12 @@ public class GarbageCollectionTest {
     gce.candidates.add("hdfs://foo:6000/accumulo/tables/7/t-0/");
 
     gce.addDirReference("7", null, "hdfs://foo.com:6000/accumulo/tables/7/t-0");
-    gce.addPrevRowReference("7", null);
 
     gca.collect(gce);
 
-    HashSet<String> tids = new HashSet<>();
-    tids.add("5");
-    tids.add("6");
+    HashSet<TableId> tids = new HashSet<>();
+    tids.add(TableId.of("5"));
+    tids.add(TableId.of("6"));
 
     assertEquals(tids.size(), gce.tablesDirsToDelete.size());
     assertTrue(tids.containsAll(gce.tablesDirsToDelete));
@@ -770,114 +611,4 @@ public class GarbageCollectionTest {
     assertEquals(1, gce.deletes.size());
     assertEquals("hdfs://foo.com:6000/accumulo/tables/2/t-00002/A000002.rf", gce.deletes.get(0));
   }
-
-  /**
-   * Minimal test to show that dir and prevRow are required for valid scan (go path)
-   */
-  @Test
-  public void testDirAndPrevRow() throws Exception {
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet");
-    gce.addDirReference("1636", null, "/default_tablet");
-    gce.addPrevRowReference("1636", null);
-    gca.collect(gce);
-    assertEquals(0, gce.deletes.size());
-  }
-
-  /**
-   * Show that IllegalState is thrown when no dir entry present in metadata scan in last row seen.
-   */
-  @Test
-  public void testNoDirAsLastRow() {
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet");
-    gce.addPrevRowReference("1636", null);
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-    assertEquals(1, gce.candidates.size());
-  }
-
-  /**
-   * Show that IllegalState is thrown when no dir entry present in metadata scan.
-   */
-  @Test
-  public void testNoDir() {
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet/f1");
-    gce.addPrevRowReference("1636", "a");
-
-    gce.candidates.add("/1636/t1/f2");
-    gce.addDirReference("1636", null, "/t1");
-    gce.addPrevRowReference("1636", null);
-
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-    assertEquals(2, gce.candidates.size());
-  }
-
-  /**
-   * Show that IllegalState is thrown when no prev row present in metadata scan in last row seen.
-   */
-  @Test
-  public void testNoPrevRowAsLastRow() {
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet");
-    gce.addDirReference("1636", null, "/default_tablet");
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-    assertEquals(1, gce.candidates.size());
-  }
-
-  /**
-   * Show that IllegalState is thrown when no prevRow entry present in metadata scan.
-   */
-  @Test
-  public void testPrevRow() {
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet/f1");
-    gce.addDirReference("1636", "a", "/default_tablet");
-
-    gce.candidates.add("/1636/t1/f2");
-    gce.addDirReference("1636", null, "/t1");
-    gce.addPrevRowReference("1636", null);
-
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-    assertEquals(2, gce.candidates.size());
-  }
-
-  /**
-   * Show that IllegalState is thrown when no prevRow entry present in metadata scan.
-   */
-  @Test
-  public void testPrevRowOnly() {
-    TestGCE gce = new TestGCE();
-
-    gce.candidates.add("hdfs://foo:6000/accumulo/tables/4/t0/F000.rf");
-    gce.candidates.add("hdfs://foo.com:6000/accumulo/tables/4/t0/F001.rf");
-    gce.candidates.add("hdfs://foo.com:6000/accumulo/tables/5/t0/F005.rf");
-
-    gce.addPrevRowReference("1636", null);
-
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-    assertEquals(3, gce.candidates.size());
-  }
-
-  @Test
-  public void testNoPrevRowNoDir() throws Exception {
-
-    GarbageCollectionAlgorithm gca = new GarbageCollectionAlgorithm();
-
-    TestGCE gce = new TestGCE();
-    gce.candidates.add("/1636/default_tablet");
-    gce.addFileReference("b", "m", "hdfs://foo.com:6000/user/foo/tables/b/t-0/F00.rf");
-    assertThrows(IllegalStateException.class, () -> gca.collect(gce));
-  }
 }
