@@ -16,14 +16,15 @@
  */
 package org.apache.accumulo.master;
 
-import static org.apache.accumulo.master.util.TableValidators.CAN_CLONE;
 import static org.apache.accumulo.master.util.TableValidators.NOT_METADATA;
 import static org.apache.accumulo.master.util.TableValidators.NOT_ROOT_ID;
 import static org.apache.accumulo.master.util.TableValidators.NOT_SYSTEM;
 import static org.apache.accumulo.master.util.TableValidators.VALID_ID;
 import static org.apache.accumulo.master.util.TableValidators.VALID_NAME;
 
+import java.io.IOException;
 import java.nio.ByteBuffer;
+import java.util.Base64;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -36,49 +37,53 @@ import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.NamespaceNotFoundException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.CompactionStrategyConfig;
+import org.apache.accumulo.core.client.admin.InitialTableState;
 import org.apache.accumulo.core.client.admin.TimeType;
-import org.apache.accumulo.core.client.impl.CompactionStrategyConfigUtil;
-import org.apache.accumulo.core.client.impl.Namespaces;
-import org.apache.accumulo.core.client.impl.TableOperationsImpl;
-import org.apache.accumulo.core.client.impl.Tables;
-import org.apache.accumulo.core.client.impl.thrift.SecurityErrorCode;
-import org.apache.accumulo.core.client.impl.thrift.TableOperation;
-import org.apache.accumulo.core.client.impl.thrift.TableOperationExceptionType;
-import org.apache.accumulo.core.client.impl.thrift.ThriftSecurityException;
-import org.apache.accumulo.core.client.impl.thrift.ThriftTableOperationException;
-import org.apache.accumulo.core.iterators.IteratorUtil;
+import org.apache.accumulo.core.clientImpl.CompactionStrategyConfigUtil;
+import org.apache.accumulo.core.clientImpl.Namespaces;
+import org.apache.accumulo.core.clientImpl.TableOperationsImpl;
+import org.apache.accumulo.core.clientImpl.Tables;
+import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
+import org.apache.accumulo.core.data.NamespaceId;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.master.thrift.BulkImportState;
 import org.apache.accumulo.core.master.thrift.FateOperation;
 import org.apache.accumulo.core.master.thrift.FateService;
-import org.apache.accumulo.core.security.thrift.TCredentials;
+import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.trace.thrift.TInfo;
 import org.apache.accumulo.core.util.ByteBufferUtil;
+import org.apache.accumulo.core.util.SystemIteratorUtil;
 import org.apache.accumulo.core.util.Validator;
+import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.fate.ReadOnlyTStore.TStatus;
-import org.apache.accumulo.master.tableOps.BulkImport;
-import org.apache.accumulo.master.tableOps.CancelCompactions;
 import org.apache.accumulo.master.tableOps.ChangeTableState;
-import org.apache.accumulo.master.tableOps.CloneTable;
-import org.apache.accumulo.master.tableOps.CompactRange;
-import org.apache.accumulo.master.tableOps.CreateNamespace;
-import org.apache.accumulo.master.tableOps.CreateTable;
-import org.apache.accumulo.master.tableOps.DeleteNamespace;
-import org.apache.accumulo.master.tableOps.DeleteTable;
-import org.apache.accumulo.master.tableOps.ExportTable;
-import org.apache.accumulo.master.tableOps.ImportTable;
-import org.apache.accumulo.master.tableOps.RenameNamespace;
-import org.apache.accumulo.master.tableOps.RenameTable;
-import org.apache.accumulo.master.tableOps.TableRangeOp;
 import org.apache.accumulo.master.tableOps.TraceRepo;
+import org.apache.accumulo.master.tableOps.bulkVer2.PrepBulkImport;
+import org.apache.accumulo.master.tableOps.clone.CloneTable;
+import org.apache.accumulo.master.tableOps.compact.CompactRange;
+import org.apache.accumulo.master.tableOps.compact.cancel.CancelCompactions;
+import org.apache.accumulo.master.tableOps.create.CreateTable;
+import org.apache.accumulo.master.tableOps.delete.DeleteTable;
+import org.apache.accumulo.master.tableOps.merge.TableRangeOp;
+import org.apache.accumulo.master.tableOps.namespace.create.CreateNamespace;
+import org.apache.accumulo.master.tableOps.namespace.delete.DeleteNamespace;
+import org.apache.accumulo.master.tableOps.namespace.rename.RenameNamespace;
+import org.apache.accumulo.master.tableOps.rename.RenameTable;
+import org.apache.accumulo.master.tableOps.tableExport.ExportTable;
+import org.apache.accumulo.master.tableOps.tableImport.ImportTable;
 import org.apache.accumulo.server.client.ClientServiceHandler;
 import org.apache.accumulo.server.master.state.MergeInfo;
 import org.apache.accumulo.server.util.TablePropUtil;
+import org.apache.hadoop.fs.FSDataOutputStream;
+import org.apache.hadoop.fs.FileSystem;
+import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
 import org.slf4j.Logger;
 
-/**
- *
- */
 class FateServiceHandler implements FateService.Iface {
 
   protected final Master master;
@@ -107,7 +112,7 @@ class FateServiceHandler implements FateService.Iface {
         validateArgumentCount(arguments, tableOp, 1);
         String namespace = validateNamespaceArgument(arguments.get(0), tableOp, null);
 
-        if (!master.security.canCreateNamespace(c, namespace))
+        if (!master.security.canCreateNamespace(c))
           throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
         master.fate.seedTransaction(opid,
@@ -122,9 +127,9 @@ class FateServiceHandler implements FateService.Iface {
             Namespaces.NOT_DEFAULT.and(Namespaces.NOT_ACCUMULO));
         String newName = validateNamespaceArgument(arguments.get(1), tableOp, null);
 
-        String namespaceId =
-            ClientServiceHandler.checkNamespaceId(master.getInstance(), oldName, tableOp);
-        if (!master.security.canRenameNamespace(c, namespaceId, oldName, newName))
+        NamespaceId namespaceId =
+            ClientServiceHandler.checkNamespaceId(master.getContext(), oldName, tableOp);
+        if (!master.security.canRenameNamespace(c, namespaceId))
           throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
         master.fate.seedTransaction(opid,
@@ -137,8 +142,8 @@ class FateServiceHandler implements FateService.Iface {
         String namespace = validateNamespaceArgument(arguments.get(0), tableOp,
             Namespaces.NOT_DEFAULT.and(Namespaces.NOT_ACCUMULO));
 
-        String namespaceId =
-            ClientServiceHandler.checkNamespaceId(master.getInstance(), namespace, tableOp);
+        NamespaceId namespaceId =
+            ClientServiceHandler.checkNamespaceId(master.getContext(), namespace, tableOp);
         if (!master.security.canDeleteNamespace(c, namespaceId))
           throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
@@ -148,15 +153,35 @@ class FateServiceHandler implements FateService.Iface {
       }
       case TABLE_CREATE: {
         TableOperation tableOp = TableOperation.CREATE;
-        validateArgumentCount(arguments, tableOp, 2);
+        int SPLIT_OFFSET = 4; // offset where split data begins in arguments list
+        if (arguments.size() < SPLIT_OFFSET) {
+          throw new ThriftTableOperationException(null, null, tableOp,
+              TableOperationExceptionType.OTHER,
+              "Expected at least " + SPLIT_OFFSET + " arguments, saw :" + arguments.size());
+        }
         String tableName = validateTableNameArgument(arguments.get(0), tableOp, NOT_SYSTEM);
         TimeType timeType = TimeType.valueOf(ByteBufferUtil.toString(arguments.get(1)));
-
-        String namespaceId;
+        InitialTableState initialTableState =
+            InitialTableState.valueOf(ByteBufferUtil.toString(arguments.get(2)));
+        int splitCount = Integer.parseInt(ByteBufferUtil.toString(arguments.get(3)));
+        validateArgumentCount(arguments, tableOp, SPLIT_OFFSET + splitCount);
+        String splitFile = null;
+        String splitDirsFile = null;
+        if (splitCount > 0) {
+          try {
+            splitFile = writeSplitsToFile(opid, arguments, splitCount, SPLIT_OFFSET);
+            splitDirsFile = createSplitDirsFile(opid);
+          } catch (IOException e) {
+            throw new ThriftTableOperationException(null, tableName, tableOp,
+                TableOperationExceptionType.OTHER,
+                "Exception thrown while writing splits to file system");
+          }
+        }
+        NamespaceId namespaceId;
 
         try {
           namespaceId =
-              Namespaces.getNamespaceId(master.getInstance(), Tables.qualify(tableName).getFirst());
+              Namespaces.getNamespaceId(master.getContext(), Tables.qualify(tableName).getFirst());
         } catch (NamespaceNotFoundException e) {
           throw new ThriftTableOperationException(null, tableName, tableOp,
               TableOperationExceptionType.NAMESPACE_NOTFOUND, "");
@@ -166,8 +191,8 @@ class FateServiceHandler implements FateService.Iface {
           throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
         master.fate.seedTransaction(opid,
-            new TraceRepo<>(
-                new CreateTable(c.getPrincipal(), tableName, timeType, options, namespaceId)),
+            new TraceRepo<>(new CreateTable(c.getPrincipal(), tableName, timeType, options,
+                splitFile, splitCount, splitDirsFile, initialTableState, namespaceId)),
             autoCleanup);
 
         break;
@@ -181,7 +206,7 @@ class FateServiceHandler implements FateService.Iface {
             validateTableNameArgument(arguments.get(1), tableOp, new Validator<String>() {
 
               @Override
-              public boolean apply(String argument) {
+              public boolean test(String argument) {
                 // verify they are in the same namespace
                 String oldNamespace = Tables.qualify(oldTableName).getFirst();
                 return oldNamespace.equals(Tables.qualify(argument).getFirst());
@@ -195,9 +220,9 @@ class FateServiceHandler implements FateService.Iface {
 
             });
 
-        String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), oldTableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), oldTableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canRename;
         try {
@@ -224,18 +249,13 @@ class FateServiceHandler implements FateService.Iface {
       }
       case TABLE_CLONE: {
         TableOperation tableOp = TableOperation.CLONE;
-        validateArgumentCount(arguments, tableOp, 3);
-        String srcTableId = validateTableIdArgument(arguments.get(0), tableOp, CAN_CLONE);
+        validateArgumentCount(arguments, tableOp, 2);
+        TableId srcTableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
         String tableName = validateTableNameArgument(arguments.get(1), tableOp, NOT_SYSTEM);
-        boolean keepOffline = false;
-        if (arguments.get(2) != null) {
-          keepOffline = Boolean.parseBoolean(ByteBufferUtil.toString(arguments.get(2)));
-        }
-
-        String namespaceId;
+        NamespaceId namespaceId;
         try {
           namespaceId =
-              Namespaces.getNamespaceId(master.getInstance(), Tables.qualify(tableName).getFirst());
+              Namespaces.getNamespaceId(master.getContext(), Tables.qualify(tableName).getFirst());
         } catch (NamespaceNotFoundException e) {
           // shouldn't happen, but possible once cloning between namespaces is supported
           throw new ThriftTableOperationException(null, tableName, tableOp,
@@ -274,7 +294,7 @@ class FateServiceHandler implements FateService.Iface {
         }
 
         master.fate.seedTransaction(opid, new TraceRepo<>(new CloneTable(c.getPrincipal(),
-            namespaceId, srcTableId, tableName, propertiesToSet, propertiesToExclude, keepOffline)),
+            namespaceId, srcTableId, tableName, propertiesToSet, propertiesToExclude)),
             autoCleanup);
 
         break;
@@ -284,9 +304,9 @@ class FateServiceHandler implements FateService.Iface {
         validateArgumentCount(arguments, tableOp, 1);
         String tableName = validateTableNameArgument(arguments.get(0), tableOp, NOT_SYSTEM);
 
-        final String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), tableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), tableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canDeleteTable;
         try {
@@ -305,8 +325,8 @@ class FateServiceHandler implements FateService.Iface {
       case TABLE_ONLINE: {
         TableOperation tableOp = TableOperation.ONLINE;
         validateArgumentCount(arguments, tableOp, 1);
-        final String tableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canOnlineOfflineTable;
         try {
@@ -327,8 +347,8 @@ class FateServiceHandler implements FateService.Iface {
       case TABLE_OFFLINE: {
         TableOperation tableOp = TableOperation.OFFLINE;
         validateArgumentCount(arguments, tableOp, 1);
-        final String tableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canOnlineOfflineTable;
         try {
@@ -353,9 +373,9 @@ class FateServiceHandler implements FateService.Iface {
         Text startRow = ByteBufferUtil.toText(arguments.get(1));
         Text endRow = ByteBufferUtil.toText(arguments.get(2));
 
-        final String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), tableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), tableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canMerge;
         try {
@@ -368,7 +388,7 @@ class FateServiceHandler implements FateService.Iface {
         if (!canMerge)
           throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
-        Master.log.debug("Creating merge op: " + tableId + " " + startRow + " " + endRow);
+        Master.log.debug("Creating merge op: {} {} {}", tableId, startRow, endRow);
         master.fate.seedTransaction(opid, new TraceRepo<>(
             new TableRangeOp(MergeInfo.Operation.MERGE, namespaceId, tableId, startRow, endRow)),
             autoCleanup);
@@ -381,9 +401,9 @@ class FateServiceHandler implements FateService.Iface {
         Text startRow = ByteBufferUtil.toText(arguments.get(1));
         Text endRow = ByteBufferUtil.toText(arguments.get(2));
 
-        final String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), tableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), tableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canDeleteRange;
         try {
@@ -410,9 +430,9 @@ class FateServiceHandler implements FateService.Iface {
         String failDir = ByteBufferUtil.toString(arguments.get(2));
         boolean setTime = Boolean.parseBoolean(ByteBufferUtil.toString(arguments.get(3)));
 
-        final String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), tableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        final TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), tableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canBulkImport;
         try {
@@ -428,20 +448,22 @@ class FateServiceHandler implements FateService.Iface {
 
         master.updateBulkImportStatus(dir, BulkImportState.INITIAL);
         master.fate.seedTransaction(opid,
-            new TraceRepo<>(new BulkImport(tableId, dir, failDir, setTime)), autoCleanup);
+            new TraceRepo<>(new org.apache.accumulo.master.tableOps.bulkVer1.BulkImport(tableId,
+                dir, failDir, setTime)),
+            autoCleanup);
         break;
       }
       case TABLE_COMPACT: {
         TableOperation tableOp = TableOperation.COMPACT;
         validateArgumentCount(arguments, tableOp, 5);
-        String tableId = validateTableIdArgument(arguments.get(0), tableOp, null);
+        TableId tableId = validateTableIdArgument(arguments.get(0), tableOp, null);
         byte[] startRow = ByteBufferUtil.toBytes(arguments.get(1));
         byte[] endRow = ByteBufferUtil.toBytes(arguments.get(2));
         List<IteratorSetting> iterators =
-            IteratorUtil.decodeIteratorSettings(ByteBufferUtil.toBytes(arguments.get(3)));
+            SystemIteratorUtil.decodeIteratorSettings(ByteBufferUtil.toBytes(arguments.get(3)));
         CompactionStrategyConfig compactionStrategy =
             CompactionStrategyConfigUtil.decode(ByteBufferUtil.toBytes(arguments.get(4)));
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canCompact;
         try {
@@ -461,8 +483,8 @@ class FateServiceHandler implements FateService.Iface {
       case TABLE_CANCEL_COMPACT: {
         TableOperation tableOp = TableOperation.COMPACT_CANCEL;
         validateArgumentCount(arguments, tableOp, 1);
-        String tableId = validateTableIdArgument(arguments.get(0), tableOp, null);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        TableId tableId = validateTableIdArgument(arguments.get(0), tableOp, null);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canCancelCompact;
         try {
@@ -484,10 +506,10 @@ class FateServiceHandler implements FateService.Iface {
         validateArgumentCount(arguments, tableOp, 2);
         String tableName = validateTableNameArgument(arguments.get(0), tableOp, NOT_SYSTEM);
         String exportDir = ByteBufferUtil.toString(arguments.get(1));
-        String namespaceId;
+        NamespaceId namespaceId;
         try {
           namespaceId =
-              Namespaces.getNamespaceId(master.getInstance(), Tables.qualify(tableName).getFirst());
+              Namespaces.getNamespaceId(master.getContext(), Tables.qualify(tableName).getFirst());
         } catch (NamespaceNotFoundException e) {
           throw new ThriftTableOperationException(null, tableName, tableOp,
               TableOperationExceptionType.NAMESPACE_NOTFOUND, "");
@@ -515,9 +537,9 @@ class FateServiceHandler implements FateService.Iface {
         String tableName = validateTableNameArgument(arguments.get(0), tableOp, NOT_SYSTEM);
         String exportDir = ByteBufferUtil.toString(arguments.get(1));
 
-        String tableId =
-            ClientServiceHandler.checkTableId(master.getInstance(), tableName, tableOp);
-        String namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+        TableId tableId =
+            ClientServiceHandler.checkTableId(master.getContext(), tableName, tableOp);
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
 
         final boolean canExport;
         try {
@@ -535,18 +557,48 @@ class FateServiceHandler implements FateService.Iface {
             autoCleanup);
         break;
       }
+      case TABLE_BULK_IMPORT2:
+        TableOperation tableOp = TableOperation.BULK_IMPORT;
+        validateArgumentCount(arguments, tableOp, 3);
+        TableId tableId = validateTableIdArgument(arguments.get(0), tableOp, NOT_ROOT_ID);
+        String dir = ByteBufferUtil.toString(arguments.get(1));
+
+        boolean setTime = Boolean.parseBoolean(ByteBufferUtil.toString(arguments.get(2)));
+
+        NamespaceId namespaceId = getNamespaceIdFromTableId(tableOp, tableId);
+
+        final boolean canBulkImport;
+        try {
+          String tableName = Tables.getTableName(master.getContext(), tableId);
+          canBulkImport =
+              master.security.canBulkImport(c, tableId, tableName, dir, null, namespaceId);
+        } catch (ThriftSecurityException e) {
+          throwIfTableMissingSecurityException(e, tableId, "", TableOperation.BULK_IMPORT);
+          throw e;
+        } catch (TableNotFoundException e) {
+          throw new ThriftTableOperationException(tableId.canonical(), null,
+              TableOperation.BULK_IMPORT, TableOperationExceptionType.NOTFOUND,
+              "Table no longer exists");
+        }
+
+        if (!canBulkImport)
+          throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
+
+        master.fate.seedTransaction(opid,
+            new TraceRepo<>(new PrepBulkImport(tableId, dir, setTime)), autoCleanup);
+        break;
       default:
         throw new UnsupportedOperationException();
     }
   }
 
-  private String getNamespaceIdFromTableId(TableOperation tableOp, String tableId)
+  private NamespaceId getNamespaceIdFromTableId(TableOperation tableOp, TableId tableId)
       throws ThriftTableOperationException {
-    String namespaceId;
+    NamespaceId namespaceId;
     try {
-      namespaceId = Tables.getNamespaceId(master.getInstance(), tableId);
+      namespaceId = Tables.getNamespaceId(master.getContext(), tableId);
     } catch (TableNotFoundException e) {
-      throw new ThriftTableOperationException(tableId, null, tableOp,
+      throw new ThriftTableOperationException(tableId.canonical(), null, tableOp,
           TableOperationExceptionType.NOTFOUND, e.getMessage());
     }
     return namespaceId;
@@ -572,11 +624,11 @@ class FateServiceHandler implements FateService.Iface {
    * @throws ThriftTableOperationException
    *           Thrown if {@code e} was thrown because {@link SecurityErrorCode#TABLE_DOESNT_EXIST}
    */
-  private void throwIfTableMissingSecurityException(ThriftSecurityException e, String tableId,
+  private void throwIfTableMissingSecurityException(ThriftSecurityException e, TableId tableId,
       String tableName, TableOperation op) throws ThriftTableOperationException {
     // ACCUMULO-3135 Table can be deleted after we get table ID but before we can check permission
-    if (e.isSetCode() && SecurityErrorCode.TABLE_DOESNT_EXIST == e.getCode()) {
-      throw new ThriftTableOperationException(tableId, tableName, op,
+    if (e.isSetCode() && e.getCode() == SecurityErrorCode.TABLE_DOESNT_EXIST) {
+      throw new ThriftTableOperationException(tableId.canonical(), tableName, op,
           TableOperationExceptionType.NOTFOUND, "Table no longer exists");
     }
   }
@@ -622,9 +674,9 @@ class FateServiceHandler implements FateService.Iface {
   }
 
   // Verify table name arguments are valid, and match any additional restrictions
-  private String validateTableIdArgument(ByteBuffer tableIdArg, TableOperation op,
-      Validator<String> userValidator) throws ThriftTableOperationException {
-    String tableId = tableIdArg == null ? null : ByteBufferUtil.toString(tableIdArg);
+  private TableId validateTableIdArgument(ByteBuffer tableIdArg, TableOperation op,
+      Validator<TableId> userValidator) throws ThriftTableOperationException {
+    TableId tableId = tableIdArg == null ? null : ByteBufferUtil.toTableId(tableIdArg);
     try {
       return VALID_ID.and(userValidator).validate(tableId);
     } catch (IllegalArgumentException e) {
@@ -632,7 +684,7 @@ class FateServiceHandler implements FateService.Iface {
       // Information provided by a client should generate a user-level exception, not a system-level
       // warning.
       log.debug(why);
-      throw new ThriftTableOperationException(tableId, null, op,
+      throw new ThriftTableOperationException(tableId.canonical(), null, op,
           TableOperationExceptionType.INVALID_NAME, why);
     }
   }
@@ -673,4 +725,69 @@ class FateServiceHandler implements FateService.Iface {
           TableOperationExceptionType.INVALID_NAME, why);
     }
   }
+
+  /**
+   * Create a file on the file system to hold the splits to be created at table creation.
+   */
+  private String writeSplitsToFile(final long opid, final List<ByteBuffer> arguments,
+      final int splitCount, final int splitOffset) throws IOException {
+    String opidStr = String.format("%016x", opid);
+    String splitsPath = getSplitPath("/tmp/splits-" + opidStr);
+    removeAndCreateTempFile(splitsPath);
+    try (FSDataOutputStream stream = master.getOutputStream(splitsPath)) {
+      writeSplitsToFileSystem(stream, arguments, splitCount, splitOffset);
+    } catch (IOException e) {
+      log.error("Error in FateServiceHandler while writing splits for opid: " + opidStr + ": "
+          + e.getMessage());
+      throw e;
+    }
+    return splitsPath;
+  }
+
+  /**
+   * Always check for and delete the splits file if it exists to prevent issues in case of server
+   * failure and/or FateServiceHandler retries.
+   */
+  private void removeAndCreateTempFile(String path) throws IOException {
+    FileSystem fs = master.getFileSystem().getDefaultVolume().getFileSystem();
+    if (fs.exists(new Path(path)))
+      fs.delete(new Path(path), true);
+    fs.create(new Path(path));
+  }
+
+  /**
+   * Check for and delete the temp file if it exists to prevent issues in case of server failure
+   * and/or FateServiceHandler retries. Then create/recreate the file.
+   */
+  private String createSplitDirsFile(final long opid) throws IOException {
+    String opidStr = String.format("%016x", opid);
+    String splitDirPath = getSplitPath("/tmp/splitDirs-" + opidStr);
+    removeAndCreateTempFile(splitDirPath);
+    return splitDirPath;
+  }
+
+  /**
+   * Write the split values to a tmp directory with unique name. Given that it is not known if the
+   * supplied splits will be textual or binary, all splits will be encoded to enable proper handling
+   * of binary data.
+   */
+  private void writeSplitsToFileSystem(final FSDataOutputStream stream,
+      final List<ByteBuffer> arguments, final int splitCount, final int splitOffset)
+      throws IOException {
+    for (int i = splitOffset; i < splitCount + splitOffset; i++) {
+      byte[] splitBytes = ByteBufferUtil.toBytes(arguments.get(i));
+      String encodedSplit = Base64.getEncoder().encodeToString(splitBytes);
+      stream.writeBytes(encodedSplit + '\n');
+    }
+  }
+
+  /**
+   * Get full path to location where initial splits are stored on file system.
+   */
+  private String getSplitPath(String relPath) {
+    Volume defaultVolume = master.getFileSystem().getDefaultVolume();
+    String uri = defaultVolume.getFileSystem().getUri().toString();
+    String basePath = defaultVolume.getBasePath();
+    return uri + basePath + relPath;
+  }
 }
