@@ -22,37 +22,34 @@ import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.BatchScanner;
-import org.apache.accumulo.core.client.Connector;
-import org.apache.accumulo.core.client.Instance;
-import org.apache.accumulo.core.client.IsolatedScanner;
-import org.apache.accumulo.core.client.RowIterator;
-import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.DelegationTokenConfig;
-import org.apache.accumulo.core.client.impl.AuthenticationTokenIdentifier;
-import org.apache.accumulo.core.client.impl.DelegationTokenConfigSerializer;
-import org.apache.accumulo.core.client.impl.Tables;
-import org.apache.accumulo.core.client.impl.thrift.SecurityErrorCode;
-import org.apache.accumulo.core.client.impl.thrift.TableOperation;
-import org.apache.accumulo.core.client.impl.thrift.TableOperationExceptionType;
-import org.apache.accumulo.core.client.impl.thrift.ThriftSecurityException;
-import org.apache.accumulo.core.client.impl.thrift.ThriftTableOperationException;
+import org.apache.accumulo.core.clientImpl.AuthenticationTokenIdentifier;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.DelegationTokenConfigSerializer;
+import org.apache.accumulo.core.clientImpl.Tables;
+import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
+import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Key;
+import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.data.thrift.TKeyExtent;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.master.thrift.MasterClientService;
 import org.apache.accumulo.core.master.thrift.MasterGoalState;
 import org.apache.accumulo.core.master.thrift.MasterMonitorInfo;
@@ -61,17 +58,17 @@ import org.apache.accumulo.core.master.thrift.TabletLoadState;
 import org.apache.accumulo.core.master.thrift.TabletSplit;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.ReplicationSection;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.LogColumnFamily;
+import org.apache.accumulo.core.metadata.schema.TabletDeletedException;
+import org.apache.accumulo.core.metadata.schema.TabletMetadata;
+import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.replication.ReplicationSchema.OrderSection;
 import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.security.Authorizations;
-import org.apache.accumulo.core.security.thrift.TCredentials;
-import org.apache.accumulo.core.security.thrift.TDelegationToken;
-import org.apache.accumulo.core.security.thrift.TDelegationTokenConfig;
+import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
+import org.apache.accumulo.core.securityImpl.thrift.TDelegationToken;
+import org.apache.accumulo.core.securityImpl.thrift.TDelegationTokenConfig;
 import org.apache.accumulo.core.trace.thrift.TInfo;
 import org.apache.accumulo.core.util.ByteBufferUtil;
 import org.apache.accumulo.fate.zookeeper.IZooReaderWriter;
@@ -89,8 +86,6 @@ import org.apache.accumulo.server.security.delegation.AuthenticationTokenSecretM
 import org.apache.accumulo.server.util.NamespacePropUtil;
 import org.apache.accumulo.server.util.SystemPropUtil;
 import org.apache.accumulo.server.util.TablePropUtil;
-import org.apache.accumulo.server.util.TabletIterator.TabletDeletedException;
-import org.apache.accumulo.server.zookeeper.ZooReaderWriter;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.security.token.Token;
 import org.apache.thrift.TException;
@@ -107,56 +102,58 @@ public class MasterClientServiceHandler extends FateServiceHandler
   private static final Logger log = Master.log;
   private static final Logger drainLog =
       LoggerFactory.getLogger("org.apache.accumulo.master.MasterDrainImpl");
-  private Instance instance;
 
   protected MasterClientServiceHandler(Master master) {
     super(master);
-    this.instance = master.getInstance();
   }
 
   @Override
-  public long initiateFlush(TInfo tinfo, TCredentials c, String tableId)
+  public long initiateFlush(TInfo tinfo, TCredentials c, String tableIdStr)
       throws ThriftSecurityException, ThriftTableOperationException {
-    String namespaceId = getNamespaceIdFromTableId(TableOperation.FLUSH, tableId);
+    TableId tableId = TableId.of(tableIdStr);
+    NamespaceId namespaceId = getNamespaceIdFromTableId(TableOperation.FLUSH, tableId);
     if (!master.security.canFlush(c, tableId, namespaceId))
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
-    String zTablePath = Constants.ZROOT + "/" + master.getInstance().getInstanceID()
-        + Constants.ZTABLES + "/" + tableId + Constants.ZTABLE_FLUSH_ID;
+    String zTablePath = Constants.ZROOT + "/" + master.getInstanceID() + Constants.ZTABLES + "/"
+        + tableId + Constants.ZTABLE_FLUSH_ID;
 
-    IZooReaderWriter zoo = ZooReaderWriter.getInstance();
-    byte fid[];
+    IZooReaderWriter zoo = master.getContext().getZooReaderWriter();
+    byte[] fid;
     try {
       fid = zoo.mutate(zTablePath, null, null, new Mutator() {
         @Override
-        public byte[] mutate(byte[] currentValue) throws Exception {
+        public byte[] mutate(byte[] currentValue) {
           long flushID = Long.parseLong(new String(currentValue));
           flushID++;
           return ("" + flushID).getBytes();
         }
       });
     } catch (NoNodeException nne) {
-      throw new ThriftTableOperationException(tableId, null, TableOperation.FLUSH,
+      throw new ThriftTableOperationException(tableId.canonical(), null, TableOperation.FLUSH,
           TableOperationExceptionType.NOTFOUND, null);
     } catch (Exception e) {
       Master.log.warn("{}", e.getMessage(), e);
-      throw new ThriftTableOperationException(tableId, null, TableOperation.FLUSH,
+      throw new ThriftTableOperationException(tableId.canonical(), null, TableOperation.FLUSH,
           TableOperationExceptionType.OTHER, null);
     }
     return Long.parseLong(new String(fid));
   }
 
   @Override
-  public void waitForFlush(TInfo tinfo, TCredentials c, String tableId, ByteBuffer startRow,
-      ByteBuffer endRow, long flushID, long maxLoops)
+  public void waitForFlush(TInfo tinfo, TCredentials c, String tableIdStr, ByteBuffer startRowBB,
+      ByteBuffer endRowBB, long flushID, long maxLoops)
       throws ThriftSecurityException, ThriftTableOperationException {
-    String namespaceId = getNamespaceIdFromTableId(TableOperation.FLUSH, tableId);
+    TableId tableId = TableId.of(tableIdStr);
+    NamespaceId namespaceId = getNamespaceIdFromTableId(TableOperation.FLUSH, tableId);
     if (!master.security.canFlush(c, tableId, namespaceId))
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
-    if (endRow != null && startRow != null
-        && ByteBufferUtil.toText(startRow).compareTo(ByteBufferUtil.toText(endRow)) >= 0)
-      throw new ThriftTableOperationException(tableId, null, TableOperation.FLUSH,
+    Text startRow = ByteBufferUtil.toText(startRowBB);
+    Text endRow = ByteBufferUtil.toText(endRowBB);
+
+    if (endRow != null && startRow != null && startRow.compareTo(endRow) >= 0)
+      throw new ThriftTableOperationException(tableId.canonical(), null, TableOperation.FLUSH,
           TableOperationExceptionType.BAD_RANGE, "start row must be less than end row");
 
     Set<TServerInstance> serversToFlush = new HashSet<>(master.tserverSet.getCurrentServers());
@@ -167,13 +164,16 @@ public class MasterClientServiceHandler extends FateServiceHandler
         try {
           final TServerConnection server = master.tserverSet.getConnection(instance);
           if (server != null)
-            server.flush(master.masterLock, tableId, ByteBufferUtil.toBytes(startRow),
-                ByteBufferUtil.toBytes(endRow));
+            server.flush(master.masterLock, tableId, ByteBufferUtil.toBytes(startRowBB),
+                ByteBufferUtil.toBytes(endRowBB));
         } catch (TException ex) {
           Master.log.error(ex.toString());
         }
       }
 
+      if (tableId.equals(RootTable.ID))
+        break; // this code does not properly handle the root tablet. See #798
+
       if (l == maxLoops - 1)
         break;
 
@@ -181,71 +181,23 @@ public class MasterClientServiceHandler extends FateServiceHandler
 
       serversToFlush.clear();
 
-      try {
-        Connector conn = master.getConnector();
-        Scanner scanner;
-        if (tableId.equals(MetadataTable.ID)) {
-          scanner = new IsolatedScanner(conn.createScanner(RootTable.NAME, Authorizations.EMPTY));
-          scanner.setRange(MetadataSchema.TabletsSection.getRange());
-        } else {
-          scanner =
-              new IsolatedScanner(conn.createScanner(MetadataTable.NAME, Authorizations.EMPTY));
-          Range range =
-              new KeyExtent(tableId, null, ByteBufferUtil.toText(startRow)).toMetadataRange();
-          scanner.setRange(range.clip(MetadataSchema.TabletsSection.getRange()));
-        }
-        TabletsSection.ServerColumnFamily.FLUSH_COLUMN.fetch(scanner);
-        TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.fetch(scanner);
-        scanner.fetchColumnFamily(TabletsSection.CurrentLocationColumnFamily.NAME);
-        scanner.fetchColumnFamily(LogColumnFamily.NAME);
-
-        RowIterator ri = new RowIterator(scanner);
-
+      try (TabletsMetadata tablets =
+          TabletsMetadata.builder().forTable(tableId).overlapping(startRow, endRow).fetchFlushId()
+              .fetchLocation().fetchLogs().fetchPrev().build(master.getContext())) {
         int tabletsToWaitFor = 0;
         int tabletCount = 0;
 
-        Text ert = ByteBufferUtil.toText(endRow);
-
-        while (ri.hasNext()) {
-          Iterator<Entry<Key,Value>> row = ri.next();
-          long tabletFlushID = -1;
-          int logs = 0;
-          boolean online = false;
-
-          TServerInstance server = null;
-
-          Entry<Key,Value> entry = null;
-          while (row.hasNext()) {
-            entry = row.next();
-            Key key = entry.getKey();
-
-            if (TabletsSection.ServerColumnFamily.FLUSH_COLUMN.equals(key.getColumnFamily(),
-                key.getColumnQualifier())) {
-              tabletFlushID = Long.parseLong(entry.getValue().toString());
-            }
-
-            if (LogColumnFamily.NAME.equals(key.getColumnFamily()))
-              logs++;
-
-            if (TabletsSection.CurrentLocationColumnFamily.NAME.equals(key.getColumnFamily())) {
-              online = true;
-              server = new TServerInstance(entry.getValue(), key.getColumnQualifier());
-            }
-
-          }
+        for (TabletMetadata tablet : tablets) {
+          int logs = tablet.getLogs().size();
 
           // when tablet is not online and has no logs, there is no reason to wait for it
-          if ((online || logs > 0) && tabletFlushID < flushID) {
+          if ((tablet.hasCurrent() || logs > 0) && tablet.getFlushId().orElse(-1) < flushID) {
             tabletsToWaitFor++;
-            if (server != null)
-              serversToFlush.add(server);
+            if (tablet.hasCurrent())
+              serversToFlush.add(new TServerInstance(tablet.getLocation()));
           }
 
           tabletCount++;
-
-          Text tabletEndRow = new KeyExtent(entry.getKey().getRow(), (Text) null).getEndRow();
-          if (tabletEndRow == null || (ert != null && tabletEndRow.compareTo(ert) >= 0))
-            break;
         }
 
         if (tabletsToWaitFor == 0)
@@ -253,42 +205,32 @@ public class MasterClientServiceHandler extends FateServiceHandler
 
         // TODO detect case of table offline AND tablets w/ logs? - ACCUMULO-1296
 
-        if (tabletCount == 0 && !Tables.exists(master.getInstance(), tableId))
-          throw new ThriftTableOperationException(tableId, null, TableOperation.FLUSH,
+        if (tabletCount == 0 && !Tables.exists(master.getContext(), tableId))
+          throw new ThriftTableOperationException(tableId.canonical(), null, TableOperation.FLUSH,
               TableOperationExceptionType.NOTFOUND, null);
 
-      } catch (AccumuloException e) {
-        Master.log.debug(
-            "Failed to scan " + MetadataTable.NAME + " table to wait for flush " + tableId, e);
-      } catch (TabletDeletedException tde) {
-        Master.log.debug(
-            "Failed to scan " + MetadataTable.NAME + " table to wait for flush " + tableId, tde);
-      } catch (AccumuloSecurityException e) {
-        Master.log.warn("{}", e.getMessage(), e);
-        throw new ThriftSecurityException();
-      } catch (TableNotFoundException e) {
-        Master.log.error("{}", e.getMessage(), e);
-        throw new ThriftTableOperationException();
+      } catch (TabletDeletedException e) {
+        Master.log.debug("Failed to scan {} table to wait for flush {}", MetadataTable.NAME,
+            tableId, e);
       }
     }
 
   }
 
-  private String getNamespaceIdFromTableId(TableOperation tableOp, String tableId)
+  private NamespaceId getNamespaceIdFromTableId(TableOperation tableOp, TableId tableId)
       throws ThriftTableOperationException {
-    String namespaceId;
+    NamespaceId namespaceId;
     try {
-      namespaceId = Tables.getNamespaceId(instance, tableId);
+      namespaceId = Tables.getNamespaceId(master.getContext(), tableId);
     } catch (TableNotFoundException e) {
-      throw new ThriftTableOperationException(tableId, null, tableOp,
+      throw new ThriftTableOperationException(tableId.canonical(), null, tableOp,
           TableOperationExceptionType.NOTFOUND, e.getMessage());
     }
     return namespaceId;
   }
 
   @Override
-  public MasterMonitorInfo getMasterStats(TInfo info, TCredentials credentials)
-      throws ThriftSecurityException {
+  public MasterMonitorInfo getMasterStats(TInfo info, TCredentials credentials) {
     return master.getMasterMonitorInfo();
   }
 
@@ -329,7 +271,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
     if (!force) {
       final TServerConnection server = master.tserverSet.getConnection(doomed);
       if (server == null) {
-        Master.log.warn("No server found for name " + tabletServer);
+        Master.log.warn("No server found for name {}", tabletServer);
         return;
       }
     }
@@ -350,7 +292,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
       TabletSplit split) {
     KeyExtent oldTablet = new KeyExtent(split.oldTablet);
     if (master.migrations.remove(oldTablet) != null) {
-      Master.log.info("Canceled migration of " + split.oldTablet);
+      Master.log.info("Canceled migration of {}", split.oldTablet);
     }
     for (TServerInstance instance : master.tserverSet.getCurrentServers()) {
       if (serverName.equals(instance.hostPort())) {
@@ -359,7 +301,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
         return;
       }
     }
-    Master.log.warn("Got a split from a server we don't recognize: " + serverName);
+    Master.log.warn("Got a split from a server we don't recognize: {}", serverName);
   }
 
   @Override
@@ -369,7 +311,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
 
     switch (status) {
       case LOAD_FAILURE:
-        Master.log.error(serverName + " reports assignment failed for tablet " + tablet);
+        Master.log.error("{} reports assignment failed for tablet {}", serverName, tablet);
         break;
       case LOADED:
         master.nextEvent.event("tablet %s was loaded on %s", tablet, serverName);
@@ -378,12 +320,12 @@ public class MasterClientServiceHandler extends FateServiceHandler
         master.nextEvent.event("tablet %s was unloaded from %s", tablet, serverName);
         break;
       case UNLOAD_ERROR:
-        Master.log.error(serverName + " reports unload failed for tablet " + tablet);
+        Master.log.error("{} reports unload failed for tablet {}", serverName, tablet);
         break;
       case UNLOAD_FAILURE_NOT_SERVING:
         if (Master.log.isTraceEnabled()) {
-          Master.log.trace(serverName
-              + " reports unload failed: not serving tablet, could be a split: " + tablet);
+          Master.log.trace("{} reports unload failed: not serving tablet, could be a split: {}",
+              serverName, tablet);
         }
         break;
       case CHOPPED:
@@ -408,7 +350,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
     try {
-      SystemPropUtil.removeSystemProperty(property);
+      SystemPropUtil.removeSystemProperty(master.getContext(), property);
       updatePlugins(property);
     } catch (Exception e) {
       Master.log.error("Problem removing config property in zookeeper", e);
@@ -423,7 +365,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
     try {
-      SystemPropUtil.setSystemProperty(property, value);
+      SystemPropUtil.setSystemProperty(master.getContext(), property, value);
       updatePlugins(property);
     } catch (IllegalArgumentException iae) {
       // throw the exception here so it is not caught and converted to a generic TException
@@ -450,76 +392,77 @@ public class MasterClientServiceHandler extends FateServiceHandler
       String value, TableOperation op)
       throws ThriftSecurityException, ThriftTableOperationException {
 
-    String namespaceId = null;
-    namespaceId = ClientServiceHandler.checkNamespaceId(master.getInstance(), namespace, op);
+    NamespaceId namespaceId = null;
+    namespaceId = ClientServiceHandler.checkNamespaceId(master.getContext(), namespace, op);
 
     if (!master.security.canAlterNamespace(c, namespaceId))
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
     try {
       if (value == null) {
-        NamespacePropUtil.removeNamespaceProperty(namespaceId, property);
+        NamespacePropUtil.removeNamespaceProperty(master.getContext(), namespaceId, property);
       } else {
-        NamespacePropUtil.setNamespaceProperty(namespaceId, property, value);
+        NamespacePropUtil.setNamespaceProperty(master.getContext(), namespaceId, property, value);
       }
     } catch (KeeperException.NoNodeException e) {
       // race condition... namespace no longer exists? This call will throw an exception if the
       // namespace was deleted:
-      ClientServiceHandler.checkNamespaceId(master.getInstance(), namespaceId, op);
+      ClientServiceHandler.checkNamespaceId(master.getContext(), namespace, op);
       log.info("Error altering namespace property", e);
-      throw new ThriftTableOperationException(namespaceId, namespace, op,
+      throw new ThriftTableOperationException(namespaceId.canonical(), namespace, op,
           TableOperationExceptionType.OTHER, "Problem altering namespaceproperty");
     } catch (Exception e) {
       log.error("Problem altering namespace property", e);
-      throw new ThriftTableOperationException(namespaceId, namespace, op,
+      throw new ThriftTableOperationException(namespaceId.canonical(), namespace, op,
           TableOperationExceptionType.OTHER, "Problem altering namespace property");
     }
   }
 
   private void alterTableProperty(TCredentials c, String tableName, String property, String value,
       TableOperation op) throws ThriftSecurityException, ThriftTableOperationException {
-    final String tableId = ClientServiceHandler.checkTableId(master.getInstance(), tableName, op);
-    String namespaceId = getNamespaceIdFromTableId(op, tableId);
+    final TableId tableId = ClientServiceHandler.checkTableId(master.getContext(), tableName, op);
+    NamespaceId namespaceId = getNamespaceIdFromTableId(op, tableId);
     if (!master.security.canAlterTable(c, tableId, namespaceId))
       throw new ThriftSecurityException(c.getPrincipal(), SecurityErrorCode.PERMISSION_DENIED);
 
     try {
       if (value == null || value.isEmpty()) {
-        TablePropUtil.removeTableProperty(tableId, property);
-      } else if (!TablePropUtil.setTableProperty(tableId, property, value)) {
+        TablePropUtil.removeTableProperty(master.getContext(), tableId, property);
+      } else if (!TablePropUtil.setTableProperty(master.getContext(), tableId, property, value)) {
         throw new Exception("Invalid table property.");
       }
     } catch (KeeperException.NoNodeException e) {
       // race condition... table no longer exists? This call will throw an exception if the table
       // was deleted:
-      ClientServiceHandler.checkTableId(master.getInstance(), tableName, op);
+      ClientServiceHandler.checkTableId(master.getContext(), tableName, op);
       log.info("Error altering table property", e);
-      throw new ThriftTableOperationException(tableId, tableName, op,
+      throw new ThriftTableOperationException(tableId.canonical(), tableName, op,
           TableOperationExceptionType.OTHER, "Problem altering table property");
     } catch (Exception e) {
       log.error("Problem altering table property", e);
-      throw new ThriftTableOperationException(tableId, tableName, op,
+      throw new ThriftTableOperationException(tableId.canonical(), tableName, op,
           TableOperationExceptionType.OTHER, "Problem altering table property");
     }
   }
 
   private void updatePlugins(String property) {
     if (property.equals(Property.MASTER_TABLET_BALANCER.getKey())) {
-      TabletBalancer balancer = master.getConfiguration().instantiateClassProperty(
+      AccumuloConfiguration conf = master.getConfiguration();
+      TabletBalancer balancer = Property.createInstanceFromPropertyName(conf,
           Property.MASTER_TABLET_BALANCER, TabletBalancer.class, new DefaultLoadBalancer());
-      balancer.init(master.getConfigurationFactory());
+      balancer.init(master.getContext());
       master.tabletBalancer = balancer;
-      log.info("tablet balancer changed to " + master.tabletBalancer.getClass().getName());
+      log.info("tablet balancer changed to {}", master.tabletBalancer.getClass().getName());
     }
   }
 
   @Override
-  public void waitForBalance(TInfo tinfo) throws TException {
-    master.waitForBalance(tinfo);
+  public void waitForBalance(TInfo tinfo) {
+    master.waitForBalance();
   }
 
   @Override
-  public List<String> getActiveTservers(TInfo tinfo, TCredentials credentials) throws TException {
+  public List<String> getActiveTservers(TInfo tinfo, TCredentials credentials) {
     Set<TServerInstance> tserverInstances = master.onlineTabletServers();
     List<String> servers = new ArrayList<>();
     for (TServerInstance tserverInstance : tserverInstances) {
@@ -544,7 +487,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
     }
 
     final DelegationTokenConfig config = DelegationTokenConfigSerializer.deserialize(tConfig);
-    final AuthenticationTokenSecretManager secretManager = master.getSecretManager();
+    final AuthenticationTokenSecretManager secretManager = master.getContext().getSecretManager();
     try {
       Entry<Token<AuthenticationTokenIdentifier>,AuthenticationTokenIdentifier> pair =
           secretManager.generateToken(credentials.principal, config);
@@ -559,14 +502,9 @@ public class MasterClientServiceHandler extends FateServiceHandler
   @Override
   public boolean drainReplicationTable(TInfo tfino, TCredentials credentials, String tableName,
       Set<String> logsToWatch) throws TException {
-    Connector conn;
-    try {
-      conn = master.getConnector();
-    } catch (AccumuloException | AccumuloSecurityException e) {
-      throw new RuntimeException("Failed to obtain connector", e);
-    }
+    AccumuloClient client = master.getContext();
 
-    final Text tableId = new Text(getTableId(master.getInstance(), tableName));
+    final Text tableId = new Text(getTableId(master.getContext(), tableName).canonical());
 
     drainLog.trace("Waiting for {} to be replicated for {}", logsToWatch, tableId);
 
@@ -574,7 +512,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
     final Set<Range> range = Collections.singleton(new Range(ReplicationSection.getRange()));
     BatchScanner bs;
     try {
-      bs = conn.createBatchScanner(MetadataTable.NAME, Authorizations.EMPTY, 4);
+      bs = client.createBatchScanner(MetadataTable.NAME, Authorizations.EMPTY, 4);
     } catch (TableNotFoundException e) {
       throw new RuntimeException("Could not read metadata table", e);
     }
@@ -591,7 +529,7 @@ public class MasterClientServiceHandler extends FateServiceHandler
 
     drainLog.trace("reading from replication table");
     try {
-      bs = conn.createBatchScanner(ReplicationTable.NAME, Authorizations.EMPTY, 4);
+      bs = client.createBatchScanner(ReplicationTable.NAME, Authorizations.EMPTY, 4);
     } catch (TableNotFoundException e) {
       throw new RuntimeException("Replication table was not found", e);
     }
@@ -604,9 +542,9 @@ public class MasterClientServiceHandler extends FateServiceHandler
     }
   }
 
-  protected String getTableId(Instance instance, String tableName)
+  protected TableId getTableId(ClientContext context, String tableName)
       throws ThriftTableOperationException {
-    return ClientServiceHandler.checkTableId(instance, tableName, null);
+    return ClientServiceHandler.checkTableId(context, tableName, null);
   }
 
   /**
