@@ -35,11 +35,10 @@ import java.util.TreeSet;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.BatchWriterConfig;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.client.MutationsRejectedException;
 import org.apache.accumulo.core.client.RowIterator;
 import org.apache.accumulo.core.client.Scanner;
@@ -49,8 +48,9 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.master.state.tables.TableState;
 import org.apache.accumulo.core.master.thrift.MasterState;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
@@ -71,6 +71,8 @@ import org.apache.accumulo.master.state.TableStats;
 import org.apache.accumulo.server.ServerConstants;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.FileRef;
+import org.apache.accumulo.server.fs.VolumeChooserEnvironment;
+import org.apache.accumulo.server.fs.VolumeChooserEnvironmentImpl;
 import org.apache.accumulo.server.fs.VolumeManager.FileType;
 import org.apache.accumulo.server.log.WalStateManager;
 import org.apache.accumulo.server.log.WalStateManager.WalMarkerException;
@@ -85,27 +87,23 @@ import org.apache.accumulo.server.master.state.TabletLocationState;
 import org.apache.accumulo.server.master.state.TabletLocationState.BadLocationStateException;
 import org.apache.accumulo.server.master.state.TabletState;
 import org.apache.accumulo.server.master.state.TabletStateStore;
-import org.apache.accumulo.server.tables.TableManager;
 import org.apache.accumulo.server.tablets.TabletTime;
 import org.apache.accumulo.server.util.MetadataTableUtil;
-import org.apache.accumulo.server.zookeeper.ZooReaderWriter;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
 import org.apache.thrift.TException;
-import org.gaul.modernizer_maven_annotations.SuppressModernizer;
 
-import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableSortedSet;
 import com.google.common.collect.Iterators;
 
 abstract class TabletGroupWatcher extends Daemon {
   // Constants used to make sure assignment logging isn't excessive in quantity or size
   private static final String ASSIGNMENT_BUFFER_SEPARATOR = ", ";
-  private static final int ASSIGNMENT_BUFFER_MAX_LENGTH = 4096;
+  private static final int ASSINGMENT_BUFFER_MAX_LENGTH = 4096;
 
   private final Master master;
-  private final TabletStateStore store;
-  private final TabletGroupWatcher dependentWatcher;
+  final TabletStateStore store;
+  final TabletGroupWatcher dependentWatcher;
 
   final TableStats stats = new TableStats();
   private SortedSet<TServerInstance> lastScanServers = ImmutableSortedSet.of();
@@ -119,11 +117,11 @@ abstract class TabletGroupWatcher extends Daemon {
   /** Should this {@code TabletGroupWatcher} suspend tablets? */
   abstract boolean canSuspendTablets();
 
-  Map<String,TableCounts> getStats() {
+  Map<TableId,TableCounts> getStats() {
     return stats.getLast();
   }
 
-  TableCounts getStats(String tableId) {
+  TableCounts getStats(TableId tableId) {
     return stats.getLast(tableId);
   }
 
@@ -131,7 +129,7 @@ abstract class TabletGroupWatcher extends Daemon {
    * True if the collection of live tservers specified in 'candidates' hasn't changed since the last
    * time an assignment scan was started.
    */
-  synchronized boolean isSameTserversAsLastScan(Set<TServerInstance> candidates) {
+  public synchronized boolean isSameTserversAsLastScan(Set<TServerInstance> candidates) {
     return candidates.equals(lastScanServers);
   }
 
@@ -141,7 +139,7 @@ abstract class TabletGroupWatcher extends Daemon {
     int[] oldCounts = new int[TabletState.values().length];
     EventCoordinator.Listener eventListener = this.master.nextEvent.getListener();
 
-    WalStateManager wals = new WalStateManager(master.getInstance(), ZooReaderWriter.getInstance());
+    WalStateManager wals = new WalStateManager(master.getContext());
 
     while (this.master.stillMaster()) {
       // slow things down a little, otherwise we spam the logs when there are many wake-up events
@@ -151,8 +149,8 @@ abstract class TabletGroupWatcher extends Daemon {
       int unloaded = 0;
       ClosableIterator<TabletLocationState> iter = null;
       try {
-        Map<String,MergeStats> mergeStatsCache = new HashMap<>();
-        Map<String,MergeStats> currentMerges = new HashMap<>();
+        Map<TableId,MergeStats> mergeStatsCache = new HashMap<>();
+        Map<TableId,MergeStats> currentMerges = new HashMap<>();
         for (MergeInfo merge : master.merges()) {
           if (merge.getExtent() != null) {
             currentMerges.put(merge.getExtent().getTableId(), new MergeStats(merge));
@@ -195,18 +193,13 @@ abstract class TabletGroupWatcher extends Daemon {
           if (tls == null) {
             continue;
           }
-
-          // this can get spammy during merges
-          if (currentMerges.isEmpty()) {
-            Master.log.debug("{} location State: {}", store.name(), tls);
-          }
-
+          Master.log.debug("{} location State: {}", store.name(), tls);
           // ignore entries for tables that do not exist in zookeeper
-          if (TableManager.getInstance().getTableState(tls.extent.getTableId()) == null)
+          if (master.getTableManager().getTableState(tls.extent.getTableId()) == null)
             continue;
 
           if (Master.log.isTraceEnabled())
-            Master.log.trace(tls + " walogs " + tls.walogs.size());
+            Master.log.trace("{} walogs {}", tls, tls.walogs.size());
 
           // Don't overwhelm the tablet servers with work
           if (unassigned.size() + unloaded
@@ -221,7 +214,7 @@ abstract class TabletGroupWatcher extends Daemon {
             unloaded = 0;
             eventListener.waitForEvents(Master.TIME_TO_WAIT_BETWEEN_SCANS);
           }
-          String tableId = tls.extent.getTableId();
+          TableId tableId = tls.extent.getTableId();
           TableConfiguration tableConf =
               this.master.getConfigurationFactory().getTableConfiguration(tableId);
 
@@ -237,7 +230,7 @@ abstract class TabletGroupWatcher extends Daemon {
           TServerInstance server = tls.getServer();
           TabletState state = tls.getState(currentTServers.keySet());
           if (Master.log.isTraceEnabled()) {
-            Master.log.trace("Goal state " + goal + " current " + state + " for " + tls.extent);
+            Master.log.trace("Goal state {} current {} for {}", goal, state, tls.extent);
           }
           stats.update(tableId, state);
           mergeStats.update(tls.extent, state, tls.chopped, !tls.walogs.isEmpty());
@@ -294,9 +287,9 @@ abstract class TabletGroupWatcher extends Daemon {
                   // Old tablet server is back. Return this tablet to its previous owner.
                   if (returnInstance != null) {
                     assignments.add(new Assignment(tls.extent, returnInstance));
+                  } else {
+                    // leave suspended, don't ask for a new assignment.
                   }
-                  // else - tablet server not back. Don't ask for a new assignment right now.
-
                 } else {
                   // Treat as unassigned, ask for a new assignment.
                   unassigned.put(tls.extent, server);
@@ -307,7 +300,7 @@ abstract class TabletGroupWatcher extends Daemon {
                 TServerInstance dest = this.master.migrations.get(tls.extent);
                 if (dest != null) {
                   // if destination is still good, assign it
-                  if (destinations.containsKey(dest)) {
+                  if (destinations.keySet().contains(dest)) {
                     assignments.add(new Assignment(tls.extent, dest));
                   } else {
                     // get rid of this migration
@@ -341,14 +334,14 @@ abstract class TabletGroupWatcher extends Daemon {
                 }
                 break;
               case HOSTED:
-                TServerConnection conn = this.master.tserverSet.getConnection(server);
-                if (conn != null) {
-                  conn.unloadTablet(this.master.masterLock, tls.extent, goal.howUnload(),
+                TServerConnection client = this.master.tserverSet.getConnection(server);
+                if (client != null) {
+                  client.unloadTablet(this.master.masterLock, tls.extent, goal.howUnload(),
                       master.getSteadyTime());
                   unloaded++;
                   totalUnloaded++;
                 } else {
-                  Master.log.warn("Could not connect to server " + server);
+                  Master.log.warn("Could not connect to server {}", server);
                 }
                 break;
               case ASSIGNED:
@@ -412,14 +405,14 @@ abstract class TabletGroupWatcher extends Daemon {
 
   private void cancelOfflineTableMigrations(TabletLocationState tls) {
     TServerInstance dest = this.master.migrations.get(tls.extent);
-    TableState tableState = TableManager.getInstance().getTableState(tls.extent.getTableId());
+    TableState tableState = master.getTableManager().getTableState(tls.extent.getTableId());
     if (dest != null && tableState == TableState.OFFLINE) {
       this.master.migrations.remove(tls.extent);
     }
   }
 
   private void repairMetadata(Text row) {
-    Master.log.debug("Attempting repair on " + row);
+    Master.log.debug("Attempting repair on {}", row);
     // ACCUMULO-2261 if a dying tserver writes a location before its lock information propagates, it
     // may cause duplicate assignment.
     // Attempt to find the dead server entry and remove it.
@@ -430,7 +423,7 @@ abstract class TabletGroupWatcher extends Daemon {
       String table = MetadataTable.NAME;
       if (extent.isMeta())
         table = RootTable.NAME;
-      Scanner scanner = this.master.getConnector().createScanner(table, Authorizations.EMPTY);
+      Scanner scanner = this.master.getContext().createScanner(table, Authorizations.EMPTY);
       scanner.fetchColumnFamily(CurrentLocationColumnFamily.NAME);
       scanner.fetchColumnFamily(FutureLocationColumnFamily.NAME);
       scanner.setRange(new Range(row));
@@ -448,8 +441,8 @@ abstract class TabletGroupWatcher extends Daemon {
       } else if (future.size() == 0 && assigned.size() > 1) {
         Master.log.warn("Found a tablet hosted on multiple servers, attempting to repair");
       } else {
-        Master.log.info("Attempted a repair, but nothing seems to be obviously wrong. " + assigned
-            + " " + future);
+        Master.log.info("Attempted a repair, but nothing seems to be obviously wrong. {} {}",
+            assigned, future);
         return;
       }
       Iterator<Entry<Key,Value>> iter =
@@ -458,9 +451,9 @@ abstract class TabletGroupWatcher extends Daemon {
         Entry<Key,Value> entry = iter.next();
         TServerInstance alive = master.tserverSet.find(entry.getValue().toString());
         if (alive == null) {
-          Master.log.info("Removing entry " + entry);
+          Master.log.info("Removing entry  {}", entry);
           BatchWriter bw =
-              this.master.getConnector().createBatchWriter(table, new BatchWriterConfig());
+              this.master.getContext().createBatchWriter(table, new BatchWriterConfig());
           Mutation m = new Mutation(entry.getKey().getRow());
           m.putDelete(entry.getKey().getColumnFamily(), entry.getKey().getColumnQualifier());
           bw.addMutation(m);
@@ -468,8 +461,9 @@ abstract class TabletGroupWatcher extends Daemon {
           return;
         }
       }
-      Master.log.error("Metadata table is inconsistent at " + row
-          + " and all assigned/future tservers are still online.");
+      Master.log.error(
+          "Metadata table is inconsistent at {} and all assigned/future tservers are still online.",
+          row);
     } catch (Throwable e) {
       Master.log.error("Error attempting repair of metadata " + row + ": " + e, e);
     }
@@ -509,16 +503,15 @@ abstract class TabletGroupWatcher extends Daemon {
           TServerConnection conn;
           conn = this.master.tserverSet.getConnection(tls.current);
           if (conn != null) {
-            Master.log
-                .info("Asking " + tls.current + " to split " + tls.extent + " at " + splitPoint);
-            conn.splitTablet(this.master.masterLock, tls.extent, splitPoint);
+            Master.log.info("Asking {} to split {} at {}", tls.current, tls.extent, splitPoint);
+            conn.splitTablet(tls.extent, splitPoint);
           } else {
-            Master.log.warn("Not connected to server " + tls.current);
+            Master.log.warn("Not connected to server {}", tls.current);
           }
         } catch (NotServingTabletException e) {
-          Master.log.debug("Error asking tablet server to split a tablet: " + e);
+          Master.log.debug("Error asking tablet server to split a tablet: ", e);
         } catch (Exception e) {
-          Master.log.warn("Error asking tablet server to split a tablet: " + e);
+          Master.log.warn("Error asking tablet server to split a tablet: ", e);
         }
       }
     }
@@ -540,10 +533,10 @@ abstract class TabletGroupWatcher extends Daemon {
       try {
         conn = this.master.tserverSet.getConnection(tls.current);
         if (conn != null) {
-          Master.log.info("Asking " + tls.current + " to chop " + tls.extent);
+          Master.log.info("Asking {} to chop {}", tls.current, tls.extent);
           conn.chop(this.master.masterLock, tls.extent);
         } else {
-          Master.log.warn("Could not connect to server " + tls.current);
+          Master.log.warn("Could not connect to server {}", tls.current);
         }
       } catch (TException e) {
         Master.log.warn("Communications error asking tablet server to chop a tablet");
@@ -551,10 +544,10 @@ abstract class TabletGroupWatcher extends Daemon {
     }
   }
 
-  private void updateMergeState(Map<String,MergeStats> mergeStatsCache) {
+  private void updateMergeState(Map<TableId,MergeStats> mergeStatsCache) {
     for (MergeStats stats : mergeStatsCache.values()) {
       try {
-        MergeState update = stats.nextMergeState(this.master.getConnector(), this.master);
+        MergeState update = stats.nextMergeState(this.master.getContext(), this.master);
         // when next state is MERGING, its important to persist this before
         // starting the merge... the verification check that is done before
         // moving into the merging state could fail if merge starts but does
@@ -572,8 +565,7 @@ abstract class TabletGroupWatcher extends Daemon {
             } else {
               mergeMetadataRecords(stats.getMergeInfo());
             }
-            update = MergeState.COMPLETE;
-            this.master.setMergeState(stats.getMergeInfo(), update);
+            this.master.setMergeState(stats.getMergeInfo(), update = MergeState.COMPLETE);
           } catch (Exception ex) {
             Master.log.error("Unable merge metadata table records", ex);
           }
@@ -585,29 +577,28 @@ abstract class TabletGroupWatcher extends Daemon {
     }
   }
 
-  @SuppressModernizer
   private void deleteTablets(MergeInfo info) throws AccumuloException {
     KeyExtent extent = info.getExtent();
     String targetSystemTable = extent.isMeta() ? RootTable.NAME : MetadataTable.NAME;
-    Master.log.debug("Deleting tablets for " + extent);
+    Master.log.debug("Deleting tablets for {}", extent);
     char timeType = '\0';
     KeyExtent followingTablet = null;
     if (extent.getEndRow() != null) {
       Key nextExtent = new Key(extent.getEndRow()).followingKey(PartialKey.ROW);
       followingTablet = getHighTablet(
           new KeyExtent(extent.getTableId(), nextExtent.getRow(), extent.getEndRow()));
-      Master.log.debug("Found following tablet " + followingTablet);
+      Master.log.debug("Found following tablet {}", followingTablet);
     }
     try {
-      Connector conn = this.master.getConnector();
+      AccumuloClient client = this.master.getContext();
       Text start = extent.getPrevEndRow();
       if (start == null) {
         start = new Text();
       }
-      Master.log.debug("Making file deletion entries for " + extent);
-      Range deleteRange = new Range(KeyExtent.getMetadataEntry(extent.getTableId(), start), false,
-          KeyExtent.getMetadataEntry(extent.getTableId(), extent.getEndRow()), true);
-      Scanner scanner = conn.createScanner(targetSystemTable, Authorizations.EMPTY);
+      Master.log.debug("Making file deletion entries for {}", extent);
+      Range deleteRange = new Range(TabletsSection.getRow(extent.getTableId(), start), false,
+          TabletsSection.getRow(extent.getTableId(), extent.getEndRow()), true);
+      Scanner scanner = client.createScanner(targetSystemTable, Authorizations.EMPTY);
       scanner.setRange(deleteRange);
       TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.fetch(scanner);
       TabletsSection.ServerColumnFamily.TIME_COLUMN.fetch(scanner);
@@ -619,7 +610,7 @@ abstract class TabletGroupWatcher extends Daemon {
         if (key.compareColumnFamily(DataFileColumnFamily.NAME) == 0) {
           datafiles.add(new FileRef(this.master.fs, key));
           if (datafiles.size() > 1000) {
-            MetadataTableUtil.addDeleteEntries(extent, datafiles, master);
+            MetadataTableUtil.addDeleteEntries(extent, datafiles, master.getContext());
             datafiles.clear();
           }
         } else if (TabletsSection.ServerColumnFamily.TIME_COLUMN.hasColumns(key)) {
@@ -640,23 +631,22 @@ abstract class TabletGroupWatcher extends Daemon {
                 Path.SEPARATOR + extent.getTableId() + path)));
           }
           if (datafiles.size() > 1000) {
-            MetadataTableUtil.addDeleteEntries(extent, datafiles, master);
+            MetadataTableUtil.addDeleteEntries(extent, datafiles, master.getContext());
             datafiles.clear();
           }
         }
       }
-      MetadataTableUtil.addDeleteEntries(extent, datafiles, master);
-      BatchWriter bw = conn.createBatchWriter(targetSystemTable, new BatchWriterConfig());
+      MetadataTableUtil.addDeleteEntries(extent, datafiles, master.getContext());
+      BatchWriter bw = client.createBatchWriter(targetSystemTable, new BatchWriterConfig());
       try {
-        deleteTablets(info, deleteRange, bw, conn);
+        deleteTablets(info, deleteRange, bw, client);
       } finally {
         bw.close();
       }
 
       if (followingTablet != null) {
-        Master.log
-            .debug("Updating prevRow of " + followingTablet + " to " + extent.getPrevEndRow());
-        bw = conn.createBatchWriter(targetSystemTable, new BatchWriterConfig());
+        Master.log.debug("Updating prevRow of {} to {}", followingTablet, extent.getPrevEndRow());
+        bw = client.createBatchWriter(targetSystemTable, new BatchWriterConfig());
         try {
           Mutation m = new Mutation(followingTablet.getMetadataEntry());
           TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.put(m,
@@ -669,25 +659,27 @@ abstract class TabletGroupWatcher extends Daemon {
         }
       } else {
         // Recreate the default tablet to hold the end of the table
-        Master.log.debug("Recreating the last tablet to point to " + extent.getPrevEndRow());
-        String tdir = master.getFileSystem().choose(Optional.of(extent.getTableId()),
-            ServerConstants.getBaseUris()) + Constants.HDFS_TABLES_DIR + Path.SEPARATOR
-            + extent.getTableId() + Constants.DEFAULT_TABLET_LOCATION;
+        Master.log.debug("Recreating the last tablet to point to {}", extent.getPrevEndRow());
+        VolumeChooserEnvironment chooserEnv = new VolumeChooserEnvironmentImpl(extent.getTableId(),
+            extent.getEndRow(), master.getContext());
+
+        String tdir = master.getFileSystem().choose(chooserEnv,
+            ServerConstants.getBaseUris(master.getContext())) + Constants.HDFS_TABLES_DIR
+            + Path.SEPARATOR + extent.getTableId() + Constants.DEFAULT_TABLET_LOCATION;
         MetadataTableUtil.addTablet(
-            new KeyExtent(extent.getTableId(), null, extent.getPrevEndRow()), tdir, master,
-            timeType, this.master.masterLock);
+            new KeyExtent(extent.getTableId(), null, extent.getPrevEndRow()), tdir,
+            master.getContext(), timeType, this.master.masterLock);
       }
-    } catch (RuntimeException | IOException | TableNotFoundException
-        | AccumuloSecurityException ex) {
+    } catch (RuntimeException | TableNotFoundException ex) {
       throw new AccumuloException(ex);
     }
   }
 
   private void mergeMetadataRecords(MergeInfo info) throws AccumuloException {
     KeyExtent range = info.getExtent();
-    Master.log.debug("Merging metadata for " + range);
+    Master.log.debug("Merging metadata for {}", range);
     KeyExtent stop = getHighTablet(range);
-    Master.log.debug("Highest tablet is " + stop);
+    Master.log.debug("Highest tablet is {}", stop);
     Value firstPrevRowValue = null;
     Text stopRow = stop.getMetadataEntry();
     Text start = range.getPrevEndRow();
@@ -695,23 +687,19 @@ abstract class TabletGroupWatcher extends Daemon {
       start = new Text();
     }
     Range scanRange =
-        new Range(KeyExtent.getMetadataEntry(range.getTableId(), start), false, stopRow, false);
+        new Range(TabletsSection.getRow(range.getTableId(), start), false, stopRow, false);
     String targetSystemTable = MetadataTable.NAME;
     if (range.isMeta()) {
       targetSystemTable = RootTable.NAME;
     }
 
-    Connector conn;
-
+    BatchWriter bw = null;
     try {
-      conn = this.master.getConnector();
-    } catch (AccumuloSecurityException ex) {
-      throw new AccumuloException(ex);
-    }
-
-    try (BatchWriter bw = conn.createBatchWriter(targetSystemTable, new BatchWriterConfig())) {
       long fileCount = 0;
-      Scanner scanner = conn.createScanner(targetSystemTable, Authorizations.EMPTY);
+      AccumuloClient client = this.master.getContext();
+      // Make file entries in highest tablet
+      bw = client.createBatchWriter(targetSystemTable, new BatchWriterConfig());
+      Scanner scanner = client.createScanner(targetSystemTable, Authorizations.EMPTY);
       scanner.setRange(scanRange);
       TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.fetch(scanner);
       TabletsSection.ServerColumnFamily.TIME_COLUMN.fetch(scanner);
@@ -727,19 +715,19 @@ abstract class TabletGroupWatcher extends Daemon {
           fileCount++;
         } else if (TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.hasColumns(key)
             && firstPrevRowValue == null) {
-          Master.log.debug("prevRow entry for lowest tablet is " + value);
+          Master.log.debug("prevRow entry for lowest tablet is {}", value);
           firstPrevRowValue = new Value(value);
         } else if (TabletsSection.ServerColumnFamily.TIME_COLUMN.hasColumns(key)) {
           maxLogicalTime = TabletTime.maxMetadataTime(maxLogicalTime, value.toString());
         } else if (TabletsSection.ServerColumnFamily.DIRECTORY_COLUMN.hasColumns(key)) {
-          bw.addMutation(MetadataTableUtil.createDeleteMutation(range.getTableId(),
-              entry.getValue().toString()));
+          bw.addMutation(MetadataTableUtil.createDeleteMutation(master.getContext(),
+              range.getTableId(), entry.getValue().toString()));
         }
       }
 
       // read the logical time from the last tablet in the merge range, it is not included in
       // the loop above
-      scanner = conn.createScanner(targetSystemTable, Authorizations.EMPTY);
+      scanner = client.createScanner(targetSystemTable, Authorizations.EMPTY);
       scanner.setRange(new Range(stopRow));
       TabletsSection.ServerColumnFamily.TIME_COLUMN.fetch(scanner);
       for (Entry<Key,Value> entry : scanner) {
@@ -757,7 +745,7 @@ abstract class TabletGroupWatcher extends Daemon {
 
       bw.flush();
 
-      Master.log.debug("Moved " + fileCount + " files to " + stop);
+      Master.log.debug("Moved {} files to {}", fileCount, stop);
 
       if (firstPrevRowValue == null) {
         Master.log.debug("tablet already merged");
@@ -766,11 +754,11 @@ abstract class TabletGroupWatcher extends Daemon {
 
       stop.setPrevEndRow(KeyExtent.decodePrevEndRow(firstPrevRowValue));
       Mutation updatePrevRow = stop.getPrevRowUpdateMutation();
-      Master.log.debug("Setting the prevRow for last tablet: " + stop);
+      Master.log.debug("Setting the prevRow for last tablet: {}", stop);
       bw.addMutation(updatePrevRow);
       bw.flush();
 
-      deleteTablets(info, scanRange, bw, conn);
+      deleteTablets(info, scanRange, bw, client);
 
       // Clean-up the last chopped marker
       m = new Mutation(stopRow);
@@ -780,10 +768,17 @@ abstract class TabletGroupWatcher extends Daemon {
 
     } catch (Exception ex) {
       throw new AccumuloException(ex);
+    } finally {
+      if (bw != null)
+        try {
+          bw.close();
+        } catch (Exception ex) {
+          throw new AccumuloException(ex);
+        }
     }
   }
 
-  private void deleteTablets(MergeInfo info, Range scanRange, BatchWriter bw, Connector conn)
+  private void deleteTablets(MergeInfo info, Range scanRange, BatchWriter bw, AccumuloClient client)
       throws TableNotFoundException, MutationsRejectedException {
     Scanner scanner;
     Mutation m;
@@ -791,9 +786,9 @@ abstract class TabletGroupWatcher extends Daemon {
     // group all deletes into tablet into one mutation, this makes tablets
     // either disappear entirely or not all.. this is important for the case
     // where the process terminates in the loop below...
-    scanner = conn.createScanner(info.getExtent().isMeta() ? RootTable.NAME : MetadataTable.NAME,
+    scanner = client.createScanner(info.getExtent().isMeta() ? RootTable.NAME : MetadataTable.NAME,
         Authorizations.EMPTY);
-    Master.log.debug("Deleting range " + scanRange);
+    Master.log.debug("Deleting range {}", scanRange);
     scanner.setRange(scanRange);
     RowIterator rowIter = new RowIterator(scanner);
     while (rowIter.hasNext()) {
@@ -807,7 +802,7 @@ abstract class TabletGroupWatcher extends Daemon {
           m = new Mutation(key.getRow());
 
         m.putDelete(key.getColumnFamily(), key.getColumnQualifier());
-        Master.log.debug("deleting entry " + key);
+        Master.log.debug("deleting entry {}", key);
       }
       bw.addMutation(m);
     }
@@ -817,8 +812,8 @@ abstract class TabletGroupWatcher extends Daemon {
 
   private KeyExtent getHighTablet(KeyExtent range) throws AccumuloException {
     try {
-      Connector conn = this.master.getConnector();
-      Scanner scanner = conn.createScanner(range.isMeta() ? RootTable.NAME : MetadataTable.NAME,
+      AccumuloClient client = this.master.getContext();
+      Scanner scanner = client.createScanner(range.isMeta() ? RootTable.NAME : MetadataTable.NAME,
           Authorizations.EMPTY);
       TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.fetch(scanner);
       KeyExtent start = new KeyExtent(range.getTableId(), range.getEndRow(), null);
@@ -849,9 +844,9 @@ abstract class TabletGroupWatcher extends Daemon {
     boolean tabletsSuspendable = canSuspendTablets();
     if (!assignedToDeadServers.isEmpty()) {
       int maxServersToShow = min(assignedToDeadServers.size(), 100);
-      Master.log.debug(assignedToDeadServers.size() + " assigned to dead servers: "
-          + assignedToDeadServers.subList(0, maxServersToShow) + "...");
-      Master.log.debug("logs for dead servers: " + logsForDeadServers);
+      Master.log.debug("{} assigned to dead servers: {}...", assignedToDeadServers.size(),
+          assignedToDeadServers.subList(0, maxServersToShow));
+      Master.log.debug("logs for dead servers: {}", logsForDeadServers);
       if (tabletsSuspendable) {
         store.suspend(assignedToDeadServers, logsForDeadServers, master.getSteadyTime());
       } else {
@@ -878,9 +873,9 @@ abstract class TabletGroupWatcher extends Daemon {
         if (unassigned.containsKey(assignment.getKey())) {
           if (assignment.getValue() != null) {
             if (!currentTServers.containsKey(assignment.getValue())) {
-              Master.log.warn("balancer assigned " + assignment.getKey()
-                  + " to a tablet server that is not current " + assignment.getValue()
-                  + " ignoring");
+              Master.log.warn(
+                  "balancer assigned {} to a tablet server that is not current {} ignoring",
+                  assignment.getKey(), assignment.getValue());
               continue;
             }
 
@@ -891,25 +886,25 @@ abstract class TabletGroupWatcher extends Daemon {
             builder.append(assignment);
 
             // Don't let the log message get too gigantic
-            if (builder.length() > ASSIGNMENT_BUFFER_MAX_LENGTH) {
+            if (builder.length() > ASSINGMENT_BUFFER_MAX_LENGTH) {
               builder.append("]");
-              Master.log.debug(store.name() + " assigning tablets: [" + builder.toString());
+              Master.log.debug("{} assigning tablets: [{}", store.name(), builder);
               builder.setLength(0);
             }
 
             assignments.add(new Assignment(assignment.getKey(), assignment.getValue()));
           }
         } else {
-          Master.log.warn(store.name()
-              + " load balancer assigning tablet that was not nominated for assignment "
-              + assignment.getKey());
+          Master.log.warn(
+              "{} load balancer assigning tablet that was not nominated for assignment {}",
+              store.name(), assignment.getKey());
         }
       }
 
       if (builder.length() > 0) {
         // Make sure to log any leftover assignments
         builder.append("]");
-        Master.log.debug(store.name() + " assigning tablets: [" + builder.toString());
+        Master.log.debug("{} assigning tablets: [{}", store.name(), builder);
       }
 
       if (!unassigned.isEmpty() && assignedOut.isEmpty())
@@ -922,11 +917,11 @@ abstract class TabletGroupWatcher extends Daemon {
     }
     assignments.addAll(assigned);
     for (Assignment a : assignments) {
-      TServerConnection conn = this.master.tserverSet.getConnection(a.server);
-      if (conn != null) {
-        conn.assignTablet(this.master.masterLock, a.tablet);
+      TServerConnection client = this.master.tserverSet.getConnection(a.server);
+      if (client != null) {
+        client.assignTablet(this.master.masterLock, a.tablet);
       } else {
-        Master.log.warn("Could not connect to server " + a.server);
+        Master.log.warn("Could not connect to server {}", a.server);
       }
       master.assignedTablet(a.tablet);
     }
