@@ -25,75 +25,79 @@ import static org.junit.Assert.assertEquals;
 import java.util.Map;
 import java.util.TreeMap;
 
-import org.apache.accumulo.core.client.Connector;
-import org.apache.accumulo.core.client.Instance;
+import org.apache.accumulo.core.client.AccumuloClient;
+import org.apache.accumulo.core.client.admin.InstanceOperations;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.replication.ReplicationConstants;
 import org.apache.accumulo.core.replication.ReplicationTarget;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
+import org.apache.accumulo.fate.zookeeper.ZooCache;
+import org.apache.accumulo.fate.zookeeper.ZooUtil;
 import org.apache.accumulo.server.replication.DistributedWorkQueueWorkAssignerHelper;
 import org.apache.accumulo.server.zookeeper.DistributedWorkQueue;
-import org.apache.accumulo.server.zookeeper.ZooCache;
 import org.junit.Before;
 import org.junit.Test;
 
 public class SequentialWorkAssignerTest {
 
-  private Connector conn;
+  private AccumuloClient client;
   private SequentialWorkAssigner assigner;
 
   @Before
-  public void init() throws Exception {
+  public void init() {
     AccumuloConfiguration conf = createMock(AccumuloConfiguration.class);
-    conn = createMock(Connector.class);
-    assigner = new SequentialWorkAssigner(conf, conn);
+    client = createMock(AccumuloClient.class);
+    assigner = new SequentialWorkAssigner(conf, client);
   }
 
   @Test
-  public void basicZooKeeperCleanup() throws Exception {
+  public void basicZooKeeperCleanup() {
     DistributedWorkQueue workQueue = createMock(DistributedWorkQueue.class);
     ZooCache zooCache = createMock(ZooCache.class);
-    Instance inst = createMock(Instance.class);
 
-    Map<String,Map<String,String>> queuedWork = new TreeMap<>();
-    Map<String,String> cluster1Work = new TreeMap<>();
+    Map<String,Map<TableId,String>> queuedWork = new TreeMap<>();
+    Map<TableId,String> cluster1Work = new TreeMap<>();
 
-    // Two files for cluster1, one for table '1' and another for table '2' we havce assigned work
+    // Two files for cluster1, one for table '1' and another for table '2' we haven't assigned work
     // for
-    cluster1Work.put("1", DistributedWorkQueueWorkAssignerHelper.getQueueKey("file1",
-        new ReplicationTarget("cluster1", "1", "1")));
-    cluster1Work.put("2", DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
-        new ReplicationTarget("cluster1", "2", "2")));
+    cluster1Work.put(TableId.of("1"), DistributedWorkQueueWorkAssignerHelper.getQueueKey("file1",
+        new ReplicationTarget("cluster1", "1", TableId.of("1"))));
+    cluster1Work.put(TableId.of("2"), DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
+        new ReplicationTarget("cluster1", "2", TableId.of("2"))));
 
     queuedWork.put("cluster1", cluster1Work);
 
-    assigner.setConnector(conn);
+    assigner.setClient(client);
     assigner.setZooCache(zooCache);
     assigner.setWorkQueue(workQueue);
     assigner.setQueuedWork(queuedWork);
 
-    expect(conn.getInstance()).andReturn(inst);
-    expect(inst.getInstanceID()).andReturn("instance");
+    InstanceOperations opts = createMock(InstanceOperations.class);
+    expect(opts.getInstanceID()).andReturn("instance");
+    expect(client.instanceOperations()).andReturn(opts);
 
     // file1 replicated
     expect(zooCache.get(ZooUtil.getRoot("instance") + ReplicationConstants.ZOO_WORK_QUEUE + "/"
         + DistributedWorkQueueWorkAssignerHelper.getQueueKey("file1",
-            new ReplicationTarget("cluster1", "1", "1"))))
-        .andReturn(null);
+            new ReplicationTarget("cluster1", "1", TableId.of("1"))))).andReturn(null);
     // file2 still needs to replicate
-    expect(zooCache.get(ZooUtil.getRoot("instance") + ReplicationConstants.ZOO_WORK_QUEUE + "/"
-        + DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
-            new ReplicationTarget("cluster1", "2", "2"))))
-        .andReturn(new byte[0]);
+    expect(
+        zooCache
+            .get(ZooUtil.getRoot("instance") + ReplicationConstants.ZOO_WORK_QUEUE + "/"
+                + DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
+                    new ReplicationTarget("cluster1", "2", TableId.of("2")))))
+                        .andReturn(new byte[0]);
 
-    replay(workQueue, zooCache, conn, inst);
+    replay(workQueue, zooCache, opts, client);
 
     assigner.cleanupFinishedWork();
 
-    verify(workQueue, zooCache, conn, inst);
+    verify(workQueue, zooCache, client);
 
     assertEquals(1, cluster1Work.size());
-    assertEquals(DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
-        new ReplicationTarget("cluster1", "2", "2")), cluster1Work.get("2"));
+    assertEquals(
+        DistributedWorkQueueWorkAssignerHelper.getQueueKey("file2",
+            new ReplicationTarget("cluster1", "2", TableId.of("2"))),
+        cluster1Work.get(TableId.of("2")));
   }
 }
