@@ -28,6 +28,16 @@ public class MonitorExecutable implements KeywordExecutable {
     return "monitor";
   }
 
+  @Override
+  public UsageGroup usageGroup() {
+    return UsageGroup.PROCESS;
+  }
+
+  @Override
+  public String description() {
+    return "Starts Accumulo monitor";
+  }
+
   @Override
   public void execute(final String[] args) throws Exception {
     Monitor.main(args);
