@@ -23,12 +23,10 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
-import java.util.SortedMap;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentSkipListMap;
 import java.util.concurrent.TimeUnit;
@@ -42,12 +40,12 @@ import org.apache.accumulo.core.client.sample.Sampler;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.ColumnUpdate;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.file.FileSKVIterator;
 import org.apache.accumulo.core.file.FileSKVWriter;
@@ -65,12 +63,12 @@ import org.apache.accumulo.core.iterators.system.SourceSwitchingIterator;
 import org.apache.accumulo.core.iterators.system.SourceSwitchingIterator.DataSource;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.sample.impl.SamplerFactory;
-import org.apache.accumulo.core.util.CachedConfiguration;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
 import org.apache.accumulo.core.util.LocalityGroupUtil.Partitioner;
 import org.apache.accumulo.core.util.Pair;
 import org.apache.accumulo.core.util.PreAllocatedArray;
-import org.apache.commons.lang.mutable.MutableLong;
+import org.apache.accumulo.server.ServerContext;
+import org.apache.commons.lang3.mutable.MutableLong;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -84,6 +82,7 @@ public class InMemoryMap {
 
   private static final Logger log = LoggerFactory.getLogger(InMemoryMap.class);
 
+  private ServerContext context;
   private volatile String memDumpFile = null;
   private final String memDumpDir;
   private final String mapType;
@@ -128,7 +127,7 @@ public class InMemoryMap {
     return pair.getSecond();
   }
 
-  public InMemoryMap(AccumuloConfiguration config, String tableId) {
+  public InMemoryMap(AccumuloConfiguration config, ServerContext serverContext, TableId tableId) {
 
     boolean useNativeMap = config.getBoolean(Property.TSERV_NATIVEMAP_ENABLED);
 
@@ -136,6 +135,7 @@ public class InMemoryMap {
     this.lggroups = LocalityGroupUtil.getLocalityGroupsIgnoringErrors(config, tableId);
 
     this.config = config;
+    this.context = serverContext;
 
     SimpleMap allMap;
     SimpleMap sampleMap;
@@ -180,9 +180,6 @@ public class InMemoryMap {
   }
 
   private interface SimpleMap {
-    Value get(Key key);
-
-    Iterator<Entry<Key,Value>> iterator(Key startKey);
 
     int size();
 
@@ -205,16 +202,6 @@ public class InMemoryMap {
       this.sample = sampleMap;
     }
 
-    @Override
-    public Value get(Key key) {
-      return map.get(key);
-    }
-
-    @Override
-    public Iterator<Entry<Key,Value>> iterator(Key startKey) {
-      throw new UnsupportedOperationException();
-    }
-
     @Override
     public int size() {
       return map.size();
@@ -292,7 +279,7 @@ public class InMemoryMap {
     private PreAllocatedArray<Map<ByteSequence,MutableLong>> groupFams;
 
     // the last map in the array is the default locality group
-    private SimpleMap maps[];
+    private SimpleMap[] maps;
     private Partitioner partitioner;
     private PreAllocatedArray<List<Mutation>> partitioned;
 
@@ -316,20 +303,10 @@ public class InMemoryMap {
       partitioner = new LocalityGroupUtil.Partitioner(this.groupFams);
 
       for (int i = 0; i < partitioned.length; i++) {
-        partitioned.set(i, new ArrayList<Mutation>());
+        partitioned.set(i, new ArrayList<>());
       }
     }
 
-    @Override
-    public Value get(Key key) {
-      throw new UnsupportedOperationException();
-    }
-
-    @Override
-    public Iterator<Entry<Key,Value>> iterator(Key startKey) {
-      throw new UnsupportedOperationException();
-    }
-
     @Override
     public int size() {
       int sum = 0;
@@ -343,7 +320,7 @@ public class InMemoryMap {
       if (samplerConfig != null)
         throw new SampleNotPresentException();
 
-      LocalityGroup groups[] = new LocalityGroup[maps.length];
+      LocalityGroup[] groups = new LocalityGroup[maps.length];
       for (int i = 0; i < groups.length; i++) {
         if (i < groupFams.length)
           groups[i] = new LocalityGroup(maps[i].skvIterator(null), groupFams.get(i), false);
@@ -408,18 +385,6 @@ public class InMemoryMap {
         size.incrementAndGet();
     }
 
-    @Override
-    public Value get(Key key) {
-      return map.get(key);
-    }
-
-    @Override
-    public Iterator<Entry<Key,Value>> iterator(Key startKey) {
-      Key lk = new Key(startKey);
-      SortedMap<Key,Value> tm = map.tailMap(lk);
-      return tm.entrySet().iterator();
-    }
-
     @Override
     public int size() {
       return size.get();
@@ -475,16 +440,6 @@ public class InMemoryMap {
       nativeMap = new NativeMap();
     }
 
-    @Override
-    public Value get(Key key) {
-      return nativeMap.get(key);
-    }
-
-    @Override
-    public Iterator<Entry<Key,Value>> iterator(Key startKey) {
-      return nativeMap.iterator(startKey);
-    }
-
     @Override
     public int size() {
       return nativeMap.size();
@@ -522,11 +477,7 @@ public class InMemoryMap {
    * Applies changes to a row in the InMemoryMap
    *
    */
-  public void mutate(List<Mutation> mutations) {
-    int numKVs = 0;
-    for (int i = 0; i < mutations.size(); i++)
-      numKVs += mutations.get(i).size();
-
+  public void mutate(List<Mutation> mutations, int numKVs) {
     // Can not update mutationCount while writes that started before
     // are in progress, this would cause partial mutations to be seen.
     // Also, can not continue until mutation count is updated, because
@@ -556,18 +507,13 @@ public class InMemoryMap {
     return map.getMemoryUsed();
   }
 
-  Iterator<Map.Entry<Key,Value>> iterator(Key startKey) {
-    return map.iterator(startKey);
-  }
-
   public synchronized long getNumEntries() {
     if (map == null)
       return 0;
     return map.size();
   }
 
-  private final Set<MemoryIterator> activeIters =
-      Collections.synchronizedSet(new HashSet<MemoryIterator>());
+  private final Set<MemoryIterator> activeIters = Collections.synchronizedSet(new HashSet<>());
 
   class MemoryDataSource implements DataSource {
 
@@ -633,11 +579,12 @@ public class InMemoryMap {
 
     private synchronized FileSKVIterator getReader() throws IOException {
       if (reader == null) {
-        Configuration conf = CachedConfiguration.getInstance();
+        Configuration conf = context.getHadoopConf();
         FileSystem fs = FileSystem.getLocal(conf);
 
-        reader = new RFileOperations().newReaderBuilder().forFile(memDumpFile, fs, conf)
-            .withTableConfiguration(SiteConfiguration.getInstance()).seekToBeginning().build();
+        reader = new RFileOperations().newReaderBuilder()
+            .forFile(memDumpFile, fs, conf, context.getCryptoService())
+            .withTableConfiguration(context.getConfiguration()).seekToBeginning().build();
         if (iflag != null)
           reader.setInterruptFlag(iflag);
 
@@ -754,6 +701,8 @@ public class InMemoryMap {
 
     int mc = kvCount.get();
     MemoryDataSource mds = new MemoryDataSource(iteratorSamplerConfig);
+    // TODO seems like a bug that two MemoryDataSources are created... may need to fix in older
+    // branches
     SourceSwitchingIterator ssi = new SourceSwitchingIterator(mds);
     MemoryIterator mi = new MemoryIterator(new PartialMutationSkippingIterator(ssi, mc));
     mi.setSSI(ssi);
@@ -791,7 +740,7 @@ public class InMemoryMap {
     if (activeIters.size() > 0) {
       // dump memmap exactly as is to a tmp file on disk, and switch scans to that temp file
       try {
-        Configuration conf = CachedConfiguration.getInstance();
+        Configuration conf = context.getHadoopConf();
         FileSystem fs = FileSystem.getLocal(conf);
 
         String tmpFile = memDumpDir + "/memDump" + UUID.randomUUID() + "." + RFile.EXTENSION;
@@ -799,14 +748,15 @@ public class InMemoryMap {
         Configuration newConf = new Configuration(conf);
         newConf.setInt("io.seqfile.compress.blocksize", 100000);
 
-        AccumuloConfiguration siteConf = SiteConfiguration.getInstance();
+        AccumuloConfiguration aconf = context.getConfiguration();
 
         if (getOrCreateSampler() != null) {
-          siteConf = createSampleConfig(siteConf);
+          aconf = createSampleConfig(aconf);
         }
 
-        FileSKVWriter out = new RFileOperations().newWriterBuilder().forFile(tmpFile, fs, newConf)
-            .withTableConfiguration(siteConf).build();
+        FileSKVWriter out = new RFileOperations().newWriterBuilder()
+            .forFile(tmpFile, fs, newConf, context.getCryptoService()).withTableConfiguration(aconf)
+            .build();
 
         InterruptibleIterator iter = map.skvIterator(null);
 
@@ -826,7 +776,7 @@ public class InMemoryMap {
 
         out.close();
 
-        log.debug("Created mem dump file " + tmpFile);
+        log.debug("Created mem dump file {}", tmpFile);
 
         memDumpFile = tmpFile;
 
@@ -841,7 +791,7 @@ public class InMemoryMap {
         fs.delete(new Path(memDumpFile), true);
 
       } catch (IOException ioe) {
-        log.error("Failed to create mem dump file ", ioe);
+        log.error("Failed to create mem dump file", ioe);
 
         while (activeIters.size() > 0) {
           sleepUninterruptibly(100, TimeUnit.MILLISECONDS);
