@@ -17,12 +17,9 @@
 package org.apache.accumulo.tserver;
 
 import java.io.File;
-import java.io.IOException;
 import java.util.AbstractMap.SimpleImmutableEntry;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.ConcurrentModificationException;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -36,6 +33,7 @@ import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import org.apache.accumulo.core.client.SampleNotPresentException;
+import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.ColumnUpdate;
 import org.apache.accumulo.core.data.Key;
@@ -52,6 +50,8 @@ import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 /**
  * This class stores data in a C++ map. Doing this allows us to store more in memory and avoid
  * pauses caused by Java GC.
@@ -63,7 +63,6 @@ import com.google.common.annotations.VisibleForTesting;
  * garbage collected quickly, therefore a process could easily use too much memory.
  *
  */
-
 public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
   private static final Logger log = LoggerFactory.getLogger(NativeMap.class);
@@ -71,33 +70,40 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
   // Load native library
   static {
-    // Check standard directories
-    List<File> directories =
-        new ArrayList<>(Arrays.asList(new File[] {new File("/usr/lib64"), new File("/usr/lib")}));
-    // Check in ACCUMULO_HOME location, too
-    String envAccumuloHome = System.getenv("ACCUMULO_HOME");
-    if (envAccumuloHome != null) {
-      directories.add(new File(envAccumuloHome + "/lib/native"));
-      directories.add(new File(envAccumuloHome + "/lib/native/map")); // old location, just in case
-                                                                      // somebody puts it here
+    // Check in directories set by JVM system property
+    List<File> directories = new ArrayList<>();
+    String accumuloNativeLibDirs = System.getProperty("accumulo.native.lib.path");
+    if (accumuloNativeLibDirs != null) {
+      for (String libDir : accumuloNativeLibDirs.split(":")) {
+        directories.add(new File(libDir));
+      }
     }
     // Attempt to load from these directories, using standard names
     loadNativeLib(directories);
 
     // Check LD_LIBRARY_PATH (DYLD_LIBRARY_PATH on Mac)
     if (!isLoaded()) {
+      log.error("Tried and failed to load Accumulo native library from {}", accumuloNativeLibDirs);
       String ldLibraryPath = System.getProperty("java.library.path");
-      String errMsg = "Tried and failed to load native map library from " + ldLibraryPath;
       try {
         System.loadLibrary("accumulo");
         loadedNativeLibraries.set(true);
-        log.info("Loaded native map shared library from " + ldLibraryPath);
-      } catch (Exception e) {
-        log.error(errMsg, e);
-      } catch (UnsatisfiedLinkError e) {
-        log.error(errMsg, e);
+        log.info("Loaded native map shared library from {}", ldLibraryPath);
+      } catch (Exception | UnsatisfiedLinkError e) {
+        log.error("Tried and failed to load Accumulo native library from {}", ldLibraryPath, e);
       }
     }
+
+    // Exit if native libraries could not be loaded
+    if (!isLoaded()) {
+      log.error(
+          "FATAL! Accumulo native libraries were requested but could not"
+              + " be be loaded. Either set '{}' to false in accumulo.properties or make"
+              + " sure native libraries are created in directories set by the JVM"
+              + " system property 'accumulo.native.lib.path' in accumulo-env.sh!",
+          Property.TSERV_NATIVEMAP_ENABLED);
+      System.exit(1);
+    }
   }
 
   /**
@@ -110,6 +116,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
    * @param searchPath
    *          a list of files and directories to search
    */
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "search paths provided by admin")
   public static void loadNativeLib(List<File> searchPath) {
     if (!isLoaded()) {
       List<String> names = getValidLibraryNames();
@@ -156,21 +163,18 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
   }
 
   private static boolean loadNativeLib(File libFile) {
-    log.debug("Trying to load native map library " + libFile);
+    log.debug("Trying to load native map library {}", libFile);
     if (libFile.exists() && libFile.isFile()) {
-      String errMsg = "Tried and failed to load native map library " + libFile;
       try {
         System.load(libFile.getAbsolutePath());
         loadedNativeLibraries.set(true);
-        log.info("Loaded native map shared library " + libFile);
+        log.info("Loaded native map shared library {}", libFile);
         return true;
-      } catch (Exception e) {
-        log.error(errMsg, e);
-      } catch (UnsatisfiedLinkError e) {
-        log.error(errMsg, e);
+      } catch (Exception | UnsatisfiedLinkError e) {
+        log.error("Tried and failed to load native map library " + libFile, e);
       }
     } else {
-      log.debug("Native map library " + libFile + " not found or is not a file.");
+      log.debug("Native map library {} not found or is not a file.", libFile);
     }
     return false;
   }
@@ -181,19 +185,19 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
   private final Lock rlock;
   private final Lock wlock;
 
-  int modCount = 0;
+  private int modCount = 0;
 
   private static native long createNM();
 
   // private static native void putNM(long nmPointer, byte[] kd, int cfo, int cqo, int cvo, int tl,
   // long ts, boolean del, byte[] value);
 
-  private static native void singleUpdate(long nmPointer, byte[] row, byte cf[], byte cq[],
-      byte cv[], long ts, boolean del, byte[] value, int mutationCount);
+  private static native void singleUpdate(long nmPointer, byte[] row, byte[] cf, byte[] cq,
+      byte[] cv, long ts, boolean del, byte[] value, int mutationCount);
 
   private static native long startUpdate(long nmPointer, byte[] row);
 
-  private static native void update(long nmPointer, long updateID, byte cf[], byte cq[], byte cv[],
+  private static native void update(long nmPointer, long updateID, byte[] cf, byte[] cq, byte[] cv,
       long ts, boolean del, byte[] value, int mutationCount);
 
   private static native int sizeNM(long nmPointer);
@@ -211,18 +215,12 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     if (!init) {
       allocatedNativeMaps = new HashSet<>();
 
-      Runnable r = new Runnable() {
-        @Override
-        public void run() {
-          if (allocatedNativeMaps.size() > 0) {
-            log.info("There are " + allocatedNativeMaps.size() + " allocated native maps");
-          }
-
-          log.debug(totalAllocations + " native maps were allocated");
+      Runtime.getRuntime().addShutdownHook(new Thread(() -> {
+        if (allocatedNativeMaps.size() > 0) {
+          log.info("There are {} allocated native maps", allocatedNativeMaps.size());
         }
-      };
-
-      Runtime.getRuntime().addShutdownHook(new Thread(r));
+        log.debug("{} native maps were allocated", totalAllocations);
+      }));
 
       init = true;
     }
@@ -250,15 +248,15 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     }
   }
 
-  private static native long createNMI(long nmp, int fieldLens[]);
+  private static native long createNMI(long nmp, int[] fieldLens);
 
-  private static native long createNMI(long nmp, byte[] row, byte cf[], byte cq[], byte cv[],
-      long ts, boolean del, int fieldLens[]);
+  private static native long createNMI(long nmp, byte[] row, byte[] cf, byte[] cq, byte[] cv,
+      long ts, boolean del, int[] fieldLens);
 
-  private static native boolean nmiNext(long nmiPointer, int fieldLens[]);
+  private static native boolean nmiNext(long nmiPointer, int[] fieldLens);
 
-  private static native void nmiGetData(long nmiPointer, byte[] row, byte cf[], byte cq[],
-      byte cv[], byte[] valData);
+  private static native void nmiGetData(long nmiPointer, byte[] row, byte[] cf, byte[] cq,
+      byte[] cv, byte[] valData);
 
   private static native long nmiGetTS(long nmiPointer);
 
@@ -350,7 +348,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
           source.delete();
           source = new NMIterator(ret.getKey());
           fill();
-          if (0 < end && nextEntries.get(0).getKey().equals(ret.getKey())) {
+          if (end > 0 && nextEntries.get(0).getKey().equals(ret.getKey())) {
             index++;
             if (index == end) {
               fill();
@@ -391,7 +389,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     private boolean hasNext;
     private int expectedModCount;
     private int[] fieldsLens = new int[7];
-    private byte lastRow[];
+    private byte[] lastRow;
 
     // it is assumed the read lock is held when this method is called
     NMIterator(Key key) {
@@ -460,11 +458,11 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
         lastRow = row;
       }
 
-      byte cf[] = new byte[fieldsLens[1]];
-      byte cq[] = new byte[fieldsLens[2]];
-      byte cv[] = new byte[fieldsLens[3]];
-      boolean deleted = fieldsLens[4] == 0 ? false : true;
-      byte val[] = new byte[fieldsLens[5]];
+      byte[] cf = new byte[fieldsLens[1]];
+      byte[] cq = new byte[fieldsLens[2]];
+      byte[] cv = new byte[fieldsLens[3]];
+      boolean deleted = fieldsLens[4] != 0;
+      byte[] val = new byte[fieldsLens[5]];
 
       nmiGetData(nmiPointer, row, cf, cq, cv, val);
       long ts = nmiGetTS(nmiPointer);
@@ -529,11 +527,6 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     return mutationCount;
   }
 
-  @VisibleForTesting
-  public void mutate(Mutation mutation, int mutationCount) {
-    mutate(Collections.singletonList(mutation), mutationCount);
-  }
-
   void mutate(List<Mutation> mutations, int mutationCount) {
     Iterator<Mutation> iter = mutations.iterator();
 
@@ -708,7 +701,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     }
 
     @Override
-    public void next() throws IOException {
+    public void next() {
 
       if (entry == null)
         throw new IllegalStateException();
@@ -729,8 +722,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     }
 
     @Override
-    public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive)
-        throws IOException {
+    public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive) {
 
       if (interruptFlag != null && interruptFlag.get())
         throw new IterationInterruptedException();
@@ -760,7 +752,7 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
     @Override
     public void init(SortedKeyValueIterator<Key,Value> source, Map<String,String> options,
-        IteratorEnvironment env) throws IOException {
+        IteratorEnvironment env) {
       throw new UnsupportedOperationException();
     }
 
