@@ -21,5 +21,5 @@ import java.util.Iterator;
 
 public interface CloseableIterator<T> extends Iterator<T>, AutoCloseable {
   @Override
-  public void close() throws IOException;
+  void close() throws IOException;
 }
