@@ -16,14 +16,13 @@
  */
 package org.apache.accumulo.tserver.log;
 
+import static java.util.Collections.singletonList;
+
 import java.io.IOException;
-import java.util.ArrayList;
+import java.nio.channels.ClosedChannelException;
 import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.SynchronousQueue;
 import java.util.concurrent.ThreadPoolExecutor;
@@ -36,20 +35,18 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 import org.apache.accumulo.core.client.Durability;
 import org.apache.accumulo.core.data.Mutation;
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.replication.ReplicationConfigurationUtil;
 import org.apache.accumulo.core.util.SimpleThreadPool;
 import org.apache.accumulo.fate.util.LoggingRunnable;
 import org.apache.accumulo.fate.util.Retry;
 import org.apache.accumulo.fate.util.Retry.RetryFactory;
-import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.replication.StatusUtil;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.server.util.Halt;
 import org.apache.accumulo.server.util.ReplicationTableUtil;
-import org.apache.accumulo.tserver.Mutations;
 import org.apache.accumulo.tserver.TabletMutations;
 import org.apache.accumulo.tserver.TabletServer;
 import org.apache.accumulo.tserver.log.DfsLogger.LoggerOperation;
@@ -105,7 +102,7 @@ public class TabletServerLogger {
 
   private final RetryFactory writeRetryFactory;
 
-  static private abstract class TestCallWithWriteLock {
+  private abstract static class TestCallWithWriteLock {
     abstract boolean test();
 
     abstract void withWriteLock() throws IOException;
@@ -126,7 +123,7 @@ public class TabletServerLogger {
     try {
       // does some condition exist that needs the write lock?
       if (code.test()) {
-        // Yes, let go of the readlock
+        // Yes, let go of the readLock
         rwlock.readLock().unlock();
         // Grab the write lock
         rwlock.writeLock().lock();
@@ -137,7 +134,7 @@ public class TabletServerLogger {
             code.withWriteLock();
           }
         } finally {
-          // regain the readlock
+          // regain the readLock
           rwlock.readLock().lock();
           // unlock the write lock
           rwlock.writeLock().unlock();
@@ -174,17 +171,13 @@ public class TabletServerLogger {
       }
 
       @Override
-      void withWriteLock() throws IOException {
-        try {
-          createLogger();
-          result.set(currentLog);
-          if (currentLog != null)
-            logIdOut.set(logId.get());
-          else
-            logIdOut.set(-1);
-        } catch (IOException e) {
-          log.error("Unable to create loggers", e);
-        }
+      void withWriteLock() {
+        createLogger();
+        result.set(currentLog);
+        if (currentLog != null)
+          logIdOut.set(logId.get());
+        else
+          logIdOut.set(-1);
       }
     });
     return result.get();
@@ -198,7 +191,7 @@ public class TabletServerLogger {
   public String getLogFile() {
     logIdLock.readLock().lock();
     try {
-      if (null == currentLog) {
+      if (currentLog == null) {
         return null;
       }
       return currentLog.getFileName();
@@ -207,7 +200,7 @@ public class TabletServerLogger {
     }
   }
 
-  synchronized private void createLogger() throws IOException {
+  private synchronized void createLogger() {
     if (!logIdLock.isWriteLockedByCurrentThread()) {
       throw new IllegalStateException("createLoggers should be called with write lock held!");
     }
@@ -225,10 +218,10 @@ public class TabletServerLogger {
       if (next instanceof DfsLogger) {
         currentLog = (DfsLogger) next;
         logId.incrementAndGet();
-        log.info("Using next log " + currentLog.getFileName());
+        log.info("Using next log {}", currentLog.getFileName());
 
         // When we successfully create a WAL, make sure to reset the Retry.
-        if (null != createRetry) {
+        if (createRetry != null) {
           createRetry = null;
         }
 
@@ -238,7 +231,7 @@ public class TabletServerLogger {
         throw new RuntimeException("Error: unexpected type seen: " + next);
       }
     } catch (Exception t) {
-      if (null == createRetry) {
+      if (createRetry == null) {
         createRetry = createRetryFactory.createRetry();
       }
 
@@ -280,7 +273,7 @@ public class TabletServerLogger {
           DfsLogger alog = null;
 
           try {
-            alog = new DfsLogger(conf, syncCounter, flushCounter);
+            alog = new DfsLogger(tserver.getContext(), conf, syncCounter, flushCounter);
             alog.open(tserver.getClientAddressString());
           } catch (Exception t) {
             log.error("Failed to open WAL", t);
@@ -312,7 +305,7 @@ public class TabletServerLogger {
           }
 
           String fileName = alog.getFileName();
-          log.debug("Created next WAL " + fileName);
+          log.debug("Created next WAL {}", fileName);
 
           try {
             tserver.addNewLogMarker(alog);
@@ -349,7 +342,7 @@ public class TabletServerLogger {
 
           try {
             while (!nextLog.offer(alog, 12, TimeUnit.HOURS)) {
-              log.info("Our WAL was not used for 12 hours: " + fileName);
+              log.info("Our WAL was not used for 12 hours: {}", fileName);
             }
           } catch (InterruptedException e) {
             // ignore - server is shutting down
@@ -359,12 +352,12 @@ public class TabletServerLogger {
     }));
   }
 
-  synchronized private void close() throws IOException {
+  private synchronized void close() throws IOException {
     if (!logIdLock.isWriteLockedByCurrentThread()) {
       throw new IllegalStateException("close should be called with write lock held!");
     }
     try {
-      if (null != currentLog) {
+      if (currentLog != null) {
         try {
           currentLog.close();
         } catch (DfsLogger.LogClosedException ex) {
@@ -386,22 +379,6 @@ public class TabletServerLogger {
     LoggerOperation write(DfsLogger logger) throws Exception;
   }
 
-  private void write(CommitSession commitSession, boolean mincFinish, Writer writer)
-      throws IOException {
-    write(commitSession, mincFinish, writer, writeRetryFactory.createRetry());
-  }
-
-  private void write(CommitSession commitSession, boolean mincFinish, Writer writer,
-      Retry writeRetry) throws IOException {
-    List<CommitSession> sessions = Collections.singletonList(commitSession);
-    write(sessions, mincFinish, writer, writeRetry);
-  }
-
-  private void write(final Collection<CommitSession> sessions, boolean mincFinish, Writer writer)
-      throws IOException {
-    write(sessions, mincFinish, writer, writeRetryFactory.createRetry());
-  }
-
   private void write(final Collection<CommitSession> sessions, boolean mincFinish, Writer writer,
       Retry writeRetry) throws IOException {
     // Work very hard not to lock this during calls to the outside world
@@ -411,9 +388,8 @@ public class TabletServerLogger {
     while (!success) {
       try {
         // get a reference to the loggers that no other thread can touch
-        DfsLogger copy = null;
         AtomicInteger currentId = new AtomicInteger(-1);
-        copy = initializeLoggers(currentId);
+        DfsLogger copy = initializeLoggers(currentId);
         currentLogId = currentId.get();
 
         // add the logger to the log set for the memory in the tablet,
@@ -424,7 +400,8 @@ public class TabletServerLogger {
             if (commitSession.beginUpdatingLogsUsed(copy, mincFinish)) {
               try {
                 // Scribble out a tablet definition and then write to the metadata table
-                defineTablet(commitSession, writeRetry);
+                write(singletonList(commitSession), false,
+                    logger -> logger.defineTablet(commitSession), writeRetry);
               } finally {
                 commitSession.finishUpdatingLogsUsed();
               }
@@ -437,7 +414,7 @@ public class TabletServerLogger {
                 log.debug("Writing " + ProtobufUtil.toString(status) + " to metadata table for "
                     + copy.getFileName());
                 // Got some new WALs, note this in the metadata table
-                ReplicationTableUtil.updateFiles(tserver, commitSession.getExtent(),
+                ReplicationTableUtil.updateFiles(tserver.getContext(), commitSession.getExtent(),
                     copy.getFileName(), status);
               }
             }
@@ -454,7 +431,7 @@ public class TabletServerLogger {
           // double-check: did the log set change?
           success = (currentLogId == logId.get());
         }
-      } catch (DfsLogger.LogClosedException ex) {
+      } catch (DfsLogger.LogClosedException | ClosedChannelException ex) {
         writeRetry.logRetry(log, "Logs closed while writing", ex);
       } catch (Exception t) {
         writeRetry.logRetry(log, "Failed to write to WAL", t);
@@ -504,61 +481,29 @@ public class TabletServerLogger {
     });
   }
 
-  public void defineTablet(final CommitSession commitSession, final Retry writeRetry)
+  /**
+   * Log a single mutation. This method expects mutations that have a durability other than NONE.
+   */
+  public void log(final CommitSession commitSession, final Mutation m, final Durability durability)
       throws IOException {
-    // scribble this into the metadata tablet, too.
-    write(commitSession, false, new Writer() {
-      @Override
-      public LoggerOperation write(DfsLogger logger) throws Exception {
-        logger.defineTablet(commitSession.getWALogSeq(), commitSession.getLogId(),
-            commitSession.getExtent());
-        return DfsLogger.NO_WAIT_LOGGER_OP;
-      }
-    }, writeRetry);
-  }
-
-  public void log(final CommitSession commitSession, final long tabletSeq, final Mutation m,
-      final Durability durability) throws IOException {
-    if (durability == Durability.NONE) {
-      return;
-    }
-    if (durability == Durability.DEFAULT) {
+    if (durability == Durability.DEFAULT || durability == Durability.NONE) {
       throw new IllegalArgumentException("Unexpected durability " + durability);
     }
-    write(commitSession, false, new Writer() {
-      @Override
-      public LoggerOperation write(DfsLogger logger) throws Exception {
-        return logger.log(tabletSeq, commitSession.getLogId(), m, durability);
-      }
-    });
+    write(singletonList(commitSession), false, logger -> logger.log(commitSession, m, durability),
+        writeRetryFactory.createRetry());
     logSizeEstimate.addAndGet(m.numBytes());
   }
 
-  public void logManyTablets(Map<CommitSession,Mutations> mutations) throws IOException {
-
-    final Map<CommitSession,Mutations> loggables = new HashMap<>(mutations);
-    for (Entry<CommitSession,Mutations> entry : mutations.entrySet()) {
-      if (entry.getValue().getDurability() == Durability.NONE) {
-        loggables.remove(entry.getKey());
-      }
-    }
+  /**
+   * Log mutations. This method expects mutations that have a durability other than NONE.
+   */
+  public void logManyTablets(Map<CommitSession,TabletMutations> loggables) throws IOException {
     if (loggables.size() == 0)
       return;
 
-    write(loggables.keySet(), false, new Writer() {
-      @Override
-      public LoggerOperation write(DfsLogger logger) throws Exception {
-        List<TabletMutations> copy = new ArrayList<>(loggables.size());
-        for (Entry<CommitSession,Mutations> entry : loggables.entrySet()) {
-          CommitSession cs = entry.getKey();
-          Durability durability = entry.getValue().getDurability();
-          copy.add(new TabletMutations(cs.getLogId(), cs.getWALogSeq(),
-              entry.getValue().getMutations(), durability));
-        }
-        return logger.logManyTablets(copy);
-      }
-    });
-    for (Mutations entry : loggables.values()) {
+    write(loggables.keySet(), false, logger -> logger.logManyTablets(loggables.values()),
+        writeRetryFactory.createRetry());
+    for (TabletMutations entry : loggables.values()) {
       if (entry.getMutations().size() < 1) {
         throw new IllegalArgumentException("logManyTablets: logging empty mutation list");
       }
@@ -568,39 +513,24 @@ public class TabletServerLogger {
     }
   }
 
-  public void minorCompactionFinished(final CommitSession commitSession,
-      final String fullyQualifiedFileName, final long walogSeq, final Durability durability)
-      throws IOException {
-
-    long t1 = System.currentTimeMillis();
-
-    write(commitSession, true, new Writer() {
-      @Override
-      public LoggerOperation write(DfsLogger logger) throws Exception {
-        return logger.minorCompactionFinished(walogSeq, commitSession.getLogId(),
-            fullyQualifiedFileName, durability);
-      }
-    });
-
-    long t2 = System.currentTimeMillis();
-
-    log.debug(" wrote MinC finish: writeTime:{}ms  durability:{}", (t2 - t1), durability);
+  public void minorCompactionFinished(final CommitSession commitSession, final long walogSeq,
+      final Durability durability) throws IOException {
+    write(singletonList(commitSession), true,
+        logger -> logger.minorCompactionFinished(walogSeq, commitSession.getLogId(), durability),
+        writeRetryFactory.createRetry());
   }
 
   public long minorCompactionStarted(final CommitSession commitSession, final long seq,
       final String fullyQualifiedFileName, final Durability durability) throws IOException {
-    write(commitSession, false, new Writer() {
-      @Override
-      public LoggerOperation write(DfsLogger logger) throws Exception {
-        return logger.minorCompactionStarted(seq, commitSession.getLogId(), fullyQualifiedFileName,
-            durability);
-      }
-    });
+    write(
+        singletonList(commitSession), false, logger -> logger.minorCompactionStarted(seq,
+            commitSession.getLogId(), fullyQualifiedFileName, durability),
+        writeRetryFactory.createRetry());
     return seq;
   }
 
-  public void recover(VolumeManager fs, KeyExtent extent, TableConfiguration tconf, List<Path> logs,
-      Set<String> tabletFiles, MutationReceiver mr) throws IOException {
+  public void recover(VolumeManager fs, KeyExtent extent, List<Path> logs, Set<String> tabletFiles,
+      MutationReceiver mr) throws IOException {
     try {
       SortedLogRecovery recovery = new SortedLogRecovery(fs);
       recovery.recover(extent, logs, tabletFiles, mr);
