@@ -31,40 +31,35 @@ import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.Instance;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.ZooKeeperInstance;
-import org.apache.accumulo.core.client.impl.ClientContext;
-import org.apache.accumulo.core.client.impl.ClientExecReturn;
-import org.apache.accumulo.core.client.impl.Credentials;
-import org.apache.accumulo.core.client.impl.ReplicationClient;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.ClientExecReturn;
+import org.apache.accumulo.core.clientImpl.ClientInfo;
+import org.apache.accumulo.core.clientImpl.ReplicationClient;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.file.rfile.RFile;
 import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.replication.ReplicationTarget;
-import org.apache.accumulo.core.replication.thrift.KeyValues;
-import org.apache.accumulo.core.replication.thrift.ReplicationCoordinator;
 import org.apache.accumulo.core.replication.thrift.ReplicationServicer;
 import org.apache.accumulo.core.replication.thrift.ReplicationServicer.Client;
 import org.apache.accumulo.core.replication.thrift.WalEdits;
-import org.apache.accumulo.core.security.thrift.TCredentials;
-import org.apache.accumulo.core.trace.ProbabilitySampler;
-import org.apache.accumulo.core.trace.Span;
-import org.apache.accumulo.core.trace.Trace;
+import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
+import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.HostAndPort;
-import org.apache.accumulo.server.client.HdfsZooInstance;
-import org.apache.accumulo.server.conf.ServerConfigurationFactory;
+import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
 import org.apache.accumulo.server.replication.ReplicaSystem;
@@ -76,14 +71,19 @@ import org.apache.accumulo.tserver.log.DfsLogger.DFSLoggerInputStreams;
 import org.apache.accumulo.tserver.log.DfsLogger.LogHeaderIncompleteException;
 import org.apache.accumulo.tserver.logger.LogFileKey;
 import org.apache.accumulo.tserver.logger.LogFileValue;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.security.UserGroupInformation;
+import org.apache.htrace.Trace;
+import org.apache.htrace.TraceScope;
+import org.apache.htrace.impl.ProbabilitySampler;
 import org.apache.thrift.transport.TTransportException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 public class AccumuloReplicaSystem implements ReplicaSystem {
   private static final Logger log = LoggerFactory.getLogger(AccumuloReplicaSystem.class);
   private static final String RFILE_SUFFIX = "." + RFile.EXTENSION;
@@ -92,38 +92,10 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
   private AccumuloConfiguration conf;
   private VolumeManager fs;
 
-  protected String getInstanceName() {
-    return instanceName;
-  }
-
-  protected void setInstanceName(String instanceName) {
-    this.instanceName = instanceName;
-  }
-
-  protected String getZookeepers() {
-    return zookeepers;
-  }
-
-  protected void setZookeepers(String zookeepers) {
-    this.zookeepers = zookeepers;
-  }
-
-  protected AccumuloConfiguration getConf() {
-    return conf;
-  }
-
   protected void setConf(AccumuloConfiguration conf) {
     this.conf = conf;
   }
 
-  protected VolumeManager getFs() {
-    return fs;
-  }
-
-  protected void setFs(VolumeManager fs) {
-    this.fs = fs;
-  }
-
   /**
    * Generate the configuration string for this ReplicaSystem
    */
@@ -132,12 +104,12 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
   }
 
   @Override
-  public void configure(String configuration) {
+  public void configure(ServerContext context, String configuration) {
     requireNonNull(configuration);
 
     // instance_name,zookeepers
     int index = configuration.indexOf(',');
-    if (-1 == index) {
+    if (index == -1) {
       try {
         Thread.sleep(1000);
       } catch (InterruptedException e) {
@@ -148,23 +120,21 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
 
     instanceName = configuration.substring(0, index);
     zookeepers = configuration.substring(index + 1);
-
-    conf = new ServerConfigurationFactory(HdfsZooInstance.getInstance()).getConfiguration();
+    conf = context.getConfiguration();
 
     try {
-      fs = VolumeManagerImpl.get(conf);
+      fs = VolumeManagerImpl.get(conf, context.getHadoopConf());
     } catch (IOException e) {
       log.error("Could not connect to filesystem", e);
       throw new RuntimeException(e);
     }
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "path provided by admin")
   @Override
   public Status replicate(final Path p, final Status status, final ReplicationTarget target,
       final ReplicaSystemHelper helper) {
-    final Instance localInstance = HdfsZooInstance.getInstance();
-    final AccumuloConfiguration localConf =
-        new ServerConfigurationFactory(localInstance).getConfiguration();
+    final AccumuloConfiguration localConf = conf;
 
     log.debug("Replication RPC timeout is {}",
         localConf.get(Property.REPLICATION_RPC_TIMEOUT.getKey()));
@@ -185,7 +155,7 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       password = getPassword(localConf, target);
     }
 
-    if (null != keytab) {
+    if (keytab != null) {
       try {
         final UserGroupInformation accumuloUgi = UserGroupInformation.getCurrentUser();
         // Get a UGI with the principal + keytab
@@ -193,20 +163,17 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
             keytab.getAbsolutePath());
 
         // Run inside a doAs to avoid nuking the Tserver's user
-        return ugi.doAs(new PrivilegedAction<Status>() {
-          @Override
-          public Status run() {
-            KerberosToken token;
-            try {
-              // Do *not* replace the current user
-              token = new KerberosToken(principal, keytab);
-            } catch (IOException e) {
-              log.error("Failed to create KerberosToken", e);
-              return status;
-            }
-            ClientContext peerContext = getContextForPeer(localConf, target, principal, token);
-            return _replicate(p, status, target, helper, localConf, peerContext, accumuloUgi);
+        return ugi.doAs((PrivilegedAction<Status>) () -> {
+          KerberosToken token;
+          try {
+            // Do *not* replace the current user
+            token = new KerberosToken(principal, keytab);
+          } catch (IOException e) {
+            log.error("Failed to create KerberosToken", e);
+            return status;
           }
+          ClientContext peerContext = getContextForPeer(localConf, target, principal, token);
+          return _replicate(p, status, target, helper, localConf, peerContext, accumuloUgi);
         });
       } catch (IOException e) {
         // Can't log in, can't replicate
@@ -241,10 +208,9 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
   private Status _replicate(final Path p, final Status status, final ReplicationTarget target,
       final ReplicaSystemHelper helper, final AccumuloConfiguration localConf,
       final ClientContext peerContext, final UserGroupInformation accumuloUgi) {
-    try {
-      double tracePercent = localConf.getFraction(Property.REPLICATION_TRACE_PERCENT);
-      ProbabilitySampler sampler = new ProbabilitySampler(tracePercent);
-      Trace.on("AccumuloReplicaSystem", sampler);
+    double tracePercent = localConf.getFraction(Property.REPLICATION_TRACE_PERCENT);
+    ProbabilitySampler sampler = TraceUtil.probabilitySampler(tracePercent);
+    try (TraceScope replicaSpan = Trace.startSpan("AccumuloReplicaSystem", sampler)) {
 
       // Remote identifier is an integer (table id) in this case.
       final String remoteTableId = target.getRemoteIdentifier();
@@ -256,29 +222,19 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
         log.debug("Attempt {}", i);
         String peerTserverStr;
         log.debug("Fetching peer tserver address");
-        Span span = Trace.start("Fetch peer tserver");
-        try {
+        try (TraceScope span = Trace.startSpan("Fetch peer tserver")) {
           // Ask the master on the remote what TServer we should talk with to replicate the data
           peerTserverStr = ReplicationClient.executeCoordinatorWithReturn(peerContext,
-              new ClientExecReturn<String,ReplicationCoordinator.Client>() {
-
-                @Override
-                public String execute(ReplicationCoordinator.Client client) throws Exception {
-                  return client.getServicerAddress(remoteTableId, peerContext.rpcCreds());
-                }
-
-              });
+              client -> client.getServicerAddress(remoteTableId, peerContext.rpcCreds()));
         } catch (AccumuloException | AccumuloSecurityException e) {
           // No progress is made
           log.error(
               "Could not connect to master at {}, cannot proceed with replication. Will retry",
               target, e);
           continue;
-        } finally {
-          span.stop();
         }
 
-        if (null == peerTserverStr) {
+        if (peerTserverStr == null) {
           // Something went wrong, and we didn't get a valid tserver from the remote for some reason
           log.warn("Did not receive tserver from master at {}, cannot proceed"
               + " with replication. Will retry.", target);
@@ -291,28 +247,21 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
 
         // We have a tserver on the remote -- send the data its way.
         Status finalStatus;
-        final long sizeLimit = conf.getMemoryInBytes(Property.REPLICATION_MAX_UNIT_SIZE);
+        final long sizeLimit = conf.getAsBytes(Property.REPLICATION_MAX_UNIT_SIZE);
         try {
           if (p.getName().endsWith(RFILE_SUFFIX)) {
-            span = Trace.start("RFile replication");
-            try {
-              finalStatus = replicateRFiles(peerContext, peerTserver, target, p, status, sizeLimit,
-                  remoteTableId, peerContext.rpcCreds(), helper, timeout);
-            } finally {
-              span.stop();
+            try (TraceScope span = Trace.startSpan("RFile replication")) {
+              finalStatus = replicateRFiles(peerContext, peerTserver, target, p, status, timeout);
             }
           } else {
-            span = Trace.start("WAL replication");
-            try {
+            try (TraceScope span = Trace.startSpan("WAL replication")) {
               finalStatus = replicateLogs(peerContext, peerTserver, target, p, status, sizeLimit,
                   remoteTableId, peerContext.rpcCreds(), helper, accumuloUgi, timeout);
-            } finally {
-              span.stop();
             }
           }
 
-          log.debug("New status for {} after replicating to {} is {}", p, peerContext.getInstance(),
-              ProtobufUtil.toString(finalStatus));
+          log.debug("New status for {} after replicating to {} is {}", p,
+              peerContext.getInstanceName(), ProtobufUtil.toString(finalStatus));
 
           return finalStatus;
         } catch (TTransportException | AccumuloException | AccumuloSecurityException e) {
@@ -326,57 +275,48 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
 
       // We made no status, punt on it for now, and let it re-queue itself for work
       return status;
-    } finally {
-      Trace.off();
     }
   }
 
   protected Status replicateRFiles(ClientContext peerContext, final HostAndPort peerTserver,
-      final ReplicationTarget target, final Path p, final Status status, final long sizeLimit,
-      final String remoteTableId, final TCredentials tcreds, final ReplicaSystemHelper helper,
-      long timeout) throws TTransportException, AccumuloException, AccumuloSecurityException {
-    try (final DataInputStream input = getRFileInputStream(p)) {
-      Status lastStatus = status, currentStatus = status;
-      while (true) {
-        // Read and send a batch of mutations
-        ReplicationStats replResult = ReplicationClient.executeServicerWithReturn(peerContext,
-            peerTserver, new RFileClientExecReturn(target, input, p, currentStatus, sizeLimit,
-                remoteTableId, tcreds),
-            timeout);
+      final ReplicationTarget target, final Path p, final Status status, long timeout)
+      throws TTransportException, AccumuloException, AccumuloSecurityException {
 
-        // Catch the overflow
-        long newBegin = currentStatus.getBegin() + replResult.entriesConsumed;
-        if (newBegin < 0) {
-          newBegin = Long.MAX_VALUE;
-        }
+    Status lastStatus = status, currentStatus = status;
+    while (true) {
+      // Read and send a batch of mutations
+      ReplicationStats replResult = ReplicationClient.executeServicerWithReturn(peerContext,
+          peerTserver, new RFileClientExecReturn(), timeout);
 
-        currentStatus = Status.newBuilder(currentStatus).setBegin(newBegin).build();
+      // Catch the overflow
+      long newBegin = currentStatus.getBegin() + replResult.entriesConsumed;
+      if (newBegin < 0) {
+        newBegin = Long.MAX_VALUE;
+      }
 
-        log.debug("Sent batch for replication of {} to {}, with new Status {}", p, target,
-            ProtobufUtil.toString(currentStatus));
+      currentStatus = Status.newBuilder(currentStatus).setBegin(newBegin).build();
 
-        // If we got a different status
-        if (!currentStatus.equals(lastStatus)) {
-          // If we don't have any more work, just quit
-          if (!StatusUtil.isWorkRequired(currentStatus)) {
-            return currentStatus;
-          } else {
-            // Otherwise, let it loop and replicate some more data
-            lastStatus = currentStatus;
-          }
+      log.debug("Sent batch for replication of {} to {}, with new Status {}", p, target,
+          ProtobufUtil.toString(currentStatus));
+
+      // If we got a different status
+      if (!currentStatus.equals(lastStatus)) {
+        // If we don't have any more work, just quit
+        if (!StatusUtil.isWorkRequired(currentStatus)) {
+          return currentStatus;
         } else {
-          log.debug("Did not replicate any new data for {} to {}, (state was {})", p, target,
-              ProtobufUtil.toString(lastStatus));
+          // Otherwise, let it loop and replicate some more data
+          lastStatus = currentStatus;
+        }
+      } else {
+        log.debug("Did not replicate any new data for {} to {}, (state was {})", p, target,
+            ProtobufUtil.toString(lastStatus));
 
-          // otherwise, we didn't actually replicate (likely because there was error sending the
-          // data)
-          // we can just not record any updates, and it will be picked up again by the work assigner
-          return status;
-        }
+        // otherwise, we didn't actually replicate (likely because there was error sending the
+        // data)
+        // we can just not record any updates, and it will be picked up again by the work assigner
+        return status;
       }
-    } catch (IOException e) {
-      log.error("Could not create input stream from RFile, will retry", e);
-      return status;
     }
   }
 
@@ -391,19 +331,18 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
     try (final FSDataInputStream fsinput = fs.open(p);
         final DataInputStream input = getWalStream(p, fsinput)) {
       log.debug("Skipping unwanted data in WAL");
-      Span span = Trace.start("Consume WAL prefix");
-      span.data("file", p.toString());
-      try {
+      try (TraceScope span = Trace.startSpan("Consume WAL prefix")) {
+        if (span.getSpan() != null) {
+          span.getSpan().addKVAnnotation("file", p.toString());
+        }
         // We want to read all records in the WAL up to the "begin" offset contained in the Status
         // message,
         // building a Set of tids from DEFINE_TABLET events which correspond to table ids for future
         // mutations
-        tids = consumeWalPrefix(target, input, p, status, sizeLimit);
+        tids = consumeWalPrefix(target, input, status);
       } catch (IOException e) {
         log.warn("Unexpected error consuming file.");
         return status;
-      } finally {
-        span.stop();
       }
 
       log.debug("Sending batches of data to peer tserver");
@@ -411,27 +350,26 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       Status lastStatus = status, currentStatus = status;
       final AtomicReference<Exception> exceptionRef = new AtomicReference<>();
       while (true) {
-        // Set some trace info
-        span = Trace.start("Replicate WAL batch");
-        span.data("Batch size (bytes)", Long.toString(sizeLimit));
-        span.data("File", p.toString());
-        span.data("Peer instance name", peerContext.getInstance().getInstanceName());
-        span.data("Peer tserver", peerTserver.toString());
-        span.data("Remote table ID", remoteTableId);
-
         ReplicationStats replResult;
-        try {
+        try (TraceScope span = Trace.startSpan("Replicate WAL batch")) {
+          if (span.getSpan() != null) {
+            // Set some trace context
+            span.getSpan().addKVAnnotation("Batch size (bytes)", Long.toString(sizeLimit));
+            span.getSpan().addKVAnnotation("File", p.toString());
+            span.getSpan().addKVAnnotation("Peer instance name", peerContext.getInstanceName());
+            span.getSpan().addKVAnnotation("Peer tserver", peerTserver.toString());
+            span.getSpan().addKVAnnotation("Remote table ID", remoteTableId);
+          }
+
           // Read and send a batch of mutations
           replResult = ReplicationClient.executeServicerWithReturn(peerContext, peerTserver,
               new WalClientExecReturn(target, input, p, currentStatus, sizeLimit, remoteTableId,
                   tcreds, tids),
               timeout);
         } catch (Exception e) {
-          log.error("Caught exception replicating data to {} at {}",
-              peerContext.getInstance().getInstanceName(), peerTserver, e);
+          log.error("Caught exception replicating data to {} at {}", peerContext.getInstanceName(),
+              peerTserver, e);
           throw e;
-        } finally {
-          span.stop();
         }
 
         // Catch the overflow
@@ -447,23 +385,19 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
 
         // If we got a different status
         if (!currentStatus.equals(lastStatus)) {
-          span = Trace.start("Update replication table");
-          try {
-            if (null != accumuloUgi) {
+          try (TraceScope span = Trace.startSpan("Update replication table")) {
+            if (accumuloUgi != null) {
               final Status copy = currentStatus;
-              accumuloUgi.doAs(new PrivilegedAction<Void>() {
-                @Override
-                public Void run() {
-                  try {
-                    helper.recordNewStatus(p, copy, target);
-                  } catch (Exception e) {
-                    exceptionRef.set(e);
-                  }
-                  return null;
+              accumuloUgi.doAs((PrivilegedAction<Void>) () -> {
+                try {
+                  helper.recordNewStatus(p, copy, target);
+                } catch (Exception e) {
+                  exceptionRef.set(e);
                 }
+                return null;
               });
               Exception e = exceptionRef.get();
-              if (null != e) {
+              if (e != null) {
                 if (e instanceof TableNotFoundException) {
                   throw (TableNotFoundException) e;
                 } else if (e instanceof AccumuloSecurityException) {
@@ -483,8 +417,6 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
                     + " {}, but the table did not exist",
                 p, ProtobufUtil.toString(currentStatus), e);
             throw new RuntimeException("Replication table did not exist, will retry", e);
-          } finally {
-            span.stop();
           }
 
           log.debug("Recorded updated status for {}: {}", p, ProtobufUtil.toString(currentStatus));
@@ -516,16 +448,13 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       } else {
         newStatus = Status.newBuilder(status).setBegin(status.getEnd()).build();
       }
-      Span span = Trace.start("Update replication table");
-      try {
+      try (TraceScope span = Trace.startSpan("Update replication table")) {
         helper.recordNewStatus(p, newStatus, target);
       } catch (TableNotFoundException tnfe) {
         log.error(
             "Tried to update status in replication table for {} as {}, but the table did not exist",
             p, ProtobufUtil.toString(newStatus), e);
         throw new RuntimeException("Replication table did not exist, will retry", e);
-      } finally {
-        span.stop();
       }
       return newStatus;
     } catch (IOException e) {
@@ -566,11 +495,11 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
 
       log.debug(
           "Read {} WAL entries and retained {} bytes of WAL entries for replication to peer '{}'",
-          (Long.MAX_VALUE == edits.entriesConsumed) ? "all remaining" : edits.entriesConsumed,
+          (edits.entriesConsumed == Long.MAX_VALUE) ? "all remaining" : edits.entriesConsumed,
           edits.sizeInBytes, p);
 
       // If we have some edits to send
-      if (0 < edits.walEdits.getEditsSize()) {
+      if (edits.walEdits.getEditsSize() > 0) {
         log.debug("Sending {} edits", edits.walEdits.getEditsSize());
         long entriesReplicated = client.replicateLog(remoteTableId, edits.walEdits, tcreds);
         if (entriesReplicated != edits.numUpdates) {
@@ -592,49 +521,17 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       }
 
       // No data sent (bytes nor records) and no progress made
-      return new ReplicationStats(0l, 0l, 0l);
+      return new ReplicationStats(0L, 0L, 0L);
     }
   }
 
   protected class RFileClientExecReturn
       implements ClientExecReturn<ReplicationStats,ReplicationServicer.Client> {
 
-    private ReplicationTarget target;
-    private DataInputStream input;
-    private Path p;
-    private Status status;
-    private long sizeLimit;
-    private String remoteTableId;
-    private TCredentials tcreds;
-
-    public RFileClientExecReturn(ReplicationTarget target, DataInputStream input, Path p,
-        Status status, long sizeLimit, String remoteTableId, TCredentials tcreds) {
-      this.target = target;
-      this.input = input;
-      this.p = p;
-      this.status = status;
-      this.sizeLimit = sizeLimit;
-      this.remoteTableId = remoteTableId;
-      this.tcreds = tcreds;
-    }
-
     @Override
-    public ReplicationStats execute(Client client) throws Exception {
-      RFileReplication kvs = getKeyValues(target, input, p, status, sizeLimit);
-      if (0 < kvs.keyValues.getKeyValuesSize()) {
-        long entriesReplicated = client.replicateKeyValues(remoteTableId, kvs.keyValues, tcreds);
-        if (entriesReplicated != kvs.keyValues.getKeyValuesSize()) {
-          log.warn(
-              "Sent {} KeyValue entries for replication but only {} were reported as replicated",
-              kvs.keyValues.getKeyValuesSize(), entriesReplicated);
-        }
-
-        // Not as important to track as WALs because we don't skip any KVs in an RFile
-        return kvs;
-      }
-
+    public ReplicationStats execute(Client client) {
       // No data sent (bytes nor records) and no progress made
-      return new ReplicationStats(0l, 0l, 0l);
+      return new ReplicationStats(0L, 0L, 0L);
     }
   }
 
@@ -646,7 +543,7 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
         localConf.getAllPropertiesWithPrefix(Property.REPLICATION_PEER_PASSWORD);
     String password =
         peerPasswords.get(Property.REPLICATION_PEER_PASSWORD.getKey() + target.getPeerName());
-    if (null == password) {
+    if (password == null) {
       throw new IllegalArgumentException("Cannot get password for " + target.getPeerName());
     }
     return password;
@@ -660,7 +557,7 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
         localConf.getAllPropertiesWithPrefix(Property.REPLICATION_PEER_KEYTAB);
     String keytab =
         peerKeytabs.get(Property.REPLICATION_PEER_KEYTAB.getKey() + target.getPeerName());
-    if (null == keytab) {
+    if (keytab == null) {
       throw new IllegalArgumentException("Cannot get keytab for " + target.getPeerName());
     }
     return keytab;
@@ -676,7 +573,7 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
         localConf.getAllPropertiesWithPrefix(Property.REPLICATION_PEER_USER);
 
     String user = peerUsers.get(userKey);
-    if (null == user) {
+    if (user == null) {
       throw new IllegalArgumentException("Cannot get user for " + target.getPeerName());
     }
     return user;
@@ -689,22 +586,17 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
     requireNonNull(principal);
     requireNonNull(token);
 
-    return new ClientContext(getPeerInstance(target), new Credentials(principal, token), localConf);
+    Properties properties = new Properties();
+    properties.setProperty(ClientProperty.INSTANCE_NAME.getKey(), instanceName);
+    properties.setProperty(ClientProperty.INSTANCE_ZOOKEEPERS.getKey(), zookeepers);
+    properties.setProperty(ClientProperty.AUTH_PRINCIPAL.getKey(), principal);
+    ClientProperty.setAuthenticationToken(properties, token);
+
+    return new ClientContext(ClientInfo.from(properties, token), localConf);
   }
 
-  protected Instance getPeerInstance(ReplicationTarget target) {
-    return new ZooKeeperInstance(instanceName, zookeepers);
-  }
-
-  protected RFileReplication getKeyValues(ReplicationTarget target, DataInputStream input, Path p,
-      Status status, long sizeLimit) {
-    // TODO ACCUMULO-2580 Implement me
-    throw new UnsupportedOperationException();
-  }
-
-  protected Set<Integer> consumeWalPrefix(ReplicationTarget target, DataInputStream wal, Path p,
-      Status status, long sizeLimit) throws IOException {
-    Set<Integer> tids = new HashSet<>();
+  protected Set<Integer> consumeWalPrefix(ReplicationTarget target, DataInputStream wal,
+      Status status) throws IOException {
     LogFileKey key = new LogFileKey();
     LogFileValue value = new LogFileValue();
 
@@ -728,17 +620,16 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       }
     }
 
-    return tids;
+    return desiredTids;
   }
 
   public DataInputStream getWalStream(Path p, FSDataInputStream input) throws IOException {
-    Span span = Trace.start("Read WAL header");
-    span.data("file", p.toString());
-    try {
+    try (TraceScope span = Trace.startSpan("Read WAL header")) {
+      if (span.getSpan() != null) {
+        span.getSpan().addKVAnnotation("file", p.toString());
+      }
       DFSLoggerInputStreams streams = DfsLogger.readHeaderAndReturnStream(input, conf);
       return streams.getDecryptingInputStream();
-    } finally {
-      span.stop();
     }
   }
 
@@ -746,9 +637,9 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
       Status status, long sizeLimit, Set<Integer> desiredTids) throws IOException {
     WalEdits edits = new WalEdits();
     edits.edits = new ArrayList<>();
-    long size = 0l;
-    long entriesConsumed = 0l;
-    long numUpdates = 0l;
+    long size = 0L;
+    long entriesConsumed = 0L;
+    long numUpdates = 0L;
     LogFileKey key = new LogFileKey();
     LogFileValue value = new LogFileValue();
 
@@ -846,10 +737,6 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
     return mutationsToSend;
   }
 
-  protected DataInputStream getRFileInputStream(Path p) throws IOException {
-    throw new UnsupportedOperationException("Not yet implemented");
-  }
-
   public static class ReplicationStats {
     /**
      * The size, in bytes, of the data sent
@@ -890,18 +777,6 @@ public class AccumuloReplicaSystem implements ReplicaSystem {
     }
   }
 
-  public static class RFileReplication extends ReplicationStats {
-    /**
-     * The data to send
-     */
-    public KeyValues keyValues;
-
-    public RFileReplication(KeyValues kvs, long size) {
-      super(size, kvs.keyValues.size(), kvs.keyValues.size());
-      this.keyValues = kvs;
-    }
-  }
-
   /**
    * A "struct" to avoid a nested Entry. Contains the resultant information from collecting data for
    * replication
