@@ -18,7 +18,6 @@ package org.apache.accumulo.tserver;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -28,53 +27,52 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.TreeMap;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.accumulo.core.client.SampleNotPresentException;
-import org.apache.accumulo.core.client.impl.BaseIteratorEnvironment;
 import org.apache.accumulo.core.client.sample.RowSampler;
 import org.apache.accumulo.core.client.sample.Sampler;
 import org.apache.accumulo.core.client.sample.SamplerConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
+import org.apache.accumulo.core.crypto.CryptoServiceFactory;
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.IterationInterruptedException;
+import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
 import org.apache.accumulo.core.sample.impl.SamplerFactory;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
 import org.apache.accumulo.core.util.LocalityGroupUtil.LocalityGroupConfigurationError;
-import org.apache.accumulo.server.client.HdfsZooInstance;
-import org.apache.accumulo.server.conf.ZooConfiguration;
+import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.tserver.InMemoryMap.MemoryIterator;
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.io.Text;
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
-import org.junit.BeforeClass;
-import org.junit.Ignore;
+import org.easymock.EasyMock;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 import org.junit.rules.TemporaryFolder;
 
 import com.google.common.collect.ImmutableMap;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
+@SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 public class InMemoryMapTest {
 
-  private static class SampleIE extends BaseIteratorEnvironment {
+  private static class SampleIE implements IteratorEnvironment {
 
     private final SamplerConfiguration sampleConfig;
 
@@ -97,11 +95,19 @@ public class InMemoryMapTest {
     }
   }
 
-  @BeforeClass
-  public static void setUp() throws Exception {
-    // suppress log messages having to do with not having an instance
-    Logger.getLogger(ZooConfiguration.class).setLevel(Level.OFF);
-    Logger.getLogger(HdfsZooInstance.class).setLevel(Level.OFF);
+  @Rule
+  public ExpectedException thrown = ExpectedException.none();
+
+  public static ServerContext getServerContext() {
+    Configuration hadoopConf = new Configuration();
+    ServerContext context = EasyMock.createMock(ServerContext.class);
+    EasyMock.expect(context.getCryptoService()).andReturn(CryptoServiceFactory.newDefaultInstance())
+        .anyTimes();
+    EasyMock.expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance())
+        .anyTimes();
+    EasyMock.expect(context.getHadoopConf()).andReturn(hadoopConf).anyTimes();
+    EasyMock.replay(context);
+    return context;
   }
 
   @Rule
@@ -113,7 +119,7 @@ public class InMemoryMapTest {
     String[] sa = column.split(":");
     m.putDelete(new Text(sa[0]), new Text(sa[1]), ts);
 
-    imm.mutate(Collections.singletonList(m));
+    imm.mutate(Collections.singletonList(m), 1);
   }
 
   public void mutate(InMemoryMap imm, String row, String column, long ts, String value) {
@@ -121,13 +127,12 @@ public class InMemoryMapTest {
     String[] sa = column.split(":");
     m.put(new Text(sa[0]), new Text(sa[1]), ts, new Value(value.getBytes()));
 
-    imm.mutate(Collections.singletonList(m));
+    imm.mutate(Collections.singletonList(m), 1);
   }
 
   static Key newKey(String row, String column, long ts) {
     String[] sa = column.split(":");
-    Key k = new Key(new Text(row), new Text(sa[0]), new Text(sa[1]), ts);
-    return k;
+    return new Key(new Text(row), new Text(sa[0]), new Text(sa[1]), ts);
   }
 
   static void testAndCallNext(SortedKeyValueIterator<Key,Value> dc, String row, String column,
@@ -140,7 +145,7 @@ public class InMemoryMapTest {
   }
 
   static void assertEqualsNoNext(SortedKeyValueIterator<Key,Value> dc, String row, String column,
-      int ts, String val) throws IOException {
+      int ts, String val) {
     assertTrue(dc.hasTop());
     assertEquals(newKey(row, column, ts), dc.getTopKey());
     assertEquals(new Value(val.getBytes()), dc.getTopValue());
@@ -175,7 +180,7 @@ public class InMemoryMapTest {
     ConfigurationCopy config = new ConfigurationCopy(DefaultConfiguration.getInstance());
     config.set(Property.TSERV_NATIVEMAP_ENABLED, "" + useNative);
     config.set(Property.TSERV_MEMDUMP_DIR, memDumpDir);
-    return new InMemoryMap(config, "--TEST--");
+    return new InMemoryMap(config, getServerContext(), TableId.of("--TEST--"));
   }
 
   @Test
@@ -372,16 +377,18 @@ public class InMemoryMapTest {
 
     if (interleaving == 1) {
       imm.delete(0);
-      if (interrupt)
+      if (interrupt) {
         iflag.set(true);
+      }
     }
 
     SortedKeyValueIterator<Key,Value> dc = ski1.deepCopy(new SampleIE());
 
     if (interleaving == 2) {
       imm.delete(0);
-      if (interrupt)
+      if (interrupt) {
         iflag.set(true);
+      }
     }
 
     dc.seek(new Range(), LocalityGroupUtil.EMPTY_CF_SET, false);
@@ -389,8 +396,9 @@ public class InMemoryMapTest {
 
     if (interleaving == 3) {
       imm.delete(0);
-      if (interrupt)
+      if (interrupt) {
         iflag.set(true);
+      }
     }
 
     testAndCallNext(dc, "r1", "foo:cq1", 3, "bar1");
@@ -399,8 +407,9 @@ public class InMemoryMapTest {
 
     if (interleaving == 4) {
       imm.delete(0);
-      if (interrupt)
+      if (interrupt) {
         iflag.set(true);
+      }
     }
 
     testAndCallNext(ski1, "r1", "foo:cq2", 3, "bar2");
@@ -409,20 +418,23 @@ public class InMemoryMapTest {
     assertFalse(dc.hasTop());
     assertFalse(ski1.hasTop());
 
-    if (interrupt)
+    if (interrupt) {
       dc.seek(new Range(), LocalityGroupUtil.EMPTY_CF_SET, false);
+    }
   }
 
   @Test
   public void testDeepCopyAndDelete() throws Exception {
-    for (int i = 0; i <= 4; i++)
+    for (int i = 0; i <= 4; i++) {
       deepCopyAndDelete(i, false);
+    }
 
-    for (int i = 1; i <= 4; i++)
+    for (int i = 1; i <= 4; i++) {
       try {
         deepCopyAndDelete(i, true);
         fail("i = " + i);
       } catch (IterationInterruptedException iie) {}
+    }
   }
 
   @Test
@@ -479,7 +491,7 @@ public class InMemoryMapTest {
     Mutation m = new Mutation(new Text("r1"));
     m.put(new Text("foo"), new Text("cq"), 3, new Value("v1".getBytes()));
     m.put(new Text("foo"), new Text("cq"), 3, new Value("v2".getBytes()));
-    imm.mutate(Collections.singletonList(m));
+    imm.mutate(Collections.singletonList(m), 2);
 
     MemoryIterator skvi1 = imm.skvIterator(null);
     skvi1.seek(new Range(), LocalityGroupUtil.EMPTY_CF_SET, false);
@@ -487,58 +499,14 @@ public class InMemoryMapTest {
     testAndCallNext(skvi1, "r1", "foo:cq", 3, "v1");
   }
 
-  private static final Logger log = Logger.getLogger(InMemoryMapTest.class);
-
   static long sum(long[] counts) {
     long result = 0;
-    for (long count : counts)
+    for (long count : counts) {
       result += count;
+    }
     return result;
   }
 
-  // - hard to get this timing test to run well on apache build machines
-  @Test
-  @Ignore
-  public void parallelWriteSpeed() throws Exception {
-    List<Double> timings = new ArrayList<>();
-    for (int threads : new int[] {1, 2, 16, /* 64, 256 */}) {
-      final long now = System.currentTimeMillis();
-      final long counts[] = new long[threads];
-      final InMemoryMap imm = newInMemoryMap(false, tempFolder.newFolder().getAbsolutePath());
-      ExecutorService e = Executors.newFixedThreadPool(threads);
-      for (int j = 0; j < threads; j++) {
-        final int threadId = j;
-        e.execute(new Runnable() {
-          @Override
-          public void run() {
-            while (System.currentTimeMillis() - now < 1000) {
-              for (int k = 0; k < 1000; k++) {
-                Mutation m = new Mutation("row");
-                m.put("cf", "cq", new Value("v".getBytes()));
-                List<Mutation> mutations = Collections.singletonList(m);
-                imm.mutate(mutations);
-                counts[threadId]++;
-              }
-            }
-          }
-        });
-      }
-      e.shutdown();
-      e.awaitTermination(10, TimeUnit.SECONDS);
-      imm.delete(10000);
-      double mutationsPerSecond = sum(counts) / ((System.currentTimeMillis() - now) / 1000.);
-      timings.add(mutationsPerSecond);
-      log.info(
-          String.format("%.1f mutations per second with %d threads", mutationsPerSecond, threads));
-    }
-    // verify that more threads doesn't go a lot faster, or a lot slower than one thread
-    for (Double timing : timings) {
-      double ratioFirst = timings.get(0) / timing;
-      assertTrue(ratioFirst < 3);
-      assertTrue(ratioFirst > 0.3);
-    }
-  }
-
   @Test
   public void testLocalityGroups() throws Exception {
     ConfigurationCopy config = newConfig(tempFolder.newFolder().getAbsolutePath());
@@ -548,7 +516,7 @@ public class InMemoryMapTest {
         LocalityGroupUtil.encodeColumnFamilies(toTextSet("cf3", "cf4")));
     config.set(Property.TABLE_LOCALITY_GROUPS.getKey(), "lg1,lg2");
 
-    InMemoryMap imm = new InMemoryMap(config, "--TEST--");
+    InMemoryMap imm = new InMemoryMap(config, getServerContext(), TableId.of("--TEST--"));
 
     Mutation m1 = new Mutation("r1");
     m1.put("cf1", "x", 2, "1");
@@ -570,7 +538,7 @@ public class InMemoryMapTest {
     m5.put("cf3", "z", 6, "A");
     m5.put("cf4", "z", 6, "B");
 
-    imm.mutate(Arrays.asList(m1, m2, m3, m4, m5));
+    imm.mutate(Arrays.asList(m1, m2, m3, m4, m5), 10);
 
     MemoryIterator iter1 = imm.skvIterator(null);
 
@@ -578,15 +546,15 @@ public class InMemoryMapTest {
     SortedKeyValueIterator<Key,Value> dc1 = iter1.deepCopy(new SampleIE());
     seekLocalityGroups(dc1);
 
-    assertTrue(imm.getNumEntries() == 10);
+    assertEquals(10, imm.getNumEntries());
     assertTrue(imm.estimatedSizeInBytes() > 0);
 
     imm.delete(0);
 
     seekLocalityGroups(iter1);
     seekLocalityGroups(dc1);
-    // TODO uncomment following when ACCUMULO-1628 is fixed
-    // seekLocalityGroups(iter1.deepCopy(null));
+    // tests ACCUMULO-1628
+    seekLocalityGroups(iter1.deepCopy(null));
   }
 
   @Test
@@ -610,8 +578,7 @@ public class InMemoryMapTest {
     }
 
     for (ConfigurationCopy config : Arrays.asList(config1, config2)) {
-
-      InMemoryMap imm = new InMemoryMap(config, "--TEST--");
+      InMemoryMap imm = new InMemoryMap(config, getServerContext(), TableId.of("--TEST--"));
 
       TreeMap<Key,Value> expectedSample = new TreeMap<>();
       TreeMap<Key,Value> expectedAll = new TreeMap<>();
@@ -697,7 +664,7 @@ public class InMemoryMapTest {
       config1.set(entry.getKey(), entry.getValue());
     }
 
-    InMemoryMap imm = new InMemoryMap(config1, "--TEST--");
+    InMemoryMap imm = new InMemoryMap(config1, getServerContext(), TableId.of("--TEST--"));
 
     TreeMap<Key,Value> expectedSample = new TreeMap<>();
     TreeMap<Key,Value> expectedAll = new TreeMap<>();
@@ -757,7 +724,7 @@ public class InMemoryMapTest {
       config1.set(entry.getKey(), entry.getValue());
     }
 
-    InMemoryMap imm = new InMemoryMap(config1, "--TEST--");
+    InMemoryMap imm = new InMemoryMap(config1, getServerContext(), TableId.of("--TEST--"));
 
     mutate(imm, "r", "cf:cq", 5, "b");
 
@@ -802,7 +769,7 @@ public class InMemoryMapTest {
       config1.set(entry.getKey(), entry.getValue());
     }
 
-    InMemoryMap imm = new InMemoryMap(config1, "--TEST--");
+    InMemoryMap imm = new InMemoryMap(config1, getServerContext(), TableId.of("--TEST--"));
 
     // change sampler config after creating in mem map.
     SamplerConfigurationImpl sampleConfig2 = new SamplerConfigurationImpl(
@@ -832,9 +799,8 @@ public class InMemoryMapTest {
     assertEquals(expectedAll, readAll(iter));
 
     iter = imm.skvIterator(sampleConfig1);
-    final MemoryIterator finalIter = iter;
-    assertThrows(SampleNotPresentException.class,
-        () -> finalIter.seek(new Range(), LocalityGroupUtil.EMPTY_CF_SET, false));
+    thrown.expect(SampleNotPresentException.class);
+    iter.seek(new Range(), LocalityGroupUtil.EMPTY_CF_SET, false);
   }
 
   private TreeMap<Key,Value> readAll(SortedKeyValueIterator<Key,Value> iter) throws IOException {
