@@ -22,7 +22,6 @@ import static org.apache.accumulo.tserver.logger.LogEvents.DEFINE_TABLET;
 import static org.apache.accumulo.tserver.logger.LogEvents.MUTATION;
 import static org.apache.accumulo.tserver.logger.LogEvents.OPEN;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -40,8 +39,9 @@ import java.util.Set;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.data.Mutation;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.server.data.ServerMutation;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
@@ -54,16 +54,24 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.MapFile;
 import org.apache.hadoop.io.MapFile.Writer;
 import org.apache.hadoop.io.Text;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 import org.junit.rules.TemporaryFolder;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
+@SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
 public class SortedLogRecoveryTest {
 
-  static final KeyExtent extent = new KeyExtent("table", null, null);
+  static final KeyExtent extent = new KeyExtent(TableId.of("table"), null, null);
   static final Text cf = new Text("cf");
   static final Text cq = new Text("cq");
   static final Value value = new Value("value".getBytes());
 
+  @Rule
+  public ExpectedException thrown = ExpectedException.none();
+
   static class KeyValue implements Comparable<KeyValue> {
     public final LogFileKey key;
     public final LogFileValue value;
@@ -129,7 +137,7 @@ public class SortedLogRecoveryTest {
 
   private static List<Mutation> recover(Map<String,KeyValue[]> logs, KeyExtent extent)
       throws IOException {
-    return recover(logs, new HashSet<String>(), extent);
+    return recover(logs, new HashSet<>(), extent);
   }
 
   private static List<Mutation> recover(Map<String,KeyValue[]> logs, Set<String> files,
@@ -174,25 +182,25 @@ public class SortedLogRecoveryTest {
     m.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
     m2.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, 1, "2"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 4, 1, ignored),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, 1, "2"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"), createKeyValue(MUTATION, 7, 1, m),};
-    KeyValue entries3[] = new KeyValue[] {createKeyValue(OPEN, 0, 2, "23"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 5, 1, "/t1/f2"),
-        createKeyValue(COMPACTION_FINISH, 6, 1, null), createKeyValue(MUTATION, 3, 1, ignored),
-        createKeyValue(MUTATION, 4, 1, ignored),};
-    KeyValue entries4[] = new KeyValue[] {createKeyValue(OPEN, 0, 3, "69"),
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, 1, "2"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(MUTATION, 2, 1, ignored), createKeyValue(MUTATION, 4, 1, ignored),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 0, 1, "2"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"), createKeyValue(MUTATION, 7, 1, m),};
+    KeyValue[] entries3 =
+        {createKeyValue(OPEN, 0, 2, "23"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 5, 1, "/t1/f2"),
+            createKeyValue(COMPACTION_FINISH, 6, 1, null), createKeyValue(MUTATION, 3, 1, ignored),
+            createKeyValue(MUTATION, 4, 1, ignored),};
+    KeyValue[] entries4 = {createKeyValue(OPEN, 0, 3, "69"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(MUTATION, 2, 1, ignored),
         createKeyValue(MUTATION, 3, 1, ignored), createKeyValue(MUTATION, 4, 1, ignored),};
-    KeyValue entries5[] = new KeyValue[] {createKeyValue(OPEN, 0, 4, "70"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f3"), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 6, 1, m2),};
+    KeyValue[] entries5 =
+        {createKeyValue(OPEN, 0, 4, "70"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f3"),
+            createKeyValue(MUTATION, 2, 1, ignored), createKeyValue(MUTATION, 6, 1, m2),};
 
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
@@ -223,24 +231,25 @@ public class SortedLogRecoveryTest {
     m3.put(cf, cq, value);
     Mutation m4 = new ServerMutation(new Text("row4"));
     m4.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 4, 1, ignored),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 5, -1, "2"),
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(MUTATION, 2, 1, ignored), createKeyValue(MUTATION, 4, 1, ignored),};
+    KeyValue[] entries2 = {createKeyValue(OPEN, 5, -1, "2"),
         createKeyValue(DEFINE_TABLET, 6, 1, extent), createKeyValue(MUTATION, 7, 1, ignored),};
-    KeyValue entries3[] = new KeyValue[] {createKeyValue(OPEN, 8, -1, "3"),
-        createKeyValue(DEFINE_TABLET, 9, 1, extent),
-        createKeyValue(COMPACTION_FINISH, 10, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_START, 12, 1, "/t1/f2"),
-        createKeyValue(COMPACTION_FINISH, 13, 1, "/t1/f2"),
-        // createKeyValue(COMPACTION_FINISH, 14, 1, null),
-        createKeyValue(MUTATION, 11, 1, ignored), createKeyValue(MUTATION, 15, 1, m),
-        createKeyValue(MUTATION, 16, 1, m2),};
-    KeyValue entries4[] = new KeyValue[] {createKeyValue(OPEN, 17, -1, "4"),
-        createKeyValue(DEFINE_TABLET, 18, 1, extent),
-        createKeyValue(COMPACTION_START, 20, 1, "/t1/f3"), createKeyValue(MUTATION, 19, 1, m3),
-        createKeyValue(MUTATION, 21, 1, m4),};
+    // createKeyValue(COMPACTION_FINISH, 14, 1, null),
+    KeyValue[] entries3 =
+        {createKeyValue(OPEN, 8, -1, "3"), createKeyValue(DEFINE_TABLET, 9, 1, extent),
+            createKeyValue(COMPACTION_FINISH, 10, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_START, 12, 1, "/t1/f2"),
+            createKeyValue(COMPACTION_FINISH, 13, 1, "/t1/f2"),
+            // createKeyValue(COMPACTION_FINISH, 14, 1, null),
+            createKeyValue(MUTATION, 11, 1, ignored), createKeyValue(MUTATION, 15, 1, m),
+            createKeyValue(MUTATION, 16, 1, m2),};
+    KeyValue[] entries4 =
+        {createKeyValue(OPEN, 17, -1, "4"), createKeyValue(DEFINE_TABLET, 18, 1, extent),
+            createKeyValue(COMPACTION_START, 20, 1, "/t1/f3"), createKeyValue(MUTATION, 19, 1, m3),
+            createKeyValue(MUTATION, 21, 1, m4),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -271,13 +280,13 @@ public class SortedLogRecoveryTest {
     m4.put(cf, cq, value);
     Mutation m5 = new ServerMutation(new Text("row5"));
     m5.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, 1, "2"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(MUTATION, 1, 1, ignored),
-        createKeyValue(MUTATION, 3, 1, m),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, 1, "2"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 2, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_FINISH, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 3, 1, m2),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, 1, "2"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(MUTATION, 1, 1, ignored), createKeyValue(MUTATION, 3, 1, m),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 0, 1, "2"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 2, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_FINISH, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 3, 1, m2),};
 
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
@@ -295,8 +304,8 @@ public class SortedLogRecoveryTest {
   @Test
   public void testEmpty() throws IOException {
     // Create a test log
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
     // Recover
@@ -309,7 +318,7 @@ public class SortedLogRecoveryTest {
   @Test
   public void testMissingDefinition() {
     // Create a test log
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),};
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
     // Recover
@@ -324,7 +333,7 @@ public class SortedLogRecoveryTest {
     // Create a test log
     Mutation m = new ServerMutation(new Text("row1"));
     m.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(MUTATION, 2, 1, m),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
@@ -342,11 +351,11 @@ public class SortedLogRecoveryTest {
     ignored.put(cf, cq, value);
     Mutation m = new ServerMutation(new Text("row1"));
     m.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 5, 1, m),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 2, 1, ignored),
+            createKeyValue(MUTATION, 5, 1, m),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
     // Recover
@@ -363,12 +372,12 @@ public class SortedLogRecoveryTest {
     ignored.put(cf, cq, value);
     Mutation m = new ServerMutation(new Text("row1"));
     m.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent),
         createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 2, 1, ignored),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 4, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 5, 1, extent), createKeyValue(COMPACTION_FINISH, 6, 1, null),
-        createKeyValue(MUTATION, 7, 1, m),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 4, -1, "1"), createKeyValue(DEFINE_TABLET, 5, 1, extent),
+            createKeyValue(COMPACTION_FINISH, 6, 1, null), createKeyValue(MUTATION, 7, 1, m),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -388,13 +397,13 @@ public class SortedLogRecoveryTest {
     m.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
     m2.put(cf, cq, new Value("123".getBytes()));
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 4, 1, m),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 5, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 4, 1, extent), createKeyValue(COMPACTION_FINISH, 4, 1, null),
-        createKeyValue(MUTATION, 8, 1, m2),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(MUTATION, 2, 1, ignored), createKeyValue(MUTATION, 4, 1, m),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 5, -1, "1"), createKeyValue(DEFINE_TABLET, 4, 1, extent),
+            createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 8, 1, m2),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -415,7 +424,7 @@ public class SortedLogRecoveryTest {
     m.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
     m2.put(cf, cq, new Value("123".getBytes()));
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(COMPACTION_FINISH, 2, 1, null),
         createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"),
         createKeyValue(COMPACTION_FINISH, 5, 1, null), createKeyValue(MUTATION, 3, 1, ignored),
@@ -441,15 +450,15 @@ public class SortedLogRecoveryTest {
     m2.put(cf, cq, value);
     Mutation m3 = new ServerMutation(new Text("row3"));
     m3.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"), createKeyValue(MUTATION, 2, 1, ignored),
-        createKeyValue(MUTATION, 4, 1, m),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 5, -1, "1"),
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(MUTATION, 2, 1, ignored), createKeyValue(MUTATION, 4, 1, m),};
+    KeyValue[] entries2 = {createKeyValue(OPEN, 5, -1, "1"),
         createKeyValue(DEFINE_TABLET, 4, 1, extent), createKeyValue(MUTATION, 4, 1, m2),};
-    KeyValue entries3[] = new KeyValue[] {createKeyValue(OPEN, 8, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 4, 1, extent), createKeyValue(COMPACTION_FINISH, 4, 1, null),
-        createKeyValue(MUTATION, 4, 1, m3),};
+    KeyValue[] entries3 =
+        {createKeyValue(OPEN, 8, -1, "1"), createKeyValue(DEFINE_TABLET, 4, 1, extent),
+            createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 4, 1, m3),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -470,11 +479,11 @@ public class SortedLogRecoveryTest {
     m1.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
     m2.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 30, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_FINISH, 32, 1, "/t1/f1"), createKeyValue(MUTATION, 29, 1, m1),
-        createKeyValue(MUTATION, 30, 1, m2),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 30, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_FINISH, 32, 1, "/t1/f1"), createKeyValue(MUTATION, 29, 1, m1),
+            createKeyValue(MUTATION, 30, 1, m2),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
     // Recover
@@ -494,14 +503,14 @@ public class SortedLogRecoveryTest {
     m2.put(cf, cq, value);
     Mutation m3 = new ServerMutation(new Text("row3"));
     m3.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 4, 1, m),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 5, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 6, 1, extent),
-        createKeyValue(COMPACTION_START, 8, 1, "/t1/f1"), createKeyValue(MUTATION, 7, 1, m2),
-        createKeyValue(MUTATION, 9, 1, m3),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_FINISH, 4, 1, null), createKeyValue(MUTATION, 4, 1, m),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 5, -1, "1"), createKeyValue(DEFINE_TABLET, 6, 1, extent),
+            createKeyValue(COMPACTION_START, 8, 1, "/t1/f1"), createKeyValue(MUTATION, 7, 1, m2),
+            createKeyValue(MUTATION, 9, 1, m3),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -531,24 +540,31 @@ public class SortedLogRecoveryTest {
     m5.put(cf, cq, value);
     Mutation m6 = new ServerMutation(new Text("row6"));
     m6.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"),
-        // createKeyValue(COMPACTION_FINISH, 5, 1, null),
-        createKeyValue(MUTATION, 2, 1, m), createKeyValue(MUTATION, 3, 1, m2),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 5, -1, "2"),
-        createKeyValue(DEFINE_TABLET, 6, 1, extent), createKeyValue(MUTATION, 7, 1, m3),
-        createKeyValue(MUTATION, 8, 1, m4),};
-    KeyValue entries3[] = new KeyValue[] {createKeyValue(OPEN, 9, -1, "3"),
-        createKeyValue(DEFINE_TABLET, 10, 1, extent),
-        // createKeyValue(COMPACTION_FINISH, 11, 1, null),
-        createKeyValue(COMPACTION_START, 12, 1, "/t1/f1"),
-        // createKeyValue(COMPACTION_FINISH, 14, 1, null),
-        // createKeyValue(COMPACTION_START, 15, 1, "somefile"),
-        // createKeyValue(COMPACTION_FINISH, 17, 1, null),
-        // createKeyValue(COMPACTION_START, 18, 1, "somefile"),
-        // createKeyValue(COMPACTION_FINISH, 19, 1, null),
-        createKeyValue(MUTATION, 9, 1, m5), createKeyValue(MUTATION, 20, 1, m6),};
+    // createKeyValue(COMPACTION_FINISH, 5, 1, null),
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"),
+            // createKeyValue(COMPACTION_FINISH, 5, 1, null),
+            createKeyValue(MUTATION, 2, 1, m), createKeyValue(MUTATION, 3, 1, m2),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 5, -1, "2"), createKeyValue(DEFINE_TABLET, 6, 1, extent),
+            createKeyValue(MUTATION, 7, 1, m3), createKeyValue(MUTATION, 8, 1, m4),};
+    // createKeyValue(COMPACTION_FINISH, 11, 1, null),
+    // createKeyValue(COMPACTION_FINISH, 14, 1, null),
+    // createKeyValue(COMPACTION_START, 15, 1, "somefile"),
+    // createKeyValue(COMPACTION_FINISH, 17, 1, null),
+    // createKeyValue(COMPACTION_START, 18, 1, "somefile"),
+    // createKeyValue(COMPACTION_FINISH, 19, 1, null),
+    KeyValue[] entries3 =
+        {createKeyValue(OPEN, 9, -1, "3"), createKeyValue(DEFINE_TABLET, 10, 1, extent),
+            // createKeyValue(COMPACTION_FINISH, 11, 1, null),
+            createKeyValue(COMPACTION_START, 12, 1, "/t1/f1"),
+            // createKeyValue(COMPACTION_FINISH, 14, 1, null),
+            // createKeyValue(COMPACTION_START, 15, 1, "somefile"),
+            // createKeyValue(COMPACTION_FINISH, 17, 1, null),
+            // createKeyValue(COMPACTION_START, 18, 1, "somefile"),
+            // createKeyValue(COMPACTION_FINISH, 19, 1, null),
+            createKeyValue(MUTATION, 9, 1, m5), createKeyValue(MUTATION, 20, 1, m6),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -581,16 +597,16 @@ public class SortedLogRecoveryTest {
     m4.put(cf, cq, value);
     Mutation m5 = new ServerMutation(new Text("row5"));
     m5.put(cf, cq, value);
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 2, 1, "/t1/f1"),
-        createKeyValue(COMPACTION_FINISH, 3, 1, null), createKeyValue(MUTATION, 1, 1, ignored),
-        createKeyValue(MUTATION, 3, 1, m), createKeyValue(MUTATION, 3, 1, m2),
-        createKeyValue(MUTATION, 3, 1, m3),};
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "2"),
-        createKeyValue(DEFINE_TABLET, 1, 1, extent),
-        createKeyValue(COMPACTION_START, 2, 1, "/t1/f12"), createKeyValue(MUTATION, 3, 1, m4),
-        createKeyValue(MUTATION, 3, 1, m5),};
+    KeyValue[] entries =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 2, 1, "/t1/f1"),
+            createKeyValue(COMPACTION_FINISH, 3, 1, null), createKeyValue(MUTATION, 1, 1, ignored),
+            createKeyValue(MUTATION, 3, 1, m), createKeyValue(MUTATION, 3, 1, m2),
+            createKeyValue(MUTATION, 3, 1, m3),};
+    KeyValue[] entries2 =
+        {createKeyValue(OPEN, 0, -1, "2"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+            createKeyValue(COMPACTION_START, 2, 1, "/t1/f12"), createKeyValue(MUTATION, 3, 1, m4),
+            createKeyValue(MUTATION, 3, 1, m5),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
     logs.put("entries2", entries2);
@@ -616,7 +632,7 @@ public class SortedLogRecoveryTest {
     Mutation m = new ServerMutation(new Text("row1"));
     m.put("foo", "bar", "v1");
 
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(DEFINE_TABLET, 1, 2, extent),
         createKeyValue(MUTATION, 2, 2, ignored), createKeyValue(COMPACTION_START, 5, 2, "/t1/f1"),
         createKeyValue(MUTATION, 6, 2, m), createKeyValue(COMPACTION_FINISH, 6, 2, null),};
@@ -640,7 +656,7 @@ public class SortedLogRecoveryTest {
     Mutation ignored = new ServerMutation(new Text("row1"));
     ignored.put("foo", "bar", "v1");
 
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 2, extent), createKeyValue(MUTATION, 2, 2, ignored),
         createKeyValue(COMPACTION_START, 3, 2, "/t/f1")};
 
@@ -663,7 +679,7 @@ public class SortedLogRecoveryTest {
     Mutation m = new ServerMutation(new Text("row1"));
     m.put("foo", "bar", "v2");
 
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 2, extent), createKeyValue(MUTATION, 2, 2, ignored),
         createKeyValue(COMPACTION_START, 3, 2, "/t/f1"), createKeyValue(MUTATION, 4, 2, m),};
 
@@ -688,12 +704,12 @@ public class SortedLogRecoveryTest {
     Mutation m2 = new ServerMutation(new Text("r2"));
     m2.put("f1", "q1", "v2");
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 100, 10, extent), createKeyValue(MUTATION, 100, 10, m1),
         createKeyValue(COMPACTION_START, 101, 10, "/t/f1"),
         createKeyValue(COMPACTION_FINISH, 102, 10, null)};
 
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries2 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 20, extent), createKeyValue(MUTATION, 1, 20, m2)};
 
     Arrays.sort(entries1);
@@ -710,8 +726,8 @@ public class SortedLogRecoveryTest {
 
   @Test
   public void testMultipleTablets() throws IOException {
-    KeyExtent e1 = new KeyExtent("1", new Text("m"), null);
-    KeyExtent e2 = new KeyExtent("1", null, new Text("m"));
+    KeyExtent e1 = new KeyExtent(TableId.of("1"), new Text("m"), null);
+    KeyExtent e2 = new KeyExtent(TableId.of("1"), null, new Text("m"));
 
     Mutation m1 = new ServerMutation(new Text("b"));
     m1.put("f1", "q1", "v1");
@@ -725,8 +741,8 @@ public class SortedLogRecoveryTest {
     Mutation m4 = new ServerMutation(new Text("s"));
     m4.put("f1", "q2", "v4");
 
-    KeyValue entries1[] =
-        new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 7, 10, e1),
+    KeyValue[] entries1 =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 7, 10, e1),
             createKeyValue(DEFINE_TABLET, 5, 11, e2), createKeyValue(MUTATION, 8, 10, m1),
             createKeyValue(COMPACTION_START, 9, 10, "/t/f1"), createKeyValue(MUTATION, 10, 10, m2),
             createKeyValue(COMPACTION_FINISH, 10, 10, null), createKeyValue(MUTATION, 6, 11, m3),
@@ -746,7 +762,7 @@ public class SortedLogRecoveryTest {
     assertEquals(m3, mutations2.get(0));
     assertEquals(m4, mutations2.get(1));
 
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries2 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 9, 11, e2), createKeyValue(COMPACTION_FINISH, 8, 11, null)};
     Arrays.sort(entries2);
     logs.put("entries2", entries2);
@@ -763,7 +779,7 @@ public class SortedLogRecoveryTest {
     Mutation m2 = new ServerMutation(new Text("row1"));
     m2.put("foo", "bar", "v2");
 
-    KeyValue entries[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 2, extent), createKeyValue(MUTATION, 2, 2, m1),
         createKeyValue(COMPACTION_START, 3, 2, compactionStartFile),
         createKeyValue(MUTATION, 4, 2, m2),};
@@ -793,9 +809,9 @@ public class SortedLogRecoveryTest {
     runPathTest(false, "/t1/f1", "/t1/f0");
     runPathTest(true, "/t1/f1", "/t1/f0", "/t1/f1");
 
-    String aliases[] = new String[] {"/t1/f1", "hdfs://nn1/accumulo/tables/8/t1/f1",
+    String[] aliases = {"/t1/f1", "hdfs://nn1/accumulo/tables/8/t1/f1",
         "hdfs://1.2.3.4/accumulo/tables/8/t1/f1", "hdfs://1.2.3.4//accumulo//tables//8//t1//f1"};
-    String others[] = new String[] {"/t1/f0", "hdfs://nn1/accumulo/tables/8/t1/f2",
+    String[] others = {"/t1/f0", "hdfs://nn1/accumulo/tables/8/t1/f2",
         "hdfs://1.2.3.4//accumulo//tables//8//t1//f3", "hdfs://nn1/accumulo/tables/8/t1/t1",
         "hdfs://nn1/accumulo/tables/8/f1/f1"};
 
@@ -824,7 +840,7 @@ public class SortedLogRecoveryTest {
     // The presence of only a compaction finish event indicates the write ahead logs are incomplete
     // in some way. This should cause an exception.
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 100, 10, extent),
         createKeyValue(COMPACTION_FINISH, 102, 10, null), createKeyValue(MUTATION, 102, 10, m1)};
 
@@ -849,7 +865,7 @@ public class SortedLogRecoveryTest {
     // Consecutive compaction finish events indicate the write ahead logs are incomplete in some
     // way. This should cause an exception.
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 100, 10, extent), createKeyValue(MUTATION, 100, 10, m1),
         createKeyValue(COMPACTION_START, 102, 10, "/t/f1"),
         createKeyValue(COMPACTION_FINISH, 103, 10, null),
@@ -860,9 +876,9 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries1", entries1);
 
-    IllegalStateException e =
-        assertThrows(IllegalStateException.class, () -> recover(logs, extent));
-    assertTrue(e.getMessage().contains("consecutive " + LogEvents.COMPACTION_FINISH.name()));
+    thrown.expect(IllegalStateException.class);
+    thrown.expectMessage("consecutive " + LogEvents.COMPACTION_FINISH.name());
+    recover(logs, extent);
   }
 
   @Test
@@ -875,7 +891,7 @@ public class SortedLogRecoveryTest {
 
     // Duplicate consecutive compaction finish events should not cause an exception.
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 100, 10, extent), createKeyValue(MUTATION, 100, 10, m1),
         createKeyValue(COMPACTION_START, 102, 10, "/t/f1"),
         createKeyValue(COMPACTION_FINISH, 103, 10, null),
@@ -899,22 +915,22 @@ public class SortedLogRecoveryTest {
     Mutation m2 = new ServerMutation(new Text("r2"));
     m2.put("f1", "q1", "v2");
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 100, 10, extent), createKeyValue(MUTATION, 100, 10, m1)};
 
-    KeyValue entries2[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1")};
+    KeyValue[] entries2 = {createKeyValue(OPEN, 0, -1, "1")};
 
-    KeyValue entries3[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 105, 10, extent),
-        createKeyValue(COMPACTION_START, 107, 10, "/t/f1")};
+    KeyValue[] entries3 =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 105, 10, extent),
+            createKeyValue(COMPACTION_START, 107, 10, "/t/f1")};
 
-    KeyValue entries4[] = new KeyValue[] {};
+    KeyValue[] entries4 = {};
 
-    KeyValue entries5[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
-        createKeyValue(DEFINE_TABLET, 107, 10, extent),
-        createKeyValue(COMPACTION_FINISH, 111, 10, null)};
+    KeyValue[] entries5 =
+        {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 107, 10, extent),
+            createKeyValue(COMPACTION_FINISH, 111, 10, null)};
 
-    KeyValue entries6[] = new KeyValue[] {createKeyValue(OPEN, 0, -1, "1"),
+    KeyValue[] entries6 = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 122, 10, extent), createKeyValue(MUTATION, 123, 10, m2)};
 
     Arrays.sort(entries1);
@@ -973,7 +989,7 @@ public class SortedLogRecoveryTest {
     // Its expected that every log file should have an open event as the first event. Should throw
     // an error if not present.
 
-    KeyValue entries1[] = new KeyValue[] {createKeyValue(DEFINE_TABLET, 100, 10, extent),
+    KeyValue[] entries1 = {createKeyValue(DEFINE_TABLET, 100, 10, extent),
         createKeyValue(MUTATION, 100, 10, m1), createKeyValue(COMPACTION_FINISH, 102, 10, null),
         createKeyValue(MUTATION, 105, 10, m2)};
 
@@ -982,8 +998,8 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries1", entries1);
 
-    IllegalStateException e =
-        assertThrows(IllegalStateException.class, () -> recover(logs, extent));
-    assertTrue(e.getMessage().contains("not " + LogEvents.OPEN));
+    thrown.expect(IllegalStateException.class);
+    thrown.expectMessage("not " + LogEvents.OPEN);
+    recover(logs, extent);
   }
 }
