@@ -37,41 +37,37 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Objects;
+import java.util.Properties;
 import java.util.Set;
 import java.util.TreeMap;
-import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.ClientConfiguration;
-import org.apache.accumulo.core.client.ClientConfiguration.ClientProperty;
-import org.apache.accumulo.core.client.Connector;
-import org.apache.accumulo.core.client.Instance;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.NamespaceNotFoundException;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.ZooKeeperInstance;
-import org.apache.accumulo.core.client.impl.Tables;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
-import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.ClientInfo;
+import org.apache.accumulo.core.clientImpl.Tables;
+import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.thrift.TConstraintViolationSummary;
+import org.apache.accumulo.core.dataImpl.thrift.TConstraintViolationSummary;
 import org.apache.accumulo.core.tabletserver.thrift.ConstraintViolationException;
-import org.apache.accumulo.core.trace.DistributedTrace;
+import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.BadArgumentException;
-import org.apache.accumulo.core.util.DeprecationUtil;
 import org.apache.accumulo.core.util.format.DefaultFormatter;
 import org.apache.accumulo.core.util.format.Formatter;
 import org.apache.accumulo.core.util.format.FormatterConfig;
 import org.apache.accumulo.core.util.format.FormatterFactory;
-import org.apache.accumulo.core.volume.VolumeConfiguration;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
 import org.apache.accumulo.shell.commands.AboutCommand;
 import org.apache.accumulo.shell.commands.AddAuthsCommand;
 import org.apache.accumulo.shell.commands.AddSplitsCommand;
@@ -88,7 +84,6 @@ import org.apache.accumulo.shell.commands.CreateNamespaceCommand;
 import org.apache.accumulo.shell.commands.CreateTableCommand;
 import org.apache.accumulo.shell.commands.CreateUserCommand;
 import org.apache.accumulo.shell.commands.DUCommand;
-import org.apache.accumulo.shell.commands.DebugCommand;
 import org.apache.accumulo.shell.commands.DeleteAuthsCommand;
 import org.apache.accumulo.shell.commands.DeleteCommand;
 import org.apache.accumulo.shell.commands.DeleteIterCommand;
@@ -151,6 +146,7 @@ import org.apache.accumulo.shell.commands.SetIterCommand;
 import org.apache.accumulo.shell.commands.SetScanIterCommand;
 import org.apache.accumulo.shell.commands.SetShellIterCommand;
 import org.apache.accumulo.shell.commands.SleepCommand;
+import org.apache.accumulo.shell.commands.SummariesCommand;
 import org.apache.accumulo.shell.commands.SystemPermissionsCommand;
 import org.apache.accumulo.shell.commands.TableCommand;
 import org.apache.accumulo.shell.commands.TablePermissionsCommand;
@@ -170,16 +166,15 @@ import org.apache.commons.cli.MissingOptionException;
 import org.apache.commons.cli.Option;
 import org.apache.commons.cli.Options;
 import org.apache.commons.cli.ParseException;
-import org.apache.commons.configuration.ConfigurationException;
 import org.apache.commons.vfs2.FileSystemException;
-import org.apache.hadoop.fs.Path;
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.beust.jcommander.JCommander;
 import com.beust.jcommander.ParameterException;
 import com.google.auto.service.AutoService;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 import jline.console.ConsoleReader;
 import jline.console.UserInterruptException;
 import jline.console.history.FileHistory;
@@ -190,8 +185,8 @@ import jline.console.history.FileHistory;
  */
 @AutoService(KeywordExecutable.class)
 public class Shell extends ShellOptions implements KeywordExecutable {
-  public static final Logger log = Logger.getLogger(Shell.class);
-  private static final Logger audit = Logger.getLogger(Shell.class.getName() + ".audit");
+  public static final Logger log = LoggerFactory.getLogger(Shell.class);
+  private static final Logger audit = LoggerFactory.getLogger(Shell.class.getName() + ".audit");
 
   public static final Charset CHARSET = ISO_8859_1;
   public static final int NO_FIXED_ARG_LENGTH_CHECK = -1;
@@ -202,10 +197,10 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   protected int exitCode = 0;
   private String tableName;
-  protected Instance instance;
-  private Connector connector;
+  private AccumuloClient accumuloClient;
+  private Properties clientProperties = new Properties();
+  private ClientContext context;
   protected ConsoleReader reader;
-  private AuthenticationToken token;
   private final Class<? extends Formatter> defaultFormatterClass = DefaultFormatter.class;
   public Map<String,List<IteratorSetting>> scanIteratorOptions = new HashMap<>();
   public Map<String,List<IteratorSetting>> iteratorProfiles = new HashMap<>();
@@ -262,8 +257,9 @@ public class Shell extends ShellOptions implements KeywordExecutable {
    *           if problems occur creating the ConsoleReader
    */
   public boolean config(String... args) throws IOException {
-    if (this.reader == null)
+    if (this.reader == null) {
       this.reader = new ConsoleReader();
+    }
     ShellOptionsJC options = new ShellOptionsJC();
     JCommander jc = new JCommander();
 
@@ -285,103 +281,75 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     }
 
     if (options.getUnrecognizedOptions() != null) {
-      logError("Unrecognized Options: " + options.getUnrecognizedOptions().toString());
+      logError("Unrecognized Options: " + options.getUnrecognizedOptions());
       jc.usage();
       exitCode = 1;
       return false;
     }
 
-    setDebugging(options.isDebugEnabled());
+    if (options.isDebugEnabled()) {
+      log.warn("Configure debugging through your logging configuration file");
+    }
     authTimeout = TimeUnit.MINUTES.toNanos(options.getAuthTimeout());
     disableAuthTimeout = options.isAuthTimeoutDisabled();
 
-    ClientConfiguration clientConf;
-    try {
-      clientConf = options.getClientConfiguration();
-    } catch (Exception e) {
-      printException(e);
-      return true;
-    }
-
-    if (Boolean.parseBoolean(clientConf.get(ClientProperty.INSTANCE_RPC_SASL_ENABLED))) {
+    clientProperties = options.getClientProperties();
+    if (ClientProperty.SASL_ENABLED.getBoolean(clientProperties)) {
       log.debug("SASL is enabled, disabling authorization timeout");
       disableAuthTimeout = true;
     }
 
-    // get the options that were parsed
-    final String user;
-    try {
-      user = options.getUsername();
-    } catch (Exception e) {
-      printException(e);
-      return true;
-    }
-    String password = options.getPassword();
-
     tabCompletion = !options.isTabCompletionDisabled();
+    this.setTableName("");
 
-    // Use a ZK, or HdfsZK Accumulo instance
-    setInstance(options);
-
-    // AuthenticationToken options
-    try {
-      token = options.getAuthenticationToken();
-    } catch (Exception e) {
-      printException(e);
-      return true;
-    }
-
-    Map<String,String> loginOptions = options.getTokenProperties();
-
-    // process default parameters if unspecified
-    try {
-      final boolean hasToken = (token != null);
-
-      if (hasToken && password != null) {
-        throw new ParameterException("Can not supply '--pass' option with '--tokenClass' option");
+    if (accumuloClient == null) {
+      if (ClientProperty.INSTANCE_ZOOKEEPERS.isEmpty(clientProperties)) {
+        throw new IllegalArgumentException("ZooKeepers must be set using -z or -zh on command line"
+            + " or in accumulo-client.properties");
       }
-
-      Runtime.getRuntime().addShutdownHook(new Thread() {
-        @Override
-        public void run() {
-          reader.getTerminal().setEchoEnabled(true);
-        }
-      });
-
-      if (hasToken) { // implied hasTokenOptions
-        // Fully qualified name so we don't shadow java.util.Properties
-        org.apache.accumulo.core.client.security.tokens.AuthenticationToken.Properties props =
-            new org.apache.accumulo.core.client.security.tokens.AuthenticationToken.Properties();
-
-        if (!loginOptions.isEmpty()) {
-          props.putAllStrings(loginOptions);
-        }
-        token.init(props);
-      } else {
+      if (ClientProperty.INSTANCE_NAME.isEmpty(clientProperties)) {
+        throw new IllegalArgumentException("Instance name must be set using -z or -zi on command "
+            + "line or in accumulo-client.properties");
+      }
+      final String principal;
+      try {
+        principal = options.getUsername();
+      } catch (Exception e) {
+        logError(e.getMessage());
+        exitCode = 1;
+        return false;
+      }
+      String password = options.getPassword();
+      AuthenticationToken token = null;
+      if (password == null && clientProperties.containsKey(ClientProperty.AUTH_TOKEN.getKey())
+          && principal.equals(ClientProperty.AUTH_PRINCIPAL.getValue(clientProperties))) {
+        token = ClientProperty.getAuthenticationToken(clientProperties);
+      }
+      if (token == null) {
+        Runtime.getRuntime()
+            .addShutdownHook(new Thread(() -> reader.getTerminal().setEchoEnabled(true)));
         // Read password if the user explicitly asked for it, or didn't specify anything at all
         if ("stdin".equals(password) || password == null) {
           password = reader.readLine("Password: ", '*');
         }
-
         if (password == null) {
           // User cancel, e.g. Ctrl-D pressed
           throw new ParameterException("No password or token option supplied");
         } else {
-          this.token = new PasswordToken(password);
+          token = new PasswordToken(password);
         }
       }
-
-      if (!options.isFake()) {
-        DistributedTrace.enable(InetAddress.getLocalHost().getHostName(), "shell", clientConf);
+      try {
+        TraceUtil.enableClientTraces(InetAddress.getLocalHost().getHostName(), "shell",
+            clientProperties);
+        this.setTableName("");
+        accumuloClient = Accumulo.newClient().from(clientProperties).as(principal, token).build();
+        context = (ClientContext) accumuloClient;
+      } catch (Exception e) {
+        printException(e);
+        exitCode = 1;
+        return false;
       }
-
-      this.setTableName("");
-      connector = instance.getConnector(user, token);
-
-    } catch (Exception e) {
-      printException(e);
-      exitCode = 1;
-      return false;
     }
 
     // decide whether to execute commands from a file and quit
@@ -402,9 +370,10 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     Command[] dataCommands = {new DeleteCommand(), new DeleteManyCommand(), new DeleteRowsCommand(),
         new EGrepCommand(), new FormatterCommand(), new InterpreterCommand(), new GrepCommand(),
         new ImportDirectoryCommand(), new InsertCommand(), new MaxRowCommand(), new ScanCommand()};
-    Command[] debuggingCommands = {new ClasspathCommand(), new DebugCommand(),
-        new ListScansCommand(), new ListCompactionsCommand(), new TraceCommand(), new PingCommand(),
-        new ListBulkCommand()};
+    @SuppressWarnings("deprecation")
+    Command[] debuggingCommands = {new ClasspathCommand(),
+        new org.apache.accumulo.shell.commands.DebugCommand(), new ListScansCommand(),
+        new ListCompactionsCommand(), new TraceCommand(), new PingCommand(), new ListBulkCommand()};
     Command[] execCommands =
         {new ExecfileCommand(), new HistoryCommand(), new ExtensionCommand(), new ScriptCommand()};
     Command[] exitCommands = {new ByeCommand(), new ExitCommand(), new QuitCommand()};
@@ -424,7 +393,8 @@ public class Shell extends ShellOptions implements KeywordExecutable {
         new CreateTableCommand(), new DeleteTableCommand(), new DropTableCommand(), new DUCommand(),
         new ExportTableCommand(), new ImportTableCommand(), new OfflineCommand(),
         new OnlineCommand(), new RenameTableCommand(), new TablesCommand(), new NamespacesCommand(),
-        new CreateNamespaceCommand(), new DeleteNamespaceCommand(), new RenameNamespaceCommand()};
+        new CreateNamespaceCommand(), new DeleteNamespaceCommand(), new RenameNamespaceCommand(),
+        new SummariesCommand()};
     Command[] tableControlCommands = {new AddSplitsCommand(), new CompactCommand(),
         new ConstraintCommand(), new FlushCommand(), new GetGroupsCommand(), new GetSplitsCommand(),
         new MergeCommand(), new SetGroupsCommand()};
@@ -444,8 +414,9 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     commandGrouping.put("-- User Administration Commands ---------", userCommands);
 
     for (Command[] cmds : commandGrouping.values()) {
-      for (Command cmd : cmds)
+      for (Command cmd : cmds) {
         commandFactory.put(cmd.getName(), cmd);
+      }
     }
     for (Command cmd : otherCommands) {
       commandFactory.put(cmd.getName(), cmd);
@@ -453,93 +424,8 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     return true;
   }
 
-  /**
-   * Sets the instance used by the shell based on the given options.
-   *
-   * @param options
-   *          shell options
-   */
-  protected void setInstance(ShellOptionsJC options) {
-    // should only be one set of instance options set
-    instance = null;
-    if (options.isFake()) {
-      instance = DeprecationUtil.makeMockInstance("fake");
-    } else {
-      String instanceName, hosts;
-      if (options.isHdfsZooInstance()) {
-        instanceName = hosts = null;
-      } else if (options.getZooKeeperInstance().size() > 0) {
-        List<String> zkOpts = options.getZooKeeperInstance();
-        instanceName = zkOpts.get(0);
-        hosts = zkOpts.get(1);
-      } else {
-        instanceName = options.getZooKeeperInstanceName();
-        hosts = options.getZooKeeperHosts();
-      }
-      final ClientConfiguration clientConf;
-      try {
-        clientConf = options.getClientConfiguration();
-      } catch (ConfigurationException | FileNotFoundException e) {
-        throw new IllegalArgumentException(
-            "Unable to load client config from " + options.getClientConfigFile(), e);
-      }
-      instance = getZooInstance(instanceName, hosts, clientConf);
-    }
-  }
-
-  /**
-   * Get the ZooKeepers. Use the value passed in (if there was one), then fall back to the
-   * ClientConf, finally trying the accumulo-site.xml.
-   *
-   * @param keepers
-   *          ZooKeepers passed to the shell
-   * @param clientConfig
-   *          ClientConfiguration instance
-   * @return The ZooKeepers to connect to
-   */
-  static String getZooKeepers(String keepers, ClientConfiguration clientConfig) {
-    if (null != keepers) {
-      return keepers;
-    }
-
-    if (clientConfig.containsKey(ClientProperty.INSTANCE_ZK_HOST.getKey())) {
-      return clientConfig.get(ClientProperty.INSTANCE_ZK_HOST);
-    }
-
-    return SiteConfiguration.getInstance().get(Property.INSTANCE_ZK_HOST);
-  }
-
-  /*
-   * Takes instanceName and keepers as separate arguments, rather than just packaged into the
-   * clientConfig, so that we can fail over to accumulo-site.xml or HDFS config if they're
-   * unspecified.
-   */
-  private static Instance getZooInstance(String instanceName, String keepersOption,
-      ClientConfiguration clientConfig) {
-    UUID instanceId = null;
-    if (instanceName == null) {
-      instanceName = clientConfig.get(ClientProperty.INSTANCE_NAME);
-    }
-
-    String keepers = getZooKeepers(keepersOption, clientConfig);
-    if (instanceName == null) {
-      AccumuloConfiguration conf = SiteConfiguration.getInstance();
-      Path instanceDir = new Path(VolumeConfiguration.getVolumeUris(conf)[0], "instance_id");
-      instanceId = UUID.fromString(ZooUtil.getInstanceIDFromHdfs(instanceDir, conf));
-    }
-    if (instanceId != null) {
-      return new ZooKeeperInstance(clientConfig.withInstance(instanceId).withZkHosts(keepers));
-    } else {
-      return new ZooKeeperInstance(clientConfig.withInstance(instanceName).withZkHosts(keepers));
-    }
-  }
-
-  public Connector getConnector() {
-    return connector;
-  }
-
-  public Instance getInstance() {
-    return instance;
+  public AccumuloClient getAccumuloClient() {
+    return accumuloClient;
   }
 
   public ClassLoader getClassLoader(final CommandLine cl, final Shell shellState)
@@ -555,13 +441,13 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     if (namespaces) {
       try {
-        tableProps = shellState.getConnector().namespaceOperations()
+        tableProps = shellState.getAccumuloClient().namespaceOperations()
             .getProperties(OptUtil.getNamespaceOpt(cl, shellState));
       } catch (NamespaceNotFoundException e) {
         throw new IllegalArgumentException(e);
       }
     } else if (tables) {
-      tableProps = shellState.getConnector().tableOperations()
+      tableProps = shellState.getAccumuloClient().tableOperations()
           .getProperties(OptUtil.getTableOpt(cl, shellState));
     } else {
       throw new IllegalArgumentException("No table or namespace specified");
@@ -575,13 +461,13 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     ClassLoader classloader;
 
     if (classpath != null && !classpath.equals("")) {
-      shellState.getConnector().instanceOperations().getSystemConfiguration()
+      shellState.getAccumuloClient().instanceOperations().getSystemConfiguration()
           .get(Property.VFS_CONTEXT_CLASSPATH_PROPERTY.getKey() + classpath);
 
       try {
 
         final Map<String,String> systemConfig =
-            shellState.getConnector().instanceOperations().getSystemConfiguration();
+            shellState.getAccumuloClient().instanceOperations().getSystemConfiguration();
 
         AccumuloVFSClassLoader.getContextManager()
             .setContextConfig(new ContextManager.DefaultContextsConfig() {
@@ -610,6 +496,17 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     return "shell";
   }
 
+  @Override
+  public UsageGroup usageGroup() {
+    return UsageGroup.CORE;
+  }
+
+  @Override
+  public String description() {
+    return "Runs Accumulo shell";
+  }
+
+  @SuppressFBWarnings(value = "DM_EXIT", justification = "System.exit() from a main class is okay")
   @Override
   public void execute(final String[] args) throws IOException {
     try {
@@ -620,43 +517,45 @@ public class Shell extends ShellOptions implements KeywordExecutable {
       System.exit(start());
     } finally {
       shutdown();
-      DistributedTrace.disable();
+      TraceUtil.disable();
     }
   }
 
-  public static void main(String args[]) throws IOException {
+  public static void main(String[] args) throws IOException {
     new Shell(new ConsoleReader()).execute(args);
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN",
+      justification = "user-provided paths intentional")
   public int start() throws IOException {
     String input;
-    if (isVerbose())
+    if (isVerbose()) {
       printInfo();
+    }
 
     String home = System.getProperty("HOME");
-    if (home == null)
+    if (home == null) {
       home = System.getenv("HOME");
+    }
     String configDir = home + "/" + HISTORY_DIR_NAME;
     String historyPath = configDir + "/" + HISTORY_FILE_NAME;
     File accumuloDir = new File(configDir);
-    if (!accumuloDir.exists() && !accumuloDir.mkdirs())
-      log.warn("Unable to make directory for history at " + accumuloDir);
+    if (!accumuloDir.exists() && !accumuloDir.mkdirs()) {
+      log.warn("Unable to make directory for history at {}", accumuloDir);
+    }
     try {
       final FileHistory history = new FileHistory(new File(historyPath));
       reader.setHistory(history);
       // Add shutdown hook to flush file history, per jline javadocs
-      Runtime.getRuntime().addShutdownHook(new Thread() {
-        @Override
-        public void run() {
-          try {
-            history.flush();
-          } catch (IOException e) {
-            log.warn("Could not flush history to file.");
-          }
+      Runtime.getRuntime().addShutdownHook(new Thread(() -> {
+        try {
+          history.flush();
+        } catch (IOException e) {
+          log.warn("Could not flush history to file.");
         }
-      });
+      }));
     } catch (IOException e) {
-      log.warn("Unable to load history file at " + historyPath);
+      log.warn("Unable to load history file at {}", historyPath);
     }
 
     // Turn Ctrl+C into Exception instead of JVM exit
@@ -665,13 +564,10 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     ShellCompletor userCompletor = null;
 
     if (execFile != null) {
-      java.util.Scanner scanner = new java.util.Scanner(execFile, UTF_8.name());
-      try {
+      try (java.util.Scanner scanner = new java.util.Scanner(execFile, UTF_8.name())) {
         while (scanner.hasNextLine() && !hasExited()) {
           execCommand(scanner.nextLine(), true, isVerbose());
         }
-      } finally {
-        scanner.close();
       }
     } else if (execCommand != null) {
       for (String command : execCommand.split("\n")) {
@@ -682,13 +578,15 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     while (true) {
       try {
-        if (hasExited())
+        if (hasExited()) {
           return exitCode;
+        }
 
         // If tab completion is true we need to reset
         if (tabCompletion) {
-          if (userCompletor != null)
+          if (userCompletor != null) {
             reader.removeCompleter(userCompletor);
+          }
 
           userCompletor = setupCompletion();
           reader.addCompleter(userCompletor);
@@ -721,27 +619,32 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     if (reader != null) {
       reader.shutdown();
     }
+    if (accumuloClient != null) {
+      accumuloClient.close();
+    }
   }
 
   public void printInfo() throws IOException {
+    ClientInfo info = ClientInfo.from(accumuloClient.properties());
     reader.print("\n" + SHELL_DESCRIPTION + "\n" + "- \n" + "- version: " + Constants.VERSION + "\n"
-        + "- instance name: " + connector.getInstance().getInstanceName() + "\n" + "- instance id: "
-        + connector.getInstance().getInstanceID() + "\n" + "- \n"
+        + "- instance name: " + info.getInstanceName() + "\n" + "- instance id: "
+        + accumuloClient.instanceOperations().getInstanceID() + "\n" + "- \n"
         + "- type 'help' for a list of available commands\n" + "- \n");
     reader.flush();
   }
 
   public void printVerboseInfo() throws IOException {
     StringBuilder sb = new StringBuilder("-\n");
-    sb.append("- Current user: ").append(connector.whoami()).append("\n");
-    if (execFile != null)
+    sb.append("- Current user: ").append(accumuloClient.whoami()).append("\n");
+    if (execFile != null) {
       sb.append("- Executing commands from: ").append(execFile).append("\n");
-    if (disableAuthTimeout)
+    }
+    if (disableAuthTimeout) {
       sb.append("- Authorization timeout: disabled\n");
-    else
+    } else {
       sb.append("- Authorization timeout: ")
           .append(String.format("%ds%n", TimeUnit.NANOSECONDS.toSeconds(authTimeout)));
-    sb.append("- Debug: ").append(isDebuggingEnabled() ? "on" : "off").append("\n");
+    }
     if (!scanIteratorOptions.isEmpty()) {
       for (Entry<String,List<IteratorSetting>> entry : scanIteratorOptions.entrySet()) {
         sb.append("- Session scan iterators for table ").append(entry.getKey()).append(":\n");
@@ -763,13 +666,23 @@ public class Shell extends ShellOptions implements KeywordExecutable {
   }
 
   public String getDefaultPrompt() {
-    return connector.whoami() + "@" + connector.getInstance().getInstanceName()
+    Objects.requireNonNull(accumuloClient);
+    ClientInfo info = ClientInfo.from(accumuloClient.properties());
+    return accumuloClient.whoami() + "@" + info.getInstanceName()
         + (getTableName().isEmpty() ? "" : " ") + getTableName() + "> ";
   }
 
+  /**
+   * Prevent potential CRLF injection into logs from read in user data See
+   * https://find-sec-bugs.github.io/bugs.htm#CRLF_INJECTION_LOGS
+   */
+  private String sanitize(String msg) {
+    return msg.replaceAll("[\r\n]", "");
+  }
+
   public void execCommand(String input, boolean ignoreAuthTimeout, boolean echoPrompt)
       throws IOException {
-    audit.log(Level.INFO, getDefaultPrompt() + input);
+    audit.info("{}", sanitize(getDefaultPrompt() + input));
     if (echoPrompt) {
       reader.print(getDefaultPrompt());
       reader.println(input);
@@ -779,7 +692,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
       return;
     }
 
-    String fields[];
+    String[] fields;
     try {
       fields = new QuotedStringTokenizer(input).getTokens();
     } catch (BadArgumentException e) {
@@ -787,8 +700,9 @@ public class Shell extends ShellOptions implements KeywordExecutable {
       ++exitCode;
       return;
     }
-    if (fields.length == 0)
+    if (fields.length == 0) {
       return;
+    }
 
     String command = fields[0];
     fields = fields.length > 1 ? Arrays.copyOfRange(fields, 1, fields.length) : new String[] {};
@@ -811,23 +725,24 @@ public class Shell extends ShellOptions implements KeywordExecutable {
           reader.println("Shell has been idle for too long. Please re-authenticate.");
           boolean authFailed = true;
           do {
-            String pwd =
-                readMaskedLine("Enter current password for '" + connector.whoami() + "': ", '*');
+            String pwd = readMaskedLine(
+                "Enter current password for '" + accumuloClient.whoami() + "': ", '*');
             if (pwd == null) {
               reader.println();
               return;
             } // user canceled
 
             try {
-              authFailed = !connector.securityOperations().authenticateUser(connector.whoami(),
-                  new PasswordToken(pwd));
+              authFailed = !accumuloClient.securityOperations()
+                  .authenticateUser(accumuloClient.whoami(), new PasswordToken(pwd));
             } catch (Exception e) {
               ++exitCode;
               printException(e);
             }
 
-            if (authFailed)
+            if (authFailed) {
               reader.print("Invalid password. ");
+            }
           } while (authFailed);
           lastUserActivity = System.nanoTime();
         }
@@ -863,8 +778,9 @@ public class Shell extends ShellOptions implements KeywordExecutable {
         printConstraintViolationException(e);
       } catch (TableNotFoundException e) {
         ++exitCode;
-        if (getTableName().equals(e.getTableName()))
+        if (getTableName().equals(e.getTableName())) {
           setTableName("");
+        }
         printException(e);
       } catch (ParseException e) {
         // not really an error if the exception is a missing required
@@ -898,7 +814,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     Set<String> tableNames = null;
     try {
-      tableNames = connector.tableOperations().list();
+      tableNames = accumuloClient.tableOperations().list();
     } catch (Exception e) {
       log.debug("Unable to obtain list of tables", e);
       tableNames = Collections.emptySet();
@@ -906,7 +822,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     Set<String> userlist = null;
     try {
-      userlist = connector.securityOperations().listLocalUsers();
+      userlist = accumuloClient.securityOperations().listLocalUsers();
     } catch (Exception e) {
       log.debug("Unable to obtain list of users", e);
       userlist = Collections.emptySet();
@@ -914,7 +830,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     Set<String> namespaces = null;
     try {
-      namespaces = connector.namespaceOperations().list();
+      namespaces = accumuloClient.namespaceOperations().list();
     } catch (Exception e) {
       log.debug("Unable to obtain list of namespaces", e);
       namespaces = Collections.emptySet();
@@ -923,17 +839,20 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     Map<Command.CompletionSet,Set<String>> options = new HashMap<>();
 
     Set<String> commands = new HashSet<>();
-    for (String a : commandFactory.keySet())
+    for (String a : commandFactory.keySet()) {
       commands.add(a);
+    }
 
     Set<String> modifiedUserlist = new HashSet<>();
     Set<String> modifiedTablenames = new HashSet<>();
     Set<String> modifiedNamespaces = new HashSet<>();
 
-    for (String a : tableNames)
+    for (String a : tableNames) {
       modifiedTablenames.add(a.replaceAll("([\\s'\"])", "\\\\$1"));
-    for (String a : userlist)
+    }
+    for (String a : userlist) {
       modifiedUserlist.add(a.replaceAll("([\\s'\"])", "\\\\$1"));
+    }
     for (String a : namespaces) {
       String b = a.replaceAll("([\\s'\"])", "\\\\$1");
       modifiedNamespaces.add(b.isEmpty() ? "\"\"" : b);
@@ -960,7 +879,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
    * execute along with some methods to help tab completion, and return the command name, help, and
    * usage.
    */
-  public static abstract class Command {
+  public abstract static class Command {
     // Helper methods for completion
     public enum CompletionSet {
       TABLENAMES, USERNAMES, COMMANDS, NAMESPACES
@@ -1011,7 +930,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
     // OPTIONAL methods to override:
 
-    // the general version of getname uses reflection to get the class name
+    // the general version of getName uses reflection to get the class name
     // and then cuts off the suffix -Command to get the name of the command
     public String getName() {
       String s = this.getClass().getName();
@@ -1085,6 +1004,8 @@ public class Shell extends ShellOptions implements KeywordExecutable {
   public static class PrintFile implements PrintLine {
     PrintWriter writer;
 
+    @SuppressFBWarnings(value = "PATH_TRAVERSAL_OUT",
+        justification = "app is run in same security context as user providing the filename")
     public PrintFile(String filename) throws FileNotFoundException {
       writer = new PrintWriter(
           new BufferedWriter(new OutputStreamWriter(new FileOutputStream(filename), UTF_8)));
@@ -1107,7 +1028,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   public final void printLines(Iterator<String> lines, boolean paginate, PrintLine out)
       throws IOException {
-    int linesPrinted = 0;
+    double linesPrinted = 0;
     String prompt = "-- hit any key to continue or 'q' to quit --";
     int lastPromptLength = prompt.length();
     int termWidth = reader.getTerminal().getWidth();
@@ -1116,8 +1037,9 @@ public class Shell extends ShellOptions implements KeywordExecutable {
     String peek = null;
     while (lines.hasNext()) {
       String nextLine = lines.next();
-      if (nextLine == null)
+      if (nextLine == null) {
         continue;
+      }
       for (String line : nextLine.split("\\n")) {
         if (out == null) {
           if (peek != null) {
@@ -1171,16 +1093,18 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   public static String repeat(String s, int c) {
     StringBuilder sb = new StringBuilder();
-    for (int i = 0; i < c; i++)
+    for (int i = 0; i < c; i++) {
       sb.append(s);
+    }
     return sb.toString();
   }
 
   public void checkTableState() {
-    if (getTableName().isEmpty())
+    if (getTableName().isEmpty()) {
       throw new IllegalStateException("Not in a table context. Please use"
           + " 'table <tableName>' to switch to a table, or use '-t' to specify a"
           + " table if option is available.");
+    }
   }
 
   private final void printConstraintViolationException(ConstraintViolationException cve) {
@@ -1194,9 +1118,10 @@ public class Shell extends ShellOptions implements KeywordExecutable {
         "Constraint class", "Violation code", "Violation Description"));
     logError(String.format("%" + COL1 + "s-+-%" + COL2 + "s-+-%" + col3 + "s%n", repeat("-", COL1),
         repeat("-", COL2), repeat("-", col3)));
-    for (TConstraintViolationSummary cvs : cve.violationSummaries)
+    for (TConstraintViolationSummary cvs : cve.violationSummaries) {
       logError(String.format("%-" + COL1 + "s | %" + COL2 + "d | %-" + col3 + "s%n",
           cvs.constrainClass, cvs.violationCode, cvs.violationDescription));
+    }
     logError(String.format("%" + COL1 + "s-+-%" + COL2 + "s-+-%" + col3 + "s%n", repeat("-", COL1),
         repeat("-", COL2), repeat("-", col3)));
   }
@@ -1207,18 +1132,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   private final void printException(Exception e, String msg) {
     logError(e.getClass().getName() + (msg != null ? ": " + msg : ""));
-    log.debug(e.getClass().getName() + (msg != null ? ": " + msg : ""), e);
-  }
-
-  public static final void setDebugging(boolean debuggingEnabled) {
-    Logger.getLogger(Constants.CORE_PACKAGE_NAME)
-        .setLevel(debuggingEnabled ? Level.TRACE : Level.INFO);
-    Logger.getLogger(Shell.class.getPackage().getName())
-        .setLevel(debuggingEnabled ? Level.TRACE : Level.INFO);
-  }
-
-  public static final boolean isDebuggingEnabled() {
-    return Logger.getLogger(Constants.CORE_PACKAGE_NAME).isTraceEnabled();
+    log.debug("{}{}", e.getClass().getName(), msg != null ? ": " + msg : "", e);
   }
 
   private final void printHelp(String usage, String description, Options opts) throws IOException {
@@ -1227,8 +1141,8 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   private final void printHelp(String usage, String description, Options opts, int width)
       throws IOException {
-    new HelpFormatter().printHelp(new PrintWriter(reader.getOutput()), width, usage, description,
-        opts, 2, 5, null, true);
+    PrintWriter pw = new PrintWriter(reader.getOutput()); // lgtm [java/output-resource-leak]
+    new HelpFormatter().printHelp(pw, width, usage, description, opts, 2, 5, null, true);
     reader.getOutput().flush();
   }
 
@@ -1266,16 +1180,16 @@ public class Shell extends ShellOptions implements KeywordExecutable {
 
   public void updateUser(String principal, AuthenticationToken token)
       throws AccumuloException, AccumuloSecurityException {
-    connector = instance.getConnector(principal, token);
-    this.token = token;
+    if (accumuloClient != null) {
+      accumuloClient.close();
+    }
+    accumuloClient = Accumulo.newClient().from(clientProperties).as(principal, token).build();
+    accumuloClient.securityOperations().authenticateUser(principal, token);
+    context = (ClientContext) accumuloClient;
   }
 
-  public String getPrincipal() {
-    return connector.whoami();
-  }
-
-  public AuthenticationToken getToken() {
-    return token;
+  public ClientContext getContext() {
+    return context;
   }
 
   /**
@@ -1297,7 +1211,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
   public Class<? extends Formatter> getFormatter(String tableName) {
     Class<? extends Formatter> formatter = FormatterCommand.getCurrentFormatter(tableName, this);
 
-    if (null == formatter) {
+    if (formatter == null) {
       logError("Could not load the specified formatter. Using the DefaultFormatter");
       return this.defaultFormatterClass;
     } else {
@@ -1310,7 +1224,7 @@ public class Shell extends ShellOptions implements KeywordExecutable {
   }
 
   private void logError(String s) {
-    log.error(s);
+    log.error("{}", s);
     if (logErrorsToConsole) {
       try {
         reader.println("ERROR: " + s);
