@@ -19,7 +19,6 @@ package org.apache.accumulo.shell.commands;
 import java.io.IOException;
 import java.util.EnumSet;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
 
@@ -46,7 +45,7 @@ import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
 import org.apache.commons.cli.OptionGroup;
 import org.apache.commons.cli.Options;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 
 import jline.console.ConsoleReader;
 
@@ -54,7 +53,7 @@ public class SetIterCommand extends Command {
 
   private Option allScopeOpt, mincScopeOpt, majcScopeOpt, scanScopeOpt;
   Option profileOpt, priorityOpt, nameOpt;
-  Option aggTypeOpt, ageoffTypeOpt, regexTypeOpt, versionTypeOpt, reqvisTypeOpt, classnameTypeOpt;
+  Option ageoffTypeOpt, regexTypeOpt, versionTypeOpt, reqvisTypeOpt, classnameTypeOpt;
 
   @Override
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
@@ -69,13 +68,7 @@ public class SetIterCommand extends Command {
 
     final Map<String,String> options = new HashMap<>();
     String classname = cl.getOptionValue(classnameTypeOpt.getOpt());
-    if (cl.hasOption(aggTypeOpt.getOpt())) {
-      Shell.log.warn("aggregators are deprecated");
-      @SuppressWarnings("deprecation")
-      String deprecatedClassName =
-          org.apache.accumulo.core.iterators.AggregatingIterator.class.getName();
-      classname = deprecatedClassName;
-    } else if (cl.hasOption(regexTypeOpt.getOpt())) {
+    if (cl.hasOption(regexTypeOpt.getOpt())) {
       classname = RegExFilter.class.getName();
     } else if (cl.hasOption(ageoffTypeOpt.getOpt())) {
       classname = AgeOffFilter.class.getName();
@@ -117,9 +110,9 @@ public class SetIterCommand extends Command {
     String name = cl.getOptionValue(nameOpt.getOpt(), null);
 
     // Cannot continue if no name is provided
-    if (null == name && null == configuredName) {
+    if (name == null && configuredName == null) {
       throw new IllegalArgumentException("No provided or default name for iterator");
-    } else if (null == name) {
+    } else if (name == null) {
       // Fall back to the name from OptionDescriber or user input if none is provided on setiter
       // option
       name = configuredName;
@@ -149,23 +142,8 @@ public class SetIterCommand extends Command {
 
     ScanCommand.ensureTserversCanLoadIterator(shellState, tableName, classname);
 
-    final String aggregatorClass = options.get("aggregatorClass");
-    @SuppressWarnings("deprecation")
-    String deprecatedAggregatorClassName =
-        org.apache.accumulo.core.iterators.aggregation.Aggregator.class.getName();
-    if (aggregatorClass != null && !shellState.getConnector().tableOperations()
-        .testClassLoad(tableName, aggregatorClass, deprecatedAggregatorClassName)) {
-      throw new ShellCommandException(ErrorCode.INITIALIZATION_FAILURE,
-          "Servers are unable to load " + aggregatorClass + " as type "
-              + deprecatedAggregatorClassName);
-    }
+    options.values().removeIf(v -> v == null || v.isEmpty());
 
-    for (Iterator<Entry<String,String>> i = options.entrySet().iterator(); i.hasNext();) {
-      final Entry<String,String> entry = i.next();
-      if (entry.getValue() == null || entry.getValue().isEmpty()) {
-        i.remove();
-      }
-    }
     final EnumSet<IteratorScope> scopes = EnumSet.noneOf(IteratorScope.class);
     if (cl.hasOption(allScopeOpt.getOpt()) || cl.hasOption(mincScopeOpt.getOpt())) {
       scopes.add(IteratorScope.minc);
@@ -180,7 +158,7 @@ public class SetIterCommand extends Command {
       throw new IllegalArgumentException("You must select at least one scope to configure");
     }
     final IteratorSetting setting = new IteratorSetting(priority, name, classname, options);
-    shellState.getConnector().tableOperations().attachIterator(tableName, setting, scopes);
+    shellState.getAccumuloClient().tableOperations().attachIterator(tableName, setting, scopes);
   }
 
   protected void setNamespaceProperties(final CommandLine cl, final Shell shellState,
@@ -191,30 +169,15 @@ public class SetIterCommand extends Command {
 
     final String namespace = OptUtil.getNamespaceOpt(cl, shellState);
 
-    if (!shellState.getConnector().namespaceOperations().testClassLoad(namespace, classname,
+    if (!shellState.getAccumuloClient().namespaceOperations().testClassLoad(namespace, classname,
         SortedKeyValueIterator.class.getName())) {
       throw new ShellCommandException(ErrorCode.INITIALIZATION_FAILURE,
           "Servers are unable to load " + classname + " as type "
               + SortedKeyValueIterator.class.getName());
     }
 
-    final String aggregatorClass = options.get("aggregatorClass");
-    @SuppressWarnings("deprecation")
-    String deprecatedAggregatorClassName =
-        org.apache.accumulo.core.iterators.aggregation.Aggregator.class.getName();
-    if (aggregatorClass != null && !shellState.getConnector().namespaceOperations()
-        .testClassLoad(namespace, aggregatorClass, deprecatedAggregatorClassName)) {
-      throw new ShellCommandException(ErrorCode.INITIALIZATION_FAILURE,
-          "Servers are unable to load " + aggregatorClass + " as type "
-              + deprecatedAggregatorClassName);
-    }
+    options.values().removeIf(v -> v == null || v.isEmpty());
 
-    for (Iterator<Entry<String,String>> i = options.entrySet().iterator(); i.hasNext();) {
-      final Entry<String,String> entry = i.next();
-      if (entry.getValue() == null || entry.getValue().isEmpty()) {
-        i.remove();
-      }
-    }
     final EnumSet<IteratorScope> scopes = EnumSet.noneOf(IteratorScope.class);
     if (cl.hasOption(allScopeOpt.getOpt()) || cl.hasOption(mincScopeOpt.getOpt())) {
       scopes.add(IteratorScope.minc);
@@ -229,7 +192,7 @@ public class SetIterCommand extends Command {
       throw new IllegalArgumentException("You must select at least one scope to configure");
     }
     final IteratorSetting setting = new IteratorSetting(priority, name, classname, options);
-    shellState.getConnector().namespaceOperations().attachIterator(namespace, setting, scopes);
+    shellState.getAccumuloClient().namespaceOperations().attachIterator(namespace, setting, scopes);
   }
 
   private static String setUpOptions(ClassLoader classloader, final ConsoleReader reader,
@@ -251,9 +214,7 @@ public class SetIterCommand extends Command {
         msg.append("; class not found.");
       }
       throw new ShellCommandException(ErrorCode.INITIALIZATION_FAILURE, msg.toString());
-    } catch (InstantiationException e) {
-      throw new IllegalArgumentException(e.getMessage());
-    } catch (IllegalAccessException e) {
+    } catch (InstantiationException | IllegalAccessException e) {
       throw new IllegalArgumentException(e.getMessage());
     } catch (ClassCastException e) {
       String msg = className + " loaded successfully but does not implement SortedKeyValueIterator."
@@ -269,7 +230,7 @@ public class SetIterCommand extends Command {
     }
 
     String iteratorName;
-    if (null != iterOptions) {
+    if (iterOptions != null) {
       final IteratorOptions itopts = iterOptions.describeOptions();
       iteratorName = itopts.getName();
 
@@ -345,7 +306,7 @@ public class SetIterCommand extends Command {
       reader.println("The iterator class does not implement OptionDescriber."
           + " Consider this for better iterator configuration using this setiter" + " command.");
       iteratorName = reader.readLine("Name for iterator (enter to skip): ");
-      if (null == iteratorName) {
+      if (iteratorName == null) {
         reader.println();
         throw new IOException("Input stream closed");
       } else if (StringUtils.isWhitespace(iteratorName)) {
@@ -439,7 +400,6 @@ public class SetIterCommand extends Command {
     classnameTypeOpt = new Option("class", "class-name", true,
         "a java class that implements SortedKeyValueIterator");
     classnameTypeOpt.setArgName("name");
-    aggTypeOpt = new Option("agg", "aggregator", false, "an aggregating type");
     regexTypeOpt = new Option("regex", "regular-expression", false, "a regex matching iterator");
     versionTypeOpt = new Option("vers", "version", false, "a versioning iterator");
     reqvisTypeOpt = new Option("reqvis", "require-visibility", false,
@@ -447,7 +407,6 @@ public class SetIterCommand extends Command {
     ageoffTypeOpt = new Option("ageoff", "ageoff", false, "an aging off iterator");
 
     typeGroup.addOption(classnameTypeOpt);
-    typeGroup.addOption(aggTypeOpt);
     typeGroup.addOption(regexTypeOpt);
     typeGroup.addOption(versionTypeOpt);
     typeGroup.addOption(reqvisTypeOpt);
