@@ -26,7 +26,7 @@ public class WhoAmICommand extends Command {
   @Override
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
       throws IOException {
-    shellState.getReader().println(shellState.getConnector().whoami());
+    shellState.getReader().println(shellState.getAccumuloClient().whoami());
     return 0;
   }
 
