@@ -32,17 +32,16 @@ import java.util.EnumSet;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.cluster.ClusterUser;
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.BatchWriterConfig;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.MutationsRejectedException;
 import org.apache.accumulo.core.client.NamespaceExistsException;
@@ -54,13 +53,13 @@ import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.NamespaceOperations;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
 import org.apache.accumulo.core.client.admin.TableOperations;
-import org.apache.accumulo.core.client.impl.Namespaces;
-import org.apache.accumulo.core.client.impl.Tables;
-import org.apache.accumulo.core.client.impl.thrift.TableOperation;
-import org.apache.accumulo.core.client.impl.thrift.TableOperationExceptionType;
-import org.apache.accumulo.core.client.impl.thrift.ThriftTableOperationException;
 import org.apache.accumulo.core.client.security.SecurityErrorCode;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
+import org.apache.accumulo.core.clientImpl.Namespace;
+import org.apache.accumulo.core.clientImpl.Tables;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
@@ -76,69 +75,80 @@ import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.NamespacePermission;
 import org.apache.accumulo.core.security.SystemPermission;
 import org.apache.accumulo.core.security.TablePermission;
-import org.apache.accumulo.examples.simple.constraints.NumericValueConstraint;
-import org.apache.accumulo.harness.AccumuloClusterHarness;
+import org.apache.accumulo.harness.SharedMiniClusterBase;
 import org.apache.accumulo.test.categories.MiniClusterOnlyTests;
+import org.apache.accumulo.test.constraints.NumericValueConstraint;
 import org.apache.hadoop.io.Text;
 import org.junit.After;
-import org.junit.Assume;
+import org.junit.AfterClass;
 import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
-// Testing default namespace configuration with inheritance requires altering
-// the system state and restoring it back to normal. Punt on this for now and
-// just let it use a minicluster.
+/**
+ * Test different namespace permissions
+ */
 @Category(MiniClusterOnlyTests.class)
-public class NamespacesIT extends AccumuloClusterHarness {
+public class NamespacesIT extends SharedMiniClusterBase {
 
-  private Connector c;
+  private AccumuloClient c;
   private String namespace;
 
+  @BeforeClass
+  public static void setup() throws Exception {
+    SharedMiniClusterBase.startMiniCluster();
+  }
+
+  @AfterClass
+  public static void teardown() {
+    SharedMiniClusterBase.stopMiniCluster();
+  }
+
   @Override
   public int defaultTimeoutSeconds() {
     return 60;
   }
 
   @Before
-  public void setupConnectorAndNamespace() throws Exception {
-    Assume.assumeTrue(ClusterType.MINI == getClusterType());
-
-    // prepare a unique namespace and get a new root connector for each test
-    c = getConnector();
+  public void setupConnectorAndNamespace() {
+    // prepare a unique namespace and get a new root client for each test
+    c = Accumulo.newClient().from(getClientProps()).build();
     namespace = "ns_" + getUniqueNames(1)[0];
   }
 
   @After
   public void swingMjölnir() throws Exception {
-    if (null == c) {
+    if (c == null) {
       return;
     }
     // clean up any added tables, namespaces, and users, after each test
     for (String t : c.tableOperations().list())
-      if (!Tables.qualify(t).getFirst().equals(Namespaces.ACCUMULO_NAMESPACE))
+      if (!Tables.qualify(t).getFirst().equals(Namespace.ACCUMULO.name()))
         c.tableOperations().delete(t);
     assertEquals(3, c.tableOperations().list().size());
     for (String n : c.namespaceOperations().list())
-      if (!n.equals(Namespaces.ACCUMULO_NAMESPACE) && !n.equals(Namespaces.DEFAULT_NAMESPACE))
+      if (!n.equals(Namespace.ACCUMULO.name()) && !n.equals(Namespace.DEFAULT.name()))
         c.namespaceOperations().delete(n);
     assertEquals(2, c.namespaceOperations().list().size());
     for (String u : c.securityOperations().listLocalUsers())
       if (!getAdminPrincipal().equals(u))
         c.securityOperations().dropLocalUser(u);
     assertEquals(1, c.securityOperations().listLocalUsers().size());
+
+    c.close();
   }
 
   @Test
-  public void checkReservedNamespaces() throws Exception {
-    assertEquals(c.namespaceOperations().defaultNamespace(), Namespaces.DEFAULT_NAMESPACE);
-    assertEquals(c.namespaceOperations().systemNamespace(), Namespaces.ACCUMULO_NAMESPACE);
+  public void checkReservedNamespaces() {
+    assertEquals(c.namespaceOperations().defaultNamespace(), Namespace.DEFAULT.name());
+    assertEquals(c.namespaceOperations().systemNamespace(), Namespace.ACCUMULO.name());
   }
 
   @Test
   public void checkBuiltInNamespaces() throws Exception {
-    assertTrue(c.namespaceOperations().exists(Namespaces.DEFAULT_NAMESPACE));
-    assertTrue(c.namespaceOperations().exists(Namespaces.ACCUMULO_NAMESPACE));
+    assertTrue(c.namespaceOperations().exists(Namespace.DEFAULT.name()));
+    assertTrue(c.namespaceOperations().exists(Namespace.ACCUMULO.name()));
   }
 
   @Test
@@ -150,19 +160,19 @@ public class NamespacesIT extends AccumuloClusterHarness {
 
   @Test(expected = AccumuloException.class)
   public void createTableInAccumuloNamespace() throws Exception {
-    String tableName = Namespaces.ACCUMULO_NAMESPACE + ".1";
+    String tableName = Namespace.ACCUMULO.name() + ".1";
     assertFalse(c.tableOperations().exists(tableName));
     c.tableOperations().create(tableName); // should fail
   }
 
   @Test(expected = AccumuloSecurityException.class)
   public void deleteDefaultNamespace() throws Exception {
-    c.namespaceOperations().delete(Namespaces.DEFAULT_NAMESPACE); // should fail
+    c.namespaceOperations().delete(Namespace.DEFAULT.name()); // should fail
   }
 
   @Test(expected = AccumuloSecurityException.class)
   public void deleteAccumuloNamespace() throws Exception {
-    c.namespaceOperations().delete(Namespaces.ACCUMULO_NAMESPACE); // should fail
+    c.namespaceOperations().delete(Namespace.ACCUMULO.name()); // should fail
   }
 
   @Test
@@ -255,14 +265,14 @@ public class NamespacesIT extends AccumuloClusterHarness {
     // verify no property
     assertFalse(checkNamespaceHasProp(namespace, k, v));
     assertFalse(checkTableHasProp(t1, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(t0, k, v));
 
     // set property and verify
     c.namespaceOperations().setProperty(namespace, k, v);
     assertTrue(checkNamespaceHasProp(namespace, k, v));
     assertTrue(checkTableHasProp(t1, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(t0, k, v));
 
     // add a new table to namespace and verify
@@ -272,7 +282,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
     assertTrue(checkNamespaceHasProp(namespace, k, v));
     assertTrue(checkTableHasProp(t1, k, v));
     assertTrue(checkTableHasProp(t2, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(t0, k, v));
 
     // remove property and verify
@@ -280,15 +290,15 @@ public class NamespacesIT extends AccumuloClusterHarness {
     assertFalse(checkNamespaceHasProp(namespace, k, v));
     assertFalse(checkTableHasProp(t1, k, v));
     assertFalse(checkTableHasProp(t2, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(t0, k, v));
 
     // set property on default namespace and verify
-    c.namespaceOperations().setProperty(Namespaces.DEFAULT_NAMESPACE, k, v);
+    c.namespaceOperations().setProperty(Namespace.DEFAULT.name(), k, v);
     assertFalse(checkNamespaceHasProp(namespace, k, v));
     assertFalse(checkTableHasProp(t1, k, v));
     assertFalse(checkTableHasProp(t2, k, v));
-    assertTrue(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertTrue(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertTrue(checkTableHasProp(t0, k, v));
 
     // test that table properties override namespace properties
@@ -316,49 +326,54 @@ public class NamespacesIT extends AccumuloClusterHarness {
     c.tableOperations().create(t1);
     String iterName = namespace + "_iter";
 
-    BatchWriter bw = c.createBatchWriter(t1, new BatchWriterConfig());
-    Mutation m = new Mutation("r");
-    m.put("a", "b", new Value("abcde".getBytes()));
-    bw.addMutation(m);
-    bw.flush();
-    bw.close();
+    try (BatchWriter bw = c.createBatchWriter(t1)) {
+      Mutation m = new Mutation("r");
+      m.put("a", "b", new Value("abcde".getBytes()));
+      bw.addMutation(m);
+      bw.flush();
+    }
 
     IteratorSetting setting = new IteratorSetting(250, iterName, SimpleFilter.class.getName());
 
     // verify can see inserted entry
-    Scanner s = c.createScanner(t1, Authorizations.EMPTY);
-    assertTrue(s.iterator().hasNext());
-    assertFalse(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
-    assertFalse(c.tableOperations().listIterators(t1).containsKey(iterName));
+    try (Scanner s = c.createScanner(t1)) {
+      assertTrue(s.iterator().hasNext());
+      assertFalse(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
+      assertFalse(c.tableOperations().listIterators(t1).containsKey(iterName));
 
-    // verify entry is filtered out (also, verify conflict checking API)
-    c.namespaceOperations().checkIteratorConflicts(namespace, setting,
-        EnumSet.allOf(IteratorScope.class));
-    c.namespaceOperations().attachIterator(namespace, setting);
-    sleepUninterruptibly(2, TimeUnit.SECONDS);
-    try {
+      // verify entry is filtered out (also, verify conflict checking API)
       c.namespaceOperations().checkIteratorConflicts(namespace, setting,
           EnumSet.allOf(IteratorScope.class));
-      fail();
-    } catch (AccumuloException e) {
-      assertEquals(IllegalArgumentException.class.getName(), e.getCause().getClass().getName());
+      c.namespaceOperations().attachIterator(namespace, setting);
+      sleepUninterruptibly(2, TimeUnit.SECONDS);
+      try {
+        c.namespaceOperations().checkIteratorConflicts(namespace, setting,
+            EnumSet.allOf(IteratorScope.class));
+        fail();
+      } catch (AccumuloException e) {
+        assertEquals(IllegalArgumentException.class.getName(), e.getCause().getClass().getName());
+      }
+      IteratorSetting setting2 = c.namespaceOperations().getIteratorSetting(namespace,
+          setting.getName(), IteratorScope.scan);
+      assertEquals(setting, setting2);
+      assertTrue(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
+      assertTrue(c.tableOperations().listIterators(t1).containsKey(iterName));
     }
-    IteratorSetting setting2 = c.namespaceOperations().getIteratorSetting(namespace,
-        setting.getName(), IteratorScope.scan);
-    assertEquals(setting, setting2);
-    assertTrue(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
-    assertTrue(c.tableOperations().listIterators(t1).containsKey(iterName));
-    s = c.createScanner(t1, Authorizations.EMPTY);
-    assertFalse(s.iterator().hasNext());
 
-    // verify can see inserted entry again
-    c.namespaceOperations().removeIterator(namespace, setting.getName(),
-        EnumSet.allOf(IteratorScope.class));
-    sleepUninterruptibly(2, TimeUnit.SECONDS);
-    assertFalse(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
-    assertFalse(c.tableOperations().listIterators(t1).containsKey(iterName));
-    s = c.createScanner(t1, Authorizations.EMPTY);
-    assertTrue(s.iterator().hasNext());
+    try (Scanner s = c.createScanner(t1, Authorizations.EMPTY)) {
+      assertFalse(s.iterator().hasNext());
+
+      // verify can see inserted entry again
+      c.namespaceOperations().removeIterator(namespace, setting.getName(),
+          EnumSet.allOf(IteratorScope.class));
+      sleepUninterruptibly(2, TimeUnit.SECONDS);
+      assertFalse(c.namespaceOperations().listIterators(namespace).containsKey(iterName));
+      assertFalse(c.tableOperations().listIterators(t1).containsKey(iterName));
+    }
+
+    try (Scanner s = c.createScanner(t1, Authorizations.EMPTY)) {
+      assertTrue(s.iterator().hasNext());
+    }
   }
 
   @Test
@@ -510,12 +525,12 @@ public class NamespacesIT extends AccumuloClusterHarness {
     Integer namespaceNum = null;
     for (int i = 0; i < 5; i++) {
       namespaceNum = c.namespaceOperations().listConstraints(namespace).get(constraintClassName);
-      if (null == namespaceNum) {
+      if (namespaceNum == null) {
         Thread.sleep(500);
         continue;
       }
       Integer tableNum = c.tableOperations().listConstraints(t1).get(constraintClassName);
-      if (null == tableNum) {
+      if (tableNum == null) {
         Thread.sleep(500);
         continue;
       }
@@ -533,7 +548,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
 
     passed = false;
     for (int i = 0; i < 5; i++) {
-      BatchWriter bw = c.createBatchWriter(t1, new BatchWriterConfig());
+      BatchWriter bw = c.createBatchWriter(t1);
       bw.addMutations(Arrays.asList(m1, m2, m3));
       try {
         bw.close();
@@ -566,7 +581,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
 
     passed = false;
     for (int i = 0; i < 5; i++) {
-      BatchWriter bw = c.createBatchWriter(t1, new BatchWriterConfig());
+      BatchWriter bw = c.createBatchWriter(t1);
       try {
         bw.addMutations(Arrays.asList(m1, m2, m3));
         bw.close();
@@ -656,7 +671,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
     String u1 = user1.getPrincipal();
     String u2 = user2.getPrincipal();
     PasswordToken pass =
-        (null != user1.getPassword() ? new PasswordToken(user1.getPassword()) : null);
+        (user1.getPassword() != null ? new PasswordToken(user1.getPassword()) : null);
 
     String n1 = namespace;
     String t1 = n1 + ".1";
@@ -672,193 +687,196 @@ public class NamespacesIT extends AccumuloClusterHarness {
     c.securityOperations().createLocalUser(u1, pass);
 
     loginAs(user1);
-    Connector user1Con = c.getInstance().getConnector(u1, user1.getToken());
+    try (AccumuloClient user1Con =
+        Accumulo.newClient().from(c.properties()).as(u1, user1.getToken()).build()) {
 
-    try {
-      user1Con.tableOperations().create(t2);
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
-
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.CREATE_TABLE);
-    loginAs(user1);
-    user1Con.tableOperations().create(t2);
-    loginAs(root);
-    assertTrue(c.tableOperations().list().contains(t2));
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.CREATE_TABLE);
-
-    loginAs(user1);
-    try {
-      user1Con.tableOperations().delete(t1);
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
-
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.DROP_TABLE);
-    loginAs(user1);
-    user1Con.tableOperations().delete(t1);
-    loginAs(root);
-    assertTrue(!c.tableOperations().list().contains(t1));
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.DROP_TABLE);
-
-    c.tableOperations().create(t3);
-    BatchWriter bw = c.createBatchWriter(t3, null);
-    Mutation m = new Mutation("row");
-    m.put("cf", "cq", "value");
-    bw.addMutation(m);
-    bw.close();
-
-    loginAs(user1);
-    Iterator<Entry<Key,Value>> i = user1Con.createScanner(t3, new Authorizations()).iterator();
-    try {
-      i.next();
-      fail();
-    } catch (RuntimeException e) {
-      assertEquals(AccumuloSecurityException.class.getName(), e.getCause().getClass().getName());
-      expectPermissionDenied((AccumuloSecurityException) e.getCause());
-    }
-
-    loginAs(user1);
-    m = new Mutation(u1);
-    m.put("cf", "cq", "turtles");
-    bw = user1Con.createBatchWriter(t3, null);
-    try {
-      bw.addMutation(m);
-      bw.close();
-      fail();
-    } catch (MutationsRejectedException e) {
-      assertEquals(1, e.getSecurityErrorCodes().size());
-      assertEquals(1, e.getSecurityErrorCodes().entrySet().iterator().next().getValue().size());
-      switch (e.getSecurityErrorCodes().entrySet().iterator().next().getValue().iterator().next()) {
-        case PERMISSION_DENIED:
-          break;
-        default:
-          fail();
+      try {
+        user1Con.tableOperations().create(t2);
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
       }
-    }
 
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.READ);
-    loginAs(user1);
-    i = user1Con.createScanner(t3, new Authorizations()).iterator();
-    assertTrue(i.hasNext());
-    loginAs(root);
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.READ);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.WRITE);
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.CREATE_TABLE);
+      loginAs(user1);
+      user1Con.tableOperations().create(t2);
+      loginAs(root);
+      assertTrue(c.tableOperations().list().contains(t2));
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.CREATE_TABLE);
 
-    loginAs(user1);
-    m = new Mutation(u1);
-    m.put("cf", "cq", "turtles");
-    bw = user1Con.createBatchWriter(t3, null);
-    bw.addMutation(m);
-    bw.close();
-    loginAs(root);
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.WRITE);
+      loginAs(user1);
+      try {
+        user1Con.tableOperations().delete(t1);
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    loginAs(user1);
-    try {
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.DROP_TABLE);
+      loginAs(user1);
+      user1Con.tableOperations().delete(t1);
+      loginAs(root);
+      assertTrue(!c.tableOperations().list().contains(t1));
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.DROP_TABLE);
+
+      c.tableOperations().create(t3);
+      try (BatchWriter bw = c.createBatchWriter(t3)) {
+        Mutation m = new Mutation("row");
+        m.put("cf", "cq", "value");
+        bw.addMutation(m);
+      }
+
+      loginAs(user1);
+      Iterator<Entry<Key,Value>> i = user1Con.createScanner(t3, new Authorizations()).iterator();
+      try {
+        i.next();
+        fail();
+      } catch (RuntimeException e) {
+        assertEquals(AccumuloSecurityException.class.getName(), e.getCause().getClass().getName());
+        expectPermissionDenied((AccumuloSecurityException) e.getCause());
+      }
+
+      loginAs(user1);
+      Mutation m = new Mutation(u1);
+      m.put("cf", "cq", "turtles");
+      BatchWriter bw = user1Con.createBatchWriter(t3);
+      try {
+        bw.addMutation(m);
+        bw.close();
+        fail();
+      } catch (MutationsRejectedException e) {
+        assertEquals(1, e.getSecurityErrorCodes().size());
+        assertEquals(1, e.getSecurityErrorCodes().entrySet().iterator().next().getValue().size());
+        switch (e.getSecurityErrorCodes().entrySet().iterator().next().getValue().iterator()
+            .next()) {
+          case PERMISSION_DENIED:
+            break;
+          default:
+            fail();
+        }
+      }
+
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.READ);
+      loginAs(user1);
+      i = user1Con.createScanner(t3, new Authorizations()).iterator();
+      assertTrue(i.hasNext());
+      loginAs(root);
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.READ);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.WRITE);
+
+      loginAs(user1);
+      try (BatchWriter bw2 = user1Con.createBatchWriter(t3)) {
+        m = new Mutation(u1);
+        m.put("cf", "cq", "turtles");
+        bw2.addMutation(m);
+      }
+      loginAs(root);
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.WRITE);
+
+      loginAs(user1);
+      try {
+        user1Con.tableOperations().setProperty(t3, Property.TABLE_FILE_MAX.getKey(), "42");
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
+
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.ALTER_TABLE);
+      loginAs(user1);
       user1Con.tableOperations().setProperty(t3, Property.TABLE_FILE_MAX.getKey(), "42");
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
+      user1Con.tableOperations().removeProperty(t3, Property.TABLE_FILE_MAX.getKey());
+      loginAs(root);
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.ALTER_TABLE);
 
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.ALTER_TABLE);
-    loginAs(user1);
-    user1Con.tableOperations().setProperty(t3, Property.TABLE_FILE_MAX.getKey(), "42");
-    user1Con.tableOperations().removeProperty(t3, Property.TABLE_FILE_MAX.getKey());
-    loginAs(root);
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.ALTER_TABLE);
+      loginAs(user1);
+      try {
+        user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "55");
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    loginAs(user1);
-    try {
-      user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "55");
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.ALTER_NAMESPACE);
+      loginAs(user1);
+      user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "42");
+      user1Con.namespaceOperations().removeProperty(n1, Property.TABLE_FILE_MAX.getKey());
+      loginAs(root);
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.ALTER_NAMESPACE);
 
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.ALTER_NAMESPACE);
-    loginAs(user1);
-    user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "42");
-    user1Con.namespaceOperations().removeProperty(n1, Property.TABLE_FILE_MAX.getKey());
-    loginAs(root);
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.ALTER_NAMESPACE);
+      loginAs(root);
+      c.securityOperations().createLocalUser(u2,
+          (root.getPassword() == null ? null : new PasswordToken(user2.getPassword())));
+      loginAs(user1);
+      try {
+        user1Con.securityOperations().grantNamespacePermission(u2, n1,
+            NamespacePermission.ALTER_NAMESPACE);
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    loginAs(root);
-    c.securityOperations().createLocalUser(u2,
-        (root.getPassword() == null ? null : new PasswordToken(user2.getPassword())));
-    loginAs(user1);
-    try {
+      loginAs(root);
+      c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.GRANT);
+      loginAs(user1);
       user1Con.securityOperations().grantNamespacePermission(u2, n1,
           NamespacePermission.ALTER_NAMESPACE);
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
+      user1Con.securityOperations().revokeNamespacePermission(u2, n1,
+          NamespacePermission.ALTER_NAMESPACE);
+      loginAs(root);
+      c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.GRANT);
 
-    loginAs(root);
-    c.securityOperations().grantNamespacePermission(u1, n1, NamespacePermission.GRANT);
-    loginAs(user1);
-    user1Con.securityOperations().grantNamespacePermission(u2, n1,
-        NamespacePermission.ALTER_NAMESPACE);
-    user1Con.securityOperations().revokeNamespacePermission(u2, n1,
-        NamespacePermission.ALTER_NAMESPACE);
-    loginAs(root);
-    c.securityOperations().revokeNamespacePermission(u1, n1, NamespacePermission.GRANT);
+      loginAs(user1);
+      try {
+        user1Con.namespaceOperations().create(n2);
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    loginAs(user1);
-    try {
+      loginAs(root);
+      c.securityOperations().grantSystemPermission(u1, SystemPermission.CREATE_NAMESPACE);
+      loginAs(user1);
       user1Con.namespaceOperations().create(n2);
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
+      loginAs(root);
+      c.securityOperations().revokeSystemPermission(u1, SystemPermission.CREATE_NAMESPACE);
 
-    loginAs(root);
-    c.securityOperations().grantSystemPermission(u1, SystemPermission.CREATE_NAMESPACE);
-    loginAs(user1);
-    user1Con.namespaceOperations().create(n2);
-    loginAs(root);
-    c.securityOperations().revokeSystemPermission(u1, SystemPermission.CREATE_NAMESPACE);
+      c.securityOperations().revokeNamespacePermission(u1, n2, NamespacePermission.DROP_NAMESPACE);
+      loginAs(user1);
+      try {
+        user1Con.namespaceOperations().delete(n2);
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    c.securityOperations().revokeNamespacePermission(u1, n2, NamespacePermission.DROP_NAMESPACE);
-    loginAs(user1);
-    try {
+      loginAs(root);
+      c.securityOperations().grantSystemPermission(u1, SystemPermission.DROP_NAMESPACE);
+      loginAs(user1);
       user1Con.namespaceOperations().delete(n2);
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
-    }
+      loginAs(root);
+      c.securityOperations().revokeSystemPermission(u1, SystemPermission.DROP_NAMESPACE);
 
-    loginAs(root);
-    c.securityOperations().grantSystemPermission(u1, SystemPermission.DROP_NAMESPACE);
-    loginAs(user1);
-    user1Con.namespaceOperations().delete(n2);
-    loginAs(root);
-    c.securityOperations().revokeSystemPermission(u1, SystemPermission.DROP_NAMESPACE);
+      loginAs(user1);
+      try {
+        user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "33");
+        fail();
+      } catch (AccumuloSecurityException e) {
+        expectPermissionDenied(e);
+      }
 
-    loginAs(user1);
-    try {
+      loginAs(root);
+      c.securityOperations().grantSystemPermission(u1, SystemPermission.ALTER_NAMESPACE);
+      loginAs(user1);
       user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "33");
-      fail();
-    } catch (AccumuloSecurityException e) {
-      expectPermissionDenied(e);
+      user1Con.namespaceOperations().removeProperty(n1, Property.TABLE_FILE_MAX.getKey());
+      loginAs(root);
+      c.securityOperations().revokeSystemPermission(u1, SystemPermission.ALTER_NAMESPACE);
     }
-
-    loginAs(root);
-    c.securityOperations().grantSystemPermission(u1, SystemPermission.ALTER_NAMESPACE);
-    loginAs(user1);
-    user1Con.namespaceOperations().setProperty(n1, Property.TABLE_FILE_MAX.getKey(), "33");
-    user1Con.namespaceOperations().removeProperty(n1, Property.TABLE_FILE_MAX.getKey());
-    loginAs(root);
-    c.securityOperations().revokeSystemPermission(u1, SystemPermission.ALTER_NAMESPACE);
   }
 
   @Test
@@ -886,10 +904,10 @@ public class NamespacesIT extends AccumuloClusterHarness {
       String k, String v, boolean systemNamespaceShouldInherit) throws Exception {
     // nobody should have any of these properties yet
     assertFalse(c.instanceOperations().getSystemConfiguration().containsValue(v));
-    assertFalse(checkNamespaceHasProp(Namespaces.ACCUMULO_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.ACCUMULO.name(), k, v));
     assertFalse(checkTableHasProp(RootTable.NAME, k, v));
     assertFalse(checkTableHasProp(MetadataTable.NAME, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(defaultNamespaceTable, k, v));
     assertFalse(checkNamespaceHasProp(namespace, k, v));
     assertFalse(checkTableHasProp(namespaceTable, k, v));
@@ -900,10 +918,10 @@ public class NamespacesIT extends AccumuloClusterHarness {
     sleepUninterruptibly(250, TimeUnit.MILLISECONDS);
     assertTrue(c.instanceOperations().getSystemConfiguration().containsValue(v));
     assertEquals(systemNamespaceShouldInherit,
-        checkNamespaceHasProp(Namespaces.ACCUMULO_NAMESPACE, k, v));
+        checkNamespaceHasProp(Namespace.ACCUMULO.name(), k, v));
     assertEquals(systemNamespaceShouldInherit, checkTableHasProp(RootTable.NAME, k, v));
     assertEquals(systemNamespaceShouldInherit, checkTableHasProp(MetadataTable.NAME, k, v));
-    assertTrue(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertTrue(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertTrue(checkTableHasProp(defaultNamespaceTable, k, v));
     assertTrue(checkNamespaceHasProp(namespace, k, v));
     assertTrue(checkTableHasProp(namespaceTable, k, v));
@@ -913,10 +931,10 @@ public class NamespacesIT extends AccumuloClusterHarness {
     // doesn't take effect immediately, needs time to propagate to tserver's ZooKeeper cache
     sleepUninterruptibly(250, TimeUnit.MILLISECONDS);
     assertFalse(c.instanceOperations().getSystemConfiguration().containsValue(v));
-    assertFalse(checkNamespaceHasProp(Namespaces.ACCUMULO_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.ACCUMULO.name(), k, v));
     assertFalse(checkTableHasProp(RootTable.NAME, k, v));
     assertFalse(checkTableHasProp(MetadataTable.NAME, k, v));
-    assertFalse(checkNamespaceHasProp(Namespaces.DEFAULT_NAMESPACE, k, v));
+    assertFalse(checkNamespaceHasProp(Namespace.DEFAULT.name(), k, v));
     assertFalse(checkTableHasProp(defaultNamespaceTable, k, v));
     assertFalse(checkNamespaceHasProp(namespace, k, v));
     assertFalse(checkTableHasProp(namespaceTable, k, v));
@@ -928,11 +946,11 @@ public class NamespacesIT extends AccumuloClusterHarness {
     Map<String,String> map = c.namespaceOperations().namespaceIdMap();
     assertEquals(2, namespaces.size());
     assertEquals(2, map.size());
-    assertTrue(namespaces.contains(Namespaces.ACCUMULO_NAMESPACE));
-    assertTrue(namespaces.contains(Namespaces.DEFAULT_NAMESPACE));
+    assertTrue(namespaces.contains(Namespace.ACCUMULO.name()));
+    assertTrue(namespaces.contains(Namespace.DEFAULT.name()));
     assertFalse(namespaces.contains(namespace));
-    assertEquals(Namespaces.ACCUMULO_NAMESPACE_ID, map.get(Namespaces.ACCUMULO_NAMESPACE));
-    assertEquals(Namespaces.DEFAULT_NAMESPACE_ID, map.get(Namespaces.DEFAULT_NAMESPACE));
+    assertEquals(Namespace.ACCUMULO.id().canonical(), map.get(Namespace.ACCUMULO.name()));
+    assertEquals(Namespace.DEFAULT.id().canonical(), map.get(Namespace.DEFAULT.name()));
     assertNull(map.get(namespace));
 
     c.namespaceOperations().create(namespace);
@@ -940,11 +958,11 @@ public class NamespacesIT extends AccumuloClusterHarness {
     map = c.namespaceOperations().namespaceIdMap();
     assertEquals(3, namespaces.size());
     assertEquals(3, map.size());
-    assertTrue(namespaces.contains(Namespaces.ACCUMULO_NAMESPACE));
-    assertTrue(namespaces.contains(Namespaces.DEFAULT_NAMESPACE));
+    assertTrue(namespaces.contains(Namespace.ACCUMULO.name()));
+    assertTrue(namespaces.contains(Namespace.DEFAULT.name()));
     assertTrue(namespaces.contains(namespace));
-    assertEquals(Namespaces.ACCUMULO_NAMESPACE_ID, map.get(Namespaces.ACCUMULO_NAMESPACE));
-    assertEquals(Namespaces.DEFAULT_NAMESPACE_ID, map.get(Namespaces.DEFAULT_NAMESPACE));
+    assertEquals(Namespace.ACCUMULO.id().canonical(), map.get(Namespace.ACCUMULO.name()));
+    assertEquals(Namespace.DEFAULT.id().canonical(), map.get(Namespace.DEFAULT.name()));
     assertNotNull(map.get(namespace));
 
     c.namespaceOperations().delete(namespace);
@@ -952,19 +970,19 @@ public class NamespacesIT extends AccumuloClusterHarness {
     map = c.namespaceOperations().namespaceIdMap();
     assertEquals(2, namespaces.size());
     assertEquals(2, map.size());
-    assertTrue(namespaces.contains(Namespaces.ACCUMULO_NAMESPACE));
-    assertTrue(namespaces.contains(Namespaces.DEFAULT_NAMESPACE));
+    assertTrue(namespaces.contains(Namespace.ACCUMULO.name()));
+    assertTrue(namespaces.contains(Namespace.DEFAULT.name()));
     assertFalse(namespaces.contains(namespace));
-    assertEquals(Namespaces.ACCUMULO_NAMESPACE_ID, map.get(Namespaces.ACCUMULO_NAMESPACE));
-    assertEquals(Namespaces.DEFAULT_NAMESPACE_ID, map.get(Namespaces.DEFAULT_NAMESPACE));
+    assertEquals(Namespace.ACCUMULO.id().canonical(), map.get(Namespace.ACCUMULO.name()));
+    assertEquals(Namespace.DEFAULT.id().canonical(), map.get(Namespace.DEFAULT.name()));
     assertNull(map.get(namespace));
   }
 
   @Test
   public void loadClass() throws Exception {
-    assertTrue(c.namespaceOperations().testClassLoad(Namespaces.DEFAULT_NAMESPACE,
+    assertTrue(c.namespaceOperations().testClassLoad(Namespace.DEFAULT.name(),
         VersioningIterator.class.getName(), SortedKeyValueIterator.class.getName()));
-    assertFalse(c.namespaceOperations().testClassLoad(Namespaces.DEFAULT_NAMESPACE, "dummy",
+    assertFalse(c.namespaceOperations().testClassLoad(Namespace.DEFAULT.name(), "dummy",
         SortedKeyValueIterator.class.getName()));
     try {
       c.namespaceOperations().testClassLoad(namespace, "dummy", "dummy");
@@ -1110,8 +1128,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
             break;
           case 1:
             ops.create("a");
-            ops.clone("a", tableName, true, Collections.<String,String>emptyMap(),
-                Collections.<String>emptySet());
+            ops.clone("a", tableName, true, Collections.emptyMap(), Collections.emptySet());
             fail();
             break;
           case 2:
@@ -1174,7 +1191,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
             fail();
             break;
           case 1:
-            ops.addSplits(tableName, new TreeSet<Text>());
+            ops.addSplits(tableName, new TreeSet<>());
             fail();
             break;
           case 2:
@@ -1194,8 +1211,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
             fail();
             break;
           case 6:
-            ops.clone(tableName, "2", true, Collections.<String,String>emptyMap(),
-                Collections.<String>emptySet());
+            ops.clone(tableName, "2", true, Collections.emptyMap(), Collections.emptySet());
             fail();
             break;
           case 7:
@@ -1243,7 +1259,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
             fail();
             break;
           case 18:
-            ops.importDirectory(tableName, "", "", false);
+            ops.importDirectory("").to(tableName).load();
             fail();
             break;
           case 19:
@@ -1284,7 +1300,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
             fail();
             break;
           case 28:
-            ops.setLocalityGroups(tableName, Collections.<String,Set<Text>>emptyMap());
+            ops.setLocalityGroups(tableName, Collections.emptyMap());
             fail();
             break;
           default:
@@ -1400,21 +1416,21 @@ public class NamespacesIT extends AccumuloClusterHarness {
             fail();
             break;
           case 2:
-            ops.create(Namespaces.DEFAULT_NAMESPACE);
+            ops.create(Namespace.DEFAULT.name());
             fail();
             break;
           case 3:
-            ops.create(Namespaces.ACCUMULO_NAMESPACE);
+            ops.create(Namespace.ACCUMULO.name());
             fail();
             break;
           case 4:
             ops.create(namespace + i + "_1");
-            ops.rename(namespace + i + "_1", Namespaces.DEFAULT_NAMESPACE); // should fail here
+            ops.rename(namespace + i + "_1", Namespace.DEFAULT.name()); // should fail here
             fail();
             break;
           case 5:
             ops.create(namespace + i + "_1");
-            ops.rename(namespace + i + "_1", Namespaces.ACCUMULO_NAMESPACE); // should fail here
+            ops.rename(namespace + i + "_1", Namespace.ACCUMULO.name()); // should fail here
             fail();
             break;
           default:
@@ -1456,9 +1472,7 @@ public class NamespacesIT extends AccumuloClusterHarness {
   public static class SimpleFilter extends Filter {
     @Override
     public boolean accept(Key k, Value v) {
-      if (k.getColumnFamily().toString().equals("a"))
-        return false;
-      return true;
+      return !k.getColumnFamily().toString().equals("a");
     }
   }
 
