@@ -37,17 +37,18 @@ import java.util.TreeMap;
 import java.util.TreeSet;
 import java.util.concurrent.TimeUnit;
 
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.BatchWriterConfig;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableExistsException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.DiskUsage;
 import org.apache.accumulo.core.client.admin.TableOperations;
+import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.constraints.DefaultKeySizeConstraint;
 import org.apache.accumulo.core.data.Key;
@@ -61,7 +62,6 @@ import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.accumulo.test.functional.BadIterator;
 import org.apache.accumulo.test.functional.FunctionalTestUtils;
 import org.apache.hadoop.io.Text;
-import org.apache.thrift.TException;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -71,8 +71,7 @@ import com.google.common.collect.Sets;
 public class TableOperationsIT extends AccumuloClusterHarness {
 
   static TabletClientService.Client client;
-
-  private Connector connector;
+  private AccumuloClient accumuloClient;
 
   @Override
   public int defaultTimeoutSeconds() {
@@ -80,67 +79,68 @@ public class TableOperationsIT extends AccumuloClusterHarness {
   }
 
   @Before
-  public void setup() throws Exception {
-    connector = getConnector();
+  public void setup() {
+    accumuloClient = Accumulo.newClient().from(getClientProps()).build();
   }
 
   @After
   public void checkForDanglingFateLocks() {
-    FunctionalTestUtils.assertNoDanglingFateLocks(getConnector().getInstance(), getCluster());
+    FunctionalTestUtils.assertNoDanglingFateLocks((ClientContext) accumuloClient, getCluster());
+    accumuloClient.close();
   }
 
   @Test
   public void getDiskUsageErrors() throws TableExistsException, AccumuloException,
-      AccumuloSecurityException, TableNotFoundException, TException {
+      AccumuloSecurityException, TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
     List<DiskUsage> diskUsage =
-        connector.tableOperations().getDiskUsage(Collections.singleton(tableName));
+        accumuloClient.tableOperations().getDiskUsage(Collections.singleton(tableName));
     assertEquals(1, diskUsage.size());
     assertEquals(0, (long) diskUsage.get(0).getUsage());
     assertEquals(tableName, diskUsage.get(0).getTables().iterator().next());
 
-    connector.securityOperations().revokeTablePermission(getAdminPrincipal(), tableName,
+    accumuloClient.securityOperations().revokeTablePermission(getAdminPrincipal(), tableName,
         TablePermission.READ);
     try {
-      connector.tableOperations().getDiskUsage(Collections.singleton(tableName));
+      accumuloClient.tableOperations().getDiskUsage(Collections.singleton(tableName));
       fail("Should throw securityexception");
     } catch (AccumuloSecurityException e) {}
 
-    connector.tableOperations().delete(tableName);
+    accumuloClient.tableOperations().delete(tableName);
     try {
-      connector.tableOperations().getDiskUsage(Collections.singleton(tableName));
+      accumuloClient.tableOperations().getDiskUsage(Collections.singleton(tableName));
       fail("Should throw tablenotfound");
     } catch (TableNotFoundException e) {}
   }
 
   @Test
   public void getDiskUsage() throws TableExistsException, AccumuloException,
-      AccumuloSecurityException, TableNotFoundException, TException {
+      AccumuloSecurityException, TableNotFoundException {
     final String[] names = getUniqueNames(2);
     String tableName = names[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
 
     // verify 0 disk usage
     List<DiskUsage> diskUsages =
-        connector.tableOperations().getDiskUsage(Collections.singleton(tableName));
+        accumuloClient.tableOperations().getDiskUsage(Collections.singleton(tableName));
     assertEquals(1, diskUsages.size());
     assertEquals(1, diskUsages.get(0).getTables().size());
     assertEquals(Long.valueOf(0), diskUsages.get(0).getUsage());
     assertEquals(tableName, diskUsages.get(0).getTables().first());
 
     // add some data
-    BatchWriter bw = connector.createBatchWriter(tableName, new BatchWriterConfig());
-    Mutation m = new Mutation("a");
-    m.put("b", "c", new Value("abcde".getBytes()));
-    bw.addMutation(m);
-    bw.flush();
-    bw.close();
+    try (BatchWriter bw = accumuloClient.createBatchWriter(tableName)) {
+      Mutation m = new Mutation("a");
+      m.put("b", "c", new Value("abcde".getBytes()));
+      bw.addMutation(m);
+      bw.flush();
+    }
 
-    connector.tableOperations().compact(tableName, new Text("A"), new Text("z"), true, true);
+    accumuloClient.tableOperations().compact(tableName, new Text("A"), new Text("z"), true, true);
 
     // verify we have usage
-    diskUsages = connector.tableOperations().getDiskUsage(Collections.singleton(tableName));
+    diskUsages = accumuloClient.tableOperations().getDiskUsage(Collections.singleton(tableName));
     assertEquals(1, diskUsages.size());
     assertEquals(1, diskUsages.get(0).getTables().size());
     assertTrue(diskUsages.get(0).getUsage() > 0);
@@ -149,49 +149,49 @@ public class TableOperationsIT extends AccumuloClusterHarness {
     String newTable = names[1];
 
     // clone table
-    connector.tableOperations().clone(tableName, newTable, false, null, null);
+    accumuloClient.tableOperations().clone(tableName, newTable, false, null, null);
 
     // verify tables are exactly the same
     Set<String> tables = new HashSet<>();
     tables.add(tableName);
     tables.add(newTable);
-    diskUsages = connector.tableOperations().getDiskUsage(tables);
+    diskUsages = accumuloClient.tableOperations().getDiskUsage(tables);
     assertEquals(1, diskUsages.size());
     assertEquals(2, diskUsages.get(0).getTables().size());
     assertTrue(diskUsages.get(0).getUsage() > 0);
 
-    connector.tableOperations().compact(tableName, new Text("A"), new Text("z"), true, true);
-    connector.tableOperations().compact(newTable, new Text("A"), new Text("z"), true, true);
+    accumuloClient.tableOperations().compact(tableName, new Text("A"), new Text("z"), true, true);
+    accumuloClient.tableOperations().compact(newTable, new Text("A"), new Text("z"), true, true);
 
     // verify tables have differences
-    diskUsages = connector.tableOperations().getDiskUsage(tables);
+    diskUsages = accumuloClient.tableOperations().getDiskUsage(tables);
     assertEquals(2, diskUsages.size());
     assertEquals(1, diskUsages.get(0).getTables().size());
     assertEquals(1, diskUsages.get(1).getTables().size());
     assertTrue(diskUsages.get(0).getUsage() > 0);
     assertTrue(diskUsages.get(1).getUsage() > 0);
 
-    connector.tableOperations().delete(tableName);
+    accumuloClient.tableOperations().delete(tableName);
   }
 
   @Test
   public void createTable() throws TableExistsException, AccumuloException,
       AccumuloSecurityException, TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
     Iterable<Map.Entry<String,String>> itrProps =
-        connector.tableOperations().getProperties(tableName);
+        accumuloClient.tableOperations().getProperties(tableName);
     Map<String,String> props = propsToMap(itrProps);
     assertEquals(DefaultKeySizeConstraint.class.getName(),
-        props.get(Property.TABLE_CONSTRAINT_PREFIX.toString() + "1"));
-    connector.tableOperations().delete(tableName);
+        props.get(Property.TABLE_CONSTRAINT_PREFIX + "1"));
+    accumuloClient.tableOperations().delete(tableName);
   }
 
   @Test
   public void createMergeClonedTable() throws Exception {
     String[] names = getUniqueNames(2);
     String originalTable = names[0];
-    TableOperations tops = connector.tableOperations();
+    TableOperations tops = accumuloClient.tableOperations();
 
     TreeSet<Text> splits =
         Sets.newTreeSet(Arrays.asList(new Text("a"), new Text("b"), new Text("c"), new Text("d")));
@@ -199,40 +199,39 @@ public class TableOperationsIT extends AccumuloClusterHarness {
     tops.create(originalTable);
     tops.addSplits(originalTable, splits);
 
-    BatchWriter bw = connector.createBatchWriter(originalTable, new BatchWriterConfig());
-    for (Text row : splits) {
-      Mutation m = new Mutation(row);
-      for (int i = 0; i < 10; i++) {
-        for (int j = 0; j < 10; j++) {
-          m.put(Integer.toString(i), Integer.toString(j), Integer.toString(i + j));
+    try (BatchWriter bw = accumuloClient.createBatchWriter(originalTable)) {
+      for (Text row : splits) {
+        Mutation m = new Mutation(row);
+        for (int i = 0; i < 10; i++) {
+          for (int j = 0; j < 10; j++) {
+            m.put(Integer.toString(i), Integer.toString(j), Integer.toString(i + j));
+          }
         }
+        bw.addMutation(m);
       }
-
-      bw.addMutation(m);
     }
 
-    bw.close();
-
     String clonedTable = names[1];
 
     tops.clone(originalTable, clonedTable, true, null, null);
     tops.merge(clonedTable, null, new Text("b"));
 
     Map<String,Integer> rowCounts = new HashMap<>();
-    Scanner s = connector.createScanner(clonedTable, new Authorizations());
-    for (Entry<Key,Value> entry : s) {
-      final Key key = entry.getKey();
-      String row = key.getRow().toString();
-      String cf = key.getColumnFamily().toString(), cq = key.getColumnQualifier().toString();
-      String value = entry.getValue().toString();
+    try (Scanner s = accumuloClient.createScanner(clonedTable, new Authorizations())) {
+      for (Entry<Key,Value> entry : s) {
+        final Key key = entry.getKey();
+        String row = key.getRow().toString();
+        String cf = key.getColumnFamily().toString(), cq = key.getColumnQualifier().toString();
+        String value = entry.getValue().toString();
 
-      if (rowCounts.containsKey(row)) {
-        rowCounts.put(row, rowCounts.get(row) + 1);
-      } else {
-        rowCounts.put(row, 1);
+        if (rowCounts.containsKey(row)) {
+          rowCounts.put(row, rowCounts.get(row) + 1);
+        } else {
+          rowCounts.put(row, 1);
+        }
+
+        assertEquals(Integer.parseInt(cf) + Integer.parseInt(cq), Integer.parseInt(value));
       }
-
-      assertEquals(Integer.parseInt(cf) + Integer.parseInt(cq), Integer.parseInt(value));
     }
 
     Collection<Text> clonedSplits = tops.listSplits(clonedTable);
@@ -241,7 +240,6 @@ public class TableOperationsIT extends AccumuloClusterHarness {
       assertTrue("Encountered unexpected split on the cloned table: " + clonedSplit,
           expectedSplits.remove(clonedSplit));
     }
-
     assertTrue("Did not find all expected splits on the cloned table: " + expectedSplits,
         expectedSplits.isEmpty());
   }
@@ -258,18 +256,19 @@ public class TableOperationsIT extends AccumuloClusterHarness {
   public void testCompactEmptyTableWithGeneratorIterator() throws TableExistsException,
       AccumuloException, AccumuloSecurityException, TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
 
     List<IteratorSetting> list = new ArrayList<>();
     list.add(new IteratorSetting(15, HardListIterator.class));
-    connector.tableOperations().compact(tableName, null, null, list, true, true);
+    accumuloClient.tableOperations().compact(tableName, null, null, list, true, true);
 
-    Scanner scanner = connector.createScanner(tableName, Authorizations.EMPTY);
-    Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
-    for (Map.Entry<Key,Value> entry : scanner)
-      actual.put(entry.getKey(), entry.getValue());
-    assertEquals(HardListIterator.allEntriesToInject, actual);
-    connector.tableOperations().delete(tableName);
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
+      for (Map.Entry<Key,Value> entry : scanner)
+        actual.put(entry.getKey(), entry.getValue());
+      assertEquals(HardListIterator.allEntriesToInject, actual);
+      accumuloClient.tableOperations().delete(tableName);
+    }
   }
 
   /** Compare only the row, column family and column qualifier. */
@@ -286,21 +285,22 @@ public class TableOperationsIT extends AccumuloClusterHarness {
   public void testCompactEmptyTableWithGeneratorIterator_Splits() throws TableExistsException,
       AccumuloException, AccumuloSecurityException, TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
     SortedSet<Text> splitset = new TreeSet<>();
     splitset.add(new Text("f"));
-    connector.tableOperations().addSplits(tableName, splitset);
+    accumuloClient.tableOperations().addSplits(tableName, splitset);
 
     List<IteratorSetting> list = new ArrayList<>();
     list.add(new IteratorSetting(15, HardListIterator.class));
-    connector.tableOperations().compact(tableName, null, null, list, true, true);
+    accumuloClient.tableOperations().compact(tableName, null, null, list, true, true);
 
-    Scanner scanner = connector.createScanner(tableName, Authorizations.EMPTY);
-    Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
-    for (Map.Entry<Key,Value> entry : scanner)
-      actual.put(entry.getKey(), entry.getValue());
-    assertEquals(HardListIterator.allEntriesToInject, actual);
-    connector.tableOperations().delete(tableName);
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
+      for (Map.Entry<Key,Value> entry : scanner)
+        actual.put(entry.getKey(), entry.getValue());
+      assertEquals(HardListIterator.allEntriesToInject, actual);
+      accumuloClient.tableOperations().delete(tableName);
+    }
   }
 
   @Test
@@ -308,42 +308,44 @@ public class TableOperationsIT extends AccumuloClusterHarness {
       throws TableExistsException, AccumuloException, AccumuloSecurityException,
       TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
     SortedSet<Text> splitset = new TreeSet<>();
     splitset.add(new Text("f"));
-    connector.tableOperations().addSplits(tableName, splitset);
+    accumuloClient.tableOperations().addSplits(tableName, splitset);
 
     List<IteratorSetting> list = new ArrayList<>();
     list.add(new IteratorSetting(15, HardListIterator.class));
-    connector.tableOperations().compact(tableName, null, null, list, true, false); // don't block
-    connector.tableOperations().cancelCompaction(tableName);
+    accumuloClient.tableOperations().compact(tableName, null, null, list, true, false); // don't
+                                                                                        // block
+    accumuloClient.tableOperations().cancelCompaction(tableName);
     // depending on timing, compaction will finish or be canceled
 
-    Scanner scanner = connector.createScanner(tableName, Authorizations.EMPTY);
-    Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
-    for (Map.Entry<Key,Value> entry : scanner)
-      actual.put(entry.getKey(), entry.getValue());
-    switch (actual.size()) {
-      case 3:
-        // Compaction cancel didn't happen in time
-        assertTrue(HardListIterator.allEntriesToInject.equals(actual));
-        break;
-      case 2:
-        // Compacted the first tablet (-inf, f)
-        assertEquals(HardListIterator.allEntriesToInject.headMap(new Key("f")), actual);
-        break;
-      case 1:
-        // Compacted the second tablet [f, +inf)
-        assertEquals(HardListIterator.allEntriesToInject.tailMap(new Key("f")), actual);
-        break;
-      case 0:
-        // Cancelled the compaction before it ran. No generated entries.
-        break;
-      default:
-        fail("Unexpected number of entries");
-        break;
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
+      for (Map.Entry<Key,Value> entry : scanner)
+        actual.put(entry.getKey(), entry.getValue());
+      switch (actual.size()) {
+        case 3:
+          // Compaction cancel didn't happen in time
+          assertEquals(HardListIterator.allEntriesToInject, actual);
+          break;
+        case 2:
+          // Compacted the first tablet (-inf, f)
+          assertEquals(HardListIterator.allEntriesToInject.headMap(new Key("f")), actual);
+          break;
+        case 1:
+          // Compacted the second tablet [f, +inf)
+          assertEquals(HardListIterator.allEntriesToInject.tailMap(new Key("f")), actual);
+          break;
+        case 0:
+          // Cancelled the compaction before it ran. No generated entries.
+          break;
+        default:
+          fail("Unexpected number of entries");
+          break;
+      }
+      accumuloClient.tableOperations().delete(tableName);
     }
-    connector.tableOperations().delete(tableName);
   }
 
   @Test
@@ -351,24 +353,25 @@ public class TableOperationsIT extends AccumuloClusterHarness {
       throws TableExistsException, AccumuloException, AccumuloSecurityException,
       TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
     Text splitRow = new Text("f");
     SortedSet<Text> splitset = new TreeSet<>();
     splitset.add(splitRow);
-    connector.tableOperations().addSplits(tableName, splitset);
+    accumuloClient.tableOperations().addSplits(tableName, splitset);
 
     List<IteratorSetting> list = new ArrayList<>();
     list.add(new IteratorSetting(15, HardListIterator.class));
     // compact the second tablet, not the first
-    connector.tableOperations().compact(tableName, splitRow, null, list, true, true);
+    accumuloClient.tableOperations().compact(tableName, splitRow, null, list, true, true);
 
-    Scanner scanner = connector.createScanner(tableName, Authorizations.EMPTY);
-    Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
-    for (Map.Entry<Key,Value> entry : scanner)
-      actual.put(entry.getKey(), entry.getValue());
-    // only expect the entries in the second tablet
-    assertEquals(HardListIterator.allEntriesToInject.tailMap(new Key(splitRow)), actual);
-    connector.tableOperations().delete(tableName);
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      Map<Key,Value> actual = new TreeMap<>(COMPARE_KEY_TO_COLQ); // only compare row, colF, colQ
+      for (Map.Entry<Key,Value> entry : scanner)
+        actual.put(entry.getKey(), entry.getValue());
+      // only expect the entries in the second tablet
+      assertEquals(HardListIterator.allEntriesToInject.tailMap(new Key(splitRow)), actual);
+      accumuloClient.tableOperations().delete(tableName);
+    }
   }
 
   /** Test recovery from bad majc iterator via compaction cancel. */
@@ -376,20 +379,22 @@ public class TableOperationsIT extends AccumuloClusterHarness {
   public void testCompactEmptyTablesWithBadIterator_FailsAndCancel() throws TableExistsException,
       AccumuloException, AccumuloSecurityException, TableNotFoundException {
     String tableName = getUniqueNames(1)[0];
-    connector.tableOperations().create(tableName);
+    accumuloClient.tableOperations().create(tableName);
 
     List<IteratorSetting> list = new ArrayList<>();
     list.add(new IteratorSetting(15, BadIterator.class));
-    connector.tableOperations().compact(tableName, null, null, list, true, false); // don't block
+    accumuloClient.tableOperations().compact(tableName, null, null, list, true, false); // don't
+                                                                                        // block
     sleepUninterruptibly(2, TimeUnit.SECONDS); // start compaction
-    connector.tableOperations().cancelCompaction(tableName);
+    accumuloClient.tableOperations().cancelCompaction(tableName);
 
-    Scanner scanner = connector.createScanner(tableName, Authorizations.EMPTY);
-    Map<Key,Value> actual = new TreeMap<>();
-    for (Map.Entry<Key,Value> entry : scanner)
-      actual.put(entry.getKey(), entry.getValue());
-    assertTrue("Should be empty. Actual is " + actual, actual.isEmpty());
-    connector.tableOperations().delete(tableName);
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      Map<Key,Value> actual = new TreeMap<>();
+      for (Map.Entry<Key,Value> entry : scanner)
+        actual.put(entry.getKey(), entry.getValue());
+      assertTrue("Should be empty. Actual is " + actual, actual.isEmpty());
+      accumuloClient.tableOperations().delete(tableName);
+    }
   }
 
 }
