@@ -16,8 +16,9 @@
  */
 package org.apache.accumulo.test;
 
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.junit.Test;
@@ -26,9 +27,10 @@ public class ZooKeeperPropertiesIT extends AccumuloClusterHarness {
 
   @Test(expected = AccumuloException.class)
   public void testNoFiles() throws Exception {
-    Connector conn = getConnector();
-    // Should throw an error as this property can't be changed in ZooKeeper
-    conn.instanceOperations().setProperty(Property.GENERAL_RPC_TIMEOUT.getKey(), "60s");
+    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
+      // Should throw an error as this property can't be changed in ZooKeeper
+      client.instanceOperations().setProperty(Property.GENERAL_RPC_TIMEOUT.getKey(), "60s");
+    }
   }
 
 }
