@@ -16,6 +16,7 @@
  */
 package org.apache.accumulo.test.functional;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
@@ -23,29 +24,43 @@ import static org.junit.Assert.fail;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 import java.util.concurrent.Callable;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.Connector;
-import org.apache.accumulo.core.client.Instance;
+import org.apache.accumulo.core.client.BatchWriter;
+import org.apache.accumulo.core.client.IteratorSetting;
+import org.apache.accumulo.core.client.Scanner;
+import org.apache.accumulo.core.client.TableExistsException;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.impl.Tables;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.ClientInfo;
+import org.apache.accumulo.core.clientImpl.Tables;
 import org.apache.accumulo.core.conf.Property;
+import org.apache.accumulo.core.data.Key;
+import org.apache.accumulo.core.data.Mutation;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.master.state.tables.TableState;
-import org.apache.accumulo.core.zookeeper.ZooUtil;
+import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.fate.AdminUtil;
 import org.apache.accumulo.fate.ZooStore;
 import org.apache.accumulo.fate.zookeeper.IZooReaderWriter;
+import org.apache.accumulo.fate.zookeeper.ZooUtil;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.accumulo.server.zookeeper.ZooReaderWriterFactory;
-import org.apache.accumulo.test.util.SlowOps;
+import org.apache.hadoop.io.Text;
 import org.apache.zookeeper.KeeperException;
+import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Before;
 import org.junit.Test;
@@ -70,7 +85,8 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
   private static final int NUM_ROWS = 1000;
   private static final long SLOW_SCAN_SLEEP_MS = 250L;
 
-  private Connector connector;
+  private AccumuloClient accumuloClient;
+  private ClientContext context;
 
   private static final ExecutorService pool = Executors.newCachedThreadPool();
 
@@ -78,22 +94,26 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
   private String secret;
 
-  private long maxWait;
-
-  private SlowOps slowOps;
+  // Test development only. When true, multiple tables, multiple compactions will be
+  // used during the test run which simulates transient condition that was causing
+  // the test to fail..
+  private boolean runMultipleCompactions = false;
 
   @Before
   public void setup() {
-
-    connector = getConnector();
+    accumuloClient = Accumulo.newClient().from(getClientProps()).build();
+    context = (ClientContext) accumuloClient;
 
     tableName = getUniqueNames(1)[0];
 
     secret = cluster.getSiteConfiguration().get(Property.INSTANCE_SECRET);
 
-    maxWait = defaultTimeoutSeconds() <= 0 ? 60_000 : ((defaultTimeoutSeconds() * 1000) / 2);
+    createData(tableName);
+  }
 
-    slowOps = new SlowOps(connector, tableName, maxWait, 1);
+  @After
+  public void closeClient() {
+    accumuloClient.close();
   }
 
   @AfterClass
@@ -134,7 +154,7 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
     // verify that offline then online functions as expected.
 
-    connector.tableOperations().offline(tableName, true);
+    accumuloClient.tableOperations().offline(tableName, true);
     assertEquals("verify table is offline", TableState.OFFLINE, getTableState(tableName));
 
     onlineOp = new OnLineCallable(tableName);
@@ -150,7 +170,8 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
     // launch a full table compaction with the slow iterator to ensure table lock is acquired and
     // held by the compaction
-    slowOps.startCompactTask();
+
+    Future<?> compactTask = startCompactTask();
 
     // try to set online while fate transaction is in progress - before ACCUMULO-4574 this would
     // block
@@ -166,10 +187,11 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
     assertEquals("verify table is still online", TableState.ONLINE, getTableState(tableName));
 
-    assertTrue("Find FATE operation for table", findFate(tableName));
+    assertTrue("verify compaction still running and fate transaction still exists",
+        blockUntilCompactionRunning(tableName));
 
     // test complete, cancel compaction and move on.
-    connector.tableOperations().cancelCompaction(tableName);
+    accumuloClient.tableOperations().cancelCompaction(tableName);
 
     log.debug("Success: Timing results for online commands.");
     log.debug("Time for unblocked online {} ms",
@@ -180,33 +202,10 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
         TimeUnit.MILLISECONDS.convert(timing3.runningTime(), TimeUnit.NANOSECONDS));
 
     // block if compaction still running
-    slowOps.blockWhileCompactionRunning();
+    compactTask.get();
 
   }
 
-  private boolean findFate(String aTableName) {
-
-    for (int retry = 0; retry < 5; retry++) {
-
-      try {
-        boolean found = lookupFateInZookeeper(aTableName);
-        log.trace("Try {}: Fate in zk for table {} : {}", retry, aTableName, found);
-        if (found) {
-          log.trace("found for {}", aTableName);
-          return true;
-        } else {
-          Thread.sleep(150);
-        }
-      } catch (InterruptedException ex) {
-        Thread.currentThread().interrupt();
-        return false;
-      } catch (Exception ex) {
-        log.debug("Find fate failed for table name {} with exception, will retry", aTableName, ex);
-      }
-    }
-    return false;
-  }
-
   /**
    * Validate the the AdminUtil.getStatus works correctly after refactor and validate that
    * getTransactionStatus can be called without lock map(s). The test starts a long running fate
@@ -215,15 +214,20 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
   @Test
   public void getFateStatus() {
 
-    Instance instance = connector.getInstance();
-    String tableId;
+    TableId tableId;
+
+    // for development testing - force transient condition that was failing this test so that
+    // we know if multiple compactions are running, they are properly handled by the test code.
+    if (runMultipleCompactions) {
+      runMultipleCompactions();
+    }
 
     try {
 
       assertEquals("verify table online after created", TableState.ONLINE,
           getTableState(tableName));
 
-      tableId = Tables.getTableId(instance, tableName);
+      tableId = Tables.getTableId(context, tableName);
 
       log.trace("tid: {}", tableId);
 
@@ -232,7 +236,7 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
           String.format("Table %s does not exist, failing test", tableName));
     }
 
-    slowOps.startCompactTask();
+    Future<?> compactTask = startCompactTask();
 
     AdminUtil.FateStatus withLocks = null;
     List<AdminUtil.TransactionStatus> noLocks = null;
@@ -245,13 +249,14 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
       try {
 
-        IZooReaderWriter zk = new ZooReaderWriterFactory().getZooReaderWriter(
-            instance.getZooKeepers(), instance.getZooKeepersSessionTimeOut(), secret);
-
-        ZooStore<String> zs = new ZooStore<>(ZooUtil.getRoot(instance) + Constants.ZFATE, zk);
+        String instanceId = accumuloClient.instanceOperations().getInstanceID();
+        ClientInfo info = ClientInfo.from(accumuloClient.properties());
+        IZooReaderWriter zk = new ZooReaderWriterFactory().getZooReaderWriter(info.getZooKeepers(),
+            info.getZooKeepersSessionTimeOut(), secret);
+        ZooStore<String> zs = new ZooStore<>(ZooUtil.getRoot(instanceId) + Constants.ZFATE, zk);
 
         withLocks = admin.getStatus(zs, zk,
-            ZooUtil.getRoot(instance) + Constants.ZTABLE_LOCKS + "/" + tableId, null, null);
+            ZooUtil.getRoot(instanceId) + Constants.ZTABLE_LOCKS + "/" + tableId, null, null);
 
         // call method that does not use locks.
         noLocks = admin.getTransactionStatus(zs, null, null);
@@ -301,22 +306,118 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
     try {
 
       // test complete, cancel compaction and move on.
-      connector.tableOperations().cancelCompaction(tableName);
+      accumuloClient.tableOperations().cancelCompaction(tableName);
 
       // block if compaction still running
-      boolean cancelled = slowOps.blockWhileCompactionRunning();
-      log.debug("Cancel completed successfully: {}", cancelled);
+      compactTask.get();
 
-    } catch (TableNotFoundException | AccumuloSecurityException | AccumuloException ex) {
-      log.debug("Could not cancel compaction due to exception", ex);
+    } catch (InterruptedException ex) {
+      Thread.currentThread().interrupt();
+    } catch (TableNotFoundException | AccumuloSecurityException | AccumuloException
+        | ExecutionException ex) {
+      log.debug("Could not cancel compaction", ex);
     }
   }
 
+  /**
+   * This method was helpful for debugging a condition that was causing transient test failures.
+   * This forces a condition that the test should be able to handle. This method is not needed
+   * during normal testing, it was kept to aid future test development / troubleshooting if other
+   * transient failures occur.
+   */
+  private void runMultipleCompactions() {
+
+    for (int i = 0; i < 4; i++) {
+
+      String aTableName = getUniqueNames(1)[0] + "_" + i;
+
+      createData(aTableName);
+
+      log.debug("Table: {}", aTableName);
+
+      pool.submit(new SlowCompactionRunner(aTableName));
+
+      assertTrue("verify that compaction running and fate transaction exists",
+          blockUntilCompactionRunning(aTableName));
+
+    }
+  }
+
+  /**
+   * Create and run a slow running compaction task. The method will block until the compaction has
+   * been started.
+   *
+   * @return a reference to the running compaction task.
+   */
+  private Future<?> startCompactTask() {
+    Future<?> compactTask = pool.submit(new SlowCompactionRunner(tableName));
+    assertTrue("verify that compaction running and fate transaction exists",
+        blockUntilCompactionRunning(tableName));
+    return compactTask;
+  }
+
+  /**
+   * Blocks current thread until compaction is running.
+   *
+   * @return true if compaction and associate fate found.
+   */
+  private boolean blockUntilCompactionRunning(final String tableName) {
+
+    long maxWait = defaultTimeoutSeconds() <= 0 ? 60_000 : ((defaultTimeoutSeconds() * 1000) / 2);
+
+    long startWait = System.currentTimeMillis();
+
+    List<String> tservers = accumuloClient.instanceOperations().getTabletServers();
+
+    /*
+     * wait for compaction to start on table - The compaction will acquire a fate transaction lock
+     * that used to block a subsequent online command while the fate transaction lock was held.
+     */
+    while (System.currentTimeMillis() < (startWait + maxWait)) {
+
+      try {
+
+        int runningCompactions = 0;
+
+        for (String tserver : tservers) {
+          runningCompactions +=
+              accumuloClient.instanceOperations().getActiveCompactions(tserver).size();
+          log.trace("tserver {}, running compactions {}", tservers, runningCompactions);
+        }
+
+        if (runningCompactions > 0) {
+          // Validate that there is a compaction fate transaction - otherwise test is invalid.
+          if (findFate(tableName)) {
+            return true;
+          }
+        }
+
+      } catch (AccumuloSecurityException | AccumuloException ex) {
+        throw new IllegalStateException("failed to get active compactions, test fails.", ex);
+      } catch (KeeperException ex) {
+        log.trace("Saw possible transient zookeeper error");
+      }
+
+      try {
+        Thread.sleep(250);
+      } catch (InterruptedException ex) {
+        // reassert interrupt
+        Thread.currentThread().interrupt();
+      }
+    }
+
+    log.debug("Could not find compaction for {} after {} seconds", tableName,
+        TimeUnit.MILLISECONDS.toSeconds(maxWait));
+
+    return false;
+
+  }
+
   /**
    * Checks fates in zookeeper looking for transaction associated with a compaction as a double
    * check that the test will be valid because the running compaction does have a fate transaction
    * lock.
-   * <p>
+   *
    * This method throws can throw either IllegalStateException (failed) or a Zookeeper exception.
    * Throwing the Zookeeper exception allows for retries if desired to handle transient zookeeper
    * issues.
@@ -327,27 +428,30 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
    * @throws KeeperException
    *           if a zookeeper error occurred - allows for retries.
    */
-  private boolean lookupFateInZookeeper(final String tableName) throws KeeperException {
+  private boolean findFate(final String tableName) throws KeeperException {
 
-    Instance instance = connector.getInstance();
     AdminUtil<String> admin = new AdminUtil<>(false);
 
     try {
 
-      String tableId = Tables.getTableId(instance, tableName);
+      TableId tableId = Tables.getTableId(context, tableName);
 
       log.trace("tid: {}", tableId);
 
-      IZooReaderWriter zk = new ZooReaderWriterFactory().getZooReaderWriter(
-          instance.getZooKeepers(), instance.getZooKeepersSessionTimeOut(), secret);
-      ZooStore<String> zs = new ZooStore<>(ZooUtil.getRoot(instance) + Constants.ZFATE, zk);
+      ClientInfo info = ClientInfo.from(accumuloClient.properties());
+      IZooReaderWriter zk = new ZooReaderWriterFactory().getZooReaderWriter(info.getZooKeepers(),
+          info.getZooKeepersSessionTimeOut(), secret);
+      ZooStore<String> zs = new ZooStore<>(
+          ZooUtil.getRoot(accumuloClient.instanceOperations().getInstanceID()) + Constants.ZFATE,
+          zk);
       AdminUtil.FateStatus fateStatus = admin.getStatus(zs, zk,
-          ZooUtil.getRoot(instance) + Constants.ZTABLE_LOCKS + "/" + tableId, null, null);
+          ZooUtil.getRoot(accumuloClient.instanceOperations().getInstanceID())
+              + Constants.ZTABLE_LOCKS + "/" + tableId,
+          null, null);
 
       log.trace("current fates: {}", fateStatus.getTransactions().size());
 
       for (AdminUtil.TransactionStatus tx : fateStatus.getTransactions()) {
-
         if (isCompaction(tx))
           return true;
       }
@@ -396,15 +500,69 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
    */
   private TableState getTableState(String tableName) throws TableNotFoundException {
 
-    String tableId = Tables.getTableId(connector.getInstance(), tableName);
+    TableId tableId = Tables.getTableId(context, tableName);
 
-    TableState tstate = Tables.getTableState(connector.getInstance(), tableId);
+    TableState tstate = Tables.getTableState(context, tableId);
 
     log.trace("tableName: '{}': tableId {}, current state: {}", tableName, tableId, tstate);
 
     return tstate;
   }
 
+  /**
+   * Create the provided table and populate with some data using a batch writer. The table is
+   * scanned to ensure it was populated as expected.
+   *
+   * @param tableName
+   *          the name of the table
+   */
+  private void createData(final String tableName) {
+
+    try {
+
+      // create table.
+      accumuloClient.tableOperations().create(tableName);
+      try (BatchWriter bw = accumuloClient.createBatchWriter(tableName)) {
+        // populate
+        for (int i = 0; i < NUM_ROWS; i++) {
+          Mutation m = new Mutation(new Text(String.format("%05d", i)));
+          m.put(new Text("col" + ((i % 3) + 1)), new Text("qual"),
+              new Value("junk".getBytes(UTF_8)));
+          bw.addMutation(m);
+        }
+      }
+
+      long startTimestamp = System.nanoTime();
+
+      int count = scanCount(tableName);
+
+      log.trace("Scan time for {} rows {} ms", NUM_ROWS, TimeUnit.MILLISECONDS
+          .convert((System.nanoTime() - startTimestamp), TimeUnit.NANOSECONDS));
+
+      if (count != NUM_ROWS) {
+        throw new IllegalStateException(
+            String.format("Number of rows %1$d does not match expected %2$d", count, NUM_ROWS));
+      }
+    } catch (AccumuloException | AccumuloSecurityException | TableNotFoundException
+        | TableExistsException ex) {
+      throw new IllegalStateException("Create data failed with exception", ex);
+    }
+  }
+
+  private int scanCount(String tableName) throws TableNotFoundException {
+
+    int count = 0;
+    try (Scanner scanner = accumuloClient.createScanner(tableName, Authorizations.EMPTY)) {
+      for (Map.Entry<Key,Value> elt : scanner) {
+        String expected = String.format("%05d", count);
+        assert (elt.getKey().getRow().toString().equals(expected));
+        count++;
+      }
+    }
+
+    return count;
+  }
+
   /**
    * Provides timing information for online operation.
    */
@@ -456,7 +614,7 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
 
       log.trace("Setting {} online", tableName);
 
-      connector.tableOperations().online(tableName, true);
+      accumuloClient.tableOperations().online(tableName, true);
       // stop timing
       status.setComplete();
 
@@ -468,48 +626,73 @@ public class FateConcurrencyIT extends AccumuloClusterHarness {
   }
 
   /**
-   * Concurrency testing - ensure that tests are valid id multiple compactions are running. for
-   * development testing - force transient condition that was failing this test so that we know if
-   * multiple compactions are running, they are properly handled by the test code and the tests are
-   * valid.
+   * Instance to create / run a compaction using a slow iterator.
    */
-  @Test
-  public void multipleCompactions() {
+  private class SlowCompactionRunner implements Runnable {
 
-    int tableCount = 4;
+    private final String tableName;
 
-    List<SlowOps> tables = new ArrayList<>();
-
-    for (int i = 0; i < tableCount; i++) {
-      String uniqueName = getUniqueNames(1)[0] + "_" + i;
-      SlowOps gen = new SlowOps(connector, uniqueName, maxWait, tableCount);
-      tables.add(gen);
-      gen.startCompactTask();
+    /**
+     * Create an instance of this class.
+     *
+     * @param tableName
+     *          the name of the table that will be compacted with the slow iterator.
+     */
+    SlowCompactionRunner(final String tableName) {
+      this.tableName = tableName;
     }
 
-    int foundCount = 0;
+    @Override
+    public void run() {
 
-    for (SlowOps t : tables) {
-      log.debug("Look for fate {}", t.getTableName());
-      if (findFate(t.getTableName())) {
-        log.debug("Found fate {}", t.getTableName());
-        foundCount++;
-      }
-    }
+      long startTimestamp = System.nanoTime();
 
-    assertEquals(tableCount, foundCount);
+      IteratorSetting slow = new IteratorSetting(30, "slow", SlowIterator.class);
+      SlowIterator.setSleepTime(slow, SLOW_SCAN_SLEEP_MS);
+
+      List<IteratorSetting> compactIterators = new ArrayList<>();
+      compactIterators.add(slow);
+
+      log.trace("Slow iterator {}", slow);
 
-    for (SlowOps t : tables) {
       try {
-        connector.tableOperations().cancelCompaction(t.getTableName());
-        // block if compaction still running
-        boolean cancelled = t.blockWhileCompactionRunning();
-        if (!cancelled) {
-          log.info("Failed to cancel compaction during multiple compaction test clean-up for {}",
-              t.getTableName());
+
+        log.trace("Start compaction");
+
+        accumuloClient.tableOperations().compact(tableName, new Text("0"), new Text("z"),
+            compactIterators, true, true);
+
+        log.trace("Compaction wait is complete");
+
+        log.trace("Slow compaction of {} rows took {} ms", NUM_ROWS, TimeUnit.MILLISECONDS
+            .convert((System.nanoTime() - startTimestamp), TimeUnit.NANOSECONDS));
+
+        // validate that number of rows matches expected.
+
+        startTimestamp = System.nanoTime();
+
+        // validate expected data created and exists in table.
+
+        int count = scanCount(tableName);
+
+        log.trace("After compaction, scan time for {} rows {} ms", NUM_ROWS, TimeUnit.MILLISECONDS
+            .convert((System.nanoTime() - startTimestamp), TimeUnit.NANOSECONDS));
+
+        if (count != NUM_ROWS) {
+          throw new IllegalStateException(
+              String.format("After compaction, number of rows %1$d does not match expected %2$d",
+                  count, NUM_ROWS));
+        }
+      } catch (TableNotFoundException ex) {
+        throw new IllegalStateException("test failed, table " + tableName + " does not exist", ex);
+      } catch (AccumuloSecurityException ex) {
+        throw new IllegalStateException(
+            "test failed, could not add iterator due to security exception", ex);
+      } catch (AccumuloException ex) {
+        // test cancels compaction on complete, so ignore it as an exception.
+        if (!ex.getMessage().contains("Compaction canceled")) {
+          throw new IllegalStateException("test failed with an Accumulo exception", ex);
         }
-      } catch (AccumuloSecurityException | TableNotFoundException | AccumuloException ex) {
-        log.debug("Exception throw during multiple table test clean-up", ex);
       }
     }
   }
