@@ -34,22 +34,21 @@ import java.util.Map.Entry;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.cluster.ClusterUser;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.BatchScanner;
 import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.BatchWriterConfig;
-import org.apache.accumulo.core.client.Connector;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.client.TableExistsException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.CompactionConfig;
 import org.apache.accumulo.core.client.admin.DelegationTokenConfig;
-import org.apache.accumulo.core.client.impl.AuthenticationTokenIdentifier;
-import org.apache.accumulo.core.client.impl.DelegationTokenImpl;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
+import org.apache.accumulo.core.clientImpl.AuthenticationTokenIdentifier;
+import org.apache.accumulo.core.clientImpl.DelegationTokenImpl;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
@@ -66,8 +65,8 @@ import org.apache.accumulo.harness.MiniClusterConfigurationCallback;
 import org.apache.accumulo.harness.MiniClusterHarness;
 import org.apache.accumulo.harness.TestingKdc;
 import org.apache.accumulo.minicluster.ServerType;
-import org.apache.accumulo.minicluster.impl.MiniAccumuloClusterImpl;
-import org.apache.accumulo.minicluster.impl.MiniAccumuloConfigImpl;
+import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl;
+import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.test.categories.MiniClusterOnlyTests;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.CommonConfigurationKeysPublic;
@@ -85,6 +84,8 @@ import org.slf4j.LoggerFactory;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Sets;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 /**
  * MAC test which uses {@link MiniKdc} to simulate ta secure environment. Can be used as a sanity
  * check for Kerberos/SASL testing.
@@ -102,18 +103,18 @@ public class KerberosIT extends AccumuloITBase {
     kdc = new TestingKdc();
     kdc.start();
     krbEnabledForITs = System.getProperty(MiniClusterHarness.USE_KERBEROS_FOR_IT_OPTION);
-    if (null == krbEnabledForITs || !Boolean.parseBoolean(krbEnabledForITs)) {
+    if (krbEnabledForITs == null || !Boolean.parseBoolean(krbEnabledForITs)) {
       System.setProperty(MiniClusterHarness.USE_KERBEROS_FOR_IT_OPTION, "true");
     }
     rootUser = kdc.getRootUser();
   }
 
   @AfterClass
-  public static void stopKdc() throws Exception {
-    if (null != kdc) {
+  public static void stopKdc() {
+    if (kdc != null) {
       kdc.stop();
     }
-    if (null != krbEnabledForITs) {
+    if (krbEnabledForITs != null) {
       System.setProperty(MiniClusterHarness.USE_KERBEROS_FOR_IT_OPTION, krbEnabledForITs);
     }
     UserGroupInformation.setConfiguration(new Configuration(false));
@@ -151,7 +152,7 @@ public class KerberosIT extends AccumuloITBase {
 
   @After
   public void stopMac() throws Exception {
-    if (null != mac) {
+    if (mac != null) {
       mac.stop();
     }
   }
@@ -161,27 +162,26 @@ public class KerberosIT extends AccumuloITBase {
     // Login as the client (provided to `accumulo init` as the "root" user)
     UserGroupInformation ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(
         rootUser.getPrincipal(), rootUser.getKeytab().getAbsolutePath());
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        final Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      final AccumuloClient client =
+          mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
 
-        // The "root" user should have all system permissions
-        for (SystemPermission perm : SystemPermission.values()) {
-          assertTrue("Expected user to have permission: " + perm,
-              conn.securityOperations().hasSystemPermission(conn.whoami(), perm));
-        }
-
-        // and the ability to modify the root and metadata tables
-        for (String table : Arrays.asList(RootTable.NAME, MetadataTable.NAME)) {
-          assertTrue(conn.securityOperations().hasTablePermission(conn.whoami(), table,
-              TablePermission.ALTER_TABLE));
-        }
-        return null;
+      // The "root" user should have all system permissions
+      for (SystemPermission perm : SystemPermission.values()) {
+        assertTrue("Expected user to have permission: " + perm,
+            client.securityOperations().hasSystemPermission(client.whoami(), perm));
       }
+
+      // and the ability to modify the root and metadata tables
+      for (String table : Arrays.asList(RootTable.NAME, MetadataTable.NAME)) {
+        assertTrue(client.securityOperations().hasTablePermission(client.whoami(), table,
+            TablePermission.ALTER_TABLE));
+      }
+      return null;
     });
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "path provided by test")
   @Test
   public void testNewUser() throws Exception {
     String newUser = testName.getMethodName();
@@ -201,47 +201,42 @@ public class KerberosIT extends AccumuloITBase {
         rootUser.getPrincipal(), rootUser.getKeytab().getAbsolutePath());
     log.info("Logged in as {}", rootUser.getPrincipal());
 
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-        log.info("Created connector as {}", rootUser.getPrincipal());
-        assertEquals(rootUser.getPrincipal(), conn.whoami());
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client =
+          mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+      log.info("Created client as {}", rootUser.getPrincipal());
+      assertEquals(rootUser.getPrincipal(), client.whoami());
 
-        // Make sure the system user doesn't exist -- this will force some RPC to happen server-side
-        createTableWithDataAndCompact(conn);
+      // Make sure the system user doesn't exist -- this will force some RPC to happen server-side
+      createTableWithDataAndCompact(client);
 
-        assertEquals(users, conn.securityOperations().listLocalUsers());
+      assertEquals(users, client.securityOperations().listLocalUsers());
 
-        return null;
-      }
+      return null;
     });
     // Switch to a new user
     ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(newQualifiedUser,
         newUserKeytab.getAbsolutePath());
     log.info("Logged in as {}", newQualifiedUser);
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(newQualifiedUser, new KerberosToken());
-        log.info("Created connector as {}", newQualifiedUser);
-        assertEquals(newQualifiedUser, conn.whoami());
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client = mac.createAccumuloClient(newQualifiedUser, new KerberosToken());
+      log.info("Created client as {}", newQualifiedUser);
+      assertEquals(newQualifiedUser, client.whoami());
 
-        // The new user should have no system permissions
-        for (SystemPermission perm : SystemPermission.values()) {
-          assertFalse(conn.securityOperations().hasSystemPermission(newQualifiedUser, perm));
-        }
-
-        users.add(newQualifiedUser);
-
-        // Same users as before, plus the new user we just created
-        assertEquals(users, conn.securityOperations().listLocalUsers());
-        return null;
+      // The new user should have no system permissions
+      for (SystemPermission perm : SystemPermission.values()) {
+        assertFalse(client.securityOperations().hasSystemPermission(newQualifiedUser, perm));
       }
 
+      users.add(newQualifiedUser);
+
+      // Same users as before, plus the new user we just created
+      assertEquals(users, client.securityOperations().listLocalUsers());
+      return null;
     });
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "path provided by test")
   @Test
   public void testUserPrivilegesThroughGrant() throws Exception {
     String user1 = testName.getMethodName();
@@ -259,59 +254,52 @@ public class KerberosIT extends AccumuloITBase {
     UserGroupInformation ugi =
         UserGroupInformation.loginUserFromKeytabAndReturnUGI(user1, user1Keytab.getAbsolutePath());
     log.info("Logged in as {}", user1);
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        // Indirectly creates this user when we use it
-        Connector conn = mac.getConnector(qualifiedUser1, new KerberosToken());
-        log.info("Created connector as {}", qualifiedUser1);
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      // Indirectly creates this user when we use it
+      AccumuloClient client = mac.createAccumuloClient(qualifiedUser1, new KerberosToken());
+      log.info("Created client as {}", qualifiedUser1);
 
-        // The new user should have no system permissions
-        for (SystemPermission perm : SystemPermission.values()) {
-          assertFalse(conn.securityOperations().hasSystemPermission(qualifiedUser1, perm));
-        }
-
-        return null;
+      // The new user should have no system permissions
+      for (SystemPermission perm : SystemPermission.values()) {
+        assertFalse(client.securityOperations().hasSystemPermission(qualifiedUser1, perm));
       }
+
+      return null;
     });
 
     ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(rootUser.getPrincipal(),
         rootUser.getKeytab().getAbsolutePath());
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-        conn.securityOperations().grantSystemPermission(qualifiedUser1,
-            SystemPermission.CREATE_TABLE);
-        return null;
-      }
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client =
+          mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+      client.securityOperations().grantSystemPermission(qualifiedUser1,
+          SystemPermission.CREATE_TABLE);
+      return null;
     });
 
     // Switch back to the original user
     ugi =
         UserGroupInformation.loginUserFromKeytabAndReturnUGI(user1, user1Keytab.getAbsolutePath());
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(qualifiedUser1, new KerberosToken());
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client = mac.createAccumuloClient(qualifiedUser1, new KerberosToken());
 
-        // Shouldn't throw an exception since we granted the create table permission
-        final String table = testName.getMethodName() + "_user_table";
-        conn.tableOperations().create(table);
+      // Shouldn't throw an exception since we granted the create table permission
+      final String table = testName.getMethodName() + "_user_table";
+      client.tableOperations().create(table);
 
-        // Make sure we can actually use the table we made
-        BatchWriter bw = conn.createBatchWriter(table, new BatchWriterConfig());
+      // Make sure we can actually use the table we made
+      try (BatchWriter bw = client.createBatchWriter(table)) {
         Mutation m = new Mutation("a");
         m.put("b", "c", "d");
         bw.addMutation(m);
-        bw.close();
-
-        conn.tableOperations().compact(table, new CompactionConfig().setWait(true).setFlush(true));
-        return null;
       }
+
+      client.tableOperations().compact(table, new CompactionConfig().setWait(true).setFlush(true));
+      return null;
     });
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "path provided by test")
   @Test
   public void testUserPrivilegesForTable() throws Exception {
     String user1 = testName.getMethodName();
@@ -329,20 +317,16 @@ public class KerberosIT extends AccumuloITBase {
     UserGroupInformation ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(qualifiedUser1,
         user1Keytab.getAbsolutePath());
     log.info("Logged in as {}", user1);
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        // Indirectly creates this user when we use it
-        Connector conn = mac.getConnector(qualifiedUser1, new KerberosToken());
-        log.info("Created connector as {}", qualifiedUser1);
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      // Indirectly creates this user when we use it
+      AccumuloClient client = mac.createAccumuloClient(qualifiedUser1, new KerberosToken());
+      log.info("Created client as {}", qualifiedUser1);
 
-        // The new user should have no system permissions
-        for (SystemPermission perm : SystemPermission.values()) {
-          assertFalse(conn.securityOperations().hasSystemPermission(qualifiedUser1, perm));
-        }
-        return null;
+      // The new user should have no system permissions
+      for (SystemPermission perm : SystemPermission.values()) {
+        assertFalse(client.securityOperations().hasSystemPermission(qualifiedUser1, perm));
       }
-
+      return null;
     });
 
     final String table = testName.getMethodName() + "_user_table";
@@ -351,50 +335,46 @@ public class KerberosIT extends AccumuloITBase {
     ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(rootUser.getPrincipal(),
         rootUser.getKeytab().getAbsolutePath());
 
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-        conn.tableOperations().create(table);
-        // Give our unprivileged user permission on the table we made for them
-        conn.securityOperations().grantTablePermission(qualifiedUser1, table, TablePermission.READ);
-        conn.securityOperations().grantTablePermission(qualifiedUser1, table,
-            TablePermission.WRITE);
-        conn.securityOperations().grantTablePermission(qualifiedUser1, table,
-            TablePermission.ALTER_TABLE);
-        conn.securityOperations().grantTablePermission(qualifiedUser1, table,
-            TablePermission.DROP_TABLE);
-        conn.securityOperations().changeUserAuthorizations(qualifiedUser1, new Authorizations(viz));
-        return null;
-      }
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client =
+          mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+      client.tableOperations().create(table);
+      // Give our unprivileged user permission on the table we made for them
+      client.securityOperations().grantTablePermission(qualifiedUser1, table, TablePermission.READ);
+      client.securityOperations().grantTablePermission(qualifiedUser1, table,
+          TablePermission.WRITE);
+      client.securityOperations().grantTablePermission(qualifiedUser1, table,
+          TablePermission.ALTER_TABLE);
+      client.securityOperations().grantTablePermission(qualifiedUser1, table,
+          TablePermission.DROP_TABLE);
+      client.securityOperations().changeUserAuthorizations(qualifiedUser1, new Authorizations(viz));
+      return null;
     });
 
     // Switch back to the original user
     ugi = UserGroupInformation.loginUserFromKeytabAndReturnUGI(qualifiedUser1,
         user1Keytab.getAbsolutePath());
-    ugi.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(qualifiedUser1, new KerberosToken());
+    ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client = mac.createAccumuloClient(qualifiedUser1, new KerberosToken());
 
-        // Make sure we can actually use the table we made
+      // Make sure we can actually use the table we made
 
-        // Write data
-        final long ts = 1000l;
-        BatchWriter bw = conn.createBatchWriter(table, new BatchWriterConfig());
+      // Write data
+      final long ts = 1000L;
+      try (BatchWriter bw = client.createBatchWriter(table)) {
         Mutation m = new Mutation("a");
         m.put("b", "c", new ColumnVisibility(viz.getBytes()), ts, "d");
         bw.addMutation(m);
-        bw.close();
+      }
 
-        // Compact
-        conn.tableOperations().compact(table, new CompactionConfig().setWait(true).setFlush(true));
+      // Compact
+      client.tableOperations().compact(table, new CompactionConfig().setWait(true).setFlush(true));
 
-        // Alter
-        conn.tableOperations().setProperty(table, Property.TABLE_BLOOM_ENABLED.getKey(), "true");
+      // Alter
+      client.tableOperations().setProperty(table, Property.TABLE_BLOOM_ENABLED.getKey(), "true");
 
-        // Read (and proper authorizations)
-        Scanner s = conn.createScanner(table, new Authorizations(viz));
+      // Read (and proper authorizations)
+      try (Scanner s = client.createScanner(table, new Authorizations(viz))) {
         Iterator<Entry<Key,Value>> iter = s.iterator();
         assertTrue("No results from iterator", iter.hasNext());
         Entry<Key,Value> entry = iter.next();
@@ -419,15 +399,14 @@ public class KerberosIT extends AccumuloITBase {
 
     // As the "root" user, open up the connection and get a delegation token
     final AuthenticationToken delegationToken =
-        root.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-          @Override
-          public AuthenticationToken run() throws Exception {
-            Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-            log.info("Created connector as {}", rootUser.getPrincipal());
-            assertEquals(rootUser.getPrincipal(), conn.whoami());
+        root.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+          AccumuloClient client =
+              mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+          log.info("Created client as {}", rootUser.getPrincipal());
+          assertEquals(rootUser.getPrincipal(), client.whoami());
 
-            conn.tableOperations().create(tableName);
-            BatchWriter bw = conn.createBatchWriter(tableName, new BatchWriterConfig());
+          client.tableOperations().create(tableName);
+          try (BatchWriter bw = client.createBatchWriter(tableName)) {
             for (int r = 0; r < numRows; r++) {
               Mutation m = new Mutation(Integer.toString(r));
               for (int c = 0; c < numColumns; c++) {
@@ -436,26 +415,21 @@ public class KerberosIT extends AccumuloITBase {
               }
               bw.addMutation(m);
             }
-            bw.close();
-
-            return conn.securityOperations().getDelegationToken(new DelegationTokenConfig());
           }
+
+          return client.securityOperations().getDelegationToken(new DelegationTokenConfig());
         });
 
     // The above login with keytab doesn't have a way to logout, so make a fake user that won't have
     // krb credentials
     UserGroupInformation userWithoutPrivs =
         UserGroupInformation.createUserForTesting("fake_user", new String[0]);
-    int recordsSeen = userWithoutPrivs.doAs(new PrivilegedExceptionAction<Integer>() {
-      @Override
-      public Integer run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), delegationToken);
+    int recordsSeen = userWithoutPrivs.doAs((PrivilegedExceptionAction<Integer>) () -> {
+      AccumuloClient client = mac.createAccumuloClient(rootUser.getPrincipal(), delegationToken);
 
-        BatchScanner bs = conn.createBatchScanner(tableName, Authorizations.EMPTY, 2);
+      try (BatchScanner bs = client.createBatchScanner(tableName)) {
         bs.setRanges(Collections.singleton(new Range()));
-        int recordsSeen = Iterables.size(bs);
-        bs.close();
-        return recordsSeen;
+        return Iterables.size(bs);
       }
     });
 
@@ -471,15 +445,13 @@ public class KerberosIT extends AccumuloITBase {
 
     final AuthenticationToken delegationToken;
     try {
-      delegationToken = ugi.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-        @Override
-        public AuthenticationToken run() throws Exception {
-          // As the "root" user, open up the connection and get a delegation token
-          Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-          log.info("Created connector as {}", rootUser.getPrincipal());
-          assertEquals(rootUser.getPrincipal(), conn.whoami());
-          return conn.securityOperations().getDelegationToken(new DelegationTokenConfig());
-        }
+      delegationToken = ugi.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+        // As the "root" user, open up the connection and get a delegation token
+        AccumuloClient client =
+            mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+        log.info("Created client as {}", rootUser.getPrincipal());
+        assertEquals(rootUser.getPrincipal(), client.whoami());
+        return client.securityOperations().getDelegationToken(new DelegationTokenConfig());
       });
     } catch (UndeclaredThrowableException ex) {
       throw ex;
@@ -490,12 +462,10 @@ public class KerberosIT extends AccumuloITBase {
         UserGroupInformation.createUserForTesting("fake_user", new String[0]);
     try {
       // Use the delegation token to try to log in as a different user
-      userWithoutPrivs.doAs(new PrivilegedExceptionAction<Void>() {
-        @Override
-        public Void run() throws Exception {
-          mac.getConnector("some_other_user", delegationToken);
-          return null;
-        }
+      userWithoutPrivs.doAs((PrivilegedExceptionAction<Void>) () -> {
+        AccumuloClient client = mac.createAccumuloClient("some_other_user", delegationToken);
+        client.securityOperations().authenticateUser("some_other_user", delegationToken);
+        return null;
       });
       fail("Using a delegation token as a different user should throw an exception");
     } catch (UndeclaredThrowableException e) {
@@ -508,6 +478,7 @@ public class KerberosIT extends AccumuloITBase {
     }
   }
 
+  @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "path provided by test")
   @Test
   public void testGetDelegationTokenDenied() throws Exception {
     String newUser = testName.getMethodName();
@@ -525,17 +496,14 @@ public class KerberosIT extends AccumuloITBase {
     UserGroupInformation ugi = UserGroupInformation
         .loginUserFromKeytabAndReturnUGI(qualifiedNewUser, newUserKeytab.getAbsolutePath());
     try {
-      ugi.doAs(new PrivilegedExceptionAction<Void>() {
-        @Override
-        public Void run() throws Exception {
-          // As the "root" user, open up the connection and get a delegation token
-          Connector conn = mac.getConnector(qualifiedNewUser, new KerberosToken());
-          log.info("Created connector as {}", qualifiedNewUser);
-          assertEquals(qualifiedNewUser, conn.whoami());
+      ugi.doAs((PrivilegedExceptionAction<Void>) () -> {
+        // As the "root" user, open up the connection and get a delegation token
+        AccumuloClient client = mac.createAccumuloClient(qualifiedNewUser, new KerberosToken());
+        log.info("Created client as {}", qualifiedNewUser);
+        assertEquals(qualifiedNewUser, client.whoami());
 
-          conn.securityOperations().getDelegationToken(new DelegationTokenConfig());
-          return null;
-        }
+        client.securityOperations().getDelegationToken(new DelegationTokenConfig());
+        return null;
       });
     } catch (UndeclaredThrowableException ex) {
       assertTrue(ex.getCause() instanceof AccumuloSecurityException);
@@ -551,22 +519,20 @@ public class KerberosIT extends AccumuloITBase {
 
     // As the "root" user, open up the connection and get a delegation token
     final AuthenticationToken delegationToken1 =
-        root.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-          @Override
-          public AuthenticationToken run() throws Exception {
-            Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-            log.info("Created connector as {}", rootUser.getPrincipal());
-            assertEquals(rootUser.getPrincipal(), conn.whoami());
+        root.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+          AccumuloClient client =
+              mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+          log.info("Created client as {}", rootUser.getPrincipal());
+          assertEquals(rootUser.getPrincipal(), client.whoami());
 
-            AuthenticationToken token =
-                conn.securityOperations().getDelegationToken(new DelegationTokenConfig());
+          AuthenticationToken token =
+              client.securityOperations().getDelegationToken(new DelegationTokenConfig());
 
-            assertTrue("Could not get tables with delegation token",
-                mac.getConnector(rootUser.getPrincipal(), token).tableOperations().list().size()
-                    > 0);
+          assertTrue("Could not get tables with delegation token",
+              mac.createAccumuloClient(rootUser.getPrincipal(), token).tableOperations().list()
+                  .size() > 0);
 
-            return token;
-          }
+          return token;
         });
 
     log.info("Stopping master");
@@ -576,36 +542,31 @@ public class KerberosIT extends AccumuloITBase {
     mac.getClusterControl().start(ServerType.MASTER);
 
     // Make sure our original token is still good
-    root.doAs(new PrivilegedExceptionAction<Void>() {
-      @Override
-      public Void run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), delegationToken1);
+    root.doAs((PrivilegedExceptionAction<Void>) () -> {
+      AccumuloClient client = mac.createAccumuloClient(rootUser.getPrincipal(), delegationToken1);
 
-        assertTrue("Could not get tables with delegation token",
-            conn.tableOperations().list().size() > 0);
+      assertTrue("Could not get tables with delegation token",
+          client.tableOperations().list().size() > 0);
 
-        return null;
-      }
+      return null;
     });
 
     // Get a new token, so we can compare the keyId on the second to the first
     final AuthenticationToken delegationToken2 =
-        root.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-          @Override
-          public AuthenticationToken run() throws Exception {
-            Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-            log.info("Created connector as {}", rootUser.getPrincipal());
-            assertEquals(rootUser.getPrincipal(), conn.whoami());
+        root.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+          AccumuloClient client =
+              mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+          log.info("Created client as {}", rootUser.getPrincipal());
+          assertEquals(rootUser.getPrincipal(), client.whoami());
 
-            AuthenticationToken token =
-                conn.securityOperations().getDelegationToken(new DelegationTokenConfig());
+          AuthenticationToken token =
+              client.securityOperations().getDelegationToken(new DelegationTokenConfig());
 
-            assertTrue("Could not get tables with delegation token",
-                mac.getConnector(rootUser.getPrincipal(), token).tableOperations().list().size()
-                    > 0);
+          assertTrue("Could not get tables with delegation token",
+              mac.createAccumuloClient(rootUser.getPrincipal(), token).tableOperations().list()
+                  .size() > 0);
 
-            return token;
-          }
+          return token;
         });
 
     // A restarted master should reuse the same secret key after a restart if the secret key hasn't
@@ -624,21 +585,19 @@ public class KerberosIT extends AccumuloITBase {
 
     // As the "root" user, open up the connection and get a delegation token
     try {
-      root.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-        @Override
-        public AuthenticationToken run() throws Exception {
-          Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-          log.info("Created connector as {}", rootUser.getPrincipal());
-          assertEquals(rootUser.getPrincipal(), conn.whoami());
+      root.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+        AccumuloClient client =
+            mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+        log.info("Created client as {}", rootUser.getPrincipal());
+        assertEquals(rootUser.getPrincipal(), client.whoami());
 
-          // Should fail
-          return conn.securityOperations().getDelegationToken(
-              new DelegationTokenConfig().setTokenLifetime(Long.MAX_VALUE, TimeUnit.MILLISECONDS));
-        }
+        // Should fail
+        return client.securityOperations().getDelegationToken(
+            new DelegationTokenConfig().setTokenLifetime(Long.MAX_VALUE, TimeUnit.MILLISECONDS));
       });
     } catch (UndeclaredThrowableException e) {
       Throwable cause = e.getCause();
-      if (null != cause) {
+      if (cause != null) {
         throw cause;
       } else {
         throw e;
@@ -654,17 +613,16 @@ public class KerberosIT extends AccumuloITBase {
     log.info("Logged in as {}", rootUser.getPrincipal());
 
     // As the "root" user, open up the connection and get a delegation token
-    final AuthenticationToken dt = root.doAs(new PrivilegedExceptionAction<AuthenticationToken>() {
-      @Override
-      public AuthenticationToken run() throws Exception {
-        Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
-        log.info("Created connector as {}", rootUser.getPrincipal());
-        assertEquals(rootUser.getPrincipal(), conn.whoami());
+    final AuthenticationToken dt =
+        root.doAs((PrivilegedExceptionAction<AuthenticationToken>) () -> {
+          AccumuloClient client =
+              mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
+          log.info("Created client as {}", rootUser.getPrincipal());
+          assertEquals(rootUser.getPrincipal(), client.whoami());
 
-        return conn.securityOperations()
-            .getDelegationToken(new DelegationTokenConfig().setTokenLifetime(5, TimeUnit.MINUTES));
-      }
-    });
+          return client.securityOperations().getDelegationToken(
+              new DelegationTokenConfig().setTokenLifetime(5, TimeUnit.MINUTES));
+        });
 
     AuthenticationTokenIdentifier identifier = ((DelegationTokenImpl) dt).getIdentifier();
     assertTrue("Expected identifier to expire in no more than 5 minutes: " + identifier,
@@ -677,12 +635,13 @@ public class KerberosIT extends AccumuloITBase {
     UserGroupInformation.loginUserFromKeytab(rootUser.getPrincipal(),
         rootUser.getKeytab().getAbsolutePath());
 
-    final Connector conn = mac.getConnector(rootUser.getPrincipal(), new KerberosToken());
+    final AccumuloClient client =
+        mac.createAccumuloClient(rootUser.getPrincipal(), new KerberosToken());
 
     // The server-side implementation should prevent the revocation of the 'root' user's systems
     // permissions
     // because once they're gone, it's possible that they could never be restored.
-    conn.securityOperations().revokeSystemPermission(rootUser.getPrincipal(),
+    client.securityOperations().revokeSystemPermission(rootUser.getPrincipal(),
         SystemPermission.GRANT);
   }
 
@@ -691,15 +650,15 @@ public class KerberosIT extends AccumuloITBase {
    * that the system user exists (since the master does an RPC to the tserver which will create the
    * system user if it doesn't already exist).
    */
-  private void createTableWithDataAndCompact(Connector conn) throws TableNotFoundException,
+  private void createTableWithDataAndCompact(AccumuloClient client) throws TableNotFoundException,
       AccumuloSecurityException, AccumuloException, TableExistsException {
     final String table = testName.getMethodName() + "_table";
-    conn.tableOperations().create(table);
-    BatchWriter bw = conn.createBatchWriter(table, new BatchWriterConfig());
-    Mutation m = new Mutation("a");
-    m.put("b", "c", "d");
-    bw.addMutation(m);
-    bw.close();
-    conn.tableOperations().compact(table, new CompactionConfig().setFlush(true).setWait(true));
+    client.tableOperations().create(table);
+    try (BatchWriter bw = client.createBatchWriter(table)) {
+      Mutation m = new Mutation("a");
+      m.put("b", "c", "d");
+      bw.addMutation(m);
+    }
+    client.tableOperations().compact(table, new CompactionConfig().setFlush(true).setWait(true));
   }
 }
