@@ -18,6 +18,7 @@ package org.apache.accumulo.test.performance.scan;
 
 import java.io.IOException;
 import java.net.InetAddress;
+import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -33,43 +34,45 @@ import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 
-import org.apache.accumulo.core.cli.ScannerOpts;
-import org.apache.accumulo.core.client.Connector;
-import org.apache.accumulo.core.client.Instance;
+import org.apache.accumulo.core.client.Accumulo;
+import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.Scanner;
-import org.apache.accumulo.core.client.impl.ClientContext;
-import org.apache.accumulo.core.client.impl.Credentials;
-import org.apache.accumulo.core.client.impl.Tables;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.Tables;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.conf.IterConfigUtil;
+import org.apache.accumulo.core.conf.IterLoad;
+import org.apache.accumulo.core.crypto.CryptoServiceFactory;
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.data.thrift.IterInfo;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.file.FileOperations;
 import org.apache.accumulo.core.file.FileSKVIterator;
-import org.apache.accumulo.core.iterators.IteratorUtil;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.SortedMapIterator;
 import org.apache.accumulo.core.iterators.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iterators.system.ColumnQualifierFilter;
 import org.apache.accumulo.core.iterators.system.DeletingIterator;
+import org.apache.accumulo.core.iterators.system.DeletingIterator.Behavior;
 import org.apache.accumulo.core.iterators.system.MultiIterator;
 import org.apache.accumulo.core.iterators.system.VisibilityFilter;
 import org.apache.accumulo.core.metadata.MetadataServicer;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.Stat;
-import org.apache.accumulo.server.cli.ClientOnRequiredTable;
+import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.cli.ServerUtilOpts;
 import org.apache.accumulo.server.conf.ServerConfigurationFactory;
 import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.FileRef;
 import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.fs.VolumeManagerImpl;
 import org.apache.accumulo.server.util.MetadataTableUtil;
 import org.apache.hadoop.fs.BlockLocation;
 import org.apache.hadoop.fs.FileStatus;
@@ -81,47 +84,47 @@ import org.slf4j.LoggerFactory;
 
 import com.beust.jcommander.Parameter;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 public class CollectTabletStats {
   private static final Logger log = LoggerFactory.getLogger(CollectTabletStats.class);
 
-  static class CollectOptions extends ClientOnRequiredTable {
+  static class CollectOptions extends ServerUtilOpts {
+    @Parameter(names = {"-t", "--table"}, required = true, description = "table to use")
+    String tableName;
     @Parameter(names = "--iterations", description = "number of iterations")
     int iterations = 3;
     @Parameter(names = "--numThreads", description = "number of threads")
     int numThreads = 1;
     @Parameter(names = "-f", description = "select far tablets, default is to use local tablets")
     boolean selectFarTablets = false;
-    @Parameter(names = "-c", description = "comma separated list of columns")
+    @Parameter(names = "--columns", description = "comma separated list of columns")
     String columns;
   }
 
   public static void main(String[] args) throws Exception {
 
     final CollectOptions opts = new CollectOptions();
-    final ScannerOpts scanOpts = new ScannerOpts();
-    opts.parseArgs(CollectTabletStats.class.getName(), args, scanOpts);
+    opts.parseArgs(CollectTabletStats.class.getName(), args);
 
-    String columnsTmp[] = new String[] {};
+    String[] columnsTmp = {};
     if (opts.columns != null)
       columnsTmp = opts.columns.split(",");
-    final String columns[] = columnsTmp;
+    final String[] columns = columnsTmp;
 
-    final VolumeManager fs = VolumeManagerImpl.get();
+    ServerContext context = opts.getServerContext();
+    final VolumeManager fs = context.getVolumeManager();
+    ServerConfigurationFactory sconf = context.getServerConfFactory();
 
-    Instance instance = opts.getInstance();
-    final ServerConfigurationFactory sconf = new ServerConfigurationFactory(instance);
-    Credentials creds = new Credentials(opts.getPrincipal(), opts.getToken());
-    ClientContext context = new ClientContext(instance, creds, sconf.getConfiguration());
-
-    String tableId = Tables.getNameToIdMap(instance).get(opts.getTableName());
+    TableId tableId = Tables.getTableId(context, opts.tableName);
     if (tableId == null) {
-      log.error("Unable to find table named " + opts.getTableName());
+      log.error("Unable to find table named {}", opts.tableName);
       System.exit(-1);
     }
 
     TreeMap<KeyExtent,String> tabletLocations = new TreeMap<>();
     List<KeyExtent> candidates =
-        findTablets(context, !opts.selectFarTablets, opts.getTableName(), tabletLocations);
+        findTablets(context, !opts.selectFarTablets, opts.tableName, tabletLocations);
 
     if (candidates.size() < opts.numThreads) {
       System.err.println("ERROR : Unable to find " + opts.numThreads + " "
@@ -134,7 +137,7 @@ public class CollectTabletStats {
     Map<KeyExtent,List<FileRef>> tabletFiles = new HashMap<>();
 
     for (KeyExtent ke : tabletsToTest) {
-      List<FileRef> files = getTabletFiles(context, tableId, ke);
+      List<FileRef> files = getTabletFiles(context, ke);
       tabletFiles.put(ke, files);
     }
 
@@ -142,14 +145,14 @@ public class CollectTabletStats {
     System.out.println("run location      : " + InetAddress.getLocalHost().getHostName() + "/"
         + InetAddress.getLocalHost().getHostAddress());
     System.out.println("num threads       : " + opts.numThreads);
-    System.out.println("table             : " + opts.getTableName());
+    System.out.println("table             : " + opts.tableName);
     System.out.println("table id          : " + tableId);
 
     for (KeyExtent ke : tabletsToTest) {
       System.out.println("\t *** Information about tablet " + ke.getUUID() + " *** ");
       System.out.println("\t\t# files in tablet : " + tabletFiles.get(ke).size());
       System.out.println("\t\ttablet location   : " + tabletLocations.get(ke));
-      reportHdfsBlockLocations(tabletFiles.get(ke));
+      reportHdfsBlockLocations(context, tabletFiles.get(ke));
     }
 
     System.out.println("%n*** RUNNING TEST ***%n");
@@ -165,7 +168,7 @@ public class CollectTabletStats {
         Test test = new Test(ke) {
           @Override
           public int runTest() throws Exception {
-            return readFiles(fs, sconf.getConfiguration(), files, ke, columns);
+            return readFiles(fs, sconf.getSystemConfiguration(), files, ke, columns);
           }
 
         };
@@ -213,47 +216,37 @@ public class CollectTabletStats {
       runTest("read tablet files w/ table iter stack", tests, opts.numThreads, threadPool);
     }
 
-    for (int i = 0; i < opts.iterations; i++) {
-
-      ArrayList<Test> tests = new ArrayList<>();
-
-      final Connector conn = opts.getConnector();
-
-      for (final KeyExtent ke : tabletsToTest) {
-        Test test = new Test(ke) {
-          @Override
-          public int runTest() throws Exception {
-            return scanTablet(conn, opts.getTableName(), opts.auths, scanOpts.scanBatchSize,
-                ke.getPrevEndRow(), ke.getEndRow(), columns);
-          }
-        };
-
-        tests.add(test);
+    try (AccumuloClient client = Accumulo.newClient().from(opts.getClientProps()).build()) {
+      for (int i = 0; i < opts.iterations; i++) {
+        ArrayList<Test> tests = new ArrayList<>();
+        for (final KeyExtent ke : tabletsToTest) {
+          Test test = new Test(ke) {
+            @Override
+            public int runTest() throws Exception {
+              return scanTablet(client, opts.tableName, opts.auths, ke.getPrevEndRow(),
+                  ke.getEndRow(), columns);
+            }
+          };
+          tests.add(test);
+        }
+        runTest("read tablet data through accumulo", tests, opts.numThreads, threadPool);
       }
 
-      runTest("read tablet data through accumulo", tests, opts.numThreads, threadPool);
-    }
-
-    for (final KeyExtent ke : tabletsToTest) {
-      final Connector conn = opts.getConnector();
-
-      threadPool.submit(new Runnable() {
-        @Override
-        public void run() {
+      for (final KeyExtent ke : tabletsToTest) {
+        threadPool.submit(() -> {
           try {
-            calcTabletStats(conn, opts.getTableName(), opts.auths, scanOpts.scanBatchSize, ke,
-                columns);
+            calcTabletStats(client, opts.tableName, opts.auths, ke, columns);
           } catch (Exception e) {
             log.error("Failed to calculate tablet stats.", e);
           }
-        }
-      });
+        });
+      }
     }
 
     threadPool.shutdown();
   }
 
-  private static abstract class Test implements Runnable {
+  private abstract static class Test implements Runnable {
 
     private int count;
     private long t1;
@@ -315,6 +308,7 @@ public class CollectTabletStats {
 
   }
 
+  @SuppressFBWarnings(value = "DM_GC", justification = "gc is okay for test")
   private static void runTest(String desc, List<Test> tests, int numThreads,
       ExecutorService threadPool) throws Exception {
 
@@ -358,7 +352,7 @@ public class CollectTabletStats {
   private static List<KeyExtent> findTablets(ClientContext context, boolean selectLocalTablets,
       String tableName, SortedMap<KeyExtent,String> tabletLocations) throws Exception {
 
-    String tableId = Tables.getNameToIdMap(context.getInstance()).get(tableName);
+    TableId tableId = Tables.getTableId(context, tableName);
     MetadataServicer.forTableId(context, tableId).getTabletLocations(tabletLocations);
 
     InetAddress localaddress = InetAddress.getLocalHost();
@@ -384,7 +378,7 @@ public class CollectTabletStats {
   private static List<KeyExtent> selectRandomTablets(int numThreads, List<KeyExtent> candidates) {
     List<KeyExtent> tabletsToTest = new ArrayList<>();
 
-    Random rand = new Random();
+    Random rand = new SecureRandom();
     for (int i = 0; i < numThreads; i++) {
       int rindex = rand.nextInt(candidates.size());
       tabletsToTest.add(candidates.get(rindex));
@@ -394,13 +388,13 @@ public class CollectTabletStats {
     return tabletsToTest;
   }
 
-  private static List<FileRef> getTabletFiles(ClientContext context, String tableId, KeyExtent ke)
-      throws IOException {
+  private static List<FileRef> getTabletFiles(ServerContext context, KeyExtent ke) {
     return new ArrayList<>(MetadataTableUtil.getDataFileSizes(ke, context).keySet());
   }
 
-  private static void reportHdfsBlockLocations(List<FileRef> files) throws Exception {
-    VolumeManager fs = VolumeManagerImpl.get();
+  private static void reportHdfsBlockLocations(ServerContext context, List<FileRef> files)
+      throws Exception {
+    VolumeManager fs = context.getVolumeManager();
 
     System.out.println("\t\tFile block report : ");
     for (FileRef file : files) {
@@ -434,7 +428,7 @@ public class CollectTabletStats {
       Map<String,Map<String,String>> ssio, boolean useTableIterators, TableConfiguration conf)
       throws IOException {
 
-    SortedMapIterator smi = new SortedMapIterator(new TreeMap<Key,Value>());
+    SortedMapIterator smi = new SortedMapIterator(new TreeMap<>());
 
     List<SortedKeyValueIterator<Key,Value>> iters = new ArrayList<>(mapfiles.size() + 1);
 
@@ -442,15 +436,17 @@ public class CollectTabletStats {
     iters.add(smi);
 
     MultiIterator multiIter = new MultiIterator(iters, ke);
-    DeletingIterator delIter = new DeletingIterator(multiIter, false);
+    SortedKeyValueIterator<Key,Value> delIter =
+        DeletingIterator.wrap(multiIter, false, Behavior.PROCESS);
     ColumnFamilySkippingIterator cfsi = new ColumnFamilySkippingIterator(delIter);
     SortedKeyValueIterator<Key,Value> colFilter = ColumnQualifierFilter.wrap(cfsi, columnSet);
     SortedKeyValueIterator<Key,Value> visFilter =
         VisibilityFilter.wrap(colFilter, authorizations, defaultLabels);
 
-    if (useTableIterators)
-      return IteratorUtil.loadIterators(IteratorScope.scan, visFilter, ke, conf, ssiList, ssio,
-          null);
+    if (useTableIterators) {
+      IterLoad il = IterConfigUtil.loadIterConf(IteratorScope.scan, ssiList, ssio, conf);
+      return IterConfigUtil.loadIterators(visFilter, il.useAccumuloClassLoader(true));
+    }
     return visFilter;
   }
 
@@ -464,9 +460,11 @@ public class CollectTabletStats {
     for (FileRef file : files) {
       FileSystem ns = fs.getVolumeByPath(file.path()).getFileSystem();
       FileSKVIterator reader = FileOperations.getInstance().newReaderBuilder()
-          .forFile(file.path().toString(), ns, ns.getConf()).withTableConfiguration(aconf).build();
+          .forFile(file.path().toString(), ns, ns.getConf(),
+              CryptoServiceFactory.newDefaultInstance())
+          .withTableConfiguration(aconf).build();
       Range range = new Range(ke.getPrevEndRow(), false, ke.getEndRow(), true);
-      reader.seek(range, columnSet, columnSet.size() == 0 ? false : true);
+      reader.seek(range, columnSet, columnSet.size() != 0);
       while (reader.hasTop() && !range.afterEndKey(reader.getTopKey())) {
         count++;
         reader.next();
@@ -496,20 +494,21 @@ public class CollectTabletStats {
     for (FileRef file : files) {
       FileSystem ns = fs.getVolumeByPath(file.path()).getFileSystem();
       readers.add(FileOperations.getInstance().newReaderBuilder()
-          .forFile(file.path().toString(), ns, ns.getConf())
-          .withTableConfiguration(aconf.getConfiguration()).build());
+          .forFile(file.path().toString(), ns, ns.getConf(),
+              CryptoServiceFactory.newDefaultInstance())
+          .withTableConfiguration(aconf.getSystemConfiguration()).build());
     }
 
     List<IterInfo> emptyIterinfo = Collections.emptyList();
     Map<String,Map<String,String>> emptySsio = Collections.emptyMap();
     TableConfiguration tconf = aconf.getTableConfiguration(ke.getTableId());
-    reader = createScanIterator(ke, readers, auths, new byte[] {}, new HashSet<Column>(),
-        emptyIterinfo, emptySsio, useTableIterators, tconf);
+    reader = createScanIterator(ke, readers, auths, new byte[] {}, new HashSet<>(), emptyIterinfo,
+        emptySsio, useTableIterators, tconf);
 
     HashSet<ByteSequence> columnSet = createColumnBSS(columns);
 
     reader.seek(new Range(ke.getPrevEndRow(), false, ke.getEndRow(), true), columnSet,
-        columnSet.size() == 0 ? false : true);
+        columnSet.size() != 0);
 
     int count = 0;
 
@@ -522,92 +521,89 @@ public class CollectTabletStats {
 
   }
 
-  private static int scanTablet(Connector conn, String table, Authorizations auths, int batchSize,
+  private static int scanTablet(AccumuloClient client, String table, Authorizations auths,
       Text prevEndRow, Text endRow, String[] columns) throws Exception {
 
-    Scanner scanner = conn.createScanner(table, auths);
-    scanner.setBatchSize(batchSize);
-    scanner.setRange(new Range(prevEndRow, false, endRow, true));
+    try (Scanner scanner = client.createScanner(table, auths)) {
+      scanner.setRange(new Range(prevEndRow, false, endRow, true));
 
-    for (String c : columns) {
-      scanner.fetchColumnFamily(new Text(c));
+      for (String c : columns) {
+        scanner.fetchColumnFamily(new Text(c));
+      }
+
+      int count = 0;
+
+      for (Entry<Key,Value> entry : scanner) {
+        if (entry != null)
+          count++;
+      }
+      return count;
     }
-
-    int count = 0;
-
-    for (Entry<Key,Value> entry : scanner) {
-      if (entry != null)
-        count++;
-    }
-
-    return count;
   }
 
-  private static void calcTabletStats(Connector conn, String table, Authorizations auths,
-      int batchSize, KeyExtent ke, String[] columns) throws Exception {
+  private static void calcTabletStats(AccumuloClient client, String table, Authorizations auths,
+      KeyExtent ke, String[] columns) throws Exception {
 
     // long t1 = System.currentTimeMillis();
 
-    Scanner scanner = conn.createScanner(table, auths);
-    scanner.setBatchSize(batchSize);
-    scanner.setRange(new Range(ke.getPrevEndRow(), false, ke.getEndRow(), true));
+    try (Scanner scanner = client.createScanner(table, auths)) {
+      scanner.setRange(new Range(ke.getPrevEndRow(), false, ke.getEndRow(), true));
 
-    for (String c : columns) {
-      scanner.fetchColumnFamily(new Text(c));
-    }
-
-    Stat rowLen = new Stat();
-    Stat cfLen = new Stat();
-    Stat cqLen = new Stat();
-    Stat cvLen = new Stat();
-    Stat valLen = new Stat();
-    Stat colsPerRow = new Stat();
-
-    Text lastRow = null;
-    int colsPerRowCount = 0;
-
-    for (Entry<Key,Value> entry : scanner) {
-
-      Key key = entry.getKey();
-      Text row = key.getRow();
-
-      if (lastRow == null) {
-        lastRow = row;
+      for (String c : columns) {
+        scanner.fetchColumnFamily(new Text(c));
       }
 
-      if (!lastRow.equals(row)) {
-        colsPerRow.addStat(colsPerRowCount);
-        lastRow = row;
-        colsPerRowCount = 0;
+      Stat rowLen = new Stat();
+      Stat cfLen = new Stat();
+      Stat cqLen = new Stat();
+      Stat cvLen = new Stat();
+      Stat valLen = new Stat();
+      Stat colsPerRow = new Stat();
+
+      Text lastRow = null;
+      int colsPerRowCount = 0;
+
+      for (Entry<Key,Value> entry : scanner) {
+
+        Key key = entry.getKey();
+        Text row = key.getRow();
+
+        if (lastRow == null) {
+          lastRow = row;
+        }
+
+        if (!lastRow.equals(row)) {
+          colsPerRow.addStat(colsPerRowCount);
+          lastRow = row;
+          colsPerRowCount = 0;
+        }
+
+        colsPerRowCount++;
+
+        rowLen.addStat(row.getLength());
+        cfLen.addStat(key.getColumnFamilyData().length());
+        cqLen.addStat(key.getColumnQualifierData().length());
+        cvLen.addStat(key.getColumnVisibilityData().length());
+        valLen.addStat(entry.getValue().get().length);
       }
 
-      colsPerRowCount++;
-
-      rowLen.addStat(row.getLength());
-      cfLen.addStat(key.getColumnFamilyData().length());
-      cqLen.addStat(key.getColumnQualifierData().length());
-      cvLen.addStat(key.getColumnVisibilityData().length());
-      valLen.addStat(entry.getValue().get().length);
+      synchronized (System.out) {
+        System.out.println("");
+        System.out.println("\tTablet " + ke.getUUID() + " statistics : ");
+        printStat("Row length", rowLen);
+        printStat("Column family length", cfLen);
+        printStat("Column qualifier length", cqLen);
+        printStat("Column visibility length", cvLen);
+        printStat("Value length", valLen);
+        printStat("Columns per row", colsPerRow);
+        System.out.println("");
+      }
     }
-
-    synchronized (System.out) {
-      System.out.println("");
-      System.out.println("\tTablet " + ke.getUUID() + " statistics : ");
-      printStat("Row length", rowLen);
-      printStat("Column family length", cfLen);
-      printStat("Column qualifier length", cqLen);
-      printStat("Column visibility length", cvLen);
-      printStat("Value length", valLen);
-      printStat("Columns per row", colsPerRow);
-      System.out.println("");
-    }
-
   }
 
   private static void printStat(String desc, Stat s) {
-    System.out.printf(
-        "\t\tDescription: [%30s]  average: %,6.2f  std dev: %,6.2f  min: %,d  max: %,d %n", desc,
-        s.getAverage(), s.getStdDev(), s.getMin(), s.getMax());
+    System.out.printf("\t\tDescription: [%30s]  average: %,6.2f min: %,d  max: %,d %n", desc,
+        s.mean(), s.min(), s.max());
 
   }
 
